(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    685541,      26732]*)
(*NotebookOutlinePosition[    714498,      27797]*)
(*  CellTagsIndexPosition[    714454,      27793]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Example # 5 : Simple Dipole Magnet ",
  FontSize->24]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Version : 0.4", "Text",
  PageWidth->PaperWidth,
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"This example concerns the geometries dominated by iron. At any point in \
space one can consider that the magnetic field is the sum of two  \
contributions. One comes from the real sources of magnetic field such as \
coils or permanent magnets. The other comes from the iron  through its \
magnetization. Even though the magnetization of the iron is induced by  the \
coils or permanent magnets, its field contribution to the point of interest \
can be much larger than the direct contribution form coils and magnets. We \
call these geometries  : \[OpenCurlyDoubleQuote]Iron Dominated \",  \
electro-magnet dipole and quadrupole used in particle accelerators fall into \
this category. Most of undulators and wigglers used as synchrotron radiation \
sources do not fall into this category. The field computation with Radia in \
the case of Iron Dominated geometries presents a few specific difficulties \
and is usually less accurate than in the case of coil or permanent magnet \
dominated structure. Nevertheless, special methods have been developed to  \
reach a reasonable precision within a reasonable cpu time and memory. The \
example below is that of a simple dipole steerer made of a closed circuit of \
iron with a small gap and a coil wounded around the circuit that drives some \
flux in the iron (see the graphics below). This example is more delicate than \
all  previous examples and we advise the beginner to first get experienced \
with them before diving into this one. \nAmong the most important things to \
remember if one wants to  reach a good precision in a reasonable time are :\n\
- Always segment the corners of the iron circuits as parallel or \
perpendicular to the flux line as possible. For right angle corners, this can \
be done with the circular or ellipsoidal mode of segmentation (see below). \
This is extremely important. In this example, we make use of the circular \
segmentation twice (the other two corners are segmented similarly by \
symmetry) it is made in the section entitled  \"Defining the Model\" when \
calling  \"radObjDivMag[g3,{nbr,nbp,n3[[1]]},typ]\" and  \
\"radObjDivMag[g5,{nbr,nbp,n5[[1]]},typ]\". \n- Use a narrower segmentation \
on the iron faces close to the region of interest .\n- Start with low \
segmentation numbers and increase them gradually to check that the field is \
stable. Beware that the memory and cpu time tends to grow like the square \
number of elements. \n- Use symmetries as much as possible. It saves both \
memory and CPU time. The steerer dipole shown below has a symmetry of order 2 \
x 2.  16 times more memory and 4 times more cpu time would have been needed \
without using the symmetries. \nAs for the previous examples, try to modify \
some parameters (see the Reference Guide for the explanations on all Radia \
functions) and re-execute the corresponding section. All sections must be \
evaluated in the order of presentation. A section may be evaluated several \
times with the same or different parameters if the previous sections have \
been evaluated before. The only limitation is memory. The Radia.exe memory \
can be re-initialized by re-executing the section entitled \
\[OpenCurlyDoubleQuote]Load and Initialize Radia\[CloseCurlyDoubleQuote]. The \
Kernel memory can be re-initialized by executing Exit[] and then re-executing \
all sections of this example. If the Front-End is running out of memory, \
close some windows or close the Front-End and start it again. Note that if by \
mistake any section is executed before the previous ones are executed, it may \
be necessary to exit the Kernel and re-start everything from the very \
beginning. The maximum precision requires large memory and long cpu time and \
ultimately, you may want to add extra memory to your computer. However \
remember that the memory required tends to be proportional to the square \
number of sub-elements and increasing the segmentation by 2 in all three \
directions results in 8 times more sub-elements and 64 times more memory. \
Consequently, one should increase the segmentation number in some \
\[OpenCurlyDoubleQuote]intelligent\[CloseCurlyDoubleQuote] manner ,  this \
requires a bit of experience. One way to  develop this skill is to  watch the \
precision following an  increase of  the segmentation in one object and one \
plane at a time . By this method, one quickly  identifies the objects and the \
directions which require more segmentation to improve the accuracy."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Load and Initialize Radia", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"The following instruction loads the Radia package and returns the Radia  \
version number. It also load the \"PlotField3D\" package to be used later. ",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
<<Radia`;
<<Graphics`PlotField3D`;\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining The Model", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["A routine to create the geometry.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
eps=0;\t\t\t\t\t(* used for debugging *)
Off[General::\"spell1\"];
geom[circ_]:=(
ironcolor={0,0.5,1};
coilcolor={1,0,0};

(* The pole faces *)

lx1=thick/2;ly1=width;lz1=20;l1={lx1,ly1,lz1};
k1={{thick/4-chamfer/2,0,gap/2},{thick/2-chamfer,ly1-2*chamfer}};
k2={{thick/4,0,gap/2+chamfer},{thick/2,ly1}};
k3={{thick/4,0,gap/2+lz1},{thick/2,ly1}};
g1=radObjMltExtRtg[{k1,k2,k3}];
radObjDivMag[g1,n1];

(* Vertical segment on top of pole faces *)

lx2=thick/2;ly2=ly1;lz2=30;l2={lx2,ly2,lz2};
p2={thick/4,0,lz1+gap/2+lz2/2+1*eps};
g2=radObjRecMag[p2,l2];radObjDivMag[g2,n2];

(* Corner *)

lx3=thick/2;ly3=ly2;lz3=ly2*1.25;l3={lx3,ly3,lz3};
p3={thick/4,0,lz1+gap/2+lz2+lz3/2+2*eps};
g3=radObjRecMag[p3,l3];
typ={\"cyl\",{p3+{0,+ly3/2,-lz3/2},{1,0,0}},p3+{0,-ly3/2,-lz3/2},lz3/ly3};

If[circ==1,
radObjDivMag[g3,{nbr,nbp,n3[[1]]},typ],
radObjDivMag[g3,n3]];

(* Horizontal segment between the corners *)

lx4=thick/2;ly4=80;lz4=lz3;l4={lx4,ly4,lz4};p4={thick/4,ly3/2+eps+ly4/2,p3[[3]\
]};
g4=radObjRecMag[p4,l4];radObjDivMag[g4,n4];

(* The other corner  *)

lx5=thick/2;ly5=lz4*1.25;lz5=lz4;l5={lx5,ly5,lz5};
p5={thick/4,p4[[2]]+eps+(ly4+ly5)/2,p4[[3]]};
g5=radObjRecMag[p5,l5];


typ={\"cyl\",{p5+{0,-ly5/2,-lz5/2},{1,0,0}},p5+{0,ly5/2,-lz5/2},lz5/ly5};

If[circ==1,
radObjDivMag[g5,{nbr,nbp,n5[[1]]},typ],
radObjDivMag[g5,n5]];

(* The vertical segment inside the coil *)

lx6=thick/2;ly6=ly5;lz6=gap/2+lz1+lz2;l6={lx6,ly6,lz6};
p6={thick/4,p5[[2]],p5[[3]]-(lz6+lz5)/2-eps};
g6=radObjRecMag[p6,l6];radObjDivMag[g6,n6];

(* Generation of the coil *)

Rmin=5;Rmax=40;Nseg=4;H=2*lz6-5;
CurDens=current/H/(Rmax-Rmin);
pc={0,p6[[2]],0};
coil=radObjRaceTrk[pc,{Rmin,Rmax},{thick,ly6},H,3,CurDens];
radObjDrwAtr[coil,coilcolor];

(* make container and set the colors *)

g=radObjCnt[{g1,g2,g3,g4,g5,g6}];
radObjDrwAtr[g,ironcolor];
radMatApl[g,ironmat];
t=radObjCnt[{g,coil}];

(* define the symmetries *)

RadTrfZerPerp[g,{0,0,0},{1,0,0}];
RadTrfZerPara[g,{0,0,0},{0,0,1}];
);\
\>", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating the Model and Solving", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Creating and solving of the field geometry. The Bz field printed is the \
vertical field in the middle of the gap. In this computation, the subdivision \
in the iron is low in order to achieve a short CPU time at the cost of a \
reduced precision. The excitation current is low and the iron has a very \
large permeability. Therefore there is no saturation in the iron and the \
Ampere law gives a good estimate of the field on axis to which the computed \
field can be compared. The sources of discrepancy between the computed and \
estimated fields from Ampere's law are the residual small deviation from \
uniformity in the gap and the unsufficient  segmentation. A closer agreement \
between them is reached if one uses the following higher segmentation \
parameters : nx=3; nbp=3; nbr=3; n1={nx,3,2}; n2={nx,3,3};n4={nx,3,3}  \
n6={nx,3,3}, the cpu time is longer but still reasonable. One can observe \
some saturation in the iron by either increasing the current in the coil (for \
example current =-10000) or using a lower saturated magnetization when \
calling   \"radMatSatIso\" or by using an other material. The computed \
Mag_Max and  H_Max are the maximum value of the magnetization vector and H \
vector in the iron circuit both expressed in Tesla. If saturation starts \
somewhere in the circuit,  Mag_Max approaches the saturated magnetization of \
the material (2T in this example as defined in \"radMatSatIso\")  and H_Max \
deviates from 0. One may want to vary the   gap, thick, width and chamfer \
parameters but one may need to increase or reduce some segmentation parameter \
accordingly to keep a reasonable precision  for a reasonable cpu time. Just \
try and play  by changing some parameters and re-executing ! The only risk is \
if one sets a  too large segmentation parameter  resulting in insufficient \
memory or too long cpu time. If this happens, in the worst case you will have \
to kill the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Kernel by one way on an other, if Radia.exe is still alive kill it also \
(by switching to it and then exiting) then re-execute all sections of this \
notebook  starting by \"Load and Initialize Radia\" etc... One may estimate \
the memory requirement by looking at the size of the interaction matrix. You \
may then switch to the next sections to see how to display the 3D graphics of \
your geometry  or make field or field integral plots at whatever point you \
are interested in. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
(* Geometry Parameters *)

gap=10;  \t\t\t\t\t(* in mm  *)
thick=50;\t\t\t\t\t(* in mm  *)
width=40;\t\t\t\t\t(* in mm  *)
chamfer=8;\t\t\t\t\t(* in mm  *)
current=-2000;\t\t\t\t(* in Ampere  *)

(* Segmentation Parameters *)

nx=2;\t\t\t\t\t\t
nbp=2;nbr=2; \t\t\t\t(* for the corners *)
n1={nx,3,2};\t\t\t\t(* pole faces *)
n2={nx,2,2};\t\t\t\t(* Small Vert. Arm *)
n3={nx,2,2};\t\t\t\t
n4={nx,2,2};\t\t\t\t(* Horiz.  Arm  *)
n5={nx,2,2};\t\t\t\t
n6={nx,2,2};\t\t\t\t(* Inside the Coil *)

(* Build the geometry *)

t0=AbsoluteTime[];
radUtiDelAll[];
ironmat=radMatSatIso[{20000,2},{0.1,2},{0.1,2}];
geom[1];
size=radObjDegFre[t];

(* Solve the geometry *)

t1=AbsoluteTime[];
res=RadSolve[t,0.0001,1500];
t2=AbsoluteTime[];

(* Print The results *)

b0=radFld[t,\"Bz\",{0,0,0}];
bampere=(-4*Pi*current/gap)/10000;
r=b0/bampere;

Print[\"Mag_Max  H_Max  N_Iter = \",N[res[[2]],3],\" T \",N[res[[3]],3],\" T \
\",res[[4]]];
Print[\"Built & Solved in \",Round[t1-t0],\" & \",Round[t2-t1], \" seconds\"]
Print[\"Interaction Matrix : \",size,\" X \",size,\" or \", \
N[size*size*4/1000000,2],\" Mbytes\"]
Print[\"Bz = \", N[b0,4],\" T,   Bz Computed / Bz Ampere Law  = \
\",N[r,4]]\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Mag_Max  H_Max  N_Iter = \"\>", "\[InvisibleSpace]", 
        StyleBox["0.92234172108745458`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" T \"\>", 
        "\[InvisibleSpace]", 
        StyleBox["0.0000498791078411529298`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", "\<\" T \"\>", 
        "\[InvisibleSpace]", "666"}],
      SequenceForm[ 
      "Mag_Max  H_Max  N_Iter = ", 0.9223417210874546, " T ", 
        4.9879107841152933*^-05, " T ", 666],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Built & Solved in "\[InvisibleSpace]6
        \[InvisibleSpace]" & "\[InvisibleSpace]11
        \[InvisibleSpace]" seconds"\),
      SequenceForm[ "Built & Solved in ", 6, " & ", 11, " seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "\<\"Interaction Matrix : \"\>", "\[InvisibleSpace]", "216", 
        "\[InvisibleSpace]", "\<\" X \"\>", "\[InvisibleSpace]", "216", 
        "\[InvisibleSpace]", "\<\" or \"\>", "\[InvisibleSpace]", 
        StyleBox["0.186624000000000016`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2], "\[InvisibleSpace]", "\<\" Mbytes\"\>"}],
      SequenceForm[ 
      "Interaction Matrix : ", 216, " X ", 216, " or ", 0.18662400000000001, 
        " Mbytes"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Bz = \"\>", "\[InvisibleSpace]", 
        StyleBox["0.258101166581553709`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", 
        "\<\" T,   Bz Computed / Bz Ampere Law  = \"\>", 
        "\[InvisibleSpace]", 
        StyleBox["1.02695191198097446`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4]}],
      SequenceForm[ 
      "Bz = ", 0.25810116658155369, " T,   Bz Computed / Bz Ampere Law  = ", 
        1.0269519119809745],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetization in the  Iron ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"Plot the magnetization in the center of each subdivided element of the iron. \
",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(RadPlot3DOptions[]; \n\t
    ListPlotVectorField3D[radObjM[t]\n, VectorHeads -> True\n\t, 
      ColorFunction -> \ Hue\n\t, 
      PlotLabel -> "\<Magnetization in Element # \>"<>ToString[t]\n\t, 
      ViewPoint -> {3, 2\ , \ 0}\n\t\ , PlotRange -> {All, All, {0, 110}}\ \n
      \t, ScaleFactor -> 8]; \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.5 1.0125 -76.5 0 ]
[.5 1.0125 76.5 15 ]
[.91564 .22189 -12.5 -15 ]
[.91564 .22189 12.5 0 ]
[.89418 .21826 -12.5 -15 ]
[.89418 .21826 12.5 0 ]
[.87211 .21452 -5 -15 ]
[.87211 .21452 5 0 ]
[.84943 .21068 -8 -15 ]
[.84943 .21068 8 0 ]
[.8261 .20673 -8 -15 ]
[.8261 .20673 8 0 ]
[.87211 .15202 -8 -15 ]
[.87211 .15202 8 0 ]
[.19598 .2432 -5 -15 ]
[.19598 .2432 5 0 ]
[.37563 .23266 -8 -15 ]
[.37563 .23266 8 0 ]
[.57148 .22116 -11 -15 ]
[.57148 .22116 11 0 ]
[.78584 .20857 -11 -15 ]
[.78584 .20857 11 0 ]
[.44526 .16607 -8 -15 ]
[.44526 .16607 8 0 ]
[.93001 .23682 0 -6.23032 ]
[.93001 .23682 10 8.76968 ]
[.93013 .35646 0 -6.80745 ]
[.93013 .35646 16 8.19255 ]
[.93018 .47608 0 -7.38457 ]
[.93018 .47608 16 7.61543 ]
[.93016 .59569 0 -7.9617 ]
[.93016 .59569 16 7.0383 ]
[.93006 .71532 0 -8.53883 ]
[.93006 .71532 22 6.46117 ]
[.99268 .5 0 -7.5 ]
[.99268 .5 15 7.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.0125 -137.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnetization) show
134.937500 14.625000 moveto
(in) show
147.250000 14.625000 moveto
(Element) show
190.062500 14.625000 moveto
(#) show
199.062500 14.625000 moveto
(92) show
211.062500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.91768 .23473 m
.82382 .21884 L
s
.25 Mabswid
.91564 .23439 m
.91564 .24064 L
s
gsave
.91564 .22189 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.89418 .23076 m
.89418 .23701 L
s
gsave
.89418 .21826 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87211 .22702 m
.87211 .23327 L
s
gsave
.87211 .21452 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.84943 .22318 m
.84943 .22943 L
s
gsave
.84943 .21068 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.8261 .21923 m
.8261 .22548 L
s
gsave
.8261 .20673 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9114 .23367 m
.9114 .23742 L
s
.90713 .23295 m
.90713 .2367 L
s
.90283 .23222 m
.90283 .23597 L
s
.89852 .23149 m
.89852 .23524 L
s
.88981 .23002 m
.88981 .23377 L
s
.88542 .22927 m
.88542 .23302 L
s
.88101 .22853 m
.88101 .23228 L
s
.87657 .22778 m
.87657 .23153 L
s
.86763 .22626 m
.86763 .23001 L
s
.86312 .2255 m
.86312 .22925 L
s
.85858 .22473 m
.85858 .22848 L
s
.85402 .22396 m
.85402 .22771 L
s
.84482 .2224 m
.84482 .22615 L
s
.84018 .22161 m
.84018 .22536 L
s
.83551 .22082 m
.83551 .22457 L
s
.83082 .22003 m
.83082 .22378 L
s
gsave
.87211 .15202 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.12216 .26004 m
.82382 .21884 L
s
.25 Mabswid
.19598 .2557 m
.19598 .26195 L
s
gsave
.19598 .2432 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.37563 .24516 m
.37563 .25141 L
s
gsave
.37563 .23266 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.57148 .23366 m
.57148 .23991 L
s
gsave
.57148 .22116 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.78584 .22107 m
.78584 .22732 L
s
gsave
.78584 .20857 -72 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.23071 .25366 m
.23071 .25741 L
s
.26603 .25159 m
.26603 .25534 L
s
.30194 .24948 m
.30194 .25323 L
s
.33847 .24734 m
.33847 .25109 L
s
.41343 .24294 m
.41343 .24669 L
s
.4519 .24068 m
.4519 .24443 L
s
.49105 .23838 m
.49105 .24213 L
s
.53091 .23604 m
.53091 .23979 L
s
.61279 .23123 m
.61279 .23498 L
s
.65486 .22876 m
.65486 .23251 L
s
.69771 .22625 m
.69771 .23 L
s
.74136 .22369 m
.74136 .22744 L
s
.16182 .25771 m
.16182 .26146 L
s
.12822 .25968 m
.12822 .26343 L
s
gsave
.44526 .16607 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.91768 .23473 m
.91768 .76527 L
s
.25 Mabswid
.91768 .23473 m
.91152 .23369 L
s
gsave
.93001 .23682 -61 -10.2303 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.91768 .35531 m
.91146 .35474 L
s
gsave
.93013 .35646 -61 -10.8074 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.91768 .47588 m
.91143 .47579 L
s
gsave
.93018 .47608 -61 -11.3846 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.91768 .59646 m
.91144 .59684 L
s
gsave
.93016 .59569 -61 -11.9617 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(75) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.91768 .71704 m
.91149 .71789 L
s
gsave
.93006 .71532 -61 -12.5388 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.91768 .25885 m
.91397 .25828 L
s
.91768 .28296 m
.91397 .28245 L
s
.91768 .30708 m
.91396 .30662 L
s
.91768 .33119 m
.91395 .33079 L
s
.91768 .37942 m
.91394 .37914 L
s
.91768 .40354 m
.91394 .40331 L
s
.91768 .42765 m
.91393 .42748 L
s
.91768 .45177 m
.91393 .45165 L
s
.91768 .5 m
.91393 .5 L
s
.91768 .52412 m
.91393 .52417 L
s
.91768 .54823 m
.91393 .54835 L
s
.91768 .57235 m
.91393 .57252 L
s
.91768 .62058 m
.91394 .62086 L
s
.91768 .64469 m
.91395 .64503 L
s
.91768 .66881 m
.91395 .66921 L
s
.91768 .69292 m
.91396 .69338 L
s
.91768 .74115 m
.91397 .74172 L
s
gsave
.99268 .5 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.23707 .27171 m
.23707 .72829 L
s
.23707 .72829 m
.91768 .76527 L
s
.91768 .76527 m
.91768 .23473 L
s
.91768 .23473 m
.23707 .27171 L
s
.12216 .26004 m
.82382 .21884 L
s
.82382 .21884 m
.82382 .78116 L
s
.82382 .78116 m
.12216 .73996 L
s
.12216 .73996 m
.12216 .26004 L
s
.23707 .27171 m
.23707 .72829 L
s
.23707 .72829 m
.12216 .73996 L
s
.12216 .73996 m
.12216 .26004 L
s
.12216 .26004 m
.23707 .27171 L
s
.91768 .23473 m
.82382 .21884 L
s
.82382 .21884 m
.82382 .78116 L
s
.82382 .78116 m
.91768 .76527 L
s
.91768 .76527 m
.91768 .23473 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .452 0 r
.5 Mabswid
[ ] 0 setdash
.24678 .59918 m
.24764 .59646 L
s
.2473 .59668 m
.24793 .59699 L
s
.247 .59701 m
.2473 .59668 L
s
.2473 .59668 m
.24764 .59646 L
s
.24793 .59699 m
.24762 .59732 L
s
.24764 .59646 m
.24793 .59699 L
s
.24762 .59732 m
.247 .59701 L
s
.247 .59701 m
.24764 .59646 L
s
.24764 .59646 m
.24762 .59732 L
s
0 1 .396 r
.25909 .36176 m
.26321 .37409 L
s
0 1 .071 r
.25909 .33663 m
.25843 .34816 L
s
.25887 .34646 m
.25683 .34586 L
s
.2603 .34584 m
.25887 .34646 L
s
.25843 .34816 m
.25887 .34646 L
s
.022 1 0 r
.2607 .32407 m
.25872 .32449 L
s
.26202 .32447 m
.2607 .32407 L
s
.2607 .32407 m
.26052 .32677 L
s
0 1 .396 r
.26392 .37168 m
.26122 .37258 L
s
.26355 .37066 m
.26392 .37168 L
s
.26321 .37409 m
.26392 .37168 L
s
.022 1 0 r
.26052 .32677 m
.26004 .3249 L
s
.26052 .32677 m
.25872 .32449 L
s
.26202 .32447 m
.26052 .32677 L
s
.25978 .31532 m
.26052 .32677 L
s
0 1 .396 r
.26122 .37258 m
.26086 .37156 L
s
.26321 .37409 m
.26122 .37258 L
s
0 1 .071 r
.25683 .34586 m
.25826 .34525 L
s
.25683 .34586 m
.25843 .34816 L
s
.022 1 0 r
.25872 .32449 m
.26004 .3249 L
s
0 1 .071 r
.25826 .34525 m
.2603 .34584 L
s
.25843 .34816 m
.2603 .34584 L
s
.022 1 0 r
.26004 .3249 m
.26202 .32447 L
s
0 1 .071 r
.25826 .34525 m
.25843 .34816 L
s
0 1 .396 r
.26355 .37066 m
.26321 .37409 L
s
.26086 .37156 m
.26321 .37409 L
s
.26086 .37156 m
.26355 .37066 L
s
0 1 .635 r
.26982 .48094 m
.26823 .48074 L
s
.27249 .48075 m
.26982 .48094 L
s
.27042 .48381 m
.26982 .48094 L
s
0 1 .307 r
.26999 .41653 m
.26834 .41627 L
s
.2722 .41629 m
.26999 .41653 L
s
.27031 .41898 m
.26999 .41653 L
s
0 1 .635 r
.27011 .4685 m
.27042 .48381 L
s
0 1 .307 r
.27011 .4055 m
.27031 .41898 L
s
0 1 .635 r
.27091 .48055 m
.27249 .48075 L
s
.27042 .48381 m
.27249 .48075 L
s
0 1 .307 r
.27055 .41603 m
.2722 .41629 L
s
.27031 .41898 m
.2722 .41629 L
s
0 1 .635 r
.27091 .48055 m
.27042 .48381 L
s
.26823 .48074 m
.27042 .48381 L
s
0 1 .307 r
.27055 .41603 m
.27031 .41898 L
s
.26834 .41627 m
.27031 .41898 L
s
.26834 .41627 m
.27055 .41603 L
s
0 1 .635 r
.26823 .48074 m
.27091 .48055 L
s
1 .539 0 r
.27739 .6801 m
.27949 .67792 L
s
.27951 .67833 m
.27928 .67884 L
s
.27886 .67788 m
.27951 .67833 L
s
.27949 .67792 m
.27951 .67833 L
s
.27863 .67838 m
.27886 .67788 L
s
.27886 .67788 m
.27949 .67792 L
s
.27928 .67884 m
.27863 .67838 L
s
.27949 .67792 m
.27928 .67884 L
s
.27863 .67838 m
.27949 .67792 L
s
0 .827 1 r
.28103 .54932 m
.28724 .5658 L
s
.28773 .56246 m
.28423 .56365 L
s
.28776 .56135 m
.28773 .56246 L
s
.28724 .5658 m
.28773 .56246 L
s
0 1 .192 r
.26118 .29774 m
.26324 .31021 L
s
.26425 .3078 m
.26166 .30825 L
s
.264 .30718 m
.26425 .3078 L
s
.26324 .31021 m
.26425 .3078 L
s
0 .827 1 r
.28423 .56365 m
.28426 .56254 L
s
.28724 .5658 m
.28423 .56365 L
s
0 1 .192 r
.26166 .30825 m
.26141 .30763 L
s
.26324 .31021 m
.26166 .30825 L
s
.264 .30718 m
.26324 .31021 L
s
.26141 .30763 m
.26324 .31021 L
s
0 .827 1 r
.28776 .56135 m
.28724 .5658 L
s
.28426 .56254 m
.28724 .5658 L
s
0 1 .192 r
.26141 .30763 m
.264 .30718 L
s
0 .827 1 r
.28426 .56254 m
.28776 .56135 L
s
0 1 .142 r
.30194 .34518 m
.30017 .34467 L
s
.30017 .34467 m
.29847 .34398 L
s
.30017 .34467 m
.29938 .34699 L
s
0 1 .22 r
.30508 .32295 m
.30429 .32374 L
s
.30732 .32195 m
.30508 .32295 L
s
.30702 .32518 m
.30508 .32295 L
s
0 1 .834 r
.30352 .36031 m
.3105 .37374 L
s
0 1 .142 r
.30352 .33491 m
.29938 .34699 L
s
.30024 .34448 m
.30194 .34518 L
s
.29938 .34699 m
.30194 .34518 L
s
.29847 .34398 m
.29938 .34699 L
s
.29938 .34699 m
.30024 .34448 L
s
.29847 .34398 m
.30024 .34448 L
s
0 1 .22 r
.30653 .32275 m
.30732 .32195 L
s
.30732 .32195 m
.30702 .32518 L
s
.30702 .32518 m
.30429 .32374 L
s
.30653 .32275 m
.30702 .32518 L
s
.30093 .31352 m
.30702 .32518 L
s
.30429 .32374 m
.30653 .32275 L
s
0 1 .834 r
.31069 .37113 m
.30764 .37244 L
s
.31056 .36966 m
.31069 .37113 L
s
.3105 .37374 m
.31069 .37113 L
s
.30764 .37244 m
.30752 .37097 L
s
.3105 .37374 m
.30764 .37244 L
s
1 .023 0 r
.21364 .60065 m
.21429 .60161 L
s
.21425 .60141 m
.21404 .60152 L
s
.21427 .60131 m
.21425 .60141 L
s
.21429 .60161 m
.21425 .60141 L
s
.21404 .60152 m
.21407 .60142 L
s
.21429 .60161 m
.21404 .60152 L
s
.21407 .60142 m
.21427 .60131 L
s
.21427 .60131 m
.21429 .60161 L
s
.21407 .60142 m
.21429 .60161 L
s
0 1 .834 r
.31056 .36966 m
.3105 .37374 L
s
.30752 .37097 m
.3105 .37374 L
s
.30752 .37097 m
.31056 .36966 L
s
0 1 .022 r
.29541 .306 m
.29474 .30566 L
s
.29778 .30578 m
.29541 .306 L
s
.29638 .30813 m
.29541 .306 L
s
.29711 .30544 m
.29778 .30578 L
s
.29638 .30813 m
.29778 .30578 L
s
.29575 .29609 m
.29638 .30813 L
s
.115 1 0 r
.22644 .36897 m
.22625 .36888 L
s
.22625 .36888 m
.22395 .36866 L
s
.22625 .36888 m
.22498 .3711 L
s
.181 1 0 r
.22625 .3203 m
.22578 .32087 L
s
.22837 .32099 m
.22625 .3203 L
s
.22625 .3203 m
.22651 .32296 L
s
.2279 .32156 m
.22837 .32099 L
s
.22837 .32099 m
.22651 .32296 L
s
.115 1 0 r
.22395 .36866 m
.22413 .36876 L
s
.22395 .36866 m
.22498 .3711 L
s
.181 1 0 r
.22651 .32296 m
.2279 .32156 L
s
.22651 .32296 m
.22578 .32087 L
s
.22936 .3128 m
.22651 .32296 L
s
0 1 .022 r
.29711 .30544 m
.29638 .30813 L
s
.29474 .30566 m
.29638 .30813 L
s
.115 1 0 r
.22498 .3711 m
.22644 .36897 L
s
.22498 .3711 m
.22413 .36876 L
s
.22603 .35971 m
.22498 .3711 L
s
0 1 .022 r
.29474 .30566 m
.29711 .30544 L
s
.239 1 0 r
.22603 .3342 m
.22811 .34419 L
s
.115 1 0 r
.22413 .36876 m
.22644 .36897 L
s
.181 1 0 r
.22578 .32087 m
.2279 .32156 L
s
.239 1 0 r
.22686 .34276 m
.22643 .34214 L
s
.22896 .34224 m
.22686 .34276 L
s
.22811 .34419 m
.22686 .34276 L
s
.22853 .34161 m
.22896 .34224 L
s
.22811 .34419 m
.22896 .34224 L
s
.22853 .34161 m
.22811 .34419 L
s
.22643 .34214 m
.22811 .34419 L
s
.22643 .34214 m
.22853 .34161 L
s
.226 1 0 r
.23793 .3041 m
.23581 .30428 L
s
.23845 .30373 m
.23793 .3041 L
s
.2374 .30614 m
.23793 .3041 L
s
.279 0 1 r
.33106 .52218 m
.33949 .5444 L
s
0 1 .313 r
.23637 .47915 m
.23556 .47907 L
s
.23905 .47909 m
.23637 .47915 L
s
.23735 .48184 m
.23637 .47915 L
s
0 .554 1 r
.3316 .6298 m
.34665 .63648 L
s
0 1 .129 r
.2365 .41446 m
.23585 .41428 L
s
.23901 .41434 m
.2365 .41446 L
s
.23751 .41686 m
.2365 .41446 L
s
.226 1 0 r
.23581 .30428 m
.23632 .30391 L
s
.2374 .30614 m
.23581 .30428 L
s
.23602 .29545 m
.2374 .30614 L
s
0 1 .313 r
.23824 .479 m
.23905 .47909 L
s
.23735 .48184 m
.23905 .47909 L
s
0 1 .129 r
.23837 .41416 m
.23901 .41434 L
s
.23751 .41686 m
.23901 .41434 L
s
.226 1 0 r
.23845 .30373 m
.2374 .30614 L
s
.23632 .30391 m
.2374 .30614 L
s
0 1 .313 r
.23713 .46803 m
.23735 .48184 L
s
0 1 .129 r
.23713 .40409 m
.23751 .41686 L
s
0 1 .313 r
.23824 .479 m
.23735 .48184 L
s
.23556 .47907 m
.23735 .48184 L
s
.226 1 0 r
.23632 .30391 m
.23845 .30373 L
s
0 .728 1 r
.33921 .41944 m
.33609 .41933 L
s
.33609 .41933 m
.33381 .41907 L
s
.33609 .41933 m
.33628 .42307 L
s
0 1 .129 r
.23837 .41416 m
.23751 .41686 L
s
.23585 .41428 m
.23751 .41686 L
s
.279 0 1 r
.34001 .53991 m
.33533 .54147 L
s
.34028 .53843 m
.34001 .53991 L
s
.33949 .5444 m
.34001 .53991 L
s
0 .369 1 r
.33933 .48496 m
.33508 .48487 L
s
.33508 .48487 m
.33483 .48476 L
s
.33508 .48487 m
.33699 .48908 L
s
.33909 .48485 m
.33933 .48496 L
s
.33699 .48908 m
.33933 .48496 L
s
0 1 .313 r
.23556 .47907 m
.23824 .479 L
s
0 1 .129 r
.23585 .41428 m
.23837 .41416 L
s
.279 0 1 r
.33533 .54147 m
.33559 .53999 L
s
.33949 .5444 m
.33533 .54147 L
s
0 .728 1 r
.33693 .41918 m
.33921 .41944 L
s
.33628 .42307 m
.33921 .41944 L
s
0 .369 1 r
.33746 .468 m
.33699 .48908 L
s
0 .728 1 r
.33746 .404 m
.33628 .42307 L
s
.33381 .41907 m
.33628 .42307 L
s
.33628 .42307 m
.33693 .41918 L
s
0 .369 1 r
.33483 .48476 m
.33699 .48908 L
s
.33699 .48908 m
.33909 .48485 L
s
0 .728 1 r
.33381 .41907 m
.33693 .41918 L
s
.279 0 1 r
.34028 .53843 m
.33949 .5444 L
s
.33559 .53999 m
.33949 .5444 L
s
1 .172 0 r
.24446 .68279 m
.24595 .68214 L
s
0 .554 1 r
.3454 .63504 m
.34293 .63785 L
s
.34433 .63244 m
.3454 .63504 L
s
.34665 .63648 m
.3454 .63504 L
s
.279 0 1 r
.33559 .53999 m
.34028 .53843 L
s
0 .369 1 r
.33483 .48476 m
.33909 .48485 L
s
1 .172 0 r
.24584 .68225 m
.24573 .68254 L
s
.24557 .68199 m
.24584 .68225 L
s
.24595 .68214 m
.24584 .68225 L
s
.24547 .68228 m
.24557 .68199 L
s
.24557 .68199 m
.24595 .68214 L
s
.24573 .68254 m
.24547 .68228 L
s
.24595 .68214 m
.24573 .68254 L
s
.24547 .68228 m
.24595 .68214 L
s
0 .554 1 r
.34293 .63785 m
.34186 .63525 L
s
.34665 .63648 m
.34293 .63785 L
s
0 1 .531 r
.24813 .55006 m
.25164 .56447 L
s
.25231 .56155 m
.24935 .56221 L
s
.25253 .56096 m
.25231 .56155 L
s
.25164 .56447 m
.25231 .56155 L
s
0 .554 1 r
.34186 .63525 m
.34433 .63244 L
s
.34433 .63244 m
.34665 .63648 L
s
0 1 .57 r
.34669 .34538 m
.34479 .34474 L
s
.34479 .34474 m
.3426 .34387 L
s
.34479 .34474 m
.34358 .34749 L
s
0 1 .571 r
.34812 .32273 m
.3466 .32359 L
s
.35041 .32161 m
.34812 .32273 L
s
.34991 .32533 m
.34812 .32273 L
s
0 1 .531 r
.24935 .56221 m
.24957 .56162 L
s
.25164 .56447 m
.24935 .56221 L
s
0 .554 1 r
.34186 .63525 m
.34665 .63648 L
s
0 1 .571 r
.34889 .32247 m
.35041 .32161 L
s
.35041 .32161 m
.34991 .32533 L
s
0 1 .531 r
.25253 .56096 m
.25164 .56447 L
s
.24957 .56162 m
.25164 .56447 L
s
0 1 .571 r
.34991 .32533 m
.3466 .32359 L
s
.34889 .32247 m
.34991 .32533 L
s
.34289 .31169 m
.34991 .32533 L
s
0 1 .818 r
.34882 .37237 m
.34702 .37188 L
s
.35167 .37193 m
.34882 .37237 L
s
.34946 .37518 m
.34882 .37237 L
s
0 1 .57 r
.3426 .34387 m
.3445 .34451 L
s
.3426 .34387 m
.34358 .34749 L
s
.34358 .34749 m
.34669 .34538 L
s
.34358 .34749 m
.3445 .34451 L
s
.34889 .33316 m
.34358 .34749 L
s
.3445 .34451 m
.34669 .34538 L
s
0 1 .818 r
.34889 .35882 m
.34946 .37518 L
s
0 1 .531 r
.24957 .56162 m
.25253 .56096 L
s
0 1 .571 r
.3466 .32359 m
.34889 .32247 L
s
0 1 .372 r
.32966 .30579 m
.32878 .30573 L
s
.33239 .30586 m
.32966 .30579 L
s
.32966 .30579 m
.33051 .30864 L
s
0 1 .818 r
.34987 .37144 m
.35167 .37193 L
s
.34946 .37518 m
.35167 .37193 L
s
0 1 .372 r
.33152 .3058 m
.33239 .30586 L
s
.33239 .30586 m
.33051 .30864 L
s
0 1 .818 r
.34987 .37144 m
.34946 .37518 L
s
.34702 .37188 m
.34946 .37518 L
s
.34702 .37188 m
.34987 .37144 L
s
0 1 .372 r
.33051 .30864 m
.33152 .3058 L
s
.33051 .30864 m
.32878 .30573 L
s
.33089 .29441 m
.33051 .30864 L
s
.609 0 1 r
.35392 .55799 m
.37394 .56706 L
s
0 1 .372 r
.32878 .30573 m
.33152 .3058 L
s
.131 1 0 r
.26797 .36693 m
.26786 .36615 L
s
.26786 .36615 m
.26576 .36524 L
s
.26786 .36615 m
.26589 .36805 L
s
.26576 .36524 m
.26587 .36602 L
s
.26576 .36524 m
.26589 .36805 L
s
.527 1 0 r
.27051 .31789 m
.26929 .31818 L
s
.27194 .3182 m
.27051 .31789 L
s
.27051 .31789 m
.27057 .32 L
s
.131 1 0 r
.26589 .36805 m
.26797 .36693 L
s
.26589 .36805 m
.26587 .36602 L
s
.27078 .35821 m
.26589 .36805 L
s
.527 1 0 r
.27057 .32 m
.27071 .31849 L
s
.27057 .32 m
.26929 .31818 L
s
.27194 .3182 m
.27057 .32 L
s
.27078 .31095 m
.27057 .32 L
s
.27071 .31849 m
.27194 .3182 L
s
.131 1 0 r
.26587 .36602 m
.26797 .36693 L
s
.527 1 0 r
.26929 .31818 m
.27071 .31849 L
s
.498 1 0 r
.27072 .30135 m
.26941 .30132 L
s
.27211 .30134 m
.27072 .30135 L
s
.27072 .30135 m
.27076 .30322 L
s
.609 0 1 r
.37222 .56517 m
.36892 .56882 L
s
.37092 .56166 m
.37222 .56517 L
s
.37394 .56706 m
.37222 .56517 L
s
.498 1 0 r
.27081 .30131 m
.27211 .30134 L
s
.27211 .30134 m
.27076 .30322 L
s
.27076 .30322 m
.27081 .30131 L
s
.27076 .30322 m
.26941 .30132 L
s
.27078 .29376 m
.27076 .30322 L
s
.26941 .30132 m
.27081 .30131 L
s
.556 1 0 r
.27078 .33243 m
.27223 .34109 L
s
.27121 .33977 m
.27087 .33932 L
s
.273 .33941 m
.27121 .33977 L
s
.27223 .34109 m
.27121 .33977 L
s
.27267 .33895 m
.273 .33941 L
s
.27223 .34109 m
.273 .33941 L
s
.609 0 1 r
.36892 .56882 m
.36761 .56531 L
s
.37394 .56706 m
.36892 .56882 L
s
.556 1 0 r
.27267 .33895 m
.27223 .34109 L
s
.27087 .33932 m
.27223 .34109 L
s
.27087 .33932 m
.27267 .33895 L
s
.609 0 1 r
.36761 .56531 m
.37092 .56166 L
s
.37092 .56166 m
.37394 .56706 L
s
1 .023 0 r
.1795 .60216 m
.18002 .60314 L
s
.18005 .60294 m
.17982 .60305 L
s
.18001 .60284 m
.18005 .60294 L
s
.18002 .60314 m
.18005 .60294 L
s
.17982 .60305 m
.17979 .60295 L
s
.18002 .60314 m
.17982 .60305 L
s
.17979 .60295 m
.18001 .60284 L
s
.18001 .60284 m
.18002 .60314 L
s
.17979 .60295 m
.18002 .60314 L
s
.609 0 1 r
.36761 .56531 m
.37394 .56706 L
s
.115 1 0 r
.1924 .367 m
.19213 .3669 L
s
.19213 .3669 m
.1898 .36668 L
s
.19213 .3669 m
.19088 .36915 L
s
.1898 .36668 m
.19007 .36678 L
s
.1898 .36668 m
.19088 .36915 L
s
.19088 .36915 m
.1924 .367 L
s
.19088 .36915 m
.19007 .36678 L
s
.19198 .35759 m
.19088 .36915 L
s
.239 1 0 r
.19531 .33996 m
.19333 .34043 L
s
.19604 .33933 m
.19531 .33996 L
s
.19536 .34193 m
.19531 .33996 L
s
.181 1 0 r
.193 .31881 m
.19233 .31822 L
s
.19233 .31822 m
.19035 .31744 L
s
.19233 .31822 m
.19076 .32016 L
s
.239 1 0 r
.19198 .3317 m
.19536 .34193 L
s
.115 1 0 r
.19007 .36678 m
.1924 .367 L
s
.239 1 0 r
.19333 .34043 m
.19406 .3398 L
s
.19536 .34193 m
.19333 .34043 L
s
.181 1 0 r
.19035 .31744 m
.19102 .31803 L
s
.19035 .31744 m
.19076 .32016 L
s
.19076 .32016 m
.193 .31881 L
s
.19076 .32016 m
.19102 .31803 L
s
.19533 .30997 m
.19076 .32016 L
s
.239 1 0 r
.19604 .33933 m
.19536 .34193 L
s
.19406 .3398 m
.19536 .34193 L
s
.19406 .3398 m
.19604 .33933 L
s
.181 1 0 r
.19102 .31803 m
.193 .31881 L
s
0 1 .313 r
.20408 .47878 m
.20158 .47883 L
s
.20544 .47869 m
.20408 .47878 L
s
.2036 .48157 m
.20408 .47878 L
s
0 1 .129 r
.20432 .41307 m
.20196 .41314 L
s
.20549 .4129 m
.20432 .41307 L
s
.20387 .41562 m
.20432 .41307 L
s
.245 1 0 r
.29852 .52251 m
.30128 .5329 L
s
.30164 .53081 m
.29952 .5313 L
s
.30193 .53035 m
.30164 .53081 L
s
.30128 .5329 m
.30164 .53081 L
s
.226 1 0 r
.20409 .3011 m
.20187 .30132 L
s
.20399 .30072 m
.20409 .3011 L
s
.20315 .30319 m
.20409 .3011 L
s
0 1 .42 r
.29907 .63176 m
.30962 .63818 L
s
.226 1 0 r
.20187 .30132 m
.20177 .30094 L
s
.20315 .30319 m
.20187 .30132 L
s
.245 1 0 r
.29952 .5313 m
.29982 .53084 L
s
.30128 .5329 m
.29952 .5313 L
s
.226 1 0 r
.20204 .29236 m
.20315 .30319 L
s
0 1 .313 r
.20158 .47883 m
.20294 .47875 L
s
.2036 .48157 m
.20158 .47883 L
s
0 1 .129 r
.20196 .41314 m
.20312 .41297 L
s
.20387 .41562 m
.20196 .41314 L
s
0 1 .313 r
.20316 .46755 m
.2036 .48157 L
s
0 1 .129 r
.20316 .40264 m
.20387 .41562 L
s
0 1 .313 r
.20544 .47869 m
.2036 .48157 L
s
.20294 .47875 m
.2036 .48157 L
s
0 1 .129 r
.20549 .4129 m
.20387 .41562 L
s
.20312 .41297 m
.20387 .41562 L
s
.226 1 0 r
.20399 .30072 m
.20315 .30319 L
s
.20177 .30094 m
.20315 .30319 L
s
.245 1 0 r
.30193 .53035 m
.30128 .5329 L
s
.29982 .53084 m
.30128 .5329 L
s
0 1 .313 r
.20294 .47875 m
.20544 .47869 L
s
0 1 .129 r
.20312 .41297 m
.20549 .4129 L
s
.245 1 0 r
.29982 .53084 m
.30193 .53035 L
s
.305 1 0 r
.30418 .30007 m
.3037 .3003 L
s
.30624 .30042 m
.30418 .30007 L
s
.30418 .30007 m
.30469 .30244 L
s
.226 1 0 r
.20177 .30094 m
.20399 .30072 L
s
.305 1 0 r
.30577 .30066 m
.30624 .30042 L
s
.30624 .30042 m
.30469 .30244 L
s
.30469 .30244 m
.30577 .30066 L
s
.30469 .30244 m
.3037 .3003 L
s
.30611 .29204 m
.30469 .30244 L
s
.533 1 0 r
.30607 .41004 m
.30462 .41003 L
s
.30462 .41003 m
.30342 .40995 L
s
.30462 .41003 m
.30469 .41186 L
s
.384 1 0 r
.30622 .47565 m
.30433 .47564 L
s
.30433 .47564 m
.30353 .47561 L
s
.30433 .47564 m
.30485 .47766 L
s
.30543 .47562 m
.30622 .47565 L
s
.30485 .47766 m
.30622 .47565 L
s
.533 1 0 r
.30487 .40996 m
.30607 .41004 L
s
.30469 .41186 m
.30607 .41004 L
s
.384 1 0 r
.30497 .46752 m
.30485 .47766 L
s
.533 1 0 r
.30497 .40255 m
.30469 .41186 L
s
.305 1 0 r
.3037 .3003 m
.30577 .30066 L
s
.533 1 0 r
.30342 .40995 m
.30469 .41186 L
s
.30469 .41186 m
.30487 .40996 L
s
.384 1 0 r
.30353 .47561 m
.30485 .47766 L
s
.30485 .47766 m
.30543 .47562 L
s
0 1 .42 r
.30879 .63682 m
.30682 .63878 L
s
.3082 .63501 m
.30879 .63682 L
s
.30962 .63818 m
.30879 .63682 L
s
.533 1 0 r
.30342 .40995 m
.30487 .40996 L
s
.384 1 0 r
.30353 .47561 m
.30543 .47562 L
s
0 1 .42 r
.30682 .63878 m
.30622 .63698 L
s
.30962 .63818 m
.30682 .63878 L
s
1 .172 0 r
.21053 .68556 m
.21206 .68489 L
s
0 1 .42 r
.30622 .63698 m
.3082 .63501 L
s
.3082 .63501 m
.30962 .63818 L
s
1 .172 0 r
.21194 .68501 m
.21184 .68531 L
s
.21167 .68474 m
.21194 .68501 L
s
.21206 .68489 m
.21194 .68501 L
s
.21157 .68504 m
.21167 .68474 L
s
.21167 .68474 m
.21206 .68489 L
s
.21184 .68531 m
.21157 .68504 L
s
.21206 .68489 m
.21184 .68531 L
s
.21157 .68504 m
.21206 .68489 L
s
0 1 .42 r
.30622 .63698 m
.30962 .63818 L
s
.476 1 0 r
.31613 .31624 m
.31481 .3167 L
s
.31734 .31562 m
.31613 .31624 L
s
.31684 .31793 m
.31613 .31624 L
s
0 1 .531 r
.21423 .55082 m
.21786 .56545 L
s
.21849 .56248 m
.21549 .56315 L
s
.21878 .56189 m
.21849 .56248 L
s
.21786 .56545 m
.21849 .56248 L
s
.447 1 0 r
.31491 .36449 m
.3145 .36402 L
s
.3145 .36402 m
.31268 .36343 L
s
.3145 .36402 m
.31312 .36578 L
s
.476 1 0 r
.31602 .31607 m
.31734 .31562 L
s
.31734 .31562 m
.31684 .31793 L
s
.31684 .31793 m
.31481 .3167 L
s
.31602 .31607 m
.31684 .31793 L
s
.31302 .30906 m
.31684 .31793 L
s
.31481 .3167 m
.31602 .31607 L
s
0 1 .531 r
.21549 .56315 m
.21578 .56256 L
s
.21786 .56545 m
.21549 .56315 L
s
.447 1 0 r
.31268 .36343 m
.31308 .3639 L
s
.31268 .36343 m
.31312 .36578 L
s
.31312 .36578 m
.31491 .36449 L
s
.31312 .36578 m
.31308 .3639 L
s
.31648 .35668 m
.31312 .36578 L
s
.629 1 0 r
.31653 .33778 m
.31564 .33764 L
s
.31564 .33764 m
.31412 .33738 L
s
.31564 .33764 m
.31503 .33931 L
s
.447 1 0 r
.31308 .3639 m
.31491 .36449 L
s
0 1 .531 r
.21878 .56189 m
.21786 .56545 L
s
.21578 .56256 m
.21786 .56545 L
s
.629 1 0 r
.31412 .33738 m
.31501 .33751 L
s
.31412 .33738 m
.31503 .33931 L
s
.31503 .33931 m
.31653 .33778 L
s
.31503 .33931 m
.31501 .33751 L
s
.31648 .33062 m
.31503 .33931 L
s
0 1 .531 r
.21578 .56256 m
.21878 .56189 L
s
.629 1 0 r
.31501 .33751 m
.31653 .33778 L
s
.322 1 0 r
.32155 .55887 m
.32942 .56291 L
s
.32874 .56208 m
.32739 .56349 L
s
.3283 .56071 m
.32874 .56208 L
s
.32942 .56291 m
.32874 .56208 L
s
.32739 .56349 m
.32694 .56213 L
s
.32942 .56291 m
.32739 .56349 L
s
.32694 .56213 m
.3283 .56071 L
s
.3283 .56071 m
.32942 .56291 L
s
.131 1 0 r
.23427 .3649 m
.23425 .36411 L
s
.23425 .36411 m
.2321 .3632 L
s
.23425 .36411 m
.23223 .36605 L
s
.322 1 0 r
.32694 .56213 m
.32942 .56291 L
s
.131 1 0 r
.2321 .3632 m
.23212 .36399 L
s
.2321 .3632 m
.23223 .36605 L
s
.23223 .36605 m
.23427 .3649 L
s
.23223 .36605 m
.23212 .36399 L
s
.23704 .35605 m
.23223 .36605 L
s
.23212 .36399 m
.23427 .3649 L
s
.498 1 0 r
.23799 .29836 m
.23638 .29835 L
s
.23638 .29835 m
.2353 .29817 L
s
.23638 .29835 m
.23655 .30018 L
s
.527 1 0 r
.23619 .31566 m
.2347 .31534 L
s
.2347 .31534 m
.23363 .31485 L
s
.2347 .31534 m
.23438 .31705 L
s
.556 1 0 r
.23942 .33703 m
.23774 .33735 L
s
.2401 .33658 m
.23942 .33703 L
s
.23939 .33874 m
.23942 .33703 L
s
.498 1 0 r
.23691 .29818 m
.23799 .29836 L
s
.23655 .30018 m
.23799 .29836 L
s
.556 1 0 r
.23704 .32988 m
.23939 .33874 L
s
.527 1 0 r
.23704 .30807 m
.23438 .31705 L
s
.498 1 0 r
.23704 .29062 m
.23655 .30018 L
s
.2353 .29817 m
.23655 .30018 L
s
.23655 .30018 m
.23691 .29818 L
s
.527 1 0 r
.23511 .31517 m
.23619 .31566 L
s
.23438 .31705 m
.23619 .31566 L
s
.556 1 0 r
.23774 .33735 m
.23842 .33689 L
s
.23939 .33874 m
.23774 .33735 L
s
.498 1 0 r
.2353 .29817 m
.23691 .29818 L
s
.527 1 0 r
.23363 .31485 m
.23438 .31705 L
s
.23438 .31705 m
.23511 .31517 L
s
.556 1 0 r
.2401 .33658 m
.23939 .33874 L
s
.23842 .33689 m
.23939 .33874 L
s
.527 1 0 r
.23363 .31485 m
.23511 .31517 L
s
.556 1 0 r
.23842 .33689 m
.2401 .33658 L
s
1 .452 0 r
.1462 .60138 m
.14649 .60172 L
s
.14567 .60108 m
.1462 .60138 L
s
.14652 .60082 m
.1462 .60138 L
s
.14432 .60372 m
.14652 .60082 L
s
.14597 .60142 m
.14567 .60108 L
s
.14567 .60108 m
.14652 .60082 L
s
.14649 .60172 m
.14597 .60142 L
s
.14652 .60082 m
.14649 .60172 L
s
.14597 .60142 m
.14652 .60082 L
s
0 .505 1 r
.44259 .66391 m
.45956 .66417 L
s
.577 0 1 r
.44259 .55464 m
.46461 .55536 L
s
0 1 .192 r
.17877 .30048 m
.17619 .30088 L
s
.1795 .29984 m
.17877 .30048 L
s
.17843 .30296 m
.17877 .30048 L
s
.17551 .28995 m
.17843 .30296 L
s
.17619 .30088 m
.17692 .30024 L
s
.17843 .30296 m
.17619 .30088 L
s
0 1 .071 r
.15905 .3391 m
.1581 .33951 L
s
.16137 .33851 m
.15905 .3391 L
s
.16045 .34148 m
.15905 .3391 L
s
0 1 .192 r
.1795 .29984 m
.17843 .30296 L
s
.17692 .30024 m
.17843 .30296 L
s
0 1 .071 r
.16042 .33892 m
.16137 .33851 L
s
.16137 .33851 m
.16045 .34148 L
s
0 1 .192 r
.17692 .30024 m
.1795 .29984 L
s
0 1 .071 r
.16045 .34148 m
.1581 .33951 L
s
.16042 .33892 m
.16045 .34148 L
s
.15689 .32913 m
.16045 .34148 L
s
.022 1 0 r
.1619 .31717 m
.15965 .31668 L
s
.15965 .31668 m
.1588 .31601 L
s
.15965 .31668 m
.15966 .31891 L
s
.1631 .3073 m
.15966 .31891 L
s
0 1 .071 r
.1581 .33951 m
.16042 .33892 L
s
.022 1 0 r
.16105 .3165 m
.1619 .31717 L
s
.15966 .31891 m
.1619 .31717 L
s
0 .505 1 r
.45789 .66398 m
.4562 .6671 L
s
.45611 .66113 m
.45789 .66398 L
s
.45956 .66417 m
.45789 .66398 L
s
0 1 .396 r
.15689 .35541 m
.16273 .36839 L
s
.16258 .36588 m
.15991 .36678 L
s
.16321 .36482 m
.16258 .36588 L
s
.16273 .36839 m
.16258 .36588 L
s
.022 1 0 r
.1588 .31601 m
.15966 .31891 L
s
.15966 .31891 m
.16105 .3165 L
s
.1588 .31601 m
.16105 .3165 L
s
0 1 .396 r
.15991 .36678 m
.16054 .36571 L
s
.16273 .36839 m
.15991 .36678 L
s
.577 0 1 r
.46242 .55516 m
.46013 .55908 L
s
.46024 .55135 m
.46242 .55516 L
s
.46461 .55536 m
.46242 .55516 L
s
0 .505 1 r
.45442 .66425 m
.45611 .66113 L
s
.45611 .66113 m
.45956 .66417 L
s
.4562 .6671 m
.45442 .66425 L
s
.45956 .66417 m
.4562 .6671 L
s
0 1 .396 r
.16321 .36482 m
.16273 .36839 L
s
.16054 .36571 m
.16273 .36839 L
s
.16054 .36571 m
.16321 .36482 L
s
0 .505 1 r
.45442 .66425 m
.45956 .66417 L
s
.577 0 1 r
.46013 .55908 m
.45795 .55528 L
s
.46461 .55536 m
.46013 .55908 L
s
.45795 .55528 m
.46024 .55135 L
s
.46024 .55135 m
.46461 .55536 L
s
0 1 .635 r
.1693 .47988 m
.16689 .48005 L
s
.17149 .47968 m
.1693 .47988 L
s
.16946 .48307 m
.1693 .47988 L
s
0 1 .307 r
.16917 .41252 m
.16727 .41266 L
s
.17132 .41227 m
.16917 .41252 L
s
.16958 .41529 m
.16917 .41252 L
s
.245 1 0 r
.26498 .52286 m
.26763 .53341 L
s
.26812 .53128 m
.26594 .53178 L
s
.26826 .53082 m
.26812 .53128 L
s
.26763 .53341 m
.26812 .53128 L
s
0 1 .42 r
.26554 .63378 m
.27625 .6403 L
s
.245 1 0 r
.26594 .53178 m
.26608 .53131 L
s
.26763 .53341 m
.26594 .53178 L
s
0 1 .307 r
.16942 .41241 m
.17132 .41227 L
s
.17132 .41227 m
.16958 .41529 L
s
.16958 .41529 m
.16727 .41266 L
s
.16942 .41241 m
.16958 .41529 L
s
.16814 .40115 m
.16958 .41529 L
s
0 1 .635 r
.16909 .47985 m
.17149 .47968 L
s
.17149 .47968 m
.16946 .48307 L
s
.16946 .48307 m
.16689 .48005 L
s
.16909 .47985 m
.16946 .48307 L
s
.16814 .46705 m
.16946 .48307 L
s
.16689 .48005 m
.16909 .47985 L
s
.577 0 1 r
.45795 .55528 m
.46461 .55536 L
s
0 1 .307 r
.16727 .41266 m
.16942 .41241 L
s
.245 1 0 r
.26826 .53082 m
.26763 .53341 L
s
.26608 .53131 m
.26763 .53341 L
s
.26608 .53131 m
.26826 .53082 L
s
.384 1 0 r
.27169 .47525 m
.27003 .47526 L
s
.27295 .47526 m
.27169 .47525 L
s
.27169 .47525 m
.27149 .47732 L
s
.533 1 0 r
.27122 .40862 m
.2701 .40861 L
s
.27278 .40863 m
.27122 .40862 L
s
.27122 .40862 m
.27143 .41051 L
s
.305 1 0 r
.27202 .29757 m
.27108 .29732 L
s
.27108 .29732 m
.26918 .29686 L
s
.27108 .29732 m
.27009 .29931 L
s
.533 1 0 r
.27166 .40862 m
.27278 .40863 L
s
.27278 .40863 m
.27143 .41051 L
s
.27143 .41051 m
.27166 .40862 L
s
.27143 .41051 m
.2701 .40861 L
s
.27147 .40105 m
.27143 .41051 L
s
.384 1 0 r
.27003 .47526 m
.27129 .47526 L
s
.27149 .47732 m
.27003 .47526 L
s
.27149 .47732 m
.27129 .47526 L
s
.27295 .47526 m
.27149 .47732 L
s
.27147 .46702 m
.27149 .47732 L
s
.305 1 0 r
.26918 .29686 m
.27011 .29711 L
s
.26918 .29686 m
.27009 .29931 L
s
.384 1 0 r
.27129 .47526 m
.27295 .47526 L
s
0 1 .42 r
.27541 .63891 m
.27341 .64091 L
s
.27481 .63709 m
.27541 .63891 L
s
.27625 .6403 m
.27541 .63891 L
s
.533 1 0 r
.2701 .40861 m
.27166 .40862 L
s
.305 1 0 r
.27009 .29931 m
.27202 .29757 L
s
.27009 .29931 m
.27011 .29711 L
s
.27263 .28885 m
.27009 .29931 L
s
.27011 .29711 m
.27202 .29757 L
s
0 1 .42 r
.27341 .64091 m
.2728 .63908 L
s
.27625 .6403 m
.27341 .64091 L
s
.2728 .63908 m
.27481 .63709 L
s
.27481 .63709 m
.27625 .6403 L
s
1 .539 0 r
.17556 .68841 m
.17861 .68606 L
s
.17828 .6865 m
.17831 .68703 L
s
.17769 .68604 m
.17828 .6865 L
s
.17861 .68606 m
.17828 .6865 L
s
.17772 .68657 m
.17769 .68604 L
s
.17769 .68604 m
.17861 .68606 L
s
0 1 .42 r
.2728 .63908 m
.27625 .6403 L
s
1 .539 0 r
.17831 .68703 m
.17772 .68657 L
s
.17861 .68606 m
.17831 .68703 L
s
.17772 .68657 m
.17861 .68606 L
s
0 .827 1 r
.17929 .5516 m
.18628 .56882 L
s
.447 1 0 r
.28176 .36242 m
.28184 .36195 L
s
.28184 .36195 m
.2799 .36137 L
s
.28184 .36195 m
.28027 .36375 L
s
.2799 .36137 m
.27983 .36185 L
s
.2799 .36137 m
.28027 .36375 L
s
.28027 .36375 m
.28176 .36242 L
s
.28027 .36375 m
.27983 .36185 L
s
.28308 .35447 m
.28027 .36375 L
s
.476 1 0 r
.27959 .30612 m
.28074 .3149 L
s
0 .827 1 r
.18651 .56532 m
.1829 .56658 L
s
.18687 .56417 m
.18651 .56532 L
s
.18628 .56882 m
.18651 .56532 L
s
.629 1 0 r
.28187 .33496 m
.28137 .33508 L
s
.2836 .33516 m
.28187 .33496 L
s
.28187 .33496 m
.28234 .33689 L
s
.2831 .33528 m
.2836 .33516 L
s
.2836 .33516 m
.28234 .33689 L
s
.28234 .33689 m
.2831 .33528 L
s
.28234 .33689 m
.28137 .33508 L
s
.28308 .32801 m
.28234 .33689 L
s
.447 1 0 r
.27983 .36185 m
.28176 .36242 L
s
0 .827 1 r
.1829 .56658 m
.18325 .56543 L
s
.18628 .56882 m
.1829 .56658 L
s
.476 1 0 r
.28013 .31377 m
.27916 .31311 L
s
.28185 .31317 m
.28013 .31377 L
s
.28074 .3149 m
.28013 .31377 L
s
.629 1 0 r
.28137 .33508 m
.2831 .33528 L
s
.476 1 0 r
.28089 .31251 m
.28185 .31317 L
s
.28074 .3149 m
.28185 .31317 L
s
0 1 .022 r
.21224 .29833 m
.21 .29843 L
s
.21347 .298 m
.21224 .29833 L
s
.21199 .30073 m
.21224 .29833 L
s
.476 1 0 r
.27916 .31311 m
.28089 .31251 L
s
.27916 .31311 m
.28074 .3149 L
s
.28089 .31251 m
.28074 .3149 L
s
0 .827 1 r
.18687 .56417 m
.18628 .56882 L
s
.18325 .56543 m
.18628 .56882 L
s
.18325 .56543 m
.18687 .56417 L
s
0 1 .022 r
.21 .29843 m
.21123 .29809 L
s
.21199 .30073 m
.21 .29843 L
s
.2107 .28817 m
.21199 .30073 L
s
.21347 .298 m
.21199 .30073 L
s
.21123 .29809 m
.21199 .30073 L
s
.21123 .29809 m
.21347 .298 L
s
.322 1 0 r
.28819 .55978 m
.29602 .56389 L
s
.2954 .56304 m
.294 .56448 L
s
.2949 .56165 m
.2954 .56304 L
s
.29602 .56389 m
.2954 .56304 L
s
.294 .56448 m
.29351 .56309 L
s
.29602 .56389 m
.294 .56448 L
s
0 1 .142 r
.20117 .33703 m
.19966 .33753 L
s
.20342 .33759 m
.20117 .33703 L
s
.20117 .33703 m
.20136 .34013 L
s
.322 1 0 r
.29351 .56309 m
.2949 .56165 L
s
.2949 .56165 m
.29602 .56389 L
s
.29351 .56309 m
.29602 .56389 L
s
0 1 .142 r
.20136 .34013 m
.20191 .33808 L
s
.20136 .34013 m
.19966 .33753 L
s
.20342 .33759 m
.20136 .34013 L
s
.20225 .32725 m
.20136 .34013 L
s
.20191 .33808 m
.20342 .33759 L
s
0 1 .22 r
.20508 .30534 m
.20397 .3169 L
s
0 1 .142 r
.19966 .33753 m
.20191 .33808 L
s
0 1 .834 r
.20225 .35382 m
.21033 .36792 L
s
0 1 .22 r
.20447 .31567 m
.20223 .31459 L
s
.20615 .31458 m
.20447 .31567 L
s
.20397 .3169 m
.20447 .31567 L
s
0 1 .834 r
.21013 .3652 m
.20702 .36654 L
s
.2104 .36365 m
.21013 .3652 L
s
.21033 .36792 m
.21013 .3652 L
s
0 1 .22 r
.20223 .31459 m
.20392 .3135 L
s
.20223 .31459 m
.20397 .3169 L
s
.20392 .3135 m
.20615 .31458 L
s
.20397 .3169 m
.20615 .31458 L
s
0 1 .834 r
.20702 .36654 m
.20729 .365 L
s
.21033 .36792 m
.20702 .36654 L
s
0 1 .22 r
.20392 .3135 m
.20397 .3169 L
s
0 1 .834 r
.2104 .36365 m
.21033 .36792 L
s
.20729 .365 m
.21033 .36792 L
s
.20729 .365 m
.2104 .36365 L
s
0 1 .293 r
.41092 .66645 m
.42252 .66673 L
s
.369 1 0 r
.41092 .55548 m
.41941 .5557 L
s
.41859 .55564 m
.4177 .55716 L
s
.41772 .55416 m
.41859 .55564 L
s
.41941 .5557 m
.41859 .55564 L
s
.4177 .55716 m
.41683 .55568 L
s
.41941 .5557 m
.4177 .55716 L
s
0 1 .293 r
.42139 .66658 m
.42022 .66872 L
s
.42018 .66463 m
.42139 .66658 L
s
.42252 .66673 m
.42139 .66658 L
s
.369 1 0 r
.41683 .55568 m
.41772 .55416 L
s
.41772 .55416 m
.41941 .5557 L
s
.41683 .55568 m
.41941 .5557 L
s
0 1 .372 r
.24788 .29826 m
.24628 .29829 L
s
.24628 .29829 m
.24375 .29805 L
s
.24628 .29829 m
.24565 .3011 L
s
0 1 .293 r
.419 .66677 m
.42018 .66463 L
s
.42018 .66463 m
.42252 .66673 L
s
.42022 .66872 m
.419 .66677 L
s
.42252 .66673 m
.42022 .66872 L
s
0 1 .372 r
.24375 .29805 m
.24535 .29801 L
s
.24375 .29805 m
.24565 .3011 L
s
0 1 .293 r
.419 .66677 m
.42252 .66673 L
s
0 1 .372 r
.24565 .3011 m
.24788 .29826 L
s
.24565 .3011 m
.24535 .29801 L
s
.24649 .28635 m
.24565 .3011 L
s
.24535 .29801 m
.24788 .29826 L
s
.279 0 1 r
.2304 .52322 m
.23949 .54647 L
s
0 .554 1 r
.23096 .63587 m
.24691 .64285 L
s
0 .728 1 r
.23656 .41541 m
.23399 .41549 L
s
.2397 .41552 m
.23656 .41541 L
s
.23656 .41541 m
.23682 .41951 L
s
0 .369 1 r
.23863 .48408 m
.23437 .48417 L
s
.24 .48415 m
.23863 .48408 L
s
.23863 .48408 m
.23724 .48857 L
s
.279 0 1 r
.23988 .54177 m
.235 .5434 L
s
.24033 .54022 m
.23988 .54177 L
s
.23949 .54647 m
.23988 .54177 L
s
0 .369 1 r
.23437 .48417 m
.23573 .48424 L
s
.23724 .48857 m
.23437 .48417 L
s
.279 0 1 r
.235 .5434 m
.23545 .54186 L
s
.23949 .54647 m
.235 .5434 L
s
0 .728 1 r
.23712 .41561 m
.2397 .41552 L
s
.2397 .41552 m
.23682 .41951 L
s
.23682 .41951 m
.23712 .41561 L
s
.23682 .41951 m
.23399 .41549 L
s
.23694 .3995 m
.23682 .41951 L
s
0 .369 1 r
.23724 .48857 m
.23573 .48424 L
s
.24 .48415 m
.23724 .48857 L
s
.23694 .4665 m
.23724 .48857 L
s
0 .728 1 r
.23399 .41549 m
.23712 .41561 L
s
0 .369 1 r
.23573 .48424 m
.24 .48415 L
s
.279 0 1 r
.24033 .54022 m
.23949 .54647 L
s
.23545 .54186 m
.23949 .54647 L
s
0 .554 1 r
.24553 .64133 m
.24297 .64429 L
s
.24445 .63862 m
.24553 .64133 L
s
.24691 .64285 m
.24553 .64133 L
s
.279 0 1 r
.23545 .54186 m
.24033 .54022 L
s
0 1 .571 r
.24791 .30334 m
.24853 .31703 L
s
0 1 .57 r
.24652 .33686 m
.24503 .3375 L
s
.24937 .3376 m
.24652 .33686 L
s
.24652 .33686 m
.24685 .3406 L
s
.24685 .3406 m
.24789 .33824 L
s
.24685 .3406 m
.24503 .3375 L
s
.24937 .3376 m
.24685 .3406 L
s
.24863 .32532 m
.24685 .3406 L
s
.24789 .33824 m
.24937 .3376 L
s
0 .554 1 r
.24297 .64429 m
.24188 .64157 L
s
.24691 .64285 m
.24297 .64429 L
s
.24188 .64157 m
.24445 .63862 L
s
.24445 .63862 m
.24691 .64285 L
s
0 1 .57 r
.24503 .3375 m
.24789 .33824 L
s
0 1 .818 r
.25069 .3661 m
.24832 .36636 L
s
.25325 .36562 m
.25069 .3661 L
s
.25133 .36944 m
.25069 .3661 L
s
0 1 .571 r
.24824 .31548 m
.24612 .31426 L
s
.2507 .31431 m
.24824 .31548 L
s
.24853 .31703 m
.24824 .31548 L
s
0 .554 1 r
.24188 .64157 m
.24691 .64285 L
s
0 1 .571 r
.24858 .3131 m
.2507 .31431 L
s
.24853 .31703 m
.2507 .31431 L
s
0 1 .818 r
.25088 .36588 m
.25325 .36562 L
s
.25325 .36562 m
.25133 .36944 L
s
.25133 .36944 m
.24832 .36636 L
s
.25088 .36588 m
.25133 .36944 L
s
.24863 .3522 m
.25133 .36944 L
s
.24832 .36636 m
.25088 .36588 L
s
0 1 .571 r
.24612 .31426 m
.24858 .3131 L
s
.24612 .31426 m
.24853 .31703 L
s
.24858 .3131 m
.24853 .31703 L
s
.609 0 1 r
.25377 .56071 m
.27482 .57021 L
s
.27301 .56823 m
.26955 .57206 L
s
.27165 .56455 m
.27301 .56823 L
s
.27482 .57021 m
.27301 .56823 L
s
.26955 .57206 m
.26818 .56838 L
s
.27482 .57021 m
.26955 .57206 L
s
.26818 .56838 m
.27165 .56455 L
s
.27165 .56455 m
.27482 .57021 L
s
.26818 .56838 m
.27482 .57021 L
s
0 1 .293 r
.37826 .66908 m
.3901 .66936 L
s
.369 1 0 r
.37826 .55636 m
.38697 .55658 L
s
.3861 .55651 m
.38521 .55806 L
s
.38524 .55501 m
.3861 .55651 L
s
.38697 .55658 m
.3861 .55651 L
s
0 1 .293 r
.38893 .6692 m
.38775 .67138 L
s
.38771 .66722 m
.38893 .6692 L
s
.3901 .66936 m
.38893 .6692 L
s
.369 1 0 r
.38521 .55806 m
.38435 .55656 L
s
.38697 .55658 m
.38521 .55806 L
s
.38435 .55656 m
.38524 .55501 L
s
.38524 .55501 m
.38697 .55658 L
s
.38435 .55656 m
.38697 .55658 L
s
0 .043 1 r
.59103 .66943 m
.61149 .6697 L
s
1 0 .801 r
.59103 .55648 m
.61771 .55708 L
s
0 1 .293 r
.38653 .6694 m
.38771 .66722 L
s
.38771 .66722 m
.3901 .66936 L
s
.38775 .67138 m
.38653 .6694 L
s
.3901 .66936 m
.38775 .67138 L
s
.38653 .6694 m
.3901 .66936 L
s
0 .043 1 r
.60925 .66949 m
.60745 .67313 L
s
.60732 .66617 m
.60925 .66949 L
s
.61149 .6697 m
.60925 .66949 L
s
1 0 .801 r
.61476 .55689 m
.61232 .56148 L
s
.61238 .55244 m
.61476 .55689 L
s
.61771 .55708 m
.61476 .55689 L
s
0 .043 1 r
.60552 .66981 m
.60732 .66617 L
s
.60732 .66617 m
.61149 .6697 L
s
.60745 .67313 m
.60552 .66981 L
s
.61149 .6697 m
.60745 .67313 L
s
.60552 .66981 m
.61149 .6697 L
s
1 0 .801 r
.61232 .56148 m
.60994 .55703 L
s
.61771 .55708 m
.61232 .56148 L
s
.60994 .55703 m
.61238 .55244 L
s
.61238 .55244 m
.61771 .55708 L
s
.60994 .55703 m
.61771 .55708 L
s
0 .505 1 r
.34455 .67178 m
.36238 .67204 L
s
.577 0 1 r
.34455 .55726 m
.36758 .55802 L
s
0 1 .486 r
.56066 .67215 m
.57405 .67245 L
s
.145 1 0 r
.56066 .55738 m
.57088 .55756 L
s
0 .505 1 r
.36062 .67184 m
.35885 .67512 L
s
.35875 .66886 m
.36062 .67184 L
s
.36238 .67204 m
.36062 .67184 L
s
.577 0 1 r
.36531 .5578 m
.3629 .56192 L
s
.36301 .55382 m
.36531 .5578 L
s
.36758 .55802 m
.36531 .5578 L
s
0 .505 1 r
.35699 .67214 m
.35875 .66886 L
s
.35875 .66886 m
.36238 .67204 L
s
.35885 .67512 m
.35699 .67214 L
s
.36238 .67204 m
.35885 .67512 L
s
.145 1 0 r
.56978 .5575 m
.56883 .55927 L
s
.56884 .55578 m
.56978 .5575 L
s
.57088 .55756 m
.56978 .5575 L
s
0 1 .486 r
.5726 .67228 m
.57139 .67467 L
s
.57134 .67011 m
.5726 .67228 L
s
.57405 .67245 m
.5726 .67228 L
s
0 .505 1 r
.35699 .67214 m
.36238 .67204 L
s
.145 1 0 r
.56883 .55927 m
.56788 .55755 L
s
.57088 .55756 m
.56883 .55927 L
s
.56788 .55755 m
.56884 .55578 L
s
.56884 .55578 m
.57088 .55756 L
s
.577 0 1 r
.3629 .56192 m
.3606 .55794 L
s
.36758 .55802 m
.3629 .56192 L
s
.3606 .55794 m
.36301 .55382 L
s
.36301 .55382 m
.36758 .55802 L
s
.145 1 0 r
.56788 .55755 m
.57088 .55756 L
s
0 1 .486 r
.57013 .6725 m
.57134 .67011 L
s
.57134 .67011 m
.57405 .67245 L
s
.57139 .67467 m
.57013 .6725 L
s
.57405 .67245 m
.57139 .67467 L
s
.57013 .6725 m
.57405 .67245 L
s
.577 0 1 r
.3606 .55794 m
.36758 .55802 L
s
1 0 .121 r
.69503 .56858 m
.72406 .55501 L
s
.72085 .55765 m
.71996 .56257 L
s
.7165 .55291 m
.72085 .55765 L
s
.72406 .55501 m
.72085 .55765 L
s
.7156 .55782 m
.7165 .55291 L
s
.7165 .55291 m
.72406 .55501 L
s
.71996 .56257 m
.7156 .55782 L
s
.72406 .55501 m
.71996 .56257 L
s
1 0 .132 r
.73383 .27901 m
.73673 .27851 L
s
.72704 .27885 m
.73383 .27901 L
s
.73383 .27901 m
.73187 .27138 L
s
1 0 .121 r
.7156 .55782 m
.72406 .55501 L
s
1 0 .293 r
.73433 .40763 m
.73618 .40746 L
s
.72738 .40764 m
.73433 .40763 L
s
.73433 .40763 m
.73174 .40044 L
s
.72922 .40746 m
.72738 .40764 L
s
.72738 .40764 m
.73174 .40044 L
s
.58 0 1 r
.72791 .6554 m
.75093 .64497 L
s
1 0 .132 r
.72992 .27835 m
.72704 .27885 L
s
.72704 .27885 m
.73187 .27138 L
s
1 0 .293 r
.73191 .43595 m
.73174 .40044 L
s
1 0 .132 r
.73191 .30786 m
.73187 .27138 L
s
.73187 .27138 m
.72992 .27835 L
s
.73187 .27138 m
.73673 .27851 L
s
1 0 .293 r
.73174 .40044 m
.72922 .40746 L
s
.73174 .40044 m
.73618 .40746 L
s
1 0 .132 r
.73673 .27851 m
.72992 .27835 L
s
1 0 .293 r
.73618 .40746 m
.72922 .40746 L
s
1 0 0 r
.73722 .53034 m
.74934 .49577 L
s
0 1 .486 r
.5293 .67496 m
.54295 .67526 L
s
.145 1 0 r
.5293 .55832 m
.53975 .5585 L
s
1 0 0 r
.74964 .5027 m
.75118 .50471 L
s
.74264 .50069 m
.74964 .5027 L
s
.74934 .49577 m
.74964 .5027 L
s
.58 0 1 r
.74836 .6469 m
.7477 .65091 L
s
.74491 .64323 m
.74836 .6469 L
s
.75093 .64497 m
.74836 .6469 L
s
1 0 0 r
.74417 .5027 m
.74264 .50069 L
s
.74264 .50069 m
.74934 .49577 L
s
.58 0 1 r
.74424 .64723 m
.74491 .64323 L
s
.74491 .64323 m
.75093 .64497 L
s
.145 1 0 r
.5386 .55843 m
.53765 .56023 L
s
.53766 .55669 m
.5386 .55843 L
s
.53975 .5585 m
.5386 .55843 L
s
0 1 .486 r
.54146 .67509 m
.54024 .67752 L
s
.54019 .67288 m
.54146 .67509 L
s
.54295 .67526 m
.54146 .67509 L
s
.145 1 0 r
.53765 .56023 m
.53671 .55849 L
s
.53975 .5585 m
.53765 .56023 L
s
.53671 .55849 m
.53766 .55669 L
s
.53766 .55669 m
.53975 .5585 L
s
.58 0 1 r
.7477 .65091 m
.74424 .64723 L
s
.75093 .64497 m
.7477 .65091 L
s
1 0 0 r
.74934 .49577 m
.75118 .50471 L
s
.74417 .5027 m
.74934 .49577 L
s
.145 1 0 r
.53671 .55849 m
.53975 .5585 L
s
0 1 .486 r
.53897 .67531 m
.54019 .67288 L
s
.54019 .67288 m
.54295 .67526 L
s
.54024 .67752 m
.53897 .67531 L
s
.54295 .67526 m
.54024 .67752 L
s
.58 0 1 r
.74424 .64723 m
.75093 .64497 L
s
1 0 0 r
.75118 .50471 m
.74417 .5027 L
s
0 1 .486 r
.53897 .67531 m
.54295 .67526 L
s
0 1 .037 r
.66567 .56971 m
.67688 .56585 L
s
.67561 .56658 m
.67513 .56848 L
s
.67414 .56476 m
.67561 .56658 L
s
.67688 .56585 m
.67561 .56658 L
s
.67366 .56666 m
.67414 .56476 L
s
.67414 .56476 m
.67688 .56585 L
s
.67513 .56848 m
.67366 .56666 L
s
.67688 .56585 m
.67513 .56848 L
s
.67366 .56666 m
.67688 .56585 L
s
1 .49 0 r
.78675 .71755 m
.78717 .71697 L
s
.78717 .71697 m
.78725 .71648 L
s
.78717 .71697 m
.78627 .71663 L
s
.78627 .71663 m
.78675 .71755 L
s
.78725 .71648 m
.78627 .71663 L
s
.78627 .71663 m
.78684 .71706 L
s
.78993 .71855 m
.78627 .71663 L
s
.78684 .71706 m
.78675 .71755 L
s
.78725 .71648 m
.78684 .71706 L
s
0 1 .72 r
.69887 .65797 m
.71371 .65331 L
s
.135 1 0 r
.70144 .29453 m
.70183 .2947 L
s
.70183 .2947 m
.70435 .29465 L
s
.70183 .2947 m
.70289 .29207 L
s
.202 1 0 r
.70136 .42513 m
.70192 .42517 L
s
.70192 .42517 m
.70433 .42514 L
s
.70192 .42517 m
.70283 .42269 L
s
.135 1 0 r
.70435 .29465 m
.70397 .29449 L
s
.70435 .29465 m
.70289 .29207 L
s
.202 1 0 r
.70433 .42514 m
.70377 .42509 L
s
.70433 .42514 m
.70283 .42269 L
s
.70292 .43489 m
.70283 .42269 L
s
.135 1 0 r
.70292 .30468 m
.70289 .29207 L
s
.70289 .29207 m
.70144 .29453 L
s
.70289 .29207 m
.70397 .29449 L
s
.202 1 0 r
.70283 .42269 m
.70136 .42513 L
s
.70283 .42269 m
.70377 .42509 L
s
.70377 .42509 m
.70136 .42513 L
s
.135 1 0 r
.70397 .29449 m
.70144 .29453 L
s
0 1 .72 r
.71201 .65413 m
.71137 .65671 L
s
.71009 .65178 m
.71201 .65413 L
s
.71371 .65331 m
.71201 .65413 L
s
.073 1 0 r
.70828 .53085 m
.71275 .51891 L
s
.71278 .52129 m
.71335 .52204 L
s
.71037 .52056 m
.71278 .52129 L
s
.71275 .51891 m
.71278 .52129 L
s
0 1 .72 r
.70945 .65435 m
.71009 .65178 L
s
.71009 .65178 m
.71371 .65331 L
s
.073 1 0 r
.71094 .52131 m
.71037 .52056 L
s
.71037 .52056 m
.71275 .51891 L
s
0 .043 1 r
.4969 .67785 m
.51837 .67814 L
s
1 0 .801 r
.4969 .55928 m
.52476 .55993 L
s
0 1 .72 r
.71137 .65671 m
.70945 .65435 L
s
.71371 .65331 m
.71137 .65671 L
s
.073 1 0 r
.71275 .51891 m
.71335 .52204 L
s
.71094 .52131 m
.71275 .51891 L
s
.71335 .52204 m
.71094 .52131 L
s
0 1 .72 r
.70945 .65435 m
.71371 .65331 L
s
.714 0 1 r
.82528 .56955 m
.83488 .54159 L
s
.8351 .54714 m
.83647 .54881 L
s
.82945 .54559 m
.8351 .54714 L
s
.83488 .54159 m
.8351 .54714 L
s
.83081 .54725 m
.82945 .54559 L
s
.82945 .54559 m
.83488 .54159 L
s
0 .043 1 r
.51602 .6779 m
.51412 .68173 L
s
.51399 .67443 m
.51602 .6779 L
s
.51837 .67814 m
.51602 .6779 L
s
1 0 .801 r
.52172 .55972 m
.51913 .56454 L
s
.51919 .55505 m
.52172 .55972 L
s
.52476 .55993 m
.52172 .55972 L
s
0 .043 1 r
.51209 .67827 m
.51399 .67443 L
s
.51399 .67443 m
.51837 .67814 L
s
.51412 .68173 m
.51209 .67827 L
s
.51837 .67814 m
.51412 .68173 L
s
.714 0 1 r
.83488 .54159 m
.83647 .54881 L
s
.83081 .54725 m
.83488 .54159 L
s
.83647 .54881 m
.83081 .54725 L
s
0 .043 1 r
.51209 .67827 m
.51837 .67814 L
s
1 0 .801 r
.51913 .56454 m
.5166 .55988 L
s
.52476 .55993 m
.51913 .56454 L
s
.5166 .55988 m
.51919 .55505 L
s
.51919 .55505 m
.52476 .55993 L
s
.5166 .55988 m
.52476 .55993 L
s
0 1 .037 r
.63532 .57087 m
.64661 .56695 L
s
.745 0 1 r
.8582 .27818 m
.86286 .27839 L
s
.86286 .27839 m
.86698 .27796 L
s
.86286 .27839 m
.86252 .27197 L
s
.571 0 1 r
.85791 .41074 m
.86215 .41073 L
s
.86215 .41073 m
.86639 .41046 L
s
.86215 .41073 m
.86197 .40471 L
s
0 1 .037 r
.64537 .5677 m
.64485 .56963 L
s
.64385 .56584 m
.64537 .5677 L
s
.64661 .56695 m
.64537 .5677 L
s
.64333 .56777 m
.64385 .56584 L
s
.64385 .56584 m
.64661 .56695 L
s
.64485 .56963 m
.64333 .56777 L
s
.64661 .56695 m
.64485 .56963 L
s
.745 0 1 r
.86232 .27775 m
.8582 .27818 L
s
.86252 .27197 m
.8582 .27818 L
s
.571 0 1 r
.86216 .41048 m
.85791 .41074 L
s
.86197 .40471 m
.85791 .41074 L
s
0 1 .037 r
.64333 .56777 m
.64661 .56695 L
s
.571 0 1 r
.86639 .41046 m
.86197 .40471 L
s
.86197 .40471 m
.86216 .41048 L
s
.86287 .43417 m
.86197 .40471 L
s
.745 0 1 r
.86698 .27796 m
.86252 .27197 L
s
.86252 .27197 m
.86232 .27775 L
s
.86287 .30251 m
.86252 .27197 L
s
.571 0 1 r
.86639 .41046 m
.86216 .41048 L
s
.745 0 1 r
.86698 .27796 m
.86232 .27775 L
s
1 0 0 r
.76154 .72221 m
.7625 .72159 L
s
.76238 .7217 m
.7624 .72187 L
s
.76223 .72156 m
.76238 .7217 L
s
.7625 .72159 m
.76238 .7217 L
s
.76224 .72173 m
.76223 .72156 L
s
.76223 .72156 m
.7625 .72159 L
s
.7624 .72187 m
.76224 .72173 L
s
.7625 .72159 m
.7624 .72187 L
s
.76224 .72173 m
.7625 .72159 L
s
0 1 .72 r
.66886 .66062 m
.68394 .65588 L
s
.202 1 0 r
.67302 .42394 m
.67473 .42387 L
s
.67118 .42388 m
.67302 .42394 L
s
.67295 .42139 m
.67302 .42394 L
s
.135 1 0 r
.67316 .29127 m
.67478 .29112 L
s
.67113 .29116 m
.67316 .29127 L
s
.67295 .28857 m
.67316 .29127 L
s
1 .507 0 r
.88886 .66516 m
.88947 .66472 L
s
.88947 .66472 m
.88978 .66434 L
s
.88947 .66472 m
.88875 .66408 L
s
.135 1 0 r
.67275 .29101 m
.67113 .29116 L
s
.67295 .28857 m
.67113 .29116 L
s
.202 1 0 r
.67289 .42381 m
.67118 .42388 L
s
.67295 .42139 m
.67118 .42388 L
s
.67289 .42381 m
.67295 .42139 L
s
.67473 .42387 m
.67295 .42139 L
s
.67295 .4338 m
.67295 .42139 L
s
.135 1 0 r
.67275 .29101 m
.67295 .28857 L
s
.67478 .29112 m
.67295 .28857 L
s
.67295 .3014 m
.67295 .28857 L
s
1 .507 0 r
.88875 .66408 m
.88886 .66516 L
s
.88978 .66434 m
.88875 .66408 L
s
.88875 .66408 m
.88918 .66478 L
s
.89162 .66742 m
.88875 .66408 L
s
.88918 .66478 m
.88886 .66516 L
s
.202 1 0 r
.67473 .42387 m
.67289 .42381 L
s
.135 1 0 r
.67478 .29112 m
.67275 .29101 L
s
1 .507 0 r
.88978 .66434 m
.88918 .66478 L
s
0 1 .72 r
.68221 .65672 m
.68156 .65934 L
s
.68026 .65433 m
.68221 .65672 L
s
.68394 .65588 m
.68221 .65672 L
s
.073 1 0 r
.67836 .53137 m
.68288 .51923 L
s
.68293 .52165 m
.68348 .52241 L
s
.68047 .52091 m
.68293 .52165 L
s
.68288 .51923 m
.68293 .52165 L
s
0 1 .72 r
.67961 .65695 m
.68026 .65433 L
s
.68026 .65433 m
.68394 .65588 L
s
.073 1 0 r
.68102 .52167 m
.68047 .52091 L
s
.68047 .52091 m
.68288 .51923 L
s
0 1 .72 r
.68156 .65934 m
.67961 .65695 L
s
.68394 .65588 m
.68156 .65934 L
s
.073 1 0 r
.68288 .51923 m
.68348 .52241 L
s
.68102 .52167 m
.68288 .51923 L
s
.68348 .52241 m
.68102 .52167 L
s
0 1 .72 r
.67961 .65695 m
.68394 .65588 L
s
0 1 .572 r
.79727 .57073 m
.80378 .55519 L
s
.80367 .55826 m
.80445 .55938 L
s
.80051 .55722 m
.80367 .55826 L
s
.80378 .55519 m
.80367 .55826 L
s
.80129 .55834 m
.80051 .55722 L
s
.80051 .55722 m
.80378 .55519 L
s
.80378 .55519 m
.80445 .55938 L
s
.80129 .55834 m
.80378 .55519 L
s
.80445 .55938 m
.80129 .55834 L
s
1 0 .121 r
.60394 .57207 m
.63432 .55781 L
s
0 1 .355 r
.83277 .42026 m
.83519 .42027 L
s
.83519 .42027 m
.83737 .42016 L
s
.83519 .42027 m
.83502 .417 L
s
0 1 .426 r
.83285 .28602 m
.83556 .28612 L
s
.83556 .28612 m
.83753 .28589 L
s
.83556 .28612 m
.83516 .28265 L
s
.83481 .28579 m
.83285 .28602 L
s
.83516 .28265 m
.83285 .28602 L
s
0 1 .355 r
.83494 .42015 m
.83277 .42026 L
s
.83502 .417 m
.83277 .42026 L
s
.83737 .42016 m
.83502 .417 L
s
.83502 .417 m
.83494 .42015 L
s
.83528 .43305 m
.83502 .417 L
s
0 1 .426 r
.83753 .28589 m
.83516 .28265 L
s
.83516 .28265 m
.83481 .28579 L
s
.83528 .29915 m
.83516 .28265 L
s
0 1 .355 r
.83737 .42016 m
.83494 .42015 L
s
0 1 .426 r
.83753 .28589 m
.83481 .28579 L
s
1 0 .121 r
.63098 .56059 m
.63002 .56575 L
s
.6264 .55561 m
.63098 .56059 L
s
.63432 .55781 m
.63098 .56059 L
s
1 0 0 r
.73219 .72599 m
.73307 .72538 L
s
.73299 .72549 m
.73297 .72566 L
s
.73281 .72535 m
.73299 .72549 L
s
.73307 .72538 m
.73299 .72549 L
s
.73279 .72551 m
.73281 .72535 L
s
.73281 .72535 m
.73307 .72538 L
s
.73297 .72566 m
.73279 .72551 L
s
.73307 .72538 m
.73297 .72566 L
s
.73279 .72551 m
.73307 .72538 L
s
1 0 .121 r
.62543 .56077 m
.6264 .55561 L
s
.6264 .55561 m
.63432 .55781 L
s
.63002 .56575 m
.62543 .56077 L
s
.63432 .55781 m
.63002 .56575 L
s
.62543 .56077 m
.63432 .55781 L
s
1 0 .293 r
.64477 .40301 m
.64672 .40272 L
s
.63748 .40291 m
.64477 .40301 L
s
.64213 .39535 m
.64477 .40301 L
s
1 0 .132 r
.6454 .26767 m
.64633 .26705 L
s
.63771 .26761 m
.6454 .26767 L
s
.64203 .25966 m
.6454 .26767 L
s
.63862 .26699 m
.63771 .26761 L
s
.64203 .25966 m
.63771 .26761 L
s
1 0 .293 r
.63942 .40262 m
.63748 .40291 L
s
.64213 .39535 m
.63748 .40291 L
s
.58 0 1 r
.63782 .66337 m
.66204 .65241 L
s
1 0 .293 r
.63942 .40262 m
.64213 .39535 L
s
.64672 .40272 m
.64213 .39535 L
s
.64196 .43267 m
.64213 .39535 L
s
1 0 .132 r
.63862 .26699 m
.64203 .25966 L
s
.64633 .26705 m
.64203 .25966 L
s
.64196 .298 m
.64203 .25966 L
s
1 .128 0 r
.8635 .66885 m
.86387 .66873 L
s
.86387 .66873 m
.864 .66863 L
s
.86387 .66873 m
.8636 .66836 L
s
.86363 .66876 m
.8635 .66885 L
s
.8636 .66836 m
.8635 .66885 L
s
.864 .66863 m
.8636 .66836 L
s
.8636 .66836 m
.86363 .66876 L
s
.86436 .67028 m
.8636 .66836 L
s
.864 .66863 m
.86363 .66876 L
s
1 0 .293 r
.64672 .40272 m
.63942 .40262 L
s
1 0 .132 r
.64633 .26705 m
.63862 .26699 L
s
1 0 0 r
.64742 .5319 m
.66037 .49555 L
s
.66049 .50283 m
.66234 .50496 L
s
.65322 .50072 m
.66049 .50283 L
s
.66037 .49555 m
.66049 .50283 L
s
.58 0 1 r
.65932 .65442 m
.65864 .65864 L
s
.65571 .65057 m
.65932 .65442 L
s
.66204 .65241 m
.65932 .65442 L
s
1 0 0 r
.65505 .50284 m
.65322 .50072 L
s
.65322 .50072 m
.66037 .49555 L
s
.58 0 1 r
.65502 .6548 m
.65571 .65057 L
s
.65571 .65057 m
.66204 .65241 L
s
0 1 .572 r
.7683 .57194 m
.77498 .55613 L
s
.58 0 1 r
.65864 .65864 m
.65502 .6548 L
s
.66204 .65241 m
.65864 .65864 L
s
0 1 .572 r
.77482 .55926 m
.77566 .5604 L
s
.77162 .5582 m
.77482 .55926 L
s
.77498 .55613 m
.77482 .55926 L
s
1 0 0 r
.66037 .49555 m
.66234 .50496 L
s
.65505 .50284 m
.66037 .49555 L
s
0 1 .572 r
.77247 .55934 m
.77162 .5582 L
s
.77162 .5582 m
.77498 .55613 L
s
.58 0 1 r
.65502 .6548 m
.66204 .65241 L
s
1 0 0 r
.66234 .50496 m
.65505 .50284 L
s
0 1 .572 r
.77498 .55613 m
.77566 .5604 L
s
.77247 .55934 m
.77498 .55613 L
s
.77566 .5604 m
.77247 .55934 L
s
0 1 .355 r
.80516 .41893 m
.80845 .41887 L
s
.80476 .4188 m
.80516 .41893 L
s
.80657 .41557 m
.80516 .41893 L
s
0 1 .426 r
.805 .28241 m
.8084 .28236 L
s
.80494 .28214 m
.805 .28241 L
s
.80665 .2789 m
.805 .28241 L
s
.8084 .28236 m
.80835 .2821 L
s
.8084 .28236 m
.80665 .2789 L
s
0 1 .355 r
.80845 .41887 m
.80805 .41874 L
s
.80845 .41887 m
.80657 .41557 L
s
.80805 .41874 m
.80657 .41557 L
s
.80657 .41557 m
.80476 .4188 L
s
.80674 .43189 m
.80657 .41557 L
s
0 1 .426 r
.80835 .2821 m
.80665 .2789 L
s
.80665 .2789 m
.80494 .28214 L
s
.80674 .29567 m
.80665 .2789 L
s
0 1 .355 r
.80805 .41874 m
.80476 .4188 L
s
0 1 .426 r
.80835 .2821 m
.80494 .28214 L
s
1 .49 0 r
.69886 .72778 m
.69925 .72876 L
s
.69965 .72765 m
.69886 .72778 L
s
.69886 .72778 m
.69903 .72824 L
s
.69987 .72817 m
.69886 .72778 L
s
.70182 .72991 m
.69886 .72778 L
s
.69925 .72876 m
.69987 .72817 L
s
.69987 .72817 m
.69965 .72765 L
s
.69903 .72824 m
.69925 .72876 L
s
.69965 .72765 m
.69903 .72824 L
s
1 .128 0 r
.83533 .67178 m
.83572 .67166 L
s
.83572 .67166 m
.83581 .67157 L
s
.83572 .67166 m
.83542 .67128 L
s
.83541 .67169 m
.83533 .67178 L
s
.83542 .67128 m
.83533 .67178 L
s
.83581 .67157 m
.83542 .67128 L
s
.83542 .67128 m
.83541 .67169 L
s
.83615 .67325 m
.83542 .67128 L
s
.83581 .67157 m
.83541 .67169 L
s
.714 0 1 r
.73833 .5732 m
.7487 .54377 L
s
.74866 .5496 m
.75041 .55135 L
s
.74283 .54797 m
.74866 .5496 L
s
.7487 .54377 m
.74866 .5496 L
s
.74458 .54973 m
.74283 .54797 L
s
.74283 .54797 m
.7487 .54377 L
s
.7487 .54377 m
.75041 .55135 L
s
.74458 .54973 m
.7487 .54377 L
s
.75041 .55135 m
.74458 .54973 L
s
.571 0 1 r
.77422 .40615 m
.78041 .40597 L
s
.7731 .40583 m
.77422 .40615 L
s
.77665 .3997 m
.77422 .40615 L
s
.745 0 1 r
.77414 .26672 m
.78062 .26656 L
s
.77338 .26617 m
.77414 .26672 L
s
.77696 .25994 m
.77414 .26672 L
s
.571 0 1 r
.78041 .40597 m
.7793 .40564 L
s
.78041 .40597 m
.77665 .3997 L
s
.745 0 1 r
.78062 .26656 m
.77987 .26601 L
s
.78062 .26656 m
.77696 .25994 L
s
.571 0 1 r
.7793 .40564 m
.77665 .3997 L
s
.77665 .3997 m
.7731 .40583 L
s
.77719 .43069 m
.77665 .3997 L
s
.745 0 1 r
.77987 .26601 m
.77696 .25994 L
s
.77696 .25994 m
.77338 .26617 L
s
.77719 .29207 m
.77696 .25994 L
s
.571 0 1 r
.7793 .40564 m
.7731 .40583 L
s
.745 0 1 r
.77987 .26601 m
.77338 .26617 L
s
1 .507 0 r
.8047 .67387 m
.8055 .67343 L
s
.8055 .67343 m
.80544 .67303 L
s
.8055 .67343 m
.8046 .67274 L
s
.8046 .67274 m
.8047 .67387 L
s
.80544 .67303 m
.8046 .67274 L
s
.8046 .67274 m
.80463 .67348 L
s
.80693 .67632 m
.8046 .67274 L
s
.80463 .67348 m
.8047 .67387 L
s
.80544 .67303 m
.80463 .67348 L
s
0 g
.001 w
[ .01 .01 ] 0 setdash
.12216 .26004 m
.82382 .21884 L
s
.82382 .21884 m
.82382 .78116 L
s
.82382 .78116 m
.12216 .73996 L
s
.12216 .73996 m
.12216 .26004 L
s
.91768 .23473 m
.82382 .21884 L
s
.82382 .21884 m
.82382 .78116 L
s
.82382 .78116 m
.91768 .76527 L
s
.91768 .76527 m
.91768 .23473 L
s
.003 w
[ ] 0 setdash
.91768 .23473 m
.82382 .21884 L
s
.25 Mabswid
.91564 .23439 m
.91564 .24064 L
s
gsave
.91564 .22189 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.89418 .23076 m
.89418 .23701 L
s
gsave
.89418 .21826 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87211 .22702 m
.87211 .23327 L
s
gsave
.87211 .21452 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.84943 .22318 m
.84943 .22943 L
s
gsave
.84943 .21068 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.8261 .21923 m
.8261 .22548 L
s
gsave
.8261 .20673 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.9114 .23367 m
.9114 .23742 L
s
.90713 .23295 m
.90713 .2367 L
s
.90283 .23222 m
.90283 .23597 L
s
.89852 .23149 m
.89852 .23524 L
s
.88981 .23002 m
.88981 .23377 L
s
.88542 .22927 m
.88542 .23302 L
s
.88101 .22853 m
.88101 .23228 L
s
.87657 .22778 m
.87657 .23153 L
s
.86763 .22626 m
.86763 .23001 L
s
.86312 .2255 m
.86312 .22925 L
s
.85858 .22473 m
.85858 .22848 L
s
.85402 .22396 m
.85402 .22771 L
s
.84482 .2224 m
.84482 .22615 L
s
.84018 .22161 m
.84018 .22536 L
s
.83551 .22082 m
.83551 .22457 L
s
.83082 .22003 m
.83082 .22378 L
s
gsave
.87211 .15202 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00>Ioo`<0009oo`<0039oo`00igoo00<007ooOol00Woo00<007ooOol0<Goo003XOol01000Oomo
o`00=7oo001fOol3001`Ool2000eOol007Moo`03001oogoo071oo`03001oogoo03=oo`00Mgoo00<0
07ooOol0Kgoo0P00=Goo001gOol00`00Oomoo`1^Ool01000Oomoo`00=7oo001fOol00`00Ool0001^
Ool00`00Oomoo`02Ool00`00Oomoo`0aOol007Ioo`03001oo`0006eoo`<0009oo`<0039oo`00MWoo
00@007ooOol00:Ioo`00MGoo00<007ooOol00Woo00<007ooOol0Xgoo001dOol30002Ool3002TOol0
0?moob5oo`00ogoo8Goo003JOol50002Ool3000lOol00<eoo`<0009oo`<000Aoo`<0009oo`03001o
o`0000@0009oo`<003Ioo`00cWoo00<007ooOol017oo00@007ooOol000=oo`0;001oogooOol007oo
001oo`00Ool00003Ool00`00Oomoo`0cOol00<ioo`03001oogoo00Eoo`03001oo`0000=oo`80009o
o`07001oo`00Ool007oo00000goo0`00<goo002DOol30003Ool30003Ool3000[Ool00`00Oomoo`05
Ool00`00Ool00003Ool02`00Ool007oo001oo`00Ool007oo00000Woo0P000Woo00@007ooOomoo`<0
009oo`D0009oo`<0021oo`00UGoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo02Qo
o`03001oogoo00Eoo`03001oo`0000=oo`0;001oo`00Ool007oo001oo`00Ool00002Ool20002Ool0
0`00Oomoo`02Ool01000Oomoogoo0P000Woo00<007oo00000goo00<007ooOol07Goo002EOol01@00
Oomoogoo00000goo00<007oo00000goo00<007ooOol0:7oo00<007ooOol017oo00@007ooOol000=o
o`0;001oo`00Ool007oo001oo`00Ool00002Ool20002Ool00`00Oomoo`02Ool02`00Oomoogoo001o
o`00Ool007oo00000goo00<007ooOol07Goo001QOol30004Ool3000ZOol01@00Oomoogoo00000goo
00<007oo00000goo00<007ooOol0:7oo00<007ooOol00Woo0P000goo00l007oo001oo`00Ool007oo
001oo`00Ool007oo00000Woo3P000Woo0P0000=oo`00Ool00Woo00<007ooOol07Goo001TOol01000
Oomoo`000goo00<007ooOol09goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo02Mo
o`8000Aoo`03001oogoo009oo`03001oogoo00<000=oo`<0009oo`03001oogoo0080009oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0MOol006Eoo`03001oo`00
00=oo`03001oogoo02Moo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0XOol00`00
Oomoo`03Ool30002Ool30006Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007oo00000goo00<007ooOol07Goo000eOol3000]Ool00`00Ool00003Ool00`00Oomo
o`0WOol01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol0@goo00D007ooOomoo`0000Ao
o`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0MOol003Aoo`05001oogooOol0000/
Ool00`00Ool00003Ool00`00Oomoo`0VOol20003Ool01`00Oomoogoo001oo`0000=oo`03001oogoo
04Aoo`<000Aoo`8000=oo`07001oogooOol007oo00000goo00<007ooOol07Goo000dOol01@00Oomo
ogoo0000:goo00@007ooOol000=oo`03001oogoo02Moo`03001oogoo009oo`<000=oo`<004moo`03
001oogoo009oo`<000=oo`<0021oo`00=7oo00D007ooOomoo`0002Uoo`8000=oo`05001oogooOol0
001[Ool;000nOol003Aoo`05001oogooOol0000YOol00`00Oomoo`02Ool01@00Oomoogoo0000FWoo
4P0000=oo`0000000P000Woo2@00>7oo000dOol01@00Oomoogoo0000:Woo0`000Woo0`00BWoo4`00
00=oo`0000002Woo00<007ooOol01goo0`0000=oo`0000002000<goo000dOol01@00Oomoogoo0000
Jgoo4`000Woo0P000goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
17oo00<007oo00002P00;Goo000dOol01@00Oomoogoo0000FWoo5@0000=oo`0000001goo00<007oo
Ool0=goo00<007oo00002P001Woo0`007Woo000eOol3001:OolA000017oo000000001Goo00<007oo
Ool027oo00<007ooOol0?Woo0P0000=oo`0000000P000Woo2@0017oo00D007ooOomoo`0001eoo`00
L7oo4P0000=oo`0000000P002Woo00<007ooOol027oo00<007ooOol0=goo100000=oo`0000000`00
00Aoo`000000009oo`80011oo`8000Aoo`05001oogooOol0000MOol005mooa<00003Ool0000000Mo
o`03001oogoo00Moo`03001oogoo03Uoo`80009oo`<0009oo`@00003Ool00000008000]oo`03001o
ogoo01Moo`03001oogoo009oo`05001oogooOol0000MOol004iooa@00003Ool00000009oo`03001o
ogoo00Moo`03001oogoo03aoo`@0009oo`<0009oo`@00003Ool0000001eoo`03001oogoo01Moo`03
001oogoo009oo`05001oogooOol0000MOol003eooaD00003Ool0000000Qoo`03001oogoo00Moo`03
001oogoo03Ioo`@0009oo`<0009oo`@004Yoo`03001oogoo009oo`05001oogooOol0000MOol002ao
oa400004Ool000000009Ool00`00Oomoo`06Ool00`00Oomoo`0gOol00`00Oomoo`0400000goo0000
00020002Ool3001KOol00`00Oomoo`02Ool01@00Oomoogoo00007Goo000SOol90002Ool30006Ool0
0`00Oomoo`06Ool00`00Oomoo`0hOol30002Ool400000goo000000020002Ool2000ROol00g`4Oomo
o`0QOol00e`OOomoo`09Ool00`00Oomoo`0FOol20004Ool01@00Oomoogoo00007Goo000UOol20000
0goo000000020002Ool00`00Oomoo`06Ool00`00Oomoo`0]Ool20002Ool30002Ool400000goo0000
0002000eOol2O0@ROol2G1l;Ool00`00Oomoo`0GOol00`00Oomoo`03Ool3000NOol002moo`80009o
o`@001ioo`@00003Ool000000080009oo`<0009oo`8004Ioo`Al125oo`=L7`Yoo`03001oogoo01Mo
o`03001oogoo02Aoo`008goo00<007ooOol04Woo10000Woo0`0000Aoo`00Oomoo`@00003Ool00000
0080009oo`<005aoo`03O0Aoogoo01Eoo`03O0Aoogoo00Uoo`03G1moogoo00Uoo`03001oogoo01Mo
o`03001oogoo02Aoo`008goo00<007ooOol077oo00<007ooOol0JWoo00=l17ooOol057oo0W`42goo
00=L7gooOol057oo00=L7gooOol037oo00<007ooOol097oo000SOol00`00Oomoo`0LOol00`00Oomo
o`1ZOol00g`4Oomoo`0COol4O0@:Ool00e`OOomoo`05Ool01@?]Oomoogoo00002Goo0e`O3Goo00<0
07ooOol097oo000SOol00`00Oomoo`0LOol00`00Oomoo`1ZOol00g`4Oomoo`0EOol00g`4Oomoo`09
Ool00e`OOomoo`04Ool20nd3Ool01@00Oomoogoo0nd01Woo00=L7gooOol02goo0P009Woo0014Ool0
0`?[Oomoo`1XOol00g`4Oomoo`0EOol00g`4Oomoo`09Ool00e`OOomoo`05Ool01@?]Oomoogoo0000
0Woo0P?]1Woo00=L7gooOol037oo00<007ooOol097oo000SOol00`00Oomoo`0;Ool00`?VOomoo`07
Ool00`?POomoo`06Ool00`?[Oomoo`04Ool00bOPOomoo`1QOol00g`4Oomoo`05Ool00a?POomoo`0=
Ool00g`4Oomoo`09Ool00e`OOomoo`05Ool01@?]Oomoogoo00000goo00<3kGooOol017oo00=L7goo
Ool037oo00<007ooOol097oo000SOol00`00Oomoo`0;Ool00`?VOomoo`04Ool011oPOomoo`?P1Woo
00<oh7oo0n/01Woo00<Wh7ooOol01Woo00<Wh7ooOol0F7oo00=l17ooOol017oo0Q?P1goo00<Ch7oo
Ool01Goo00=l17ooOol02Goo00=L7gooOol01Goo00<3kGooOol01Goo00<3kGooOol017oo00=L7goo
Ool037oo00<007ooOol097oo000SOol00`00Oomoo`0;Ool00`?VOomoo`04Ool011oPOomoo`?P1Woo
00<oh7oo0n/00goo00@3iWoo9n0Wh0Ioo`030n1oobOP00Ioo`030n]oogoo055oo`03O0Aoogoo00Eo
o`034n1oogoo00Eoo`034n1oogoo00Eoo`03O0Aoogoo015oo`030neoogoo00Eoo`030neoogoo00Ao
o`03G1moogoo00aoo`03001oogoo02Aoo`008goo00<007ooOol02goo0P?V1Goo0QoP00=oo`?P0n00
17oo0SoP00=oo`?[0n/00Woo00@3iWooOolWh0Ioo`030n1oobOP00Ioo`030n]oogoo055oo`03O0Ao
ogoo00Eoo`034n1oogoo00Eoo`034n1oogoo00Eoo`03O0Aoogoo01Eoo`05001oogooOol3k@06Ool0
0e`OOomoo`0<Ool00`00Oomoo`0TOol0039oo`030nIoogoo00Aoo`037n1oogoo00Ioo`047n1oogoo
0o82Ool010?VOomoocoP1Woo00<3h7oo9n001Woo00<3jgooOol0HGoo00<Ch7ooOol01Goo00=l17oo
Ool05Goo00<007ooOol027oo00=L7gooOol037oo00<007ooOol097oo000^Ool00`?POomoo`08Ool0
0`?WOomoo`06Ool014?POomoo`?b0Woo0P?V0goo00@oh7ooOomoo`83h0Moo`83jf]oo`03O0Aoogoo
01Eoo`03001oogoo01Ioo`8002Ioo`008goo00<007ooOol027oo00<3h7ooOol01Woo00<Gh7oo0nL0
27oo00A3h7ooOol3lP=oo`040nIood?POol2?n07Ool00coPOomoo`05Ool00`?bOomoo`2HOol00`00
Oomoo`0TOol002=oo`03001oogoo00Moo`030n1oogoo00Ioo`035n1oo`?W0083i`Eoo`045n13h4?P
Ool30o801Woo0n1oogoo@n1oo`8oh0Aoo`030nMoogoo008oh0Ioo`030o9oogoo09Qoo`03001oogoo
02Aoo`008goo00<007ooOol01goo0P?P1Woo0QOP0Woo00<3igooOol00goo00@Gh7oo@n00009oo`04
0o9oogoo0n02Ool00d?POomoo`06Ool010?WOomoocoP1goo00<3lWooOol0OGoo00<007ooOol05goo
00<007ooOol097oo000eOol00aOPOomoo`07Ool25n000goo001oo`04Ool00`?POomoo`09Ool20nL9
Ool20o9nOol00`00Oomoo`0GOol00`00Oomoo`0TOol003Qoo`030nAoogoo00Yoo`030o9oogoo0083
h0]oo`030nMoogoo00Qoo`030o9oogoo07aoo`03001oogoo01Moo`03001oogoo02Aoo`008goo00<0
07ooOol01Woo00<3hWooOol02Goo00<3i7ooOol01goo00A7h7ooOol3lPQoo`03Dn1oogoo00Ioo`03
Dn1oogoo08Eoo`03001oogoo01Ioo`8002Ioo`008goo00<007ooOol01Woo00<3hWooOol01goo00<O
h7oo0n@01Woo00HOh7ooOom7h7oo0o86Ool014OPOomooe?P1Goo00@3i7ooOomCh0Qoo`030o9oogoo
09Ioo`03001oogoo02Aoo`008goo00<007ooOol01goo0P?R1goo00@Oh7oo0n@3i0Eoo`037n1oogoo
0097h083lP9oo`040n9oogooAn02Ool00e?POomoo`03Ool010?TOomooe?P1goo00<3lWooOol0Ugoo
00<007ooOol097oo000SOol00`00Oomoo`07Ool00`?ROomoo`06Ool27n000`?TOomoo`04Ool27n00
17oo001oo`?b0goo00<3hWooOol00TOP1Woo00D3i7ooOomooe?P00Moo`030o9oogoo07eoo`03001o
ogoo01Moo`03001oogoo02Aoo`00?goo00<Oh7ooOol01Goo0P?R2Goo0P?T2Woo0P?bOgoo00<007oo
Ool05goo00<007ooOol097oo0018Ool00`?ROomoo`08Ool00`?TOomoo`08Ool00`?bOomoo`1nOol0
0`00Oomoo`0GOol00`00Oomoo`0TOol002=oo`03001oogoo01aoo`04001oogoo0oZcOol00`00Oomo
o`02Ool5000017oo000000006Goo000SOol00`00Oomoo`06Ool00`?/Oomoo`09Ool00`?jOomoo`07
Ool011?POomoo`?j27oo00<kh7ooOol01Woo00<kh7ooOol0WGoo0`001Goo00@007ooOol000Aoo`03
001oogoo01Ioo`008goo00<007ooOol01goo00<3k7ooOol01Woo00@?h7ooOol3nPEoo`043n1oogoo
4n02Ool00`?jOomoo`03Ool00a?POolkh006Ool010?jOomooc_P27oo00<3nWooOol0O7oo00<007oo
Ool05goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol05Goo000]Ool00`?/Oomoo`06Ool0
10oPOomoogoo0P?j0goo00@?h7oo4n0000=oo`050oYoo`?/OolCh002Ool2>n05Ool010?jOolkh3_P
27oo00<3nWooOol0O7oo00<007ooOol05goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
5Goo000]Ool20n`6Ool23n03Ool20oX3Ool00`oPOolCh003Ool20oX017oo0naooa?P2Woo00<3nS_P
Ool027oo00<3nWooOol0O7oo00<007ooOol05goo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool05Goo000SOol00`00Oomoo`0?Ool00`oPOomoo`06Ool23n02Ool01P00Oomoogoo0oYoo`83k0]o
o`83nPQoo`<3nWeoo`03001oogoo01Moo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo01Io
o`008goo00<007ooOol077oo00<007ooOol00goo0P?/2goo0P?j2Goo00<3nWooOol0UWoo00<007oo
Ool01Woo00<007ooOol00P006Goo000SOol00`00Oomoo`0LOol00`00Oomoo`2JOol00`00Oomoo`0F
Ool20004Ool01@00Oomoogoo00000Woo00<007ooOol067oo000SOol00`00Oomoo`0LOol00`00Oomo
o`2JOol00`00Oomoo`0GOol00`00Oomoo`03Ool30004Ool3000GOol00=moo`03001oogoo01Moo`03
001oogoo02Aoo`008goo00<007ooOol0^Goo00<007ooOol05goo00<007ooOol097oo000SOol00`00
Oomoo`0LOol00`00Oomoo`2dOol00`00Oomoo`0TOol002=oo`03001oogoo01aoo`03001oogoo06Yo
o`03O0Uoogoo04Moo`03001oogoo02Aoo`008goo00<007ooOol02Goo00<3jGooOol047oo00<2ogoo
Ool01Woo00=7h7ooOol0H7oo0W`95goo00=l2GooOol02Goo00=87gooOol02Goo00<007ooOol05goo
00<007ooOol097oo000_Ool00`?YOomoo`07Ool00`?TOomoo`06Ool00`;oOomoo`06Ool00dOPOomo
o`06Ool00dOPOomoo`06Ool00`;oOomoo`1=Ool4O0TEOol2O0T:Ool3B1l:Ool00`00Oomoo`08Ool0
0dPOOomoo`0;Ool2000VOol002moo`030nUoogoo00Moo`030nAoogoo00Ioo`030_moogoo00Ioo`03
An1oogoo00Ioo`03An1oogoo00Ioo`030_moogoo04moo`03O0Uoogoo01Aoo`=l2@Uoo`=87`Yoo`03
001oogoo00Moo`987`ioo`03001oogoo02Aoo`008goo00<007ooOol02Goo0P?Y1goo0P?T27oo00<2
ogooOol01Woo00=7h7ooOol01Woo00=7h7ooOol01Woo00<2ogooOol0Cgoo00=l2GooOol05Goo00=l
2GooOol02Goo00=87gooOol04goo0dPO3Goo00<007ooOol097oo000SOol00`00Oomoo`0:Ool00`?Y
Oomoo`06Ool00`?TOomoo`05Ool30_l6Ool20nTAOol00`;oOomoo`1?Ool00g`9Oomoo`0EOol00g`9
Oomoo`09Ool00dPOOomoo`05Ool00`?[Oomoo`0<Ool00dPOOomoo`0<Ool00`00Oomoo`0TOol002=o
o`03001oogoo01aoo`030_moogoo00Ioo`030nUoogoo00ioo`82oe5oo`03O0Uoogoo01Eoo`03O0Uo
ogoo00Uoo`03B1moogoo00Aoo`83j`=oo`03001oogoo0083j`Ioo`03B1moogoo00aoo`03001oogoo
02Aoo`00@Woo00<007ooOol067oo00<2ogooOol0Cgoo00=l2GooOol017oo0Q_P1goo00<Kh7ooOol0
1Goo00=l2GooOol02Goo00=87gooOol01Goo00D3jgooOomoo`00009oo`030n]oogoo00Eoo`03B1mo
ogoo00aoo`03001oogoo02Aoo`00[goo00=l2GooOol01Goo00<Kh7ooOol01Goo00<Kh7ooOol01Goo
00=l2GooOol02Goo00=87gooOol01Goo00D3jgooOomoo`00009oo`030n]oogoo00Eoo`03B1moogoo
00]oo`8002Ioo`008goo00<007ooOol077oo00<007ooOol0JWoo00=l2GooOol01Goo00<Kh7ooOol0
1Goo00<Kh7ooOol01Goo00=l2GooOol02Goo00=87gooOol01Goo00D3jgooOomoo`0000=oo`030n]o
ogoo00Aoo`03B1moogoo00aoo`03001oogoo02Aoo`008goo00<007ooOol077oo00<007ooOol0JWoo
00=l2GooOol01Goo00<Kh7ooOol01Goo00<Kh7ooOol01Goo00=l2GooOol04Goo00<3jgooOol01Goo
00<3jgooOol017oo00=87gooOol037oo00<007ooOol097oo000SOol00`00Oomoo`0LOol00`00Oomo
o`22Ool00g`9Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0TOol002=oo`03001oogoo01aoo`03
001oogoo09Yoo`03001oogoo01Moo`03001oogoo02Aoo`00ggoo00<007ooOol05goo00<007ooOol0
97oo000SOol00`00Oomoo`2iOol00`00Oomoo`0GOol00`00Oomoo`0TOol002=oo`03001oogoo01ao
o`03001oogoo0;=oo`8002Ioo`008goo00<007ooOol077oo00<007ooOol0]7oo00<007ooOol097oo
000SOol00`00Oomoo`0LOol00`00Oomoo`2JOol00`00Oomoo`0GOol00`00Oomoo`0TOol0049oo`03
001oogoo09Yoo`03001oogoo01Moo`03001oogoo02Aoo`00;goo00<3m7ooOol01goo00<3jWooOol0
1Woo00<1OgooOol01Woo00<ch7ooOol01Woo00<ch7ooOol01Woo00<1OgooOol0Ogoo00<007ooOol0
5goo00<007ooOol00Woo0`0017oo0`0067oo000SOol00`00Oomoo`09Ool00`?dOomoo`07Ool00`?Z
Oomoo`06Ool00`5oOomoo`06Ool00c?POomoo`06Ool00c?POomoo`06Ool00`5oOomoo`2IOol00`00
Oomoo`05Ool01000Oomoo`000goo00<007ooOol05Goo000SOol00`00Oomoo`09Ool00`?dOomoo`07
Ool00`?ZOomoo`06Ool00`5oOomoo`06Ool00c?POomoo`06Ool00c?POomoo`06Ool00`5oOomoo`2G
Ool30008Ool00`00Ool00003Ool00`00Oomoo`0EOol002=oo`03001oogoo00Uoo`83m0Moo`83jPMo
o`030nX1Ogoo00Moo`03<n1oogoo00Ioo`03<n1oogoo00Ioo`030Gmoogoo07moo`03001oogoo01Mo
o`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo01Eoo`00<7oo00<3m7ooOol01Woo00<3jWoo
Ool01Woo00<1OgooOol01Goo0P?d4Goo00<1OgooOol0Ogoo00<007ooOol05goo00<007ooOol01Woo
00<007oo00000goo00<007ooOol05Goo0011Ool30GlHOol20Gn1Ool00`00Oomoo`0GOol00`00Oomo
o`05Ool01000Oomoo`000goo00<007ooOol05Goo000SOol00`00Oomoo`0LOol00`5oOomoo`0HOol0
0`5oOomoo`1oOol00`00Oomoo`0GOol00`00Oomoo`03Ool20003Ool01@00Oomoogoo00005goo000S
Ool00`00Oomoo`0LOol00`00Oomoo`2dOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
00001Woo1`002Woo000SOol00`00Oomoo`0LOol00`00Oomoo`1_Ool00g`0Oomoo`0DOol00g`0Oomo
o`0[Ool00`00Oomoo`04Ool30002Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool002=oo`03
001oogoo01aoo`03001oogoo06eoo`=l01Eoo`9l01=oo`03001oogoo01Ioo`8001Ioo`03001oogoo
009oo`03001oogoo00Qoo`00/Woo0g`05Goo0g`04Woo00<007ooOol05goo00<007ooOol05Goo00<0
07ooOol037oo002cOol00g`0Oomoo`0DOol00g`0Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0F
Ool00`00Oomoo`0;Ool002=oo`03001oogoo01aoo`03001oogoo06eoo`03O01oogoo01Eoo`03O01o
ogoo02aoo`03001oogoo01Ioo`03001oogoo00]oo`008goo00<007ooOol077oo00<007ooOol0KGoo
00=l07ooOol057oo00=l07ooOol0;Goo00<007ooOol05goo00<007ooOol02Woo000SOol00`00Oomo
o`0LOol00`00Oomoo`1/Ool00g`0Oomoo`05Ool22n06Ool22n06Ool00g`0Oomoo`0COol00`00Oomo
o`0GOol00`00Oomoo`0DOol01@00Oomoogoo00002goo0010Ool00b0OOol00006Ool00aoPOomoo`06
Ool00aoPOomoo`06Ool00b0OOomoo`1COol00g`0Oomoo`05Ool22n06Ool22n06Ool00g`0Oomoo`0C
Ool00`00Oomoo`0FOol2000FOol6000:Ool0041oo`0381moogoo00Ioo`037n1oogoo00Ioo`037n1o
ogoo00Ioo`0381moogoo059oo`03O01oogoo00Ioo`032n1oogoo00Eoo`032n1oogoo00Aoo`03O01o
ogoo01Aoo`03001oogoo01Moo`03001oogoo02Aoo`008goo00<007ooOol06goo00<P7`00Ool01Woo
00<Oh7ooOol01Woo00<Oh7ooOol01Woo00<P7gooOol0DGoo00=l07ooOol01Goo00<;h7ooOol01Goo
00<;h7ooOol01Goo00=l07ooOol057oo00<007ooOol05goo00<007ooOol097oo000SOol00`00Oomo
o`0KOol00b0O001oo`06Ool00aoPOomoo`06Ool00aoPOomoo`06Ool00b0OOomoo`2JOol00`00Oomo
o`0TOol002=oo`03001oogoo01aoo`0381moogoo01Moo`0381moob0O081oo`03001oogoo01Moo`03
001oogoo02Aoo`008goo00<007ooOol06goo0b0O67oo0b0OP7oo00@007ooOomH7aIoo`03001oogoo
02Aoo`00@Woo0R0O6Goo00<P7gooOol0Jgoo00=H7gooOol04Goo00<007ooF1l00UPO5Goo00<007oo
Ool097oo000SOol00`00Oomoo`0FOol00`?`Oomoo`06Ool00`?`Oomoo`06Ool00`=OOomoo`1iOol2
F1lCOol00`00OomH7`02F1lDOol2000VOol002=oo`03001oogoo00aoo`030emoogoo00Moo`030o1o
ogoo00=oo`04001oogoo0o08Ool00`=OOomoo`0COol00dPOOomoo`0;Ool00boPOomoo`04Ool3B1l2
Ool00dPOOomoo`0VOol00g`IOomoo`0IOol00g`3Oomoo`04Ool3F1lDOol00ePOOomoo`0EOol00`00
Oomoo`0TOol002=oo`03001oogoo00aoo`030emoogoo00Moo`030o1oogoo00=oo`04001oogoo0o08
Ool00`=OOomoo`0>Ool7B1l2Ool3;n06Ool3;n08Ool4B1l>Ool01W`IOolCh1?POolCh0Eoo`@Ch0Ao
o`Ql6@03Ooml0g`3009l0aAoo`Al0`Aoo`03F1moogoo00Aoo`83lPIoo`83lPIoo`03F1moogoo01Eo
o`03001oogoo02Aoo`008goo00<007ooOol03Goo00<3GgooOol01goo00<3l7ooOol00Woo00D007oo
Ool3l4`O00Qoo`030el[h2_P00Moo`8[h0Moo`9<7`03B1mood`O01Moo`03B1moogoo00Moo`Ql6@9o
o`8Ch0Moo`034n1oogoo00Uoo`03O1Uoogoo00=l0aEoo`=l0`Eoo`03F1moogoo00Eoo`83lPEoo`83
lPAoo`03001ooePO01Moo`03001oogoo02Aoo`00<goo0P=O1goo0P?`1goo0P?`0T`O0Woo00I<7goo
Oomoo`=OOol2:n07Ool2:n08Ool3C1lWOol00g`IOomoo`0GOol2O0<00gooO0=oo`0:Ool00`?QOomo
o`05Ool3O0<2Ool00g`3Oomoo`03Ool00ePOOomoo`04Ool00`?bOomoo`05Ool00`?bOomoo`03Ool0
0`00F1moo`0GOol00`00Oomoo`0TOol003=oo`83GaAoo`A<7aQoo`=<7cioo`9l0`Moo`83h@Ioo`83
h@Aoo`9l0`Yoo`03F1moogoo00Eoo`030o9oogoo00Aoo`030o9oogoo00Aoo`03001H7goo01Moo`03
001oogoo02Aoo`008goo00<007ooOol077oo00<007ooOol01Woo0T`OEgoo0W`31goo0`?Q1Goo0P?Q
4Woo00=H7gooOol01Goo00<3lWooOol017oo00<3lWooOol01Goo00=H7gooOol05Goo0P009Woo000S
Ool00`00Oomoo`0LOol00`00Oomoo`2dOol00`00Oomoo`0TOol002=oo`03001oogoo01aoo`03001o
ogoo09Yoo`03001oogoo01Moo`03001oogoo02Aoo`00@Woo00<007ooOol0VWoo00<007ooOol05goo
00<007ooOol097oo003OOol00`00Oomoo`0GOol00`00Oomoo`04Ool01000Oomoogoo0`006Goo000S
Ool00`00Oomoo`0LOol00`00Oomoo`2JOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`0FOol002=oo`03001oogoo01aoo`03001oogoo0;Aoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo01Eoo`008goo00<007ooOol077oo00@007ooOL1m`9Uoo`03001oogoo01Eo
o`<000Moo`03001oogoo00Aoo`03001oogoo01Eoo`008goo00<007ooOol00goo0Wg01goo0W`027oo
00=l07ooOol00goo00<007ooOol0VWoo00<007ooOol05goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol05Goo000YOol00gg0Oomoo`06Ool2O02[Ool00`00Oomoo`0GOol00`00Oomoo`05Ool0
0`00Oomoo`03Ool00`00Oomoo`0FOol002=oo`03001oogoo0;Uoo`03001oogoo01Moo`03001oogoo
00Ioo`03001oogoo008001Uoo`008goo00<007ooOol077oo00<007ooOol0]7oo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo01Qoo`008goo00<007ooOol077oo00<007ooOol0]7oo00<0
07ooOol00goo10000goo0`005goo000SOol00`00Oomoo`0LOol00`00Oomoo`2JOol00`00Oomoo`0F
Ool2000VOol0049oo`03001oogoo09Yoo`03001oogoo01Moo`03001oogoo02Aoo`00ggoo00<007oo
Ool05goo00<007ooOol097oo000SOol00`00Oomoo`0LOol00`00Oomoo`0>Ool00`?]Oomoo`05Ool2
0Sl2Ool00`8oOomoo`2GOol00`00Oomoo`0TOol002=oo`03001oogoo01Yoo`030Smoo`0000Moo`03
0neoogoo00Moo`83k@Moo`<2?iUoo`03001oogoo02Aoo`008goo00<007ooOol06goo0P8o00=oo`8o
Ool01Goo0P?]1goo0P?]27oo00<2?gooOol0OWoo00<007ooOol05goo00<007ooOol097oo0012Ool0
0`000Sl2?`07Ool00`?]Oomoo`1kOol00dPOOomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0TOol0
04=oo`030Smoogoo08Aoo`=87a9oo`03001oogoo01Ioo`8002Ioo`008goo00<007ooOol0S7oo00=8
7gooOol05Goo0TPO4goo00<007ooOol05goo00<007ooOol097oo000SOol00`00Oomoo`0LOol00`00
Oomoo`1]Ool3B1l4Ool00`?gOomoo`05Ool20oL5Ool2B1l_Ool00`00Oomoo`0TOol002=oo`03001o
ogoo01aoo`03001oogoo06eoo`987`Eoo`83m`=oo`@3m`Aoo`987c5oo`03001oogoo02Aoo`008goo
00<007ooOol077oo00<007ooOol0>7oo00<27gooOol0<7oo0TPO17oo10?g9Goo00<007ooOol05goo
00<007ooOol097oo001cOol00`?YOomoo`03Ool60QlVOol00`0oOomoo`06Ool2B1l_Ool00`00Oomo
o`0?Ool00gh0Oomoo`05Ool00`00Oomoo`0TOol006=oo`030Qmoogoo009oo`@3j@Eoo`@3j@Qoo`03
0Qmoogoo025oo`H0?cQoo`03001oogoo00Qoo`03O81oogoo00Eoo`03OP1oogoo00=oo`8002Ioo`00
8goo00<007ooOol077oo00<007ooOol06Woo1P8O1Goo00<3jGooOol09Woo00<3kgooOol00goo10?_
27oo00<0?gooOol0<Woo0Wh01goo00=lP7ooOol017oo00=lP7ooOol037oo00<007ooOol097oo000S
Ool00`00Oomoo`0LOol00`00Oomoo`0NOol00`8OOomoo`0VOol0100oOomoogoo1@?_1goo00<3kgoo
Ool0>goo0Wh07Goo00<007ooOol097oo000SOol00`00Oomoo`0LOol00`00Oomoo`08Ool00ghPOomo
o`0hOol603l5Ool00`?_Oomoo`19Ool00`00Oomoo`0GOol00`00Oomoo`0TOol003]oo`03O:1oogoo
00Aoo`03001oogbP04Moo`0303moogoo051oo`03001oogoo01Moo`03001oogoo02Aoo`00<Goo0WhP
27oo00=lX7ooOol0XGoo00<007ooOol05goo00<007ooOol097oo000SOol00`00Oomoo`0LOol00`00
Oomoo`2JOol00`00Oomoo`0GOol00`00Oomoo`0TOol002=oo`03001oogoo01aoo`03001oogoo0;=o
o`8002Ioo`008goo00<007ooOol077oo00<007ooOol0VWoo00<007ooOol05goo00<007ooOol097oo
000SOol00`00Oomoo`0LOol00`00Oomoo`2JOol00`00Oomoo`0GOol00`00Oomoo`03Ool30003Ool3
0003Ool3000BOol00=moo`03001oogoo01Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00
Ool00003Ool00`00Oomoo`0?Ool002=oo`03001oogoo0;Uoo`03001oogoo01Moo`03001oogoo00Ao
o`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0?Ool002=oo`03001oogoo01aoo`03
001oogoo0;Aoo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0?
Ool002=oo`03001oogoo01aoo`03001oogoo091oo`9mh21oo`<000Ioo`05001oogooOol00003Ool0
0`00Ool00003Ool00`00Oomoo`0?Ool002=oo`03001oogoo01aoo`03001oogoo08Yoo`03O01oogoo
00Aoo`03ON1oogoo00Ioo`03001oogoo01Moo`03001oogoo00Aoo`05001oogooOol00003Ool00`00
Ool00003Ool00`00Oomoo`0?Ool00<Moo`03O01oogoo00Eoo`03O01oogoo00eoo`03001oogoo01Mo
o`03001oogoo00Aoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0?Ool003moo`H0
009oo`8007Eoo`03ON1oogoo00Ioo`03O01oogoo01Eoo`03001oogoo01Moo`03001oogoo00=oo`80
00=oo`07001oogooOol007oo00000goo00<007ooOol03goo000SOol00`00Oomoo`0@Ool20002Ool3
000<Ool20002Ool30002Ool400000goo00000002001TOol00ggPOomoo`0gOol00`00Oomoo`04Ool0
0`00Oomoo`02Ool30003Ool3000BOol002=oo`03001oogoo00Ioo`03001oogoo00@00003Ool00000
02Moo`<0009oo`@00003Ool00000008008ioo`03001oogoo02Aoo`008goo1@000Woo0P00@Goo0`00
0Woo100000=oo`0000000P000Woo0P00H7oo00<007ooOol05goo00<007ooOol097oo000VOol40002
Ool30002Ool400000goo00000017Ool200000goo000000020002Ool30002Ool4001>Ool00`00Oomo
o`0FOol2000VOol003Qoo`80009oo`@00003Ool000000080009oo`03001oogoo04Qoo`@0009oo`<0
009oo`@00003Ool0000003]oo`03001oogoo01Moo`03001oogoo02Aoo`00B7oo0P000Woo100000=o
o`0000000P000Woo00<007ooOol0BWoo0P000Woo0`000Woo100000=oo`0000000P00:Goo00<007oo
Ool05goo00<007ooOol097oo001HOol20002Ool400000goo000000020002Ool3001>Ool400000goo
000000020002Ool30002Ool2000_Ool00`00Oomoo`0TOol006aoo`@00003Ool000000080009oo`@0
04moo`800003Ool000000080009oo`<0009oo`@000=oo`03001oogoo01Moo`03001oogoo02Aoo`00
O7oo10000Woo0`000Woo100000=oo`000000Cgoo10000Woo0`000Woo10003Goo00<007ooOol097oo
002>Ool20002Ool30002Ool400000goo00000011Ool00`00Oomoo`0;Ool40002Ool7000VOol009io
o`80009oo`<0009oo`@00003Ool00000035oo`03001oogoo00moo`80009oo`8002Uoo`00[Woo0P00
0Woo100000=oo`0000000P000Woo0`00;7oo0P0000=oo`000000;goo0032Ool400000goo00000002
0002Ool3000EOol30002Ool2000dOol00=9oo`@00003Ool000000080009oo`H003eoo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo001@Ool3003=Ool004moo`05001oogooOol0003<Ool004mo
o`05001oogooOol0003<Ool003ioo`<0009oo`03001oogoo00<0009oo`@00005Ool00000001oo`03
000017oo000007oo0P000goo0P0000=oo`0000001P000Woo100000Aoo`00001oo`<00004Ool00000
0002Ool300000goo00000002Ool600000goo00000003Ool600001Goo00000000Ool00P000Woo0`00
00Aoo`00001oo`800003Ool00000009oo`<00004Ool00000Ool20005Ool01000Oomoo`001Goo0P00
17oo1@00Cgoo000oOol01@00Oomoogoo00000goo00@007ooOol0009oo`03001oo`0000Eoo`06001o
ogoo001oo`000Woo00@007ooOol000=oo`04001oogoo0002Ool00`00Ool00002Ool01000Oomoo`00
0goo00<007oo00000goo00@007ooOol0009oo`03001oogoo009oo`04001oogoo0002Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool01@00Ool007oo00000Woo00@007ooOol0009oo`06001oogoo001oo`00
0Woo00@007ooOol0009oo`04001oogoo0006Ool01000Oomoo`001goo00<007ooOol00Woo00@007oo
Ool004moo`00?goo00H007ooOol007oo0002Ool01000Oomoo`000Woo00<007ooOol00P000goo00H0
07ooOol007oo0005Ool01@00Oomoogoo00000goo00D007ooOomoo`00009oo`04001oogoo0003Ool0
0`00Ool00003Ool01000Oomoo`000Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oo`0000Eoo`04001oogoo0002Ool00`00Ool00005Ool01000Oomoo`00
0Woo00<007ooOol01Goo00@007ooOol000Moo`03001oogoo009oo`03001oogoo04moo`00?goo00H0
07ooOol007oo0002Ool01000Oomoogoo0`0000Eoo`00Oomoo`00009oo`05001oogoo001oo`040002
Ool01@00Oomoogoo00000goo00<007ooOol00Woo0`000Woo00L007ooOomoo`00Ool00003Ool01000
Oomoo`000Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo00=oo`04001oogoo0003Ool0
0`00Ool000030002Ool01000Oomoo`000Woo00<007oo00000`000Woo00@007ooOol0009oo`03001o
ogoo00Aoo`H000Aoo`@000Aoo`03001oogoo04ioo`00?goo00H007ooOol007oo0002Ool01000Oomo
o`000Woo00<007oo00000Woo00<007ooOol00P0000Aoo`00Ool0009oo`04001oogoo0003Ool00`00
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oo`0000=oo`03001oogoo00800003
Ool007oo00=oo`03001oogoo00800003Ool007oo00Aoo`@000=oo`03001oo`00009oo`03001oogoo
00800007Ool00000Ool007oo00000Woo00<007ooOol00P0000Eoo`00Oomoo`0000Moo`04001oogoo
0004Ool01@00Oomoogoo00001Goo00<007ooOol0CGoo000oOol00`00Ool00003Ool00`00Ool00003
Ool20003Ool600000goo001oo`02Ool20002Ool3000017oo000007oo1@000Woo0P000Woo0`0000=o
o`0000000Woo0`000Woo0P0000=oo`00Ool00goo0P0000Eoo`00001oo`0000Ioo`04001oogoo0003
Ool00`00Oomoo`020002Ool200001Goo001oogoo00000goo0P000Woo0P0000Aoo`00Oomoo`<000Eo
o`H000=oo`05001oogooOol00005Ool00`00Oomoo`1=Ool003moo`03001oo`0000=oo`03001oo`00
01Qoo`03001oogoo00moo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo01Uoo`03001oogoo
00Eoo`04001oogoo0004Ool01@00Oomoogoo00001Goo00<007ooOol0CGoo000oOol20005Ool2000H
Ool00`00Oomoo`0?Ool00`00Oomoo`0NOol01@00Oomoogoo00000Woo00<007ooOol06Goo00<007oo
Ool01Woo00@007ooOol000=oo`07001oogooOol007oo00000goo00<007ooOol0CGoo000nOol30005
Ool3000KOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`08Ool600000goo0000000TOol0
1000Oomoo`0017oo0`000goo0`00D7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.00991506, -5.06255*^-06, 
  0.00372246, 0.00372246}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["QuickDraw 3D  Graphics", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Here are instructions to plot the steerer geometry using QuickDraw3D. One \
can save the geometry with colors in a 3dmf format using the menu \
\"File->Save As\"  in Radia.exe before returning to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ". A 3dmf file can be read by a number of CAD and RayTracing Packages. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text"],

Cell[BoxData[
    \(\( (*\ The\ whole\ geometry\ *) \n\(radObjDrwQD3D[t]; \)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Graphics"
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"These instructions plot the geometry of the steerer dipole.",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"draw", "=", 
        RowBox[{
          StyleBox["radObjDrw",
            FontColor->RGBColor[1, 0, 0]], "[", "t", "]"}]}], ";", "\n", 
      RowBox[{
        StyleBox["RadPlot3DOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      \(Show[Graphics3D[draw]\n, ViewPoint -> {5, \(-1.5\), 1}\n, 
        PlotRange -> All\n\ , AmbientLight\  -> \ GrayLevel[0.1]]\), ";"}]], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.76419 .84714 -12.3237 0 ]
[.76419 .84714 12.6763 15 ]
[.81448 .83438 -4.91601 0 ]
[.81448 .83438 5.08399 15 ]
[.8687 .82063 -7.84233 0 ]
[.8687 .82063 8.15767 15 ]
[.81553 .89687 -7.86561 0 ]
[.81553 .89687 8.13439 15 ]
[.2965 .11046 -4.94346 -15 ]
[.2965 .11046 5.05654 0 ]
[.44098 .12297 -7.97378 -15 ]
[.44098 .12297 8.02622 0 ]
[.58205 .13518 -11.0501 -15 ]
[.58205 .13518 10.9499 0 ]
[.71986 .14711 -11.1341 -15 ]
[.71986 .14711 10.8659 0 ]
[.85449 .15877 -11.2161 -15 ]
[.85449 .15877 10.7839 0 ]
[.55741 .07057 -8.02557 -15 ]
[.55741 .07057 7.97443 0 ]
[.88922 .2025 0 -6.8695 ]
[.88922 .2025 31 8.1305 ]
[.89214 .34183 0 -6.95972 ]
[.89214 .34183 25 8.04028 ]
[.8951 .48333 0 -7.05139 ]
[.8951 .48333 10 7.94861 ]
[.8981 .62705 0 -7.14455 ]
[.8981 .62705 16 7.85545 ]
[.90115 .77303 0 -7.23923 ]
[.90115 .77303 22 7.76077 ]
[.95749 .48707 0 -7.05139 ]
[.95749 .48707 15 7.94861 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
.74656 .83907 m
.88929 .80284 L
s
.25 Mabswid
.76401 .83464 m
.76393 .82839 L
s
gsave
.76419 .84714 -73.3237 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.81427 .82189 m
.81417 .81564 L
s
gsave
.81448 .83438 -65.916 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.86845 .80813 m
.86833 .80189 L
s
gsave
.8687 .82063 -68.8423 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.77377 .83217 m
.77372 .82842 L
s
.78367 .82965 m
.78362 .8259 L
s
.79372 .8271 m
.79366 .82335 L
s
.80392 .82451 m
.80386 .82076 L
s
.82478 .81922 m
.82472 .81547 L
s
.83545 .81651 m
.83538 .81276 L
s
.84628 .81376 m
.84621 .81001 L
s
.85728 .81097 m
.85721 .80722 L
s
.75439 .83708 m
.75434 .83333 L
s
.8798 .80525 m
.87972 .80151 L
s
gsave
.81553 .89687 -68.8656 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.2211 .11645 m
.87617 .17312 L
s
.25 Mabswid
.29636 .12296 m
.29629 .12921 L
s
gsave
.2965 .11046 -65.9435 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.44094 .13547 m
.44092 .14172 L
s
gsave
.44098 .12297 -68.9738 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.58211 .14768 m
.58214 .15393 L
s
gsave
.58205 .13518 -72.0501 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.72001 .15961 m
.72008 .16586 L
s
gsave
.71986 .14711 -72.1341 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.85474 .17127 m
.85486 .17752 L
s
gsave
.85449 .15877 -72.2161 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.32555 .12549 m
.32552 .12924 L
s
.35461 .128 m
.35458 .13175 L
s
.38352 .1305 m
.3835 .13425 L
s
.4123 .13299 m
.41228 .13674 L
s
.46944 .13794 m
.46943 .14169 L
s
.49781 .14039 m
.49781 .14414 L
s
.52604 .14283 m
.52605 .14658 L
s
.55414 .14526 m
.55415 .14901 L
s
.60995 .15009 m
.60997 .15384 L
s
.63766 .15249 m
.63769 .15624 L
s
.66524 .15487 m
.66527 .15862 L
s
.69269 .15725 m
.69273 .161 L
s
.7472 .16197 m
.74726 .16572 L
s
.77427 .16431 m
.77433 .16806 L
s
.80122 .16664 m
.80128 .17039 L
s
.82804 .16896 m
.82811 .17271 L
s
.26703 .12043 m
.26698 .12418 L
s
.23755 .11788 m
.2375 .12163 L
s
gsave
.55741 .07057 -69.0256 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.87617 .17312 m
.88929 .80284 L
s
.25 Mabswid
.87676 .20145 m
.87054 .20093 L
s
gsave
.88922 .2025 -61 -10.8695 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87967 .34094 m
.87344 .34049 L
s
gsave
.89214 .34183 -61 -10.9597 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.88262 .48259 m
.87638 .48221 L
s
gsave
.8951 .48333 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88562 .62646 m
.87937 .62616 L
s
gsave
.8981 .62705 -61 -11.1446 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88866 .7726 m
.88241 .77238 L
s
gsave
.90115 .77303 -61 -11.2392 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87734 .22918 m
.8736 .22887 L
s
.87792 .25699 m
.87418 .25669 L
s
.8785 .28489 m
.87476 .2846 L
s
.87908 .31287 m
.87535 .31259 L
s
.88026 .36909 m
.87652 .36883 L
s
.88084 .39733 m
.8771 .39708 L
s
.88143 .42566 m
.87769 .42542 L
s
.88203 .45408 m
.87828 .45385 L
s
.88322 .51118 m
.87947 .51097 L
s
.88381 .53987 m
.88007 .53966 L
s
.88441 .56864 m
.88067 .56844 L
s
.88501 .5975 m
.88127 .59732 L
s
.88622 .6555 m
.88248 .65533 L
s
.88683 .68464 m
.88308 .68448 L
s
.88744 .71387 m
.88369 .71372 L
s
.88805 .74319 m
.8843 .74305 L
s
.87619 .17381 m
.87245 .17349 L
s
.88928 .80211 m
.88553 .80198 L
s
gsave
.95749 .48707 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.14199 .22149 m
.13013 .8214 L
s
.13013 .8214 m
.74656 .83907 L
s
.74656 .83907 m
.73904 .26772 L
s
.73904 .26772 m
.14199 .22149 L
s
.2211 .11645 m
.87617 .17312 L
s
.87617 .17312 m
.88929 .80284 L
s
.88929 .80284 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.14199 .22149 m
.13013 .8214 L
s
.13013 .8214 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.2211 .11645 m
.14199 .22149 L
s
.73904 .26772 m
.87617 .17312 L
s
.87617 .17312 m
.88929 .80284 L
s
.88929 .80284 m
.74656 .83907 L
s
.74656 .83907 m
.73904 .26772 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.68559 .40522 m .63296 .68006 L .68838 .68029 L .81 0 0 r
F
.68559 .40522 m .63099 .40488 L .63296 .68006 L F
.66855 .38542 m .63099 .40488 L .68559 .40522 L .652 0 0 r
F
.73545 .39962 m .68559 .40522 L .68838 .68029 L .738 0 0 r
F
.67489 .38469 m .68559 .40522 L .73545 .39962 L .652 0 0 r
F
.67489 .38469 m .66855 .38542 L .68559 .40522 L F
.66855 .38542 m .66155 .38538 L .63099 .40488 L F
[ ] 0 setdash
.66405 .66734 m .66155 .38538 L .63099 .40488 L p .393 0 0 r
F P
0 g
s
.66173 .40507 m
.68559 .40522 L
s
.63099 .40488 m .63296 .68006 L .66405 .66734 L p .393 0 0 r
F P
0 g
s
.63296 .68006 m .63099 .40488 L .47243 .39455 L p .844 0 0 r
F P
0 g
s
.47243 .39455 m .63099 .40488 L .66155 .38538 L p .652 0 0 r
F P
0 g
s
.66155 .38538 m .63296 .68006 L .63099 .40488 L .393 0 0 r
F
.73545 .39962 m .68838 .68029 L .73902 .67663 L .738 0 0 r
F
.7679 .38936 m .73545 .39962 L .73902 .67663 L .603 0 0 r
F
.67888 .38337 m .73545 .39962 L .7679 .38936 L .652 0 0 r
F
.67888 .38337 m .67489 .38469 L .73545 .39962 L F
0 g
.68559 .40522 m
.73545 .39962 L
s
.47243 .39455 m .47201 .67332 L .63296 .68006 L p .844 0 0 r
F P
0 g
s
.49933 .66025 m .47201 .67332 L .47243 .39455 L p .326 0 0 r
F P
0 g
s
.66155 .38538 m .49934 .37452 L .47243 .39455 L p .652 0 0 r
F P
0 g
s
.47243 .39455 m .49934 .37452 L .49933 .66025 L p .326 0 0 r
F P
0 g
s
.47243 .39455 m .42348 .66915 L .47201 .67332 L .881 0 0 r
F
.47243 .39455 m .42464 .38816 L .42348 .66915 L F
.49934 .37452 m .42464 .38816 L .47243 .39455 L .652 0 0 r
F
.49934 .37452 m .47243 .39455 L .47201 .67332 L .326 0 0 r
F
.67115 .66737 m .68838 .68029 L .63296 .68006 L .538 0 0 r
F
.67759 .66689 m .68838 .68029 L .67115 .66737 L F
.67759 .66689 m .73902 .67663 L .68838 .68029 L F
.66155 .38538 m .66405 .66734 L .63296 .68006 L .393 0 0 r
F
.66405 .66734 m .63296 .68006 L .47201 .67332 L p .538 0 0 r
F P
0 g
s
.63099 .40488 m
.63287 .66831 L
s
.67115 .66737 m .63296 .68006 L .66405 .66734 L .538 0 0 r
F
0 g
.63296 .68006 m
.68838 .68029 L
s
.82315 .65078 m .81808 .36003 L .7679 .38936 L p .428 0 0 r
F P
0 g
s
.7679 .38936 m .77201 .66993 L .82315 .65078 L p .428 0 0 r
F P
0 g
s
.7679 .38936 m .73902 .67663 L .77201 .66993 L .603 0 0 r
F
.77201 .66993 m .7679 .38936 L .67888 .38337 L p .845 0 0 r
F P
0 g
s
.67888 .38337 m .7679 .38936 L .79253 .37496 L p .652 0 0 r
F P
0 g
s
.67888 .38337 m .79253 .37496 L .74747 .37187 L .652 0 0 r
F
.67888 .38337 m .7679 .38936 L .77201 .66993 L .845 0 0 r
F
.66855 .38542 m .66405 .66734 L .66155 .38538 L .811 0 0 r
F
.66855 .38542 m .67115 .66737 L .66405 .66734 L F
.67489 .38469 m .67115 .66737 L .66855 .38542 L .735 0 0 r
F
.49934 .37452 m .66155 .38538 L .66405 .66734 L p .845 0 0 r
F P
0 g
s
.67489 .38469 m .67759 .66689 L .67115 .66737 L .735 0 0 r
F
.67888 .38337 m .67759 .66689 L .67489 .38469 L .593 0 0 r
F
.67888 .38337 m .68164 .66603 L .77201 .66993 L p .845 0 0 r
F P
0 g
s
.67888 .38337 m .77201 .66993 L .68164 .66603 L .845 0 0 r
F
.72974 .64657 m .68164 .66603 L .67888 .38337 L p .398 0 0 r
F P
0 g
s
.81808 .36003 m .7261 .35359 L .70205 .36875 L p .652 0 0 r
F P
0 g
s
.70205 .36875 m .67888 .38337 L p .74747 .37187 L .652 0 0 r
F P
0 g
s
.74747 .37187 m .81808 .36003 L .70205 .36875 L .652 0 0 r
F
.7261 .35359 m .72974 .64657 L p .70363 .51149 L .398 0 0 r
F P
0 g
s
.67888 .38337 m .70205 .36875 L p .70363 .51149 L .398 0 0 r
F P
0 g
s
.70205 .36875 m .7261 .35359 L p .70363 .51149 L .398 0 0 r
F P
0 g
s
.67888 .38337 m .68164 .66603 L .67759 .66689 L .593 0 0 r
F
.58554 .4441 m .66665 .44909 L .66599 .37588 L p 0 .344 .781 r
F P
0 g
s
.66599 .37588 m .66665 .44909 L .67808 .44242 L p 0 .162 .706 r
F P
0 g
s
.67808 .44242 m .67736 .36856 L .66599 .37588 L p 0 .162 .706 r
F P
0 g
s
.67736 .36856 m .67808 .44242 L .68972 .43563 L p 0 .162 .706 r
F P
0 g
s
.68972 .43563 m .68894 .36111 L .67736 .36856 L p 0 .162 .706 r
F P
0 g
s
.68972 .43563 m .60725 .43045 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.68901 .36786 m .68972 .43563 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.60725 .43045 m .68972 .43563 L .68901 .36786 L p 0 .344 .78 r
F P
0 g
s
.68894 .36111 m .68901 .36786 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.68901 .36786 m .68894 .36111 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.60725 .43045 m .68901 .36786 L .68159 .36735 L 0 .344 .78 r
F
.79253 .37496 m .81808 .36003 L p .74747 .37187 L .652 0 0 r
F P
0 g
s
.72651 .38657 m
.7679 .38936 L
s
.63284 .24172 m .66479 .24424 L .67607 .23578 L p 0 .451 1 r
F P
0 g
s
.67607 .23578 m .66479 .24424 L .66599 .37588 L p 0 .162 .706 r
F P
0 g
s
.66599 .37588 m .66479 .24424 L .63284 .24172 L p 0 .344 .781 r
F P
0 g
s
.63284 .24172 m .60485 .26832 L .66599 .37588 L p 0 .344 .781 r
F P
0 g
s
.5852 .3704 m .66599 .37588 L .66599 .37588 L p 0 .344 .781 r
F P
0 g
s
.66599 .37588 m .60485 .26832 L p .5852 .3704 L 0 .344 .781 r
F P
0 g
s
.5852 .3704 m .66599 .37588 L .5852 .3704 L 0 .344 .781 r
F
.59591 .36299 m .5852 .3704 L .66599 .37588 L p 0 .456 1 r
F P
0 g
s
.66599 .37588 m .67736 .36856 L .67607 .23578 L p 0 .162 .706 r
F P
0 g
s
.66599 .37588 m .67736 .36856 L .59591 .36299 L p 0 .456 1 r
F P
0 g
s
.42464 .38816 m .3951 .66201 L .42348 .66915 L .992 0 0 r
F
.42464 .38816 m .39671 .37721 L .3951 .66201 L F
.49329 .37368 m .39671 .37721 L .42464 .38816 L .652 0 0 r
F
.49934 .37452 m .49329 .37368 L .42464 .38816 L F
0 g
.42464 .38816 m
.47243 .39455 L
s
.68164 .66603 m .73902 .67663 L .67759 .66689 L .538 0 0 r
F
.68164 .66603 m .77201 .66993 L .73902 .67663 L F
0 g
.68838 .68029 m
.73902 .67663 L
s
.63284 .24172 m .64386 .23322 L .51322 .2228 L p 0 .451 1 r
F P
0 g
s
.51322 .2228 m .50328 .2315 L .63284 .24172 L p 0 .451 1 r
F P
0 g
s
.60485 .26832 m .63284 .24172 L .50328 .2315 L closepath p 0 .344 .781 r
F P
0 g
s
.55444 .31624 m .60485 .26832 L .50328 .2315 L p 0 .344 .781 r
F P
0 g
s
.50329 .29793 m .55444 .31624 L p .50328 .2315 L 0 .344 .781 r
F P
0 g
s
.39718 .29015 m .50329 .29793 L .50328 .2315 L p 0 .344 .781 r
F P
0 g
s
.50328 .2315 m .50329 .29793 L p .50328 .2315 L 0 .344 .781 r
F P
0 g
s
.50328 .2315 m .50329 .29793 L .51327 .28982 L p 0 .134 .679 r
F P
0 g
s
.51327 .28982 m .51322 .2228 L .50328 .2315 L p 0 .134 .679 r
F P
0 g
s
.67607 .23578 m .64386 .23322 L .63284 .24172 L p 0 .451 1 r
F P
0 g
s
.60485 .26832 m .55444 .31624 L .5852 .3704 L p 0 .344 .781 r
F P
0 g
s
.5033 .36485 m .5852 .3704 L .5852 .3704 L p 0 .344 .781 r
F P
0 g
s
.5852 .3704 m .55444 .31624 L .5033 .36485 L p 0 .344 .781 r
F P
0 g
s
.5033 .36485 m .55444 .31624 L .50329 .29793 L closepath p 0 .344 .781 r
F P
0 g
s
.51332 .35733 m .51327 .28982 L .50329 .29793 L p 0 .134 .679 r
F P
0 g
s
.50329 .29793 m .5033 .36485 L .51332 .35733 L p 0 .134 .679 r
F P
0 g
s
.5033 .36485 m .5033 .36485 L p .5852 .3704 L 0 .344 .781 r
F P
0 g
s
.51332 .35733 m .5033 .36485 L .5852 .3704 L p 0 .456 1 r
F P
0 g
s
.66405 .66734 m .49933 .66025 L .49934 .37452 L p .845 0 0 r
F P
0 g
s
.5852 .3704 m .5033 .36485 L .50331 .43904 L p 0 .344 .781 r
F P
0 g
s
.50331 .43904 m .58554 .4441 L .5852 .3704 L p 0 .344 .781 r
F P
0 g
s
.5852 .3704 m .5033 .36485 L .51332 .35733 L p 0 .456 1 r
F P
0 g
s
.5033 .36485 m .51332 .35733 L .51338 .43218 L p 0 .134 .679 r
F P
0 g
s
.5852 .3704 m .59591 .36299 L .51332 .35733 L p 0 .456 1 r
F P
0 g
s
.66599 .37588 m .5852 .3704 L .58554 .4441 L p 0 .344 .781 r
F P
0 g
s
.67736 .36856 m .66599 .37588 L .5852 .3704 L p 0 .456 1 r
F P
0 g
s
.47201 .67332 m .49933 .66025 L .66405 .66734 L p .538 0 0 r
F P
0 g
s
.49934 .37452 m .47201 .67332 L .49933 .66025 L .326 0 0 r
F
.49933 .66025 m .47201 .67332 L .42348 .66915 L .538 0 0 r
F
0 g
.47202 .66345 m
.47243 .39455 L
s
.65508 .22455 m .64386 .23322 L .67607 .23578 L p 0 .451 1 r
F P
0 g
s
.67607 .23578 m .68756 .22717 L .65508 .22455 L p 0 .451 1 r
F P
0 g
s
.68756 .22717 m .67607 .23578 L .67736 .36856 L p 0 .162 .706 r
F P
0 g
s
.66665 .44909 m .58554 .4441 L .58589 .5184 L p 0 .344 .781 r
F P
0 g
s
.58589 .5184 m .66732 .5229 L .66665 .44909 L p 0 .344 .781 r
F P
0 g
s
.66665 .44909 m .66732 .5229 L .6788 .51688 L p 0 .162 .706 r
F P
0 g
s
.6788 .51688 m .67808 .44242 L .66665 .44909 L p 0 .162 .706 r
F P
0 g
s
.64386 .23322 m .65508 .22455 L .52335 .21395 L p 0 .451 1 r
F P
0 g
s
.52335 .21395 m .51322 .2228 L .64386 .23322 L p 0 .451 1 r
F P
0 g
s
.50328 .2315 m .39756 .22315 L .39718 .29015 L p 0 .344 .781 r
F P
0 g
s
.50328 .2315 m .51322 .2228 L .40662 .2143 L p 0 .451 1 r
F P
0 g
s
.40662 .2143 m .39756 .22315 L .50328 .2315 L p 0 .451 1 r
F P
0 g
s
.50329 .29793 m .50328 .2315 L .51322 .2228 L p 0 .134 .679 r
F P
0 g
s
.5852 .3704 m .59591 .36299 L .67736 .36856 L p 0 .456 1 r
F P
0 g
s
.51332 .35733 m .59591 .36299 L .5852 .3704 L p 0 .456 1 r
F P
0 g
s
.82315 .65078 m .77201 .66993 L .68164 .66603 L p .538 0 0 r
F P
0 g
s
.7679 .38936 m
.77181 .65631 L
s
.73902 .67663 m
.77201 .66993 L
s
.39671 .37721 m .39513 .65365 L .3951 .66201 L .809 0 0 r
F
.49318 .6597 m .42348 .66915 L .3951 .66201 L .538 0 0 r
F
.49933 .66025 m .42348 .66915 L .49318 .6597 L F
.48974 .65879 m .3951 .66201 L .39513 .65365 L F
.49318 .6597 m .3951 .66201 L .48974 .65879 L F
.50337 .73492 m .50335 .66526 L .39509 .66065 L p 0 .344 .781 r
F P
0 g
s
.39671 .37721 m .39676 .36441 L .39513 .65365 L .809 0 0 r
F
.4899 .37228 m .39676 .36441 L .39671 .37721 L .652 0 0 r
F
.49329 .37368 m .4899 .37228 L .39671 .37721 L F
0 g
.39671 .37721 m
.42464 .38816 L
s
.66732 .5229 m .58589 .5184 L .59669 .5123 L p 0 .458 1 r
F P
0 g
s
.66277 .52265 m
.66279 .52528 L
s
.59669 .5123 m .6788 .51688 L .66732 .5229 L p 0 .458 1 r
F P
0 g
s
.668 .5973 m .66732 .5229 L .58589 .5184 L p 0 .344 .781 r
F P
0 g
s
.6788 .51688 m .66732 .5229 L .668 .5973 L p 0 .162 .706 r
F P
0 g
s
.66732 .5229 m .6788 .51688 L .59669 .5123 L p 0 .458 1 r
F P
0 g
s
.59669 .5123 m .58589 .5184 L .66732 .5229 L p 0 .458 1 r
F P
0 g
s
.3951 .66201 m
.39822 .66279 L
s
.67736 .36856 m .68894 .36111 L .68756 .22717 L p 0 .162 .706 r
F P
0 g
s
.67736 .36856 m .68894 .36111 L .60681 .35543 L p 0 .456 1 r
F P
0 g
s
.60681 .35543 m .59591 .36299 L .67736 .36856 L p 0 .456 1 r
F P
0 g
s
.68894 .36111 m .67736 .36856 L .59591 .36299 L p 0 .456 1 r
F P
0 g
s
.50329 .29793 m .39718 .29015 L .3968 .35764 L p 0 .344 .781 r
F P
0 g
s
.3968 .35764 m .5033 .36485 L .50329 .29793 L p 0 .344 .781 r
F P
0 g
s
.51322 .2228 m .51327 .28982 L .50329 .29793 L p 0 .134 .679 r
F P
0 g
s
.50329 .29793 m .51327 .28982 L .51332 .35733 L p 0 .134 .679 r
F P
0 g
s
.51332 .35733 m .5033 .36485 L .50329 .29793 L p 0 .134 .679 r
F P
0 g
s
.49934 .37452 m .49318 .6597 L .49329 .37368 L .883 0 0 r
F
0 g
.47243 .39455 m
.49328 .37903 L
s
.49934 .37452 m .49933 .66025 L .49318 .6597 L .883 0 0 r
F
0 g
.49004 .66469 m
.49933 .66025 L
s
.58554 .4441 m .50331 .43904 L .50333 .51383 L p 0 .344 .781 r
F P
0 g
s
.50333 .51383 m .58589 .5184 L .58554 .4441 L p 0 .344 .781 r
F P
0 g
s
.68756 .22717 m .68894 .36111 L .62667 .25158 L p 0 .344 .78 r
F P
0 g
s
.62667 .25158 m .65508 .22455 L .68756 .22717 L p 0 .344 .78 r
F P
0 g
s
.68756 .22717 m .69926 .2184 L .66651 .21573 L p 0 .451 1 r
F P
0 g
s
.66651 .21573 m .65508 .22455 L .68756 .22717 L p 0 .451 1 r
F P
0 g
s
.69926 .2184 m .68756 .22717 L .68894 .36111 L p 0 .162 .706 r
F P
0 g
s
.68894 .36111 m .68756 .22717 L .65508 .22455 L p 0 .344 .78 r
F P
0 g
s
.49329 .37368 m .48974 .65879 L .4899 .37228 L .999 0 0 r
F
.49329 .37368 m .49318 .6597 L .48974 .65879 L F
0 g
.49329 .37368 m
.49934 .37452 L
s
.66868 .67231 m .668 .5973 L .58624 .5933 L p 0 .344 .781 r
F P
0 g
s
.66864 .66736 m
.67115 .66737 L
s
.66339 .59287 m
.66343 .59708 L
s
.63296 .68006 m
.66366 .6675 L
s
.67953 .59195 m .668 .5973 L .66868 .67231 L p 0 .162 .706 r
F P
0 g
s
.58624 .5933 m .58659 .66881 L .66868 .67231 L p 0 .344 .781 r
F P
0 g
s
.66868 .67231 m .68027 .66763 L .67953 .59195 L p 0 .162 .706 r
F P
0 g
s
.72974 .64657 m .82315 .65078 L p .75135 .65852 L .538 0 0 r
F P
0 g
s
.68164 .66603 m .70524 .65648 L p .75135 .65852 L .538 0 0 r
F P
0 g
s
.70524 .65648 m .72974 .64657 L p .75135 .65852 L .538 0 0 r
F P
0 g
s
.58589 .5184 m .58624 .5933 L .668 .5973 L p 0 .344 .781 r
F P
0 g
s
.668 .5973 m .67953 .59195 L .6788 .51688 L p 0 .162 .706 r
F P
0 g
s
.69049 .51075 m .6788 .51688 L .67953 .59195 L p 0 .162 .706 r
F P
0 g
s
.69128 .5865 m .67953 .59195 L .68027 .66763 L p 0 .162 .706 r
F P
0 g
s
.67953 .59195 m .69128 .5865 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
.68027 .66763 m .69207 .66287 L .69128 .5865 L p 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .60859 .65924 L .60814 .58234 L p 0 .344 .78 r
F P
0 g
s
.68027 .66763 m .69207 .66287 L .60859 .65924 L p 0 .455 1 r
F P
0 g
s
.66868 .67231 m .68027 .66763 L .59749 .66407 L p 0 .455 1 r
F P
0 g
s
.59749 .66407 m .58659 .66881 L .66868 .67231 L p 0 .455 1 r
F P
0 g
s
.66868 .67231 m .58659 .66881 L .59749 .66407 L p 0 .455 1 r
F P
0 g
s
.59749 .66407 m .68027 .66763 L .66868 .67231 L p 0 .455 1 r
F P
0 g
s
.68027 .66763 m .66868 .67231 L .66993 .81026 L p 0 .162 .706 r
F P
0 g
s
.66868 .67231 m .58659 .66881 L .55565 .7216 L p 0 .344 .781 r
F P
0 g
s
.55565 .7216 m .6078 .77778 L .66868 .67231 L p 0 .344 .781 r
F P
0 g
s
.66993 .81026 m .66868 .67231 L .6078 .77778 L p 0 .344 .781 r
F P
0 g
s
.66993 .81026 m .68162 .80684 L .68027 .66763 L p 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .68027 .66763 L .68162 .80684 L p 0 .162 .706 r
F P
0 g
s
.60859 .65924 m .59749 .66407 L .68027 .66763 L p 0 .455 1 r
F P
0 g
s
.68027 .66763 m .59749 .66407 L .60859 .65924 L p 0 .455 1 r
F P
0 g
s
.60859 .65924 m .69207 .66287 L .68027 .66763 L p 0 .455 1 r
F P
0 g
s
.60859 .65924 m .69207 .66287 L .63029 .77024 L p 0 .344 .78 r
F P
0 g
s
.69207 .66287 m .60859 .65924 L .57719 .71298 L p 0 .344 .78 r
F P
0 g
s
.60859 .65924 m .69207 .66287 L p .69207 .66287 L 0 .344 .78 r
F P
0 g
s
.60814 .58234 m .60859 .65924 L p .69207 .66287 L 0 .344 .78 r
F P
0 g
s
.60859 .65924 m .60859 .65924 L p .69207 .66287 L 0 .344 .78 r
F P
0 g
s
.61991 .65431 m .60859 .65924 L .69207 .66287 L p 0 .455 1 r
F P
0 g
s
.60814 .58234 m .69128 .5865 L .692 .6559 L p 0 .344 .78 r
F P
0 g
s
.692 .6559 m .69207 .66287 L p .68446 .65557 L 0 .344 .78 r
F P
0 g
s
.60814 .58234 m .692 .6559 L .68446 .65557 L 0 .344 .78 r
F
0 g
.67945 .44162 m
.68018 .51616 L
s
.67808 .44242 m .6788 .51688 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
.69049 .51075 m .68972 .43563 L .67808 .44242 L p 0 .162 .706 r
F P
0 g
s
.4899 .37228 m .48993 .65774 L .49009 .37068 L .1 0 0 r
F
0 g
.49009 .37236 m
.49329 .37368 L
s
.4899 .37228 m .48974 .65879 L .48993 .65774 L .1 0 0 r
F
.4899 .37228 m .49009 .37068 L .39676 .36441 L .652 0 0 r
F
.52335 .21395 m .65508 .22455 L .62667 .25158 L closepath p 0 .344 .78 r
F P
0 g
s
.53368 .20492 m .52335 .21395 L .65508 .22455 L p 0 .451 1 r
F P
0 g
s
.62667 .25158 m .65508 .22455 L .52335 .21395 L closepath p 0 .344 .78 r
F P
0 g
s
.52344 .28156 m .52335 .21395 L .51322 .2228 L p 0 .134 .679 r
F P
0 g
s
.52344 .28156 m .52335 .21395 L .52335 .21395 L p 0 .344 .78 r
F P
0 g
s
.52335 .21395 m .62667 .25158 L p .52344 .28156 L 0 .344 .78 r
F P
0 g
s
.52344 .28156 m .52335 .21395 L .52344 .28156 L 0 .344 .78 r
F
.57547 .30027 m .62667 .25158 L .52335 .21395 L p F P
0 g
s
.52335 .21395 m .52344 .28156 L .52344 .28156 L p 0 .344 .78 r
F P
0 g
s
.52344 .28156 m .57547 .30027 L p .52335 .21395 L 0 .344 .78 r
F P
0 g
s
.52335 .21395 m .52335 .21395 L .52344 .28156 L 0 .344 .78 r
F
.62667 .25158 m .57547 .30027 L .52344 .28156 L p F P
0 g
s
.52353 .34967 m .52344 .28156 L .51327 .28982 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .52344 .28156 L .52344 .28156 L p 0 .344 .78 r
F P
0 g
s
.52344 .28156 m .57547 .30027 L .52353 .34967 L p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .52353 .34967 L p .52344 .28156 L 0 .344 .78 r
F P
0 g
s
.57547 .30027 m .52344 .28156 L .52353 .34967 L closepath p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .57547 .30027 L .60681 .35543 L closepath p 0 .344 .78 r
F P
0 g
s
.60681 .35543 m .57547 .30027 L .52353 .34967 L closepath p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .53393 .34186 L .5338 .27314 L p 0 .134 .679 r
F P
0 g
s
.5338 .27314 m .52344 .28156 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52344 .28156 m .5338 .27314 L .53368 .20492 L p 0 .134 .679 r
F P
0 g
s
.53368 .20492 m .52335 .21395 L .52344 .28156 L p 0 .134 .679 r
F P
0 g
s
.65508 .22455 m .66651 .21573 L .53368 .20492 L p 0 .451 1 r
F P
0 g
s
.65508 .22455 m .62667 .25158 L .68894 .36111 L p 0 .344 .78 r
F P
0 g
s
.51338 .43218 m .50331 .43904 L .5033 .36485 L p 0 .134 .679 r
F P
0 g
s
.5033 .36485 m .3968 .35764 L .40592 .34998 L p 0 .456 1 r
F P
0 g
s
.40592 .34998 m .51332 .35733 L .5033 .36485 L p 0 .456 1 r
F P
0 g
s
.69181 .66647 m
.77201 .66993 L
s
.58589 .5184 m .50333 .51383 L .51343 .50764 L p 0 .458 1 r
F P
0 g
s
.51343 .50764 m .59669 .5123 L .58589 .5184 L p 0 .458 1 r
F P
0 g
s
.58624 .5933 m .58589 .5184 L .50333 .51383 L p 0 .344 .781 r
F P
0 g
s
.58589 .5184 m .59669 .5123 L .51343 .50764 L p 0 .458 1 r
F P
0 g
s
.51343 .50764 m .50333 .51383 L .58589 .5184 L p 0 .458 1 r
F P
0 g
s
.39756 .22315 m .28996 .21466 L .28918 .28222 L p 0 .344 .781 r
F P
0 g
s
.28918 .28222 m .39718 .29015 L .39756 .22315 L p 0 .344 .781 r
F P
0 g
s
.39756 .22315 m .40662 .2143 L .29809 .20565 L p 0 .451 1 r
F P
0 g
s
.29809 .20565 m .28996 .21466 L .39756 .22315 L p 0 .451 1 r
F P
0 g
s
.59591 .36299 m .60681 .35543 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.52353 .34967 m .51332 .35733 L .59591 .36299 L p 0 .456 1 r
F P
0 g
s
.60681 .35543 m .59591 .36299 L .51332 .35733 L p 0 .456 1 r
F P
0 g
s
.52353 .34967 m .60681 .35543 L p .60681 .35543 L 0 .344 .78 r
F P
0 g
s
.59591 .36299 m .60681 .35543 L .68894 .36111 L p 0 .456 1 r
F P
0 g
s
.60681 .35543 m .68894 .36111 L p .68894 .36111 L 0 .344 .78 r
F P
0 g
s
.60725 .43045 m .60681 .35543 L p .68894 .36111 L 0 .344 .78 r
F P
0 g
s
.60681 .35543 m .60681 .35543 L p .68894 .36111 L 0 .344 .78 r
F P
0 g
s
.51332 .35733 m .52353 .34967 L .60681 .35543 L p 0 .456 1 r
F P
0 g
s
.52363 .42519 m .52353 .34967 L p .60681 .35543 L 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .52353 .34967 L p .60681 .35543 L 0 .344 .78 r
F P
0 g
s
.50331 .43904 m .51338 .43218 L .51343 .50764 L p 0 .134 .679 r
F P
0 g
s
.51343 .50764 m .50333 .51383 L .50331 .43904 L p 0 .134 .679 r
F P
0 g
s
.58659 .66881 m .58624 .5933 L .50334 .58924 L p 0 .344 .781 r
F P
0 g
s
.50333 .51383 m .50334 .58924 L .58624 .5933 L p 0 .344 .781 r
F P
0 g
s
.51327 .28982 m .52344 .28156 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .52344 .28156 L p .52344 .28156 L 0 .344 .78 r
F P
0 g
s
.51322 .2228 m .51327 .28982 L .52344 .28156 L p 0 .134 .679 r
F P
0 g
s
.52344 .28156 m .51327 .28982 L .51322 .2228 L p 0 .134 .679 r
F P
0 g
s
.52344 .28156 m .52335 .21395 L p .52335 .21395 L 0 .344 .78 r
F P
0 g
s
.51322 .2228 m .52335 .21395 L .52344 .28156 L p 0 .134 .679 r
F P
0 g
s
.51322 .2228 m .52335 .21395 L .41584 .20529 L p 0 .451 1 r
F P
0 g
s
.41584 .20529 m .40662 .2143 L .51322 .2228 L p 0 .451 1 r
F P
0 g
s
.41552 .27348 m .52344 .28156 L p .52335 .21395 L 0 .344 .78 r
F P
0 g
s
.52344 .28156 m .52344 .28156 L p .52335 .21395 L 0 .344 .78 r
F P
0 g
s
.51327 .28982 m .51332 .35733 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .51332 .35733 L .51327 .28982 L p 0 .134 .679 r
F P
0 g
s
.51006 .28905 m .52353 .34967 L .52344 .28156 L 0 .344 .78 r
F
.5101 .34874 m .52353 .34967 L p .51006 .28905 L F P
0 g
s
.52353 .34967 m .52353 .34967 L p .52344 .28156 L 0 .344 .78 r
F P
0 g
s
.51332 .35733 m .52353 .34967 L .52363 .42519 L p 0 .134 .679 r
F P
0 g
s
.52363 .42519 m .51338 .43218 L .51332 .35733 L p 0 .134 .679 r
F P
0 g
s
.51332 .35733 m .40592 .34998 L .4152 .34218 L p 0 .456 1 r
F P
0 g
s
.4152 .34218 m .52353 .34967 L .51332 .35733 L p 0 .456 1 r
F P
0 g
s
.50334 .58924 m .50335 .66526 L .58659 .66881 L p 0 .344 .781 r
F P
0 g
s
.59669 .5123 m .51343 .50764 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .6077 .50608 L .59669 .5123 L p 0 .458 1 r
F P
0 g
s
.59669 .5123 m .6077 .50608 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .51343 .50764 L .59669 .5123 L p 0 .458 1 r
F P
0 g
s
.60681 .35543 m .60725 .43045 L .52363 .42519 L p 0 .344 .78 r
F P
0 g
s
.62667 .25158 m .57547 .30027 L .60681 .35543 L p 0 .344 .78 r
F P
0 g
s
.60681 .35543 m .68894 .36111 L .62667 .25158 L p 0 .344 .78 r
F P
0 g
s
.68894 .36111 m .60681 .35543 L .57547 .30027 L p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .60681 .35543 L .61793 .34773 L p 0 .456 1 r
F P
0 g
s
.61793 .34773 m .60681 .35543 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.60681 .35543 m .52353 .34967 L .52363 .42519 L p 0 .344 .78 r
F P
0 g
s
.52363 .42519 m .60725 .43045 L .60681 .35543 L p 0 .344 .78 r
F P
0 g
s
.51338 .43218 m .52363 .42519 L .52373 .50134 L p 0 .134 .679 r
F P
0 g
s
.52373 .50134 m .51343 .50764 L .51338 .43218 L p 0 .134 .679 r
F P
0 g
s
.53393 .34186 m .52353 .34967 L .52344 .28156 L p 0 .134 .679 r
F P
0 g
s
.52344 .28156 m .52353 .34967 L .5101 .34874 L p 0 .344 .78 r
F P
0 g
s
.4152 .34218 m .5101 .34874 L p .51006 .28905 L 0 .344 .78 r
F P
0 g
s
.5101 .34874 m .4152 .34218 L p .51006 .28905 L 0 .344 .78 r
F P
0 g
s
.48993 .65774 m .49009 .37068 L .39676 .36441 L p .845 0 0 r
F P
0 g
s
.51006 .28905 m .52344 .28156 L .5101 .34874 L 0 .344 .78 r
F
.53393 .34186 m .52353 .34967 L .4152 .34218 L p 0 .456 1 r
F P
0 g
s
.52344 .28156 m .41552 .27348 L .4152 .34218 L p 0 .344 .78 r
F P
0 g
s
.4152 .34218 m .41552 .27348 L .52344 .28156 L p 0 .344 .78 r
F P
0 g
s
.4152 .34218 m .42466 .33423 L .53393 .34186 L p 0 .456 1 r
F P
0 g
s
.52344 .28156 m .5338 .27314 L .53393 .34186 L p 0 .134 .679 r
F P
0 g
s
.54436 .26456 m .5338 .27314 L .53393 .34186 L p 0 .134 .679 r
F P
0 g
s
.53393 .34186 m .54453 .33391 L .54436 .26456 L p 0 .134 .679 r
F P
0 g
s
.54453 .33391 m .53393 .34186 L .5338 .27314 L p 0 .134 .679 r
F P
0 g
s
.54453 .33391 m .53393 .34186 L .42466 .33423 L p 0 .456 1 r
F P
0 g
s
.39676 .36441 m .49009 .37068 L .53088 .33992 L p .652 0 0 r
F P
0 g
s
.49009 .37068 m .39513 .65365 L .39676 .36441 L .845 0 0 r
F
.49009 .37068 m .48993 .65774 L .39513 .65365 L F
.39676 .36441 m .39513 .65365 L .48993 .65774 L p F P
0 g
s
.42466 .33423 m .43431 .32613 L .54453 .33391 L p 0 .456 1 r
F P
0 g
s
.53088 .33992 m .43429 .33315 L .39676 .36441 L p .652 0 0 r
F P
0 g
s
.43429 .33315 m .4332 .63322 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.39676 .36441 m .41517 .34908 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.41517 .34908 m .43429 .33315 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.60725 .43045 m .6077 .50608 L .52373 .50134 L p 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .52363 .42519 L .60725 .43045 L p 0 .344 .78 r
F P
0 g
s
.60725 .43045 m .52363 .42519 L .52373 .50134 L p 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .6077 .50608 L .60725 .43045 L p 0 .344 .78 r
F P
0 g
s
.51349 .58373 m .51343 .50764 L .52373 .50134 L p 0 .134 .679 r
F P
0 g
s
.61793 .34773 m .53393 .34186 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.52353 .34967 m .53393 .34186 L .61793 .34773 L p 0 .456 1 r
F P
0 g
s
.52363 .42519 m .52353 .34967 L .53393 .34186 L p 0 .134 .679 r
F P
0 g
s
.6788 .51688 m .59669 .5123 L .6077 .50608 L p 0 .458 1 r
F P
0 g
s
.6077 .50608 m .59669 .5123 L .6788 .51688 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .6077 .50608 L .60814 .58234 L p 0 .344 .78 r
F P
0 g
s
.68972 .43563 m .69049 .51075 L .6077 .50608 L p 0 .344 .78 r
F P
0 g
s
.6077 .50608 m .60725 .43045 L .68972 .43563 L p 0 .344 .78 r
F P
0 g
s
.68972 .43563 m .60725 .43045 L .6077 .50608 L p 0 .344 .78 r
F P
0 g
s
.6077 .50608 m .69049 .51075 L .68972 .43563 L p 0 .344 .78 r
F P
0 g
s
.61891 .49974 m .6077 .50608 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.60814 .58234 m .6077 .50608 L .52373 .50134 L p 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .6077 .50608 L .61891 .49974 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .52382 .57812 L .51349 .58373 L p 0 .134 .679 r
F P
0 g
s
.53393 .34186 m .53407 .41807 L .52363 .42519 L p 0 .134 .679 r
F P
0 g
s
.52373 .50134 m .52363 .42519 L .53407 .41807 L p 0 .134 .679 r
F P
0 g
s
.52382 .57812 m .60814 .58234 L .60859 .65924 L p 0 .344 .78 r
F P
0 g
s
.60814 .58234 m .52382 .57812 L .52373 .50134 L p 0 .344 .78 r
F P
0 g
s
.60859 .65924 m .60814 .58234 L .52382 .57812 L p 0 .344 .78 r
F P
0 g
s
.60859 .65924 m .52392 .65555 L .52392 .65555 L p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .52392 .64849 L p .60859 .65924 L 0 .344 .78 r
F P
0 g
s
.60859 .65924 m .60859 .65924 L .52392 .65555 L 0 .344 .78 r
F
.48993 .65774 m .39513 .65365 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.52392 .64849 m .52382 .57812 L p .60091 .65188 L 0 .344 .78 r
F P
0 g
s
.50334 .58924 m .50333 .51383 L .51343 .50764 L p 0 .134 .679 r
F P
0 g
s
.50335 .66526 m .50334 .58924 L .51349 .58373 L p 0 .134 .679 r
F P
0 g
s
.51349 .58373 m .51354 .66045 L .50335 .66526 L p 0 .134 .679 r
F P
0 g
s
.51343 .50764 m .51349 .58373 L .50334 .58924 L p 0 .134 .679 r
F P
0 g
s
.51354 .66045 m .51349 .58373 L .52382 .57812 L p 0 .134 .679 r
F P
0 g
s
.50335 .66526 m .58659 .66881 L .59749 .66407 L p 0 .455 1 r
F P
0 g
s
.59749 .66407 m .51354 .66045 L .50335 .66526 L p 0 .455 1 r
F P
0 g
s
.58659 .66881 m .50335 .66526 L .51354 .66045 L p 0 .455 1 r
F P
0 g
s
.55565 .7216 m .58659 .66881 L .50335 .66526 L closepath p 0 .344 .781 r
F P
0 g
s
.50335 .66526 m .50337 .73492 L .50337 .73492 L p 0 .344 .781 r
F P
0 g
s
.50337 .73492 m .55565 .7216 L .50335 .66526 L p 0 .344 .781 r
F P
0 g
s
.50335 .66526 m .50335 .66526 L p .50337 .73492 L 0 .344 .781 r
F P
0 g
s
.50337 .73492 m .51359 .73075 L .51354 .66045 L p 0 .134 .679 r
F P
0 g
s
.51354 .66045 m .50335 .66526 L .50337 .73492 L p 0 .134 .679 r
F P
0 g
s
.51354 .66045 m .59749 .66407 L .58659 .66881 L p 0 .455 1 r
F P
0 g
s
.52392 .65555 m .51621 .65919 L .59749 .66407 L p 0 .455 1 r
F P
0 g
s
.59749 .66407 m .51354 .66045 L .52392 .65555 L p 0 .455 1 r
F P
0 g
s
.51359 .73075 m .52402 .72651 L .52392 .65555 L p 0 .134 .679 r
F P
0 g
s
.52382 .57812 m .52392 .65555 L .51354 .66045 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .51354 .66045 L .51359 .73075 L p 0 .134 .679 r
F P
0 g
s
.51354 .66045 m .52392 .65555 L .51027 .65496 L p 0 .455 1 r
F P
0 g
s
.50127 .65926 m .51354 .66045 L .51027 .65496 L 0 .455 1 r
F
.50335 .66526 m .51354 .66045 L .40434 .65575 L p F P
0 g
s
.50335 .66526 m .51354 .66045 L .51359 .73075 L p 0 .134 .679 r
F P
0 g
s
.48974 .65879 m .39513 .65365 L .48993 .65774 L .538 0 0 r
F
.49009 .37068 m .48993 .65774 L .51026 .64788 L p .32 0 0 r
F P
0 g
s
.52382 .57812 m .52392 .64849 L p .60091 .65188 L 0 .344 .78 r
F P
0 g
s
.60091 .65188 m .60859 .65924 L .52392 .64849 L 0 .344 .78 r
F
.52392 .64849 m .52392 .65555 L p .60091 .65188 L F P
0 g
s
.59749 .66407 m .60859 .65924 L .52392 .65555 L p 0 .455 1 r
F P
0 g
s
.52392 .65555 m .60859 .65924 L .59749 .66407 L p 0 .455 1 r
F P
0 g
s
.60859 .65924 m .57719 .71298 L .52392 .65555 L closepath p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .57719 .71298 L .60859 .65924 L closepath p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .60859 .65924 L p .60859 .65924 L 0 .344 .78 r
F P
0 g
s
.60091 .65188 m .52392 .65555 L .60859 .65924 L 0 .344 .78 r
F
.52392 .65555 m .52392 .65555 L .60859 .65924 L F
.53451 .65056 m .52392 .65555 L .60859 .65924 L p 0 .455 1 r
F P
0 g
s
.60859 .65924 m .61991 .65431 L .53451 .65056 L p 0 .455 1 r
F P
0 g
s
.61991 .65431 m .60859 .65924 L .52392 .65555 L p 0 .455 1 r
F P
0 g
s
.52402 .72651 m .52392 .65555 L .52392 .65555 L p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .57719 .71298 L .52402 .72651 L p 0 .344 .78 r
F P
0 g
s
.52402 .72651 m .52402 .72651 L p .52392 .65555 L 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .52402 .72651 L .52402 .72651 L p 0 .344 .78 r
F P
0 g
s
.52402 .72651 m .57719 .71298 L .52392 .65555 L p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .52392 .65555 L p .52402 .72651 L 0 .344 .78 r
F P
0 g
s
.6078 .77778 m .55565 .7216 L .50337 .73492 L p 0 .344 .781 r
F P
0 g
s
.50338 .8051 m .50337 .73492 L .39469 .73092 L p 0 .344 .781 r
F P
0 g
s
.50337 .73492 m .50338 .8051 L .50338 .8051 L p 0 .344 .781 r
F P
0 g
s
.50338 .8051 m .6078 .77778 L p .50337 .73492 L 0 .344 .781 r
F P
0 g
s
.50337 .73492 m .50338 .8051 L .50337 .73492 L 0 .344 .781 r
F
.50338 .8051 m .51365 .80159 L .51359 .73075 L p 0 .134 .679 r
F P
0 g
s
.51359 .73075 m .50337 .73492 L .50338 .8051 L p 0 .134 .679 r
F P
0 g
s
.50338 .8051 m .50337 .73492 L .51359 .73075 L p 0 .134 .679 r
F P
0 g
s
.39469 .73092 m .39429 .80173 L .50338 .8051 L p 0 .344 .781 r
F P
0 g
s
.51359 .73075 m .51365 .80159 L .50338 .8051 L p 0 .134 .679 r
F P
0 g
s
.51365 .80159 m .4036 .79815 L .4131 .7945 L p 0 .443 1 r
F P
0 g
s
.4036 .79815 m .51365 .80159 L .50338 .8051 L p 0 .443 1 r
F P
0 g
s
.57719 .71298 m .63029 .77024 L .52411 .79801 L p 0 .344 .78 r
F P
0 g
s
.52402 .72651 m .52411 .79801 L .63029 .77024 L p 0 .344 .78 r
F P
0 g
s
.52411 .79801 m .52402 .72651 L .57719 .71298 L p 0 .344 .78 r
F P
0 g
s
.52402 .72651 m .52411 .79801 L .53477 .79435 L p 0 .134 .679 r
F P
0 g
s
.52402 .72651 m .51359 .73075 L .51365 .80159 L p 0 .134 .679 r
F P
0 g
s
.51365 .80159 m .52411 .79801 L .52402 .72651 L p 0 .134 .679 r
F P
0 g
s
.52411 .79801 m .51365 .80159 L .51359 .73075 L p 0 .134 .679 r
F P
0 g
s
.51359 .73075 m .52402 .72651 L .52411 .79801 L p 0 .134 .679 r
F P
0 g
s
.52411 .79801 m .52402 .72651 L .52402 .72651 L p 0 .344 .78 r
F P
0 g
s
.51359 .73075 m .50337 .73492 L .50335 .66526 L p 0 .134 .679 r
F P
0 g
s
.39509 .66065 m .39469 .73092 L .50337 .73492 L p 0 .344 .781 r
F P
0 g
s
.52402 .72651 m .51359 .73075 L .51354 .66045 L p 0 .134 .679 r
F P
0 g
s
.39513 .65365 m .4138 .64363 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.41377 .65076 m .40434 .65575 L .51354 .66045 L p 0 .455 1 r
F P
0 g
s
.40434 .65575 m .39509 .66065 L .50335 .66526 L p 0 .455 1 r
F P
0 g
s
.41377 .65076 m .41343 .72235 L .52402 .72651 L p 0 .344 .78 r
F P
0 g
s
.52402 .72651 m .41343 .72235 L p .52411 .79801 L 0 .344 .78 r
F P
0 g
s
.52411 .79801 m .52411 .79801 L .52402 .72651 L 0 .344 .78 r
F
.53477 .79435 m .52411 .79801 L .52402 .72651 L p 0 .134 .679 r
F P
0 g
s
.41343 .72235 m .52402 .72651 L .52411 .79801 L p 0 .344 .78 r
F P
0 g
s
.41343 .72235 m .4131 .7945 L .52411 .79801 L p 0 .344 .78 r
F P
0 g
s
.52411 .79801 m .4131 .7945 L .41343 .72235 L p 0 .344 .78 r
F P
0 g
s
.4131 .7945 m .42278 .79078 L .53477 .79435 L p 0 .443 1 r
F P
0 g
s
.53477 .79435 m .52411 .79801 L .4131 .7945 L p 0 .443 1 r
F P
0 g
s
.63029 .77024 m .57719 .71298 L .52402 .72651 L p 0 .344 .78 r
F P
0 g
s
.53477 .79435 m .53464 .72218 L .52402 .72651 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52402 .72651 L .53464 .72218 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .53451 .65056 L .61991 .65431 L p 0 .455 1 r
F P
0 g
s
.53451 .65056 m .61991 .65431 L .63144 .64929 L p 0 .455 1 r
F P
0 g
s
.54529 .64546 m .63144 .64929 L .63144 .64929 L p 0 .344 .779 r
F P
0 g
s
.63144 .64929 m .61991 .65431 L .53451 .65056 L p 0 .455 1 r
F P
0 g
s
.57719 .71298 m .63029 .77024 L .69207 .66287 L p 0 .344 .78 r
F P
0 g
s
.69128 .5865 m .69207 .66287 L .7041 .65801 L p 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .69128 .5865 L .60814 .58234 L p 0 .344 .78 r
F P
0 g
s
.69207 .66287 m .7041 .65801 L .61991 .65431 L p 0 .455 1 r
F P
0 g
s
.7041 .65801 m .69207 .66287 L .60859 .65924 L p 0 .455 1 r
F P
0 g
s
.63029 .77024 m .57719 .71298 L .60859 .65924 L p 0 .344 .78 r
F P
0 g
s
.60859 .65924 m .61991 .65431 L .7041 .65801 L p 0 .455 1 r
F P
0 g
s
.63144 .64929 m .61991 .65431 L .7041 .65801 L p 0 .455 1 r
F P
0 g
s
.7041 .65801 m .70325 .58094 L .69128 .5865 L p 0 .162 .706 r
F P
0 g
s
.70325 .58094 m .7041 .65801 L .71635 .65307 L p 0 .162 .706 r
F P
0 g
s
.7041 .65801 m .71635 .65307 L .63144 .64929 L p 0 .455 1 r
F P
0 g
s
.71635 .65307 m .7041 .65801 L .61991 .65431 L p 0 .455 1 r
F P
0 g
s
.63144 .64929 m .71635 .65307 L .71635 .65307 L p 0 .344 .779 r
F P
0 g
s
.68162 .80684 m .69352 .80336 L .69207 .66287 L p 0 .162 .706 r
F P
0 g
s
.66003 .8023 m .63029 .77024 L .69207 .66287 L p 0 .344 .78 r
F P
0 g
s
.69207 .66287 m .69352 .80336 L .66003 .8023 L p 0 .344 .78 r
F P
0 g
s
.7041 .65801 m .69207 .66287 L .69352 .80336 L p 0 .162 .706 r
F P
0 g
s
.69352 .80336 m .69207 .66287 L .63029 .77024 L p 0 .344 .78 r
F P
0 g
s
.69352 .80336 m .70566 .79981 L .7041 .65801 L p 0 .162 .706 r
F P
0 g
s
.71635 .65307 m .7041 .65801 L .70566 .79981 L p 0 .162 .706 r
F P
0 g
s
.61991 .65431 m .63144 .64929 L .71635 .65307 L p 0 .455 1 r
F P
0 g
s
.65366 .7624 m .59956 .70402 L .63144 .64929 L p 0 .344 .779 r
F P
0 g
s
.71635 .65307 m .65366 .7624 L p .63144 .64929 L 0 .344 .779 r
F P
0 g
s
.63144 .64929 m .71635 .65307 L .63144 .64929 L 0 .344 .779 r
F
.63144 .64929 m .54529 .64546 L .53451 .65056 L p 0 .455 1 r
F P
0 g
s
.53451 .65056 m .54529 .64546 L .63144 .64929 L p 0 .455 1 r
F P
0 g
s
.54529 .64546 m .59956 .70402 L .54547 .71776 L closepath p 0 .344 .779 r
F P
0 g
s
.63144 .64929 m .59956 .70402 L .54529 .64546 L p 0 .344 .779 r
F P
0 g
s
.54529 .64546 m .54529 .64546 L p .63144 .64929 L 0 .344 .779 r
F P
0 g
s
.54547 .71776 m .54529 .64546 L .53451 .65056 L p 0 .134 .679 r
F P
0 g
s
.53451 .65056 m .54529 .64546 L .54547 .71776 L p 0 .134 .679 r
F P
0 g
s
.53464 .72218 m .53451 .65056 L .52392 .65555 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .53451 .65056 L .53464 .72218 L p 0 .134 .679 r
F P
0 g
s
.53451 .65056 m .52392 .65555 L .52382 .57812 L p 0 .134 .679 r
F P
0 g
s
.49688 .65437 m .48993 .65774 L p .48049 .65366 L .538 0 0 r
F P
0 g
s
.46222 .64576 m .49688 .65437 L .48049 .65366 L .538 0 0 r
F
.51026 .64788 m .49688 .65437 L p .46222 .64576 L F P
0 g
s
.41377 .65076 m .52392 .65555 L .53451 .65056 L p 0 .455 1 r
F P
0 g
s
.51026 .63669 m .53138 .63764 L p .51018 .50057 L .32 0 0 r
F P
0 g
s
.51026 .64012 m .51026 .64788 L .53138 .63764 L .32 0 0 r
F
.49009 .37068 m .51026 .64788 L .51018 .50057 L F
.4332 .63322 m .53138 .63764 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.4138 .64363 m .4332 .63322 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.51354 .66045 m .52392 .65555 L .52402 .72651 L p 0 .134 .679 r
F P
0 g
s
.51027 .65496 m .52402 .72651 L .52392 .65555 L 0 .344 .78 r
F
.51027 .65496 m .41377 .65076 L p .50127 .65926 L 0 .455 1 r
F P
0 g
s
.41377 .65076 m .5103 .71708 L .51027 .65496 L 0 .344 .78 r
F
.5103 .71708 m .52402 .72651 L .51027 .65496 L F
.51027 .65496 m .41377 .65076 L p .41377 .65076 L F P
0 g
s
.41377 .65076 m .52392 .65555 L .52392 .65555 L 0 .344 .78 r
F
.52402 .72651 m .52392 .65555 L .52392 .65555 L p F P
0 g
s
.52402 .72651 m .52402 .72651 L .52392 .65555 L 0 .344 .78 r
F
.53138 .63764 m .51026 .64788 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.52373 .50134 m .52382 .57812 L .60814 .58234 L p 0 .344 .78 r
F P
0 g
s
.53407 .41807 m .53422 .49491 L .52373 .50134 L p 0 .134 .679 r
F P
0 g
s
.52373 .50134 m .53422 .49491 L .61891 .49974 L p 0 .458 1 r
F P
0 g
s
.53436 .57241 m .52382 .57812 L .52373 .50134 L p 0 .134 .679 r
F P
0 g
s
.61891 .49974 m .53422 .49491 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .53422 .49491 L .53436 .57241 L p 0 .134 .679 r
F P
0 g
s
.52382 .57812 m .53436 .57241 L .53451 .65056 L p 0 .134 .679 r
F P
0 g
s
.54529 .64546 m .53451 .65056 L .53436 .57241 L p 0 .134 .679 r
F P
0 g
s
.54529 .64546 m .43318 .64048 L .42338 .64567 L p 0 .455 1 r
F P
0 g
s
.42338 .64567 m .53451 .65056 L .54529 .64546 L p 0 .455 1 r
F P
0 g
s
.53138 .63764 m .53088 .33992 L .5101 .35559 L p .32 0 0 r
F P
0 g
s
.5101 .35559 m .49009 .37068 L p .51018 .50057 L .32 0 0 r
F P
0 g
s
.51018 .50057 m .53138 .63764 L .5101 .35559 L .32 0 0 r
F
0 g
.43416 .36693 m
.49009 .37068 L
s
.48994 .63577 m
.49009 .37068 L
s
.6077 .50608 m .69049 .51075 L .6788 .51688 L p 0 .458 1 r
F P
0 g
s
.6788 .51688 m .69049 .51075 L .6077 .50608 L p 0 .458 1 r
F P
0 g
s
.57547 .30027 m .62667 .25158 L .68894 .36111 L p 0 .344 .78 r
F P
0 g
s
.68894 .36111 m .70074 .35352 L .69926 .2184 L p 0 .162 .706 r
F P
0 g
s
.60681 .35543 m .68894 .36111 L .70074 .35352 L p 0 .456 1 r
F P
0 g
s
.70074 .35352 m .68894 .36111 L .60681 .35543 L p 0 .456 1 r
F P
0 g
s
.70074 .35352 m .68894 .36111 L .68972 .43563 L p 0 .162 .706 r
F P
0 g
s
.68894 .36111 m .60681 .35543 L .60725 .43045 L p 0 .344 .78 r
F P
0 g
s
.39718 .29015 m .28918 .28222 L .28839 .35029 L p 0 .344 .781 r
F P
0 g
s
.28839 .35029 m .28918 .28222 L .24613 .30466 L closepath p 0 .344 .781 r
F P
0 g
s
.29733 .27382 m .28918 .28222 L .28839 .35029 L p 0 .084 .626 r
F P
0 g
s
.28839 .35029 m .29656 .34249 L .29733 .27382 L p 0 .084 .626 r
F P
0 g
s
.29656 .34249 m .28839 .35029 L .28918 .28222 L p 0 .084 .626 r
F P
0 g
s
.23345 .34657 m .28839 .35029 L .28839 .35029 L p 0 .344 .781 r
F P
0 g
s
.28839 .35029 m .24613 .30466 L .23345 .34657 L p 0 .344 .781 r
F P
0 g
s
.23345 .34657 m .23345 .34657 L p .28839 .35029 L 0 .344 .781 r
F P
0 g
s
.24114 .3387 m .23345 .34657 L .28839 .35029 L p 0 .456 1 r
F P
0 g
s
.28839 .35029 m .29579 .34323 L .24114 .3387 L p 0 .456 1 r
F P
0 g
s
.28839 .35029 m .3968 .35764 L .39718 .29015 L p 0 .344 .781 r
F P
0 g
s
.3968 .35764 m .28839 .35029 L .29656 .34249 L p 0 .456 1 r
F P
0 g
s
.2961 .38395 m .29656 .34249 L .28839 .35029 L p 0 .084 .626 r
F P
0 g
s
.66651 .21573 m .69926 .2184 L .71118 .20946 L p 0 .451 1 r
F P
0 g
s
.71118 .20946 m .69926 .2184 L .70074 .35352 L p 0 .162 .706 r
F P
0 g
s
.70157 .4287 m .68972 .43563 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
.68972 .43563 m .70157 .4287 L .70074 .35352 L p 0 .162 .706 r
F P
0 g
s
.3951 .66201 m
.39511 .66066 L
s
.39511 .66064 m
.39513 .65365 L
s
.29656 .34249 m .40592 .34998 L .3968 .35764 L p 0 .456 1 r
F P
0 g
s
.40592 .34998 m .29656 .34249 L .30489 .33455 L p 0 .456 1 r
F P
0 g
s
.30489 .33455 m .4152 .34218 L .40592 .34998 L p 0 .456 1 r
F P
0 g
s
.41552 .27348 m .30563 .26525 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .4152 .34218 L .41552 .27348 L p 0 .344 .78 r
F P
0 g
s
.41552 .27348 m .4152 .34218 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.29656 .34249 m .30489 .33455 L .30563 .26525 L p 0 .084 .626 r
F P
0 g
s
.29809 .20565 m .28996 .21466 L .28918 .28222 L p 0 .084 .626 r
F P
0 g
s
.28918 .28222 m .28996 .21466 L .20377 .25893 L p 0 .344 .781 r
F P
0 g
s
.28918 .28222 m .29733 .27382 L .29809 .20565 L p 0 .084 .626 r
F P
0 g
s
.28996 .21466 m .29809 .20565 L .29733 .27382 L p 0 .084 .626 r
F P
0 g
s
.29733 .27382 m .28918 .28222 L .28996 .21466 L p 0 .084 .626 r
F P
0 g
s
.20377 .25893 m .24613 .30466 L .28918 .28222 L p 0 .344 .781 r
F P
0 g
s
.28918 .28222 m .29733 .27382 L .29656 .34249 L p 0 .084 .626 r
F P
0 g
s
.30563 .26525 m .29733 .27382 L .29656 .34249 L p 0 .084 .626 r
F P
0 g
s
.30563 .26525 m .30489 .33455 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .30175 .33754 L .29733 .27382 L p 0 .084 .626 r
F P
0 g
s
.29656 .34249 m .30489 .33455 L .24897 .33068 L p 0 .456 1 r
F P
0 g
s
.24897 .33068 m .24114 .3387 L .29656 .34249 L p 0 .456 1 r
F P
0 g
s
.24114 .3387 m .24897 .33068 L .30489 .33455 L p 0 .456 1 r
F P
0 g
s
.29809 .20565 m .29733 .27382 L .30563 .26525 L p 0 .084 .626 r
F P
0 g
s
.30563 .26525 m .29733 .27382 L .29809 .20565 L p 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .29809 .20565 L .40662 .2143 L p 0 .451 1 r
F P
0 g
s
.30563 .26525 m .30637 .19647 L .29809 .20565 L p 0 .084 .626 r
F P
0 g
s
.29809 .20565 m .30637 .19647 L .30563 .26525 L p 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .30584 .24594 L .26184 .28803 L p 0 .344 .78 r
F P
0 g
s
.17995 .23321 m .20377 .25893 L .28996 .21466 L p 0 .344 .781 r
F P
0 g
s
.28996 .21466 m .18043 .20602 L .17995 .23321 L p 0 .344 .781 r
F P
0 g
s
.28996 .21466 m .29809 .20565 L .18759 .19684 L p 0 .451 1 r
F P
0 g
s
.18759 .19684 m .18043 .20602 L .28996 .21466 L p 0 .451 1 r
F P
0 g
s
.29809 .20565 m .30637 .19647 L .19489 .18749 L p 0 .451 1 r
F P
0 g
s
.19489 .18749 m .18759 .19684 L .29809 .20565 L p 0 .451 1 r
F P
0 g
s
.26184 .28803 m .21868 .2414 L .30637 .19647 L p 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .30637 .19647 L .21868 .2414 L p 0 .344 .78 r
F P
0 g
s
.29733 .27382 m .30563 .26525 L .30489 .33455 L p 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .30563 .26525 L .30563 .26525 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .26184 .28803 L .30563 .26525 L p 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .26184 .28803 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .30489 .33455 L p .30563 .26525 L 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .30563 .26525 L p .30489 .33455 L 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .30563 .26525 L .30563 .26525 L p 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .41552 .27348 L p .30489 .33455 L 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .30563 .26525 L .30489 .33455 L 0 .344 .78 r
F
.31338 .32645 m .30489 .33455 L .30489 .33455 L p 0 .456 1 r
F P
0 g
s
.40662 .2143 m .41584 .20529 L .30637 .19647 L p 0 .451 1 r
F P
0 g
s
.41584 .20529 m .30637 .19647 L .30563 .26525 L p 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .41552 .27348 L .41584 .20529 L p 0 .344 .78 r
F P
0 g
s
.41584 .20529 m .41552 .27348 L .30563 .26525 L p 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .30637 .19647 L .30637 .19647 L p 0 .344 .78 r
F P
0 g
s
.30637 .19647 m .41584 .20529 L p .30563 .26525 L 0 .344 .78 r
F P
0 g
s
.30563 .26525 m .30637 .19647 L .30563 .26525 L 0 .344 .78 r
F
.30637 .19647 m .30563 .26525 L .31409 .25652 L p 0 .084 .626 r
F P
0 g
s
.31409 .25652 m .30563 .26525 L .30489 .33455 L p 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .30563 .26525 L .31409 .25652 L p 0 .084 .626 r
F P
0 g
s
.26184 .28803 m .30489 .33455 L .24897 .33068 L closepath p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .31338 .32645 L .31409 .25652 L p 0 .084 .626 r
F P
0 g
s
.31409 .25652 m .31338 .32645 L .30489 .33455 L p 0 .084 .626 r
F P
0 g
s
.24897 .33068 m .30489 .33455 L .26184 .28803 L closepath p 0 .344 .78 r
F P
0 g
s
.31338 .32645 m .25696 .32251 L .24897 .33068 L p 0 .456 1 r
F P
0 g
s
.24897 .33068 m .25696 .32251 L .31338 .32645 L p 0 .456 1 r
F P
0 g
s
.30489 .33455 m .31338 .32645 L .30489 .33455 L 0 .456 1 r
F
.24897 .33068 m .30466 .33454 L .31338 .32645 L p F P
0 g
s
.24897 .33068 m .31338 .32645 L .30489 .33455 L 0 .456 1 r
F
.24897 .33068 m .24897 .33068 L .30348 .33445 L F
.24897 .33068 m .30348 .33445 L .30489 .33455 L F
.30489 .33455 m .24897 .33068 L p .24897 .33068 L F P
0 g
s
.30489 .33455 m .29656 .34249 L .24114 .3387 L p 0 .456 1 r
F P
0 g
s
.42466 .33423 m .4152 .34218 L .30489 .33455 L p 0 .456 1 r
F P
0 g
s
.30489 .33455 m .31338 .32645 L .42466 .33423 L p 0 .456 1 r
F P
0 g
s
.30444 .37639 m .31294 .36868 L .31338 .32645 L p 0 .084 .626 r
F P
0 g
s
.31338 .32645 m .30489 .33455 L .30444 .37639 L p 0 .084 .626 r
F P
0 g
s
.30444 .37639 m .30489 .33455 L .29656 .34249 L p 0 .084 .626 r
F P
0 g
s
.28839 .35029 m .23345 .34657 L .23285 .38783 L p 0 .344 .781 r
F P
0 g
s
.23285 .38783 m .28791 .39138 L .28839 .35029 L p 0 .344 .781 r
F P
0 g
s
.28839 .35029 m .28791 .39138 L .2961 .38395 L p 0 .084 .626 r
F P
0 g
s
.29656 .34249 m .28839 .35029 L .23345 .34657 L p 0 .456 1 r
F P
0 g
s
.23345 .34657 m .24114 .3387 L .29656 .34249 L p 0 .456 1 r
F P
0 g
s
.29656 .34249 m .2961 .38395 L .30444 .37639 L p 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .30444 .37639 L .24839 .3727 L p 0 .344 .78 r
F P
0 g
s
.5442 .19573 m .53368 .20492 L .66651 .21573 L p 0 .451 1 r
F P
0 g
s
.66651 .21573 m .67815 .20674 L .5442 .19573 L p 0 .451 1 r
F P
0 g
s
.71118 .20946 m .67815 .20674 L .66651 .21573 L p 0 .451 1 r
F P
0 g
s
.4332 .63322 m .39513 .65365 L .39676 .36441 L p .273 0 0 r
F P
0 g
s
.39513 .65365 m
.39676 .36441 L
s
.6078 .77778 m .637 .80924 L .66993 .81026 L p 0 .344 .781 r
F P
0 g
s
.66993 .81026 m .637 .80924 L .6484 .8058 L p 0 .443 1 r
F P
0 g
s
.6484 .8058 m .68162 .80684 L .66993 .81026 L p 0 .443 1 r
F P
0 g
s
.41584 .20529 m .52335 .21395 L .53368 .20492 L p 0 .451 1 r
F P
0 g
s
.52335 .21395 m .41584 .20529 L .41552 .27348 L p 0 .344 .78 r
F P
0 g
s
.52335 .21395 m .53368 .20492 L .5338 .27314 L p 0 .134 .679 r
F P
0 g
s
.5338 .27314 m .52344 .28156 L .52335 .21395 L p 0 .134 .679 r
F P
0 g
s
.52335 .21395 m .52344 .28156 L .41552 .27348 L p 0 .344 .78 r
F P
0 g
s
.41552 .27348 m .41584 .20529 L .52335 .21395 L p 0 .344 .78 r
F P
0 g
s
.70074 .35352 m .61793 .34773 L .60681 .35543 L p 0 .456 1 r
F P
0 g
s
.60681 .35543 m .61793 .34773 L .70074 .35352 L p 0 .456 1 r
F P
0 g
s
.50338 .8051 m .637 .80924 L .6078 .77778 L closepath p 0 .344 .781 r
F P
0 g
s
.6484 .8058 m .637 .80924 L .50338 .8051 L p 0 .443 1 r
F P
0 g
s
.6077 .50608 m .69049 .51075 L .69128 .5865 L p 0 .344 .78 r
F P
0 g
s
.69049 .51075 m .70241 .50451 L .70157 .4287 L p 0 .162 .706 r
F P
0 g
s
.70241 .50451 m .69049 .51075 L .6077 .50608 L p 0 .458 1 r
F P
0 g
s
.70325 .58094 m .70241 .50451 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
.69049 .51075 m .69128 .5865 L .70325 .58094 L p 0 .162 .706 r
F P
0 g
s
.69128 .5865 m .69049 .51075 L .6077 .50608 L p 0 .344 .78 r
F P
0 g
s
.6077 .50608 m .69049 .51075 L .70241 .50451 L p 0 .458 1 r
F P
0 g
s
.70074 .35352 m .71277 .34579 L .71118 .20946 L p 0 .162 .706 r
F P
0 g
s
.61793 .34773 m .70074 .35352 L .71277 .34579 L p 0 .456 1 r
F P
0 g
s
.71277 .34579 m .70074 .35352 L .61793 .34773 L p 0 .456 1 r
F P
0 g
s
.71277 .34579 m .70074 .35352 L .70157 .4287 L p 0 .162 .706 r
F P
0 g
s
.7261 .35359 m .81808 .36003 L .82315 .65078 L p .847 0 0 r
F P
0 g
s
.7261 .35359 m .82315 .65078 L .81808 .36003 L .847 0 0 r
F
.82504 .34666 m .81808 .36003 L .82315 .65078 L .1 0 0 r
F
.72678 .35191 m .81808 .36003 L .82504 .34666 L .652 0 0 r
F
.72678 .35191 m .7261 .35359 L .81808 .36003 L F
.71118 .20946 m .71277 .34579 L .6493 .2342 L p 0 .344 .779 r
F P
0 g
s
.6493 .2342 m .67815 .20674 L .71118 .20946 L p 0 .344 .779 r
F P
0 g
s
.69128 .5865 m .60814 .58234 L .6077 .50608 L p 0 .344 .78 r
F P
0 g
s
.6077 .50608 m .60814 .58234 L .69128 .5865 L p 0 .344 .78 r
F P
0 g
s
.39513 .65365 m
.40731 .65417 L
s
.71772 .34955 m .7529 .3271 L p .7529 .3271 L .652 0 0 r
F P
0 g
s
.71285 .35266 m .71277 .34579 L p .71174 .35336 L 0 .162 .706 r
F P
0 g
s
.71277 .34579 m .62925 .33989 L .61793 .34773 L p 0 .456 1 r
F P
0 g
s
.61793 .34773 m .62925 .33989 L .71277 .34579 L p 0 .456 1 r
F P
0 g
s
.53393 .34186 m .61793 .34773 L .62925 .33989 L p 0 .456 1 r
F P
0 g
s
.62925 .33989 m .54453 .33391 L .53393 .34186 L p 0 .456 1 r
F P
0 g
s
.54453 .33391 m .62925 .33989 L .61793 .34773 L p 0 .456 1 r
F P
0 g
s
.61793 .34773 m .53393 .34186 L .54453 .33391 L p 0 .456 1 r
F P
0 g
s
.59731 .28368 m .6493 .2342 L .71277 .34579 L p 0 .344 .779 r
F P
0 g
s
.71277 .34579 m .62925 .33989 L .59731 .28368 L p 0 .344 .779 r
F P
0 g
s
.70157 .4287 m .71365 .42165 L .71285 .35266 L p 0 .162 .706 r
F P
0 g
s
.70157 .4287 m .71285 .35266 L .71174 .35336 L 0 .162 .706 r
F
.71277 .34579 m .71365 .42165 L .62979 .41627 L p 0 .344 .779 r
F P
0 g
s
.62979 .41627 m .62925 .33989 L .71277 .34579 L p 0 .344 .779 r
F P
0 g
s
.59731 .28368 m .62925 .33989 L .54453 .33391 L closepath p 0 .344 .779 r
F P
0 g
s
.62925 .33989 m .62979 .41627 L .54472 .41081 L p 0 .344 .779 r
F P
0 g
s
.54472 .41081 m .54453 .33391 L .62925 .33989 L p 0 .344 .779 r
F P
0 g
s
.54885 .33767 m .71772 .34955 L p .7529 .3271 L .652 0 0 r
F P
0 g
s
.71772 .34955 m .71772 .34955 L p .7529 .3271 L .652 0 0 r
F P
0 g
s
.71365 .42165 m .70157 .4287 L .70241 .50451 L p 0 .162 .706 r
F P
0 g
s
.5442 .19573 m .67815 .20674 L .6493 .2342 L closepath p 0 .344 .779 r
F P
0 g
s
.24613 .30466 m .20377 .25893 L .17801 .34281 L p 0 .344 .781 r
F P
0 g
s
.17801 .34281 m .23345 .34657 L .23345 .34657 L p 0 .344 .781 r
F P
0 g
s
.23345 .34657 m .24613 .30466 L p .17801 .34281 L 0 .344 .781 r
F P
0 g
s
.17801 .34281 m .23345 .34657 L .17801 .34281 L 0 .344 .781 r
F
.1852 .33487 m .17801 .34281 L .23345 .34657 L p 0 .456 1 r
F P
0 g
s
.23345 .34657 m .17801 .34281 L .17728 .38425 L p 0 .344 .781 r
F P
0 g
s
.23345 .34657 m .17801 .34281 L .1852 .33487 L p 0 .456 1 r
F P
0 g
s
.17801 .34281 m .1852 .33487 L .18448 .37669 L p 0 .052 .589 r
F P
0 g
s
.23345 .34657 m .24114 .3387 L .1852 .33487 L p 0 .456 1 r
F P
0 g
s
.69352 .80336 m .68162 .80684 L .6484 .8058 L p 0 .443 1 r
F P
0 g
s
.17995 .23321 m .18043 .20602 L .18759 .19684 L p 0 .052 .589 r
F P
0 g
s
.6077 .50608 m .61891 .49974 L .70241 .50451 L p 0 .458 1 r
F P
0 g
s
.70241 .50451 m .61891 .49974 L .6077 .50608 L p 0 .458 1 r
F P
0 g
s
.53368 .20492 m .42524 .1961 L .41584 .20529 L p 0 .451 1 r
F P
0 g
s
.30637 .19647 m .41584 .20529 L .42524 .1961 L p 0 .451 1 r
F P
0 g
s
.28791 .39138 m .23285 .38783 L .23224 .42928 L p 0 .344 .781 r
F P
0 g
s
.23224 .42928 m .28743 .43265 L .28791 .39138 L p 0 .344 .781 r
F P
0 g
s
.28791 .39138 m .28743 .43265 L .29563 .4256 L p 0 .084 .626 r
F P
0 g
s
.28743 .43265 m .29563 .4256 L .25857 .42331 L p 0 .458 1 r
F P
0 g
s
.29563 .4256 m .2961 .38395 L .28791 .39138 L p 0 .084 .626 r
F P
0 g
s
.17801 .34281 m .20377 .25893 L .17995 .23321 L closepath p 0 .344 .781 r
F P
0 g
s
.5442 .19573 m .53368 .20492 L .5338 .27314 L p 0 .134 .679 r
F P
0 g
s
.5338 .27314 m .53368 .20492 L .5442 .19573 L p 0 .134 .679 r
F P
0 g
s
.42524 .1961 m .53368 .20492 L .5442 .19573 L p 0 .451 1 r
F P
0 g
s
.17995 .23321 m .18711 .22428 L .1852 .33487 L p 0 .052 .589 r
F P
0 g
s
.1852 .33487 m .17801 .34281 L .17995 .23321 L p 0 .052 .589 r
F P
0 g
s
.18759 .19684 m .18711 .22428 L .17995 .23321 L p 0 .052 .589 r
F P
0 g
s
.50338 .8051 m .51365 .80159 L .6484 .8058 L p 0 .443 1 r
F P
0 g
s
.66003 .8023 m .6484 .8058 L .51365 .80159 L p 0 .443 1 r
F P
0 g
s
.6484 .8058 m .66003 .8023 L .69352 .80336 L p 0 .443 1 r
F P
0 g
s
.70241 .50451 m .71454 .49814 L .71365 .42165 L p 0 .162 .706 r
F P
0 g
s
.71454 .49814 m .70241 .50451 L .61891 .49974 L p 0 .458 1 r
F P
0 g
s
.71544 .57528 m .71454 .49814 L .70241 .50451 L p 0 .162 .706 r
F P
0 g
s
.70241 .50451 m .70325 .58094 L .71544 .57528 L p 0 .162 .706 r
F P
0 g
s
.61891 .49974 m .70241 .50451 L .71454 .49814 L p 0 .458 1 r
F P
0 g
s
.17728 .38425 m .23285 .38783 L .23345 .34657 L p 0 .344 .781 r
F P
0 g
s
.25857 .42331 m .25069 .43041 L .28743 .43265 L p 0 .458 1 r
F P
0 g
s
.17654 .42588 m .23224 .42928 L .23285 .38783 L p 0 .344 .781 r
F P
0 g
s
.25069 .43041 m .25857 .42331 L .22128 .42102 L p 0 .458 1 r
F P
0 g
s
.22128 .42102 m .21373 .42815 L .25069 .43041 L p 0 .458 1 r
F P
0 g
s
.28743 .43265 m .23224 .42928 L .23995 .42217 L p 0 .458 1 r
F P
0 g
s
.23995 .42217 m .29563 .4256 L .28743 .43265 L p 0 .458 1 r
F P
0 g
s
.28743 .43265 m .25069 .43041 L .25047 .44701 L p 0 .344 .781 r
F P
0 g
s
.25047 .44701 m .28724 .44921 L .28743 .43265 L p 0 .344 .781 r
F P
0 g
s
.28743 .43265 m .28724 .44921 L .29545 .44231 L p 0 .084 .626 r
F P
0 g
s
.29545 .44231 m .29563 .4256 L .28743 .43265 L p 0 .084 .626 r
F P
0 g
s
.1852 .33487 m .24114 .3387 L .23345 .34657 L p 0 .456 1 r
F P
0 g
s
.19253 .32678 m .1852 .33487 L .24114 .3387 L p 0 .456 1 r
F P
0 g
s
.24114 .3387 m .24897 .33068 L .19253 .32678 L p 0 .456 1 r
F P
0 g
s
.24897 .33068 m .24114 .3387 L .1852 .33487 L p 0 .456 1 r
F P
0 g
s
.1852 .33487 m .19253 .32678 L .24897 .33068 L p 0 .456 1 r
F P
0 g
s
.26184 .28803 m .24897 .33068 L .19253 .32678 L p 0 .344 .78 r
F P
0 g
s
.19253 .32678 m .21868 .2414 L .26184 .28803 L p 0 .344 .78 r
F P
0 g
s
.21868 .2414 m .19253 .32678 L .24897 .33068 L p 0 .344 .78 r
F P
0 g
s
.19182 .36899 m .19253 .32678 L .24897 .33068 L p 0 .344 .78 r
F P
0 g
s
.24897 .33068 m .26184 .28803 L .21868 .2414 L p 0 .344 .78 r
F P
0 g
s
.19253 .32678 m .24897 .33068 L .25696 .32251 L p 0 .456 1 r
F P
0 g
s
.24897 .33068 m .19253 .32678 L .19182 .36899 L p 0 .344 .78 r
F P
0 g
s
.25696 .32251 m .24897 .33068 L .19253 .32678 L p 0 .456 1 r
F P
0 g
s
.25696 .32251 m .20001 .31853 L .19253 .32678 L p 0 .456 1 r
F P
0 g
s
.19253 .32678 m .20001 .31853 L .25696 .32251 L p 0 .456 1 r
F P
0 g
s
.20001 .31853 m .25696 .32251 L .2651 .31418 L p 0 .456 1 r
F P
0 g
s
.2651 .31418 m .20763 .31012 L .20001 .31853 L p 0 .456 1 r
F P
0 g
s
.25696 .32251 m .20001 .31853 L .20763 .31012 L p 0 .456 1 r
F P
0 g
s
.20763 .31012 m .20694 .35312 L .19931 .36113 L p 0 .052 .589 r
F P
0 g
s
.19931 .36113 m .20001 .31853 L .20763 .31012 L p 0 .052 .589 r
F P
0 g
s
.20001 .31853 m .19931 .36113 L .19182 .36899 L p 0 .052 .589 r
F P
0 g
s
.19182 .36899 m .19253 .32678 L .20001 .31853 L p 0 .052 .589 r
F P
0 g
s
.1852 .33487 m .19253 .32678 L .19182 .36899 L p 0 .052 .589 r
F P
0 g
s
.82315 .65078 m .72974 .64657 L .7261 .35359 L p .847 0 0 r
F P
0 g
s
.7261 .35359 m .72974 .64657 L .82315 .65078 L .847 0 0 r
F
.72678 .35191 m .72974 .64657 L .7261 .35359 L .1 0 0 r
F
0 g
.7268 .35363 m
.81808 .36003 L
s
.6493 .2342 m .59731 .28368 L .54436 .26456 L p 0 .344 .779 r
F P
0 g
s
.54436 .26456 m .5442 .19573 L .6493 .2342 L p 0 .344 .779 r
F P
0 g
s
.28724 .44921 m .25047 .44701 L .25024 .46365 L p 0 .344 .781 r
F P
0 g
s
.25024 .46365 m .28705 .4658 L .28724 .44921 L p 0 .344 .781 r
F P
0 g
s
.28724 .44921 m .28705 .4658 L .29526 .45905 L p 0 .084 .626 r
F P
0 g
s
.29526 .45905 m .29545 .44231 L .28724 .44921 L p 0 .084 .626 r
F P
0 g
s
.50338 .8051 m .39429 .80173 L .4036 .79815 L p 0 .443 1 r
F P
0 g
s
.28705 .4658 m .25024 .46365 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .29526 .45905 L .28705 .4658 L p 0 .458 1 r
F P
0 g
s
.25024 .46365 m .28705 .4658 L .29526 .45905 L p 0 .458 1 r
F P
0 g
s
.28401 .46959 m .29526 .45905 L .28705 .4658 L p 0 .05 .1 r
F P
0 g
s
.28705 .4658 m .27848 .47413 L .28401 .46959 L p 0 .05 .1 r
F P
0 g
s
.27848 .47413 m .28705 .4658 L .25024 .46365 L p 0 .267 .584 r
F P
0 g
s
.5338 .27314 m .54436 .26456 L .5442 .19573 L p 0 .134 .679 r
F P
0 g
s
.5442 .19573 m .54436 .26456 L .5338 .27314 L p 0 .134 .679 r
F P
0 g
s
.5338 .27314 m .54436 .26456 L .54453 .33391 L p 0 .134 .679 r
F P
0 g
s
.72678 .35191 m .73043 .64548 L .72974 .64657 L .1 0 0 r
F
.72372 .35043 m .73043 .64548 L .72678 .35191 L 1 0 0 r
F
.72372 .35043 m .72678 .35191 L .82504 .34666 L .652 0 0 r
F
.23285 .38783 m .17728 .38425 L .17654 .42588 L p 0 .344 .781 r
F P
0 g
s
.39469 .73092 m .39509 .66065 L .28484 .65595 L p 0 .344 .781 r
F P
0 g
s
.39509 .66065 m .40434 .65575 L .29312 .65096 L p 0 .455 1 r
F P
0 g
s
.29312 .65096 m .28484 .65595 L .39509 .66065 L p 0 .455 1 r
F P
0 g
s
.25069 .43041 m .21373 .42815 L .21347 .44481 L p 0 .344 .781 r
F P
0 g
s
.21347 .44481 m .25047 .44701 L .25069 .43041 L p 0 .344 .781 r
F P
0 g
s
.25047 .44701 m .21347 .44481 L .21321 .4615 L p 0 .344 .781 r
F P
0 g
s
.21321 .4615 m .25024 .46365 L .25047 .44701 L p 0 .344 .781 r
F P
0 g
s
.71635 .65307 m .71544 .57528 L .70325 .58094 L p 0 .162 .706 r
F P
0 g
s
.72372 .35043 m .72733 .64451 L .73043 .64548 L 1 0 0 r
F
.72372 .35043 m .82504 .34666 L .8015 .33452 L .652 0 0 r
F
.71772 .34955 m .72733 .64451 L .72372 .35043 L .888 0 0 r
F
.71772 .34955 m .72372 .35043 L .8015 .33452 L .652 0 0 r
F
0 g
.72372 .35043 m
.72678 .35191 L
s
.18448 .37669 m .17728 .38425 L .17801 .34281 L p 0 .052 .589 r
F P
0 g
s
.21373 .42815 m .22128 .42102 L .18375 .41871 L p 0 .458 1 r
F P
0 g
s
.18375 .41871 m .17654 .42588 L .21373 .42815 L p 0 .458 1 r
F P
0 g
s
.23224 .42928 m .17654 .42588 L .18375 .41871 L p 0 .458 1 r
F P
0 g
s
.18375 .41871 m .23995 .42217 L .23224 .42928 L p 0 .458 1 r
F P
0 g
s
.25024 .46365 m .21321 .4615 L .22076 .45467 L p 0 .458 1 r
F P
0 g
s
.22076 .45467 m .25813 .45687 L .25024 .46365 L p 0 .458 1 r
F P
0 g
s
.29526 .45905 m .25813 .45687 L .25024 .46365 L p 0 .458 1 r
F P
0 g
s
.25024 .46365 m .2526 .47264 L .27848 .47413 L p 0 .267 .584 r
F P
0 g
s
.21321 .4615 m .25024 .46365 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.2526 .47264 m .25024 .46365 L .21321 .4615 L p 0 .267 .584 r
F P
0 g
s
.71772 .34955 m .8015 .33452 L .7529 .3271 L .652 0 0 r
F
.7571 .62926 m .7529 .3271 L .71772 .34955 L p .393 0 0 r
F P
0 g
s
.71772 .34955 m .72124 .64393 L .72733 .64451 L .888 0 0 r
F
.71772 .34955 m .72124 .64393 L .7571 .62926 L p .393 0 0 r
F P
0 g
s
.71365 .42165 m .71454 .49814 L .63034 .49329 L p 0 .344 .779 r
F P
0 g
s
.63034 .49329 m .62979 .41627 L .71365 .42165 L p 0 .344 .779 r
F P
0 g
s
.61891 .49974 m .63034 .49329 L .71454 .49814 L p 0 .458 1 r
F P
0 g
s
.71454 .49814 m .63034 .49329 L .61891 .49974 L p 0 .458 1 r
F P
0 g
s
.63034 .49329 m .71454 .49814 L .71544 .57528 L p 0 .344 .779 r
F P
0 g
s
.62979 .41627 m .63034 .49329 L .54491 .48837 L p 0 .344 .779 r
F P
0 g
s
.54491 .48837 m .54472 .41081 L .62979 .41627 L p 0 .344 .779 r
F P
0 g
s
.63089 .57096 m .71544 .57528 L .71635 .65307 L p 0 .344 .779 r
F P
0 g
s
.71544 .57528 m .63089 .57096 L .63034 .49329 L p 0 .344 .779 r
F P
0 g
s
.72124 .64393 m .71772 .34955 L .54885 .33767 L p .847 0 0 r
F P
0 g
s
.71772 .34955 m .7571 .62926 L .72124 .64393 L .393 0 0 r
F
.71772 .34955 m .7529 .3271 L .7571 .62926 L F
.53407 .41807 m .53393 .34186 L .54453 .33391 L p 0 .134 .679 r
F P
0 g
s
.28602 .55479 m .28621 .53804 L .24925 .53611 L p 0 .344 .781 r
F P
0 g
s
.29445 .53196 m .28621 .53804 L .28602 .55479 L p 0 .084 .626 r
F P
0 g
s
.27787 .52433 m .28621 .53804 L .29445 .53196 L p 0 .292 .96 r
F P
0 g
s
.28621 .53804 m .27787 .52433 L .25192 .52294 L p 0 .387 .893 r
F P
0 g
s
.25192 .52294 m .24925 .53611 L .28621 .53804 L p 0 .387 .893 r
F P
0 g
s
.28621 .53804 m .29445 .53196 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.25716 .52999 m .24925 .53611 L .28621 .53804 L p 0 .458 1 r
F P
0 g
s
.28621 .53804 m .24925 .53611 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.25716 .52999 m .29445 .53196 L .28621 .53804 L p 0 .458 1 r
F P
0 g
s
.21373 .42815 m .17654 .42588 L .17625 .44259 L p 0 .344 .781 r
F P
0 g
s
.17625 .44259 m .21347 .44481 L .21373 .42815 L p 0 .344 .781 r
F P
0 g
s
.63029 .77024 m .66003 .8023 L .69352 .80336 L p 0 .344 .78 r
F P
0 g
s
.70566 .79981 m .69352 .80336 L .66003 .8023 L p 0 .443 1 r
F P
0 g
s
.27273 .48015 m .28401 .46959 L .27848 .47413 L p 0 .05 .1 r
F P
0 g
s
.27848 .47413 m .26982 .48253 L .27273 .48015 L p 0 .05 .1 r
F P
0 g
s
.27848 .47413 m .2526 .47264 L .25497 .48169 L p 0 .267 .584 r
F P
0 g
s
.25497 .48169 m .26982 .48253 L .27848 .47413 L p 0 .267 .584 r
F P
0 g
s
.19442 .21518 m .18711 .22428 L .18759 .19684 L p 0 .052 .589 r
F P
0 g
s
.18759 .19684 m .19489 .18749 L .19442 .21518 L p 0 .052 .589 r
F P
0 g
s
.28582 .57157 m .28602 .55479 L .24903 .55291 L p 0 .344 .781 r
F P
0 g
s
.29426 .54886 m .28602 .55479 L .28582 .57157 L p 0 .084 .626 r
F P
0 g
s
.24903 .55291 m .2488 .56974 L .28582 .57157 L p 0 .344 .781 r
F P
0 g
s
.2488 .56974 m .24903 .55291 L .21181 .55101 L p 0 .344 .781 r
F P
0 g
s
.21181 .55101 m .21155 .56789 L .2488 .56974 L p 0 .344 .781 r
F P
0 g
s
.21155 .56789 m .21181 .55101 L .17437 .5491 L p 0 .344 .781 r
F P
0 g
s
.17437 .5491 m .17407 .56603 L .21155 .56789 L p 0 .344 .781 r
F P
0 g
s
.18131 .56016 m .17407 .56603 L .2302 .56882 L p 0 .458 1 r
F P
0 g
s
.22958 .61109 m .2302 .56882 L .17407 .56603 L p 0 .344 .781 r
F P
0 g
s
.21155 .56789 m .17407 .56603 L .18131 .56016 L p 0 .458 1 r
F P
0 g
s
.17407 .56603 m .17332 .6085 L .22958 .61109 L p 0 .344 .781 r
F P
0 g
s
.17332 .6085 m .17407 .56603 L .18131 .56016 L p 0 .052 .589 r
F P
0 g
s
.2302 .56882 m .23795 .56299 L .18131 .56016 L p 0 .458 1 r
F P
0 g
s
.23795 .56299 m .2302 .56882 L .28582 .57157 L p 0 .458 1 r
F P
0 g
s
.28582 .57157 m .29407 .5658 L .29426 .54886 L p 0 .084 .626 r
F P
0 g
s
.28582 .57157 m .29407 .5658 L .23795 .56299 L p 0 .458 1 r
F P
0 g
s
.24925 .53611 m .24903 .55291 L .28602 .55479 L p 0 .344 .781 r
F P
0 g
s
.28602 .55479 m .29426 .54886 L .29445 .53196 L p 0 .084 .626 r
F P
0 g
s
.39429 .80173 m .39469 .73092 L .28402 .72685 L p 0 .344 .781 r
F P
0 g
s
.28484 .65595 m .28402 .72685 L .39469 .73092 L p 0 .344 .781 r
F P
0 g
s
.17728 .38425 m .18448 .37669 L .18375 .41871 L p 0 .052 .589 r
F P
0 g
s
.18375 .41871 m .17654 .42588 L .17728 .38425 L p 0 .052 .589 r
F P
0 g
s
.42524 .1961 m .3148 .18712 L .30637 .19647 L p 0 .451 1 r
F P
0 g
s
.31409 .25652 m .3148 .18712 L .30637 .19647 L p 0 .084 .626 r
F P
0 g
s
.30563 .26525 m .30637 .19647 L .3148 .18712 L p 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .21868 .2414 L .19442 .21518 L p 0 .344 .78 r
F P
0 g
s
.19442 .21518 m .19489 .18749 L .30637 .19647 L p 0 .344 .78 r
F P
0 g
s
.20232 .17797 m .19489 .18749 L .30637 .19647 L p 0 .451 1 r
F P
0 g
s
.30637 .19647 m .3148 .18712 L .20232 .17797 L p 0 .451 1 r
F P
0 g
s
.21868 .2414 m .30637 .19647 L .19489 .18749 L p 0 .344 .78 r
F P
0 g
s
.63034 .49329 m .61891 .49974 L .53422 .49491 L p 0 .458 1 r
F P
0 g
s
.53422 .49491 m .61891 .49974 L .63034 .49329 L p 0 .458 1 r
F P
0 g
s
.21347 .44481 m .17625 .44259 L .17595 .45932 L p 0 .344 .781 r
F P
0 g
s
.17595 .45932 m .21321 .4615 L .21347 .44481 L p 0 .344 .781 r
F P
0 g
s
.2961 .38395 m .29563 .4256 L .30399 .41842 L p 0 .084 .626 r
F P
0 g
s
.29563 .4256 m .30399 .41842 L .26659 .41609 L p 0 .458 1 r
F P
0 g
s
.30399 .41842 m .30444 .37639 L .2961 .38395 L p 0 .084 .626 r
F P
0 g
s
.30444 .37639 m .30399 .41842 L .24781 .41492 L p 0 .344 .78 r
F P
0 g
s
.31294 .36868 m .30444 .37639 L .30399 .41842 L p 0 .084 .626 r
F P
0 g
s
.24781 .41492 m .30399 .41842 L .30399 .41842 L p 0 .344 .78 r
F P
0 g
s
.30399 .41842 m .30444 .37639 L p .24781 .41492 L 0 .344 .78 r
F P
0 g
s
.24781 .41492 m .30399 .41842 L .24781 .41492 L 0 .344 .78 r
F
.30399 .41842 m .31251 .41109 L .31294 .36868 L p 0 .084 .626 r
F P
0 g
s
.32161 .36081 m .31294 .36868 L .31251 .41109 L p 0 .084 .626 r
F P
0 g
s
.31251 .41109 m .32119 .40363 L .32161 .36081 L p 0 .084 .626 r
F P
0 g
s
.27478 .40872 m .31251 .41109 L .32119 .40363 L p 0 .458 1 r
F P
0 g
s
.31251 .41109 m .27478 .40872 L .26659 .41609 L p 0 .458 1 r
F P
0 g
s
.26659 .41609 m .30399 .41842 L .31251 .41109 L p 0 .458 1 r
F P
0 g
s
.26659 .41609 m .25857 .42331 L .29563 .4256 L p 0 .458 1 r
F P
0 g
s
.25857 .42331 m .26659 .41609 L .22897 .41375 L p 0 .458 1 r
F P
0 g
s
.24781 .41492 m .30399 .41842 L .29563 .4256 L p 0 .458 1 r
F P
0 g
s
.30381 .43528 m .30399 .41842 L .29563 .4256 L p 0 .084 .626 r
F P
0 g
s
.22897 .41375 m .22128 .42102 L .25857 .42331 L p 0 .458 1 r
F P
0 g
s
.29563 .4256 m .23995 .42217 L .24781 .41492 L p 0 .458 1 r
F P
0 g
s
.29563 .4256 m .29545 .44231 L .30381 .43528 L p 0 .084 .626 r
F P
0 g
s
.30399 .41842 m .30381 .43528 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.26638 .433 m .26659 .41609 L .30399 .41842 L p 0 .344 .78 r
F P
0 g
s
.31251 .41109 m .30399 .41842 L .30381 .43528 L p 0 .084 .626 r
F P
0 g
s
.30399 .41842 m .26659 .41609 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.26638 .433 m .30381 .43528 L .30399 .41842 L p 0 .344 .78 r
F P
0 g
s
.24781 .41492 m .24839 .3727 L .30444 .37639 L p 0 .344 .78 r
F P
0 g
s
.30444 .37639 m .24839 .3727 L .24781 .41492 L p 0 .344 .78 r
F P
0 g
s
.24839 .3727 m .24781 .41492 L .19111 .41139 L p 0 .344 .78 r
F P
0 g
s
.19111 .41139 m .24781 .41492 L .24781 .41492 L p 0 .344 .78 r
F P
0 g
s
.24781 .41492 m .24839 .3727 L p .19111 .41139 L 0 .344 .78 r
F P
0 g
s
.19111 .41139 m .24781 .41492 L .19111 .41139 L 0 .344 .78 r
F
.27478 .40872 m .23681 .40633 L .22897 .41375 L p 0 .458 1 r
F P
0 g
s
.22897 .41375 m .26659 .41609 L .27478 .40872 L p 0 .458 1 r
F P
0 g
s
.31251 .41109 m .30399 .41842 L .24781 .41492 L p 0 .458 1 r
F P
0 g
s
.30381 .43528 m .31233 .42812 L .31251 .41109 L p 0 .084 .626 r
F P
0 g
s
.24781 .41492 m .25582 .40753 L .31251 .41109 L p 0 .458 1 r
F P
0 g
s
.32119 .40363 m .31251 .41109 L .31233 .42812 L p 0 .084 .626 r
F P
0 g
s
.32119 .40363 m .28312 .40121 L .27478 .40872 L p 0 .458 1 r
F P
0 g
s
.23681 .40633 m .27478 .40872 L .28312 .40121 L p 0 .458 1 r
F P
0 g
s
.32119 .40363 m .31251 .41109 L .25582 .40753 L p 0 .458 1 r
F P
0 g
s
.31233 .42812 m .32103 .42081 L .32119 .40363 L p 0 .084 .626 r
F P
0 g
s
.32119 .40363 m .32103 .42081 L .28291 .41844 L p 0 .344 .779 r
F P
0 g
s
.5442 .19573 m .43481 .18674 L .42524 .1961 L p 0 .451 1 r
F P
0 g
s
.3148 .18712 m .42524 .1961 L .43481 .18674 L p 0 .451 1 r
F P
0 g
s
.28533 .61366 m .28582 .57157 L .2302 .56882 L p 0 .344 .781 r
F P
0 g
s
.29407 .5658 m .28582 .57157 L .28533 .61366 L p 0 .084 .626 r
F P
0 g
s
.5442 .19573 m .54436 .26456 L .43456 .25617 L p 0 .344 .779 r
F P
0 g
s
.43456 .25617 m .43481 .18674 L .5442 .19573 L p 0 .344 .779 r
F P
0 g
s
.28582 .57157 m .2488 .56974 L .25671 .56393 L p 0 .458 1 r
F P
0 g
s
.25671 .56393 m .29407 .5658 L .28582 .57157 L p 0 .458 1 r
F P
0 g
s
.54436 .26456 m .59731 .28368 L .54453 .33391 L closepath p 0 .344 .779 r
F P
0 g
s
.21321 .4615 m .17595 .45932 L .18317 .45245 L p 0 .458 1 r
F P
0 g
s
.18317 .45245 m .22076 .45467 L .21321 .4615 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .22076 .45467 L .21321 .4615 L p 0 .458 1 r
F P
0 g
s
.21321 .4615 m .21544 .4705 L .2526 .47264 L p 0 .267 .584 r
F P
0 g
s
.21321 .4615 m .22076 .45467 L .18317 .45245 L p 0 .458 1 r
F P
0 g
s
.18317 .45245 m .17595 .45932 L .21321 .4615 L p 0 .458 1 r
F P
0 g
s
.21544 .4705 m .21321 .4615 L .17595 .45932 L p 0 .267 .584 r
F P
0 g
s
.18711 .22428 m .19442 .21518 L .19253 .32678 L p 0 .052 .589 r
F P
0 g
s
.19253 .32678 m .1852 .33487 L .18711 .22428 L p 0 .052 .589 r
F P
0 g
s
.82504 .34666 m .82315 .65078 L .83031 .64205 L .1 0 0 r
F
.73043 .64548 m .82315 .65078 L .72974 .64657 L .538 0 0 r
F
0 g
.72972 .64526 m
.72974 .64657 L
s
.73043 .64548 m .83031 .64205 L .82315 .65078 L .538 0 0 r
F
0 g
.72974 .64657 m
.82315 .65078 L
s
.81808 .36003 m
.823 .6423 L
s
.2526 .47264 m .21544 .4705 L .21768 .47957 L p 0 .267 .584 r
F P
0 g
s
.21768 .47957 m .25497 .48169 L .2526 .47264 L p 0 .267 .584 r
F P
0 g
s
.8015 .33452 m .82504 .34666 L .83031 .64205 L 1 0 0 r
F
.24903 .55291 m .24925 .53611 L .21207 .53416 L p 0 .344 .781 r
F P
0 g
s
.24925 .53611 m .25192 .52294 L .21466 .52095 L p 0 .387 .893 r
F P
0 g
s
.21466 .52095 m .21207 .53416 L .24925 .53611 L p 0 .387 .893 r
F P
0 g
s
.24925 .53611 m .25716 .52999 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.21965 .528 m .21207 .53416 L .24925 .53611 L p 0 .458 1 r
F P
0 g
s
.24925 .53611 m .21207 .53416 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.21965 .528 m .25716 .52999 L .24925 .53611 L p 0 .458 1 r
F P
0 g
s
.51365 .80159 m .52411 .79801 L .66003 .8023 L p 0 .443 1 r
F P
0 g
s
.63029 .77024 m .66003 .8023 L .52411 .79801 L closepath p 0 .344 .78 r
F P
0 g
s
.52411 .79801 m .66003 .8023 L .63029 .77024 L closepath p 0 .344 .78 r
F P
0 g
s
.67187 .79873 m .66003 .8023 L .52411 .79801 L p 0 .443 1 r
F P
0 g
s
.66003 .8023 m .67187 .79873 L .70566 .79981 L p 0 .443 1 r
F P
0 g
s
.17654 .42588 m .18375 .41871 L .18346 .43556 L p 0 .052 .589 r
F P
0 g
s
.18346 .43556 m .17625 .44259 L .17654 .42588 L p 0 .052 .589 r
F P
0 g
s
.29445 .53196 m .28342 .5201 L .27787 .52433 L p 0 .292 .96 r
F P
0 g
s
.26947 .51053 m .27787 .52433 L .28342 .5201 L p 0 .292 .96 r
F P
0 g
s
.25192 .52294 m .27787 .52433 L .26947 .51053 L p 0 .387 .893 r
F P
0 g
s
.21207 .53416 m .21181 .55101 L .24903 .55291 L p 0 .344 .781 r
F P
0 g
s
.28484 .65595 m .28533 .61366 L .22958 .61109 L p 0 .344 .781 r
F P
0 g
s
.29359 .60828 m .28533 .61366 L .28484 .65595 L p 0 .084 .626 r
F P
0 g
s
.22958 .61109 m .22896 .65356 L .28484 .65595 L p 0 .344 .781 r
F P
0 g
s
.28484 .65595 m .29312 .65096 L .29359 .60828 L p 0 .084 .626 r
F P
0 g
s
.30202 .6028 m .29359 .60828 L .29312 .65096 L p 0 .084 .626 r
F P
0 g
s
.29312 .65096 m .30155 .64587 L .30202 .6028 L p 0 .084 .626 r
F P
0 g
s
.2302 .56882 m .22958 .61109 L .28533 .61366 L p 0 .344 .781 r
F P
0 g
s
.30155 .64587 m .24466 .6434 L .24526 .60012 L p 0 .344 .78 r
F P
0 g
s
.24526 .60012 m .24466 .6434 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.25274 .63816 m .24466 .6434 L .30155 .64587 L p 0 .455 1 r
F P
0 g
s
.29312 .65096 m .30155 .64587 L .24466 .6434 L p 0 .455 1 r
F P
0 g
s
.28484 .65595 m .29312 .65096 L .23674 .64853 L p 0 .455 1 r
F P
0 g
s
.28533 .61366 m .29359 .60828 L .29407 .5658 L p 0 .084 .626 r
F P
0 g
s
.57989 .31457 m .54885 .33767 L .57989 .31457 L .652 0 0 r
F
.54453 .33391 m .54455 .34087 L p .54358 .3416 L 0 .134 .679 r
F P
0 g
s
.54142 .33762 m .54885 .33767 L .57989 .31457 L .652 0 0 r
F
.54885 .33767 m .54885 .33767 L .57989 .31457 L F
.54472 .41081 m .53407 .41807 L p .54358 .3416 L 0 .134 .679 r
F P
0 g
s
.54455 .34087 m .54472 .41081 L p .54358 .3416 L 0 .134 .679 r
F P
0 g
s
.53422 .49491 m .53407 .41807 L .54472 .41081 L p 0 .134 .679 r
F P
0 g
s
.17625 .44259 m .18346 .43556 L .18317 .45245 L p 0 .052 .589 r
F P
0 g
s
.18317 .45245 m .17595 .45932 L .17625 .44259 L p 0 .052 .589 r
F P
0 g
s
.29545 .44231 m .29526 .45905 L .30363 .45218 L p 0 .084 .626 r
F P
0 g
s
.30363 .45218 m .30381 .43528 L .29545 .44231 L p 0 .084 .626 r
F P
0 g
s
.28402 .72685 m .28319 .79829 L .39429 .80173 L p 0 .344 .781 r
F P
0 g
s
.39429 .80173 m .28319 .79829 L .29151 .79465 L p 0 .443 1 r
F P
0 g
s
.29151 .79465 m .4036 .79815 L .39429 .80173 L p 0 .443 1 r
F P
0 g
s
.3148 .18712 m .31409 .25652 L .30563 .26525 L p 0 .084 .626 r
F P
0 g
s
.2488 .56974 m .21155 .56789 L .21913 .56205 L p 0 .458 1 r
F P
0 g
s
.21913 .56205 m .25671 .56393 L .2488 .56974 L p 0 .458 1 r
F P
0 g
s
.21868 .2414 m .26184 .28803 L .30563 .26525 L p 0 .344 .78 r
F P
0 g
s
.17595 .45932 m .18929 .46899 L .21544 .4705 L p 0 .267 .584 r
F P
0 g
s
.18929 .46899 m .17595 .45932 L .18317 .45245 L p 0 .29 .961 r
F P
0 g
s
.27273 .48015 m .26982 .48253 L .25497 .48169 L p 0 .458 1 r
F P
0 g
s
.4131 .7945 m .52411 .79801 L .51365 .80159 L p 0 .443 1 r
F P
0 g
s
.26947 .51053 m .2546 .50972 L .25192 .52294 L p 0 .387 .893 r
F P
0 g
s
.21466 .52095 m .25192 .52294 L .2546 .50972 L p 0 .387 .893 r
F P
0 g
s
.29526 .45905 m .25813 .45687 L .26616 .44995 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .30363 .45218 L .29526 .45905 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .29526 .45905 L .30363 .45218 L p 0 .458 1 r
F P
0 g
s
.29526 .45905 m .28401 .46959 L .29229 .4628 L p 0 .05 .1 r
F P
0 g
s
.29229 .4628 m .30363 .45218 L .29526 .45905 L p 0 .05 .1 r
F P
0 g
s
.54436 .26456 m .54453 .33391 L .43431 .32613 L p 0 .344 .779 r
F P
0 g
s
.43431 .32613 m .43456 .25617 L .54436 .26456 L p 0 .344 .779 r
F P
0 g
s
.21768 .47957 m .21544 .4705 L .18929 .46899 L p 0 .267 .584 r
F P
0 g
s
.21181 .55101 m .21207 .53416 L .17466 .5322 L p 0 .344 .781 r
F P
0 g
s
.18843 .51955 m .17466 .5322 L .21207 .53416 L p 0 .387 .893 r
F P
0 g
s
.21207 .53416 m .21466 .52095 L .18843 .51955 L p 0 .387 .893 r
F P
0 g
s
.21207 .53416 m .21965 .528 L .1819 .52601 L p 0 .458 1 r
F P
0 g
s
.1819 .52601 m .17466 .5322 L .21207 .53416 L p 0 .458 1 r
F P
0 g
s
.21965 .528 m .21207 .53416 L .17466 .5322 L p 0 .458 1 r
F P
0 g
s
.24063 .69847 m .28402 .72685 L .28484 .65595 L closepath p 0 .344 .781 r
F P
0 g
s
.24063 .69847 m .28484 .65595 L .22896 .65356 L closepath p 0 .344 .781 r
F P
0 g
s
.23674 .64853 m .22896 .65356 L .28484 .65595 L p 0 .455 1 r
F P
0 g
s
.29312 .65096 m .28484 .65595 L .28402 .72685 L p 0 .084 .626 r
F P
0 g
s
.28484 .65595 m .22896 .65356 L .23674 .64853 L p 0 .455 1 r
F P
0 g
s
.23674 .64853 m .29312 .65096 L .28484 .65595 L p 0 .455 1 r
F P
0 g
s
.28402 .72685 m .28484 .65595 L .29312 .65096 L p 0 .084 .626 r
F P
0 g
s
.25497 .48169 m .25783 .4793 L .27273 .48015 L p 0 .458 1 r
F P
0 g
s
.22042 .47717 m .25783 .4793 L .25497 .48169 L p 0 .458 1 r
F P
0 g
s
.25497 .48169 m .21768 .47957 L .22042 .47717 L p 0 .458 1 r
F P
0 g
s
.28342 .5201 m .27238 .50824 L .26947 .51053 L p 0 .292 .96 r
F P
0 g
s
.26947 .51053 m .27238 .50824 L .25746 .50743 L p 0 .458 1 r
F P
0 g
s
.25746 .50743 m .2546 .50972 L .26947 .51053 L p 0 .458 1 r
F P
0 g
s
.40434 .65575 m .41377 .65076 L .30155 .64587 L p 0 .455 1 r
F P
0 g
s
.30155 .64587 m .29312 .65096 L .40434 .65575 L p 0 .455 1 r
F P
0 g
s
.17466 .5322 m .17437 .5491 L .21181 .55101 L p 0 .344 .781 r
F P
0 g
s
.29229 .4628 m .28401 .46959 L .27273 .48015 L p 0 .05 .1 r
F P
0 g
s
.53464 .72218 m .52402 .72651 L .52392 .65555 L p 0 .134 .679 r
F P
0 g
s
.41377 .65076 m .52392 .65555 L .52402 .72651 L p 0 .344 .78 r
F P
0 g
s
.18317 .45245 m .19429 .46439 L .18929 .46899 L p 0 .29 .961 r
F P
0 g
s
.18929 .46899 m .2027 .47872 L .21768 .47957 L p 0 .267 .584 r
F P
0 g
s
.18929 .46899 m .19429 .46439 L .20539 .47631 L p 0 .29 .961 r
F P
0 g
s
.20539 .47631 m .2027 .47872 L .18929 .46899 L p 0 .29 .961 r
F P
0 g
s
.2546 .50972 m .21725 .50768 L .21466 .52095 L p 0 .387 .893 r
F P
0 g
s
.21725 .50768 m .2546 .50972 L .25746 .50743 L p 0 .458 1 r
F P
0 g
s
.18131 .56016 m .21913 .56205 L .21155 .56789 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .18131 .56016 L .23795 .56299 L p 0 .458 1 r
F P
0 g
s
.21913 .56205 m .18131 .56016 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .18797 .59743 L .18057 .60302 L p 0 .052 .589 r
F P
0 g
s
.18057 .60302 m .18131 .56016 L .1887 .55416 L p 0 .052 .589 r
F P
0 g
s
.19182 .36899 m .18448 .37669 L .1852 .33487 L p 0 .052 .589 r
F P
0 g
s
.22128 .42102 m .22897 .41375 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.19111 .41139 m .18375 .41871 L .22128 .42102 L p 0 .458 1 r
F P
0 g
s
.23995 .42217 m .18375 .41871 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.19111 .41139 m .24781 .41492 L .23995 .42217 L p 0 .458 1 r
F P
0 g
s
.54472 .41081 m .54491 .48837 L .53422 .49491 L p 0 .134 .679 r
F P
0 g
s
.53422 .49491 m .54491 .48837 L .63034 .49329 L p 0 .458 1 r
F P
0 g
s
.63034 .49329 m .54491 .48837 L .53422 .49491 L p 0 .458 1 r
F P
0 g
s
.54491 .48837 m .63034 .49329 L .63089 .57096 L p 0 .344 .779 r
F P
0 g
s
.71635 .65307 m .63144 .64929 L .63089 .57096 L p 0 .344 .779 r
F P
0 g
s
.5451 .56658 m .63089 .57096 L .63144 .64929 L p 0 .344 .779 r
F P
0 g
s
.63089 .57096 m .5451 .56658 L .54491 .48837 L p 0 .344 .779 r
F P
0 g
s
.63144 .64929 m .54529 .64546 L .5451 .56658 L p 0 .344 .779 r
F P
0 g
s
.54885 .33767 m .54965 .63617 L .72124 .64393 L p .847 0 0 r
F P
0 g
s
.7529 .3271 m .57989 .31457 L .54885 .33767 L p .652 0 0 r
F P
0 g
s
.54885 .33767 m .57989 .31457 L .58056 .46653 L p .326 0 0 r
F P
0 g
s
.58056 .46653 m .58124 .62106 L p .56469 .47625 L .326 0 0 r
F P
0 g
s
.54885 .33767 m .58056 .46653 L .56469 .47625 L .326 0 0 r
F
.58124 .62106 m .54965 .63617 L .54925 .48571 L p F P
0 g
s
.54925 .48571 m .54885 .33767 L p .56469 .47625 L .326 0 0 r
F P
0 g
s
.56469 .47625 m .58124 .62106 L .54925 .48571 L .326 0 0 r
F
.5451 .56658 m .53436 .57241 L .53422 .49491 L p 0 .134 .679 r
F P
0 g
s
.53422 .49491 m .54491 .48837 L .5451 .56658 L p 0 .134 .679 r
F P
0 g
s
.20225 .50686 m .18843 .51955 L .21466 .52095 L p 0 .387 .893 r
F P
0 g
s
.21466 .52095 m .21725 .50768 L .20225 .50686 L p 0 .387 .893 r
F P
0 g
s
.25813 .45687 m .22076 .45467 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .26616 .44995 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.30363 .45218 m .26616 .44995 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .26616 .44995 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .22076 .45467 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.27273 .48015 m .28091 .47346 L .29229 .4628 L p 0 .05 .1 r
F P
0 g
s
.28091 .47346 m .27273 .48015 L .25783 .4793 L p 0 .458 1 r
F P
0 g
s
.22896 .65356 m .22958 .61109 L .17332 .6085 L p 0 .344 .781 r
F P
0 g
s
.24839 .3727 m .24897 .33068 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .24897 .33068 L .24839 .3727 L p 0 .344 .78 r
F P
0 g
s
.24839 .3727 m .30444 .37639 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.43431 .32613 m .42466 .33423 L .31338 .32645 L p 0 .456 1 r
F P
0 g
s
.31338 .32645 m .32203 .3182 L .43431 .32613 L p 0 .456 1 r
F P
0 g
s
.31294 .36868 m .32161 .36081 L .32203 .3182 L p 0 .084 .626 r
F P
0 g
s
.32203 .3182 m .31338 .32645 L .31294 .36868 L p 0 .084 .626 r
F P
0 g
s
.17466 .5322 m .1819 .52601 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.17437 .5491 m .17466 .5322 L .1819 .52601 L p 0 .052 .589 r
F P
0 g
s
.17466 .5322 m .18843 .51955 L .19344 .51526 L p 0 .05 .1 r
F P
0 g
s
.19344 .51526 m .1819 .52601 L .17466 .5322 L p 0 .05 .1 r
F P
0 g
s
.20539 .47631 m .22042 .47717 L .21768 .47957 L p 0 .458 1 r
F P
0 g
s
.21768 .47957 m .2027 .47872 L .20539 .47631 L p 0 .458 1 r
F P
0 g
s
.30284 .52576 m .29445 .53196 L .29426 .54886 L p 0 .084 .626 r
F P
0 g
s
.28342 .5201 m .29445 .53196 L .30284 .52576 L p 0 .292 .96 r
F P
0 g
s
.29445 .53196 m .30284 .52576 L .26522 .52375 L p 0 .458 1 r
F P
0 g
s
.26522 .52375 m .25716 .52999 L .29445 .53196 L p 0 .458 1 r
F P
0 g
s
.29445 .53196 m .25716 .52999 L .26522 .52375 L p 0 .458 1 r
F P
0 g
s
.26522 .52375 m .30284 .52576 L .29445 .53196 L p 0 .458 1 r
F P
0 g
s
.25783 .4793 m .26587 .47259 L .28091 .47346 L p 0 .458 1 r
F P
0 g
s
.25783 .4793 m .22042 .47717 L .22813 .47042 L p 0 .458 1 r
F P
0 g
s
.22813 .47042 m .26587 .47259 L .25783 .4793 L p 0 .458 1 r
F P
0 g
s
.30284 .52576 m .29171 .51379 L .28342 .5201 L p 0 .292 .96 r
F P
0 g
s
.28057 .50181 m .27238 .50824 L .28342 .5201 L p 0 .292 .96 r
F P
0 g
s
.28342 .5201 m .29171 .51379 L .28057 .50181 L p 0 .292 .96 r
F P
0 g
s
.70566 .79981 m .71802 .79619 L .71635 .65307 L p 0 .162 .706 r
F P
0 g
s
.70566 .79981 m .67187 .79873 L .68395 .79509 L p 0 .443 1 r
F P
0 g
s
.68395 .79509 m .71802 .79619 L .70566 .79981 L p 0 .443 1 r
F P
0 g
s
.17407 .56603 m .17437 .5491 L .18161 .54307 L p 0 .052 .589 r
F P
0 g
s
.1819 .52601 m .18161 .54307 L .17437 .5491 L p 0 .052 .589 r
F P
0 g
s
.27238 .50824 m .28057 .50181 L .26551 .50098 L p 0 .458 1 r
F P
0 g
s
.26551 .50098 m .25746 .50743 L .27238 .50824 L p 0 .458 1 r
F P
0 g
s
.28319 .79829 m .28402 .72685 L .24063 .69847 L p 0 .344 .781 r
F P
0 g
s
.29232 .72253 m .28402 .72685 L .28319 .79829 L p 0 .084 .626 r
F P
0 g
s
.28402 .72685 m .29232 .72253 L .29312 .65096 L p 0 .084 .626 r
F P
0 g
s
.28319 .79829 m .28402 .72685 L .29232 .72253 L p 0 .084 .626 r
F P
0 g
s
.24063 .69847 m .19589 .74151 L .28319 .79829 L p 0 .344 .781 r
F P
0 g
s
.28319 .79829 m .29151 .79465 L .29232 .72253 L p 0 .084 .626 r
F P
0 g
s
.17003 .79479 m .28319 .79829 L .19589 .74151 L p 0 .344 .781 r
F P
0 g
s
.29232 .72253 m .29151 .79465 L .28319 .79829 L p 0 .084 .626 r
F P
0 g
s
.17003 .79479 m .17732 .79108 L .29151 .79465 L p 0 .443 1 r
F P
0 g
s
.29151 .79465 m .28319 .79829 L .17003 .79479 L p 0 .443 1 r
F P
0 g
s
.29312 .65096 m .29232 .72253 L .28402 .72685 L p 0 .084 .626 r
F P
0 g
s
.19489 .18749 m .19442 .21518 L .21868 .2414 L p 0 .344 .78 r
F P
0 g
s
.19489 .18749 m .20232 .17797 L .20186 .20591 L p 0 .052 .589 r
F P
0 g
s
.20186 .20591 m .19442 .21518 L .19489 .18749 L p 0 .052 .589 r
F P
0 g
s
.30266 .54282 m .29426 .54886 L .29407 .5658 L p 0 .084 .626 r
F P
0 g
s
.29426 .54886 m .30266 .54282 L .30284 .52576 L p 0 .084 .626 r
F P
0 g
s
.18448 .37669 m .19182 .36899 L .19111 .41139 L p 0 .052 .589 r
F P
0 g
s
.19111 .41139 m .18375 .41871 L .18448 .37669 L p 0 .052 .589 r
F P
0 g
s
.43481 .18674 m .3234 .17758 L .3148 .18712 L p 0 .451 1 r
F P
0 g
s
.3234 .17758 m .3148 .18712 L .31409 .25652 L p 0 .084 .626 r
F P
0 g
s
.31409 .25652 m .3148 .18712 L .3234 .17758 L p 0 .084 .626 r
F P
0 g
s
.20991 .16825 m .20232 .17797 L .3148 .18712 L p 0 .451 1 r
F P
0 g
s
.3148 .18712 m .3234 .17758 L .20991 .16825 L p 0 .451 1 r
F P
0 g
s
.19344 .51526 m .18843 .51955 L .20225 .50686 L p 0 .05 .1 r
F P
0 g
s
.43429 .33315 m .53088 .33992 L .53138 .63764 L p .847 0 0 r
F P
0 g
s
.53436 .57241 m .5451 .56658 L .54529 .64546 L p 0 .134 .679 r
F P
0 g
s
.53088 .33992 m .53541 .63668 L .53484 .33844 L .564 0 0 r
F
.53088 .33992 m .53138 .63764 L .53541 .63668 L F
.53088 .33992 m .46522 .32104 L .43429 .33315 L .652 0 0 r
F
.53088 .33992 m .53484 .33844 L .46522 .32104 L F
.53088 .33992 m .4332 .63322 L .53138 .63764 L .847 0 0 r
F
.53088 .33992 m .43429 .33315 L .4332 .63322 L F
.17332 .6085 m .17256 .65116 L .22896 .65356 L p 0 .344 .781 r
F P
0 g
s
.17256 .65116 m .22896 .65356 L .23674 .64853 L p 0 .455 1 r
F P
0 g
s
.23674 .64853 m .17983 .64608 L .17256 .65116 L p 0 .455 1 r
F P
0 g
s
.22896 .65356 m .17256 .65116 L .17983 .64608 L p 0 .455 1 r
F P
0 g
s
.17983 .64608 m .23674 .64853 L .22896 .65356 L p 0 .455 1 r
F P
0 g
s
.52402 .72651 m .53464 .72218 L .53477 .79435 L p 0 .134 .679 r
F P
0 g
s
.53464 .72218 m .53477 .79435 L .54565 .79063 L p 0 .134 .679 r
F P
0 g
s
.54565 .79063 m .54547 .71776 L .53464 .72218 L p 0 .134 .679 r
F P
0 g
s
.53477 .79435 m .53464 .72218 L .54547 .71776 L p 0 .134 .679 r
F P
0 g
s
.54547 .71776 m .54565 .79063 L .53477 .79435 L p 0 .134 .679 r
F P
0 g
s
.42278 .79078 m .43265 .78698 L .54565 .79063 L p 0 .443 1 r
F P
0 g
s
.54565 .79063 m .53477 .79435 L .42278 .79078 L p 0 .443 1 r
F P
0 g
s
.52402 .72651 m .41343 .72235 L .41377 .65076 L p 0 .344 .78 r
F P
0 g
s
.22896 .65356 m .17256 .65116 L .19589 .74151 L p 0 .344 .781 r
F P
0 g
s
.19589 .74151 m .24063 .69847 L .22896 .65356 L p 0 .344 .781 r
F P
0 g
s
.25746 .50743 m .21999 .50538 L .21725 .50768 L p 0 .458 1 r
F P
0 g
s
.20225 .50686 m .21725 .50768 L .21999 .50538 L p 0 .458 1 r
F P
0 g
s
.18161 .54307 m .18131 .56016 L .17407 .56603 L p 0 .052 .589 r
F P
0 g
s
.43481 .18674 m .43456 .25617 L .32272 .24762 L p 0 .344 .779 r
F P
0 g
s
.32272 .24762 m .3234 .17758 L .43481 .18674 L p 0 .344 .779 r
F P
0 g
s
.19253 .32678 m .19442 .21518 L .21868 .2414 L closepath p 0 .344 .78 r
F P
0 g
s
.21868 .2414 m .19442 .21518 L .19253 .32678 L closepath p 0 .344 .78 r
F P
0 g
s
.30247 .55992 m .29407 .5658 L .29359 .60828 L p 0 .084 .626 r
F P
0 g
s
.29407 .5658 m .30247 .55992 L .30266 .54282 L p 0 .084 .626 r
F P
0 g
s
.29407 .5658 m .30247 .55992 L .24585 .55705 L p 0 .458 1 r
F P
0 g
s
.24585 .55705 m .23795 .56299 L .29407 .5658 L p 0 .458 1 r
F P
0 g
s
.25746 .50743 m .26551 .50098 L .22771 .49889 L p 0 .458 1 r
F P
0 g
s
.22771 .49889 m .21999 .50538 L .25746 .50743 L p 0 .458 1 r
F P
0 g
s
.24585 .55705 m .30247 .55992 L .30247 .55992 L p 0 .344 .78 r
F P
0 g
s
.29407 .5658 m .25671 .56393 L .26478 .55801 L p 0 .458 1 r
F P
0 g
s
.26478 .55801 m .30247 .55992 L .29407 .5658 L p 0 .458 1 r
F P
0 g
s
.29359 .60828 m .30202 .6028 L .30247 .55992 L p 0 .084 .626 r
F P
0 g
s
.23795 .56299 m .24585 .55705 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.25671 .56393 m .21913 .56205 L .22686 .55609 L p 0 .458 1 r
F P
0 g
s
.22686 .55609 m .26478 .55801 L .25671 .56393 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .24585 .55705 L .24585 .55705 L p 0 .344 .78 r
F P
0 g
s
.1887 .55416 m .22686 .55609 L .21913 .56205 L p 0 .458 1 r
F P
0 g
s
.24585 .55705 m .24526 .60012 L p .1887 .55416 L 0 .344 .78 r
F P
0 g
s
.1887 .55416 m .24585 .55705 L .1887 .55416 L 0 .344 .78 r
F
.24526 .60012 m .24585 .55705 L .1887 .55416 L p F P
0 g
s
.22711 .53889 m .265 .54086 L .26478 .55801 L p 0 .344 .78 r
F P
0 g
s
.26478 .55801 m .265 .54086 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.26478 .55801 m .22686 .55609 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.22711 .53889 m .22686 .55609 L .26478 .55801 L p 0 .344 .78 r
F P
0 g
s
.18899 .53691 m .22711 .53889 L .22686 .55609 L p 0 .344 .78 r
F P
0 g
s
.22686 .55609 m .22711 .53889 L .18899 .53691 L p 0 .344 .78 r
F P
0 g
s
.22686 .55609 m .1887 .55416 L .18899 .53691 L p 0 .344 .78 r
F P
0 g
s
.18899 .53691 m .1887 .55416 L .22686 .55609 L p 0 .344 .78 r
F P
0 g
s
.1887 .55416 m .24585 .55705 L .25391 .551 L p 0 .458 1 r
F P
0 g
s
.25391 .551 m .19623 .54805 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.23474 .55002 m .22686 .55609 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.24526 .60012 m .18797 .59743 L .1887 .55416 L p 0 .344 .78 r
F P
0 g
s
.1887 .55416 m .18797 .59743 L .24526 .60012 L p 0 .344 .78 r
F P
0 g
s
.1887 .55416 m .19623 .54805 L .23474 .55002 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .19623 .54805 L .19551 .59173 L p 0 .052 .589 r
F P
0 g
s
.30202 .6028 m .24526 .60012 L .24585 .55705 L p 0 .344 .78 r
F P
0 g
s
.30247 .55992 m .30202 .6028 L p .24585 .55705 L 0 .344 .78 r
F P
0 g
s
.24585 .55705 m .30247 .55992 L .24585 .55705 L 0 .344 .78 r
F
.22076 .45467 m .18317 .45245 L .19053 .44545 L p 0 .458 1 r
F P
0 g
s
.19053 .44545 m .22846 .44771 L .22076 .45467 L p 0 .458 1 r
F P
0 g
s
.22076 .45467 m .22846 .44771 L .19053 .44545 L p 0 .458 1 r
F P
0 g
s
.19053 .44545 m .18317 .45245 L .22076 .45467 L p 0 .458 1 r
F P
0 g
s
.20001 .31853 m .19253 .32678 L .19442 .21518 L p 0 .052 .589 r
F P
0 g
s
.19442 .21518 m .20186 .20591 L .20001 .31853 L p 0 .052 .589 r
F P
0 g
s
.68395 .79509 m .65366 .7624 L .71635 .65307 L p 0 .344 .779 r
F P
0 g
s
.71635 .65307 m .71802 .79619 L .68395 .79509 L p 0 .344 .779 r
F P
0 g
s
.21999 .50538 m .20494 .50455 L .20225 .50686 L p 0 .458 1 r
F P
0 g
s
.20225 .50686 m .20494 .50455 L .19344 .51526 L p 0 .05 .1 r
F P
0 g
s
.72733 .64451 m .83031 .64205 L .73043 .64548 L .538 0 0 r
F
0 g
.72974 .64657 m
.73043 .64548 L
s
.25716 .52999 m .26522 .52375 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .21965 .528 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.25716 .52999 m .21965 .528 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .26522 .52375 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.53484 .33844 m .5421 .63614 L .54142 .33762 L .729 0 0 r
F
.53484 .33844 m .53541 .63668 L .5421 .63614 L F
.53484 .33844 m .51879 .31414 L .46522 .32104 L .652 0 0 r
F
.53484 .33844 m .54142 .33762 L .51879 .31414 L F
0 g
.53088 .33992 m
.53484 .33844 L
s
.68395 .79509 m .67187 .79873 L .53477 .79435 L p 0 .443 1 r
F P
0 g
s
.52411 .79801 m .53477 .79435 L .67187 .79873 L p 0 .443 1 r
F P
0 g
s
.18375 .41871 m .19111 .41139 L .19082 .4284 L p 0 .052 .589 r
F P
0 g
s
.19082 .4284 m .18346 .43556 L .18375 .41871 L p 0 .052 .589 r
F P
0 g
s
.21296 .46955 m .22813 .47042 L .22042 .47717 L p 0 .458 1 r
F P
0 g
s
.22042 .47717 m .20539 .47631 L .21296 .46955 L p 0 .458 1 r
F P
0 g
s
.17256 .65116 m .17332 .6085 L .18057 .60302 L p 0 .052 .589 r
F P
0 g
s
.18131 .56016 m .18057 .60302 L .17332 .6085 L p 0 .052 .589 r
F P
0 g
s
.24897 .33068 m .24839 .3727 L .19182 .36899 L p 0 .344 .78 r
F P
0 g
s
.19182 .36899 m .24839 .3727 L .24897 .33068 L p 0 .344 .78 r
F P
0 g
s
.54885 .33767 m .58124 .62106 L .57989 .31457 L .326 0 0 r
F
.54885 .33767 m .54965 .63617 L .58124 .62106 L F
.54142 .33762 m .54965 .63617 L .54885 .33767 L .811 0 0 r
F
0 g
.54885 .33767 m
.54885 .33767 L
s
.54142 .33762 m .5421 .63614 L .54965 .63617 L .811 0 0 r
F
0 g
.54885 .33767 m
.54925 .48571 L
s
.54142 .33762 m .57989 .31457 L .51879 .31414 L .652 0 0 r
F
0 g
.54142 .33762 m
.54885 .33767 L
s
.53484 .33844 m
.54142 .33762 L
s
.18346 .43556 m .19082 .4284 L .19053 .44545 L p 0 .052 .589 r
F P
0 g
s
.19053 .44545 m .18317 .45245 L .18346 .43556 L p 0 .052 .589 r
F P
0 g
s
.20539 .47631 m .19429 .46439 L .20175 .4575 L p 0 .29 .961 r
F P
0 g
s
.20175 .4575 m .21296 .46955 L .20539 .47631 L p 0 .29 .961 r
F P
0 g
s
.30381 .43528 m .30363 .45218 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .26638 .433 L .30381 .43528 L p 0 .344 .78 r
F P
0 g
s
.31233 .42812 m .30381 .43528 L .30363 .45218 L p 0 .084 .626 r
F P
0 g
s
.30381 .43528 m .26638 .433 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .30363 .45218 L .30381 .43528 L p 0 .344 .78 r
F P
0 g
s
.72733 .64451 m .80646 .63411 L .83031 .64205 L .538 0 0 r
F
.72124 .64393 m .80646 .63411 L .72733 .64451 L F
0 g
.72733 .64451 m
.73043 .64548 L
s
.4036 .79815 m .29151 .79465 L .3 .79093 L p 0 .443 1 r
F P
0 g
s
.3 .79093 m .4131 .7945 L .4036 .79815 L p 0 .443 1 r
F P
0 g
s
.31409 .25652 m .32272 .24762 L .3234 .17758 L p 0 .084 .626 r
F P
0 g
s
.32272 .24762 m .31409 .25652 L .31338 .32645 L p 0 .084 .626 r
F P
0 g
s
.19429 .46439 m .18317 .45245 L .19053 .44545 L p 0 .29 .961 r
F P
0 g
s
.19053 .44545 m .20175 .4575 L .19429 .46439 L p 0 .29 .961 r
F P
0 g
s
.20494 .50455 m .21999 .50538 L .22771 .49889 L p 0 .458 1 r
F P
0 g
s
.3234 .17758 m .32272 .24762 L .31409 .25652 L p 0 .084 .626 r
F P
0 g
s
.31338 .32645 m .31409 .25652 L .32272 .24762 L p 0 .084 .626 r
F P
0 g
s
.31338 .32645 m .32203 .3182 L .32272 .24762 L p 0 .084 .626 r
F P
0 g
s
.32272 .24762 m .32203 .3182 L .31338 .32645 L p 0 .084 .626 r
F P
0 g
s
.32203 .3182 m .2651 .31418 L .25696 .32251 L p 0 .456 1 r
F P
0 g
s
.25696 .32251 m .31338 .32645 L .32203 .3182 L p 0 .456 1 r
F P
0 g
s
.32203 .3182 m .31338 .32645 L .25696 .32251 L p 0 .456 1 r
F P
0 g
s
.43456 .25617 m .43431 .32613 L .32203 .3182 L p 0 .344 .779 r
F P
0 g
s
.32203 .3182 m .32272 .24762 L .43456 .25617 L p 0 .344 .779 r
F P
0 g
s
.26602 .46126 m .26616 .44995 L .30363 .45218 L p 0 .344 .78 r
F P
0 g
s
.30363 .45218 m .29229 .4628 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.30363 .45218 m .31216 .44517 L .31233 .42812 L p 0 .084 .626 r
F P
0 g
s
.31216 .44517 m .30363 .45218 L .26616 .44995 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .30363 .45218 L .31216 .44517 L p 0 .458 1 r
F P
0 g
s
.29229 .4628 m .30363 .45218 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.30363 .45218 m .29229 .4628 L .30072 .45589 L p 0 .05 .1 r
F P
0 g
s
.30072 .45589 m .31216 .44517 L .30363 .45218 L p 0 .05 .1 r
F P
0 g
s
.7571 .62926 m .72124 .64393 L .54965 .63617 L p .538 0 0 r
F P
0 g
s
.71772 .34955 m
.72107 .63046 L
s
.72124 .64393 m .7571 .62926 L .80646 .63411 L .538 0 0 r
F
0 g
.72124 .64393 m
.72733 .64451 L
s
.18057 .60302 m .17983 .64608 L .17256 .65116 L p 0 .052 .589 r
F P
0 g
s
.19111 .41139 m .19182 .36899 L .24839 .3727 L p 0 .344 .78 r
F P
0 g
s
.17054 .76589 m .19589 .74151 L .17256 .65116 L closepath p 0 .344 .781 r
F P
0 g
s
.19589 .74151 m .17054 .76589 L .17003 .79479 L p 0 .344 .781 r
F P
0 g
s
.17256 .65116 m .17983 .64608 L .17783 .7619 L p 0 .052 .589 r
F P
0 g
s
.17783 .7619 m .17054 .76589 L .17256 .65116 L p 0 .052 .589 r
F P
0 g
s
.24839 .3727 m .19182 .36899 L .19111 .41139 L p 0 .344 .78 r
F P
0 g
s
.23681 .40633 m .1986 .40393 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.22771 .49889 m .21252 .49805 L .20494 .50455 L p 0 .458 1 r
F P
0 g
s
.19344 .51526 m .20494 .50455 L .21252 .49805 L p 0 .05 .1 r
F P
0 g
s
.21965 .528 m .22737 .52173 L .18928 .51969 L p 0 .458 1 r
F P
0 g
s
.18928 .51969 m .1819 .52601 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .21965 .528 L .1819 .52601 L p 0 .458 1 r
F P
0 g
s
.24466 .6434 m .23674 .64853 L .29312 .65096 L p 0 .455 1 r
F P
0 g
s
.30155 .64587 m .29312 .65096 L .29232 .72253 L p 0 .084 .626 r
F P
0 g
s
.29312 .65096 m .23674 .64853 L .24466 .6434 L p 0 .455 1 r
F P
0 g
s
.24466 .6434 m .30155 .64587 L .29312 .65096 L p 0 .455 1 r
F P
0 g
s
.29232 .72253 m .30078 .71812 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .30078 .71812 L .41343 .72235 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .30078 .71812 L .30078 .71812 L p 0 .344 .78 r
F P
0 g
s
.29232 .72253 m .29312 .65096 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .30078 .71812 L .29232 .72253 L p 0 .084 .626 r
F P
0 g
s
.3 .79093 m .30078 .71812 L .29232 .72253 L p 0 .084 .626 r
F P
0 g
s
.29232 .72253 m .29151 .79465 L .3 .79093 L p 0 .084 .626 r
F P
0 g
s
.29151 .79465 m .29232 .72253 L .30078 .71812 L p 0 .084 .626 r
F P
0 g
s
.30078 .71812 m .3 .79093 L .29151 .79465 L p 0 .084 .626 r
F P
0 g
s
.21105 .73299 m .3 .79093 L .18476 .78729 L p 0 .344 .78 r
F P
0 g
s
.17732 .79108 m .18476 .78729 L .3 .79093 L p 0 .443 1 r
F P
0 g
s
.30078 .71812 m .3 .79093 L .21105 .73299 L p 0 .344 .78 r
F P
0 g
s
.21105 .73299 m .25658 .68917 L .30078 .71812 L p 0 .344 .78 r
F P
0 g
s
.3 .79093 m .30056 .73844 L .25658 .68917 L p 0 .344 .78 r
F P
0 g
s
.3 .79093 m .29151 .79465 L .17732 .79108 L p 0 .443 1 r
F P
0 g
s
.30078 .71812 m .30155 .64587 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .25658 .68917 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .25658 .68917 L .30078 .71812 L p 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .30078 .71812 L p .30155 .64587 L 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .30155 .64587 L p .30078 .71812 L 0 .344 .78 r
F P
0 g
s
.53451 .65056 m .42338 .64567 L .41377 .65076 L p 0 .455 1 r
F P
0 g
s
.41343 .72235 m .41377 .65076 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .41377 .65076 L .42338 .64567 L p 0 .455 1 r
F P
0 g
s
.30155 .64587 m .41377 .65076 L .41343 .72235 L p 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .30155 .64587 L p .30155 .64587 L 0 .344 .78 r
F P
0 g
s
.41343 .72235 m .30078 .71812 L p .30155 .64587 L 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .30078 .71812 L p .30155 .64587 L 0 .344 .78 r
F P
0 g
s
.4131 .7945 m .41343 .72235 L .30078 .71812 L p 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .41343 .72235 L .4131 .7945 L p 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .3 .79093 L .4131 .7945 L p 0 .344 .78 r
F P
0 g
s
.18476 .78729 m .18526 .75783 L .21105 .73299 L p 0 .344 .78 r
F P
0 g
s
.18526 .75783 m .18476 .78729 L .3 .79093 L p 0 .344 .78 r
F P
0 g
s
.3 .79093 m .18476 .78729 L p .18476 .78729 L 0 .443 1 r
F P
0 g
s
.3 .79093 m .30078 .71812 L p .30078 .71812 L 0 .344 .78 r
F P
0 g
s
.4131 .7945 m .3 .79093 L p .30078 .71812 L 0 .344 .78 r
F P
0 g
s
.3 .79093 m .3 .79093 L p .30078 .71812 L 0 .344 .78 r
F P
0 g
s
.30078 .71812 m .3 .79093 L .30866 .78714 L p 0 .084 .626 r
F P
0 g
s
.30866 .78714 m .3 .79093 L .30078 .71812 L p 0 .084 .626 r
F P
0 g
s
.25658 .68917 m .21105 .73299 L .3 .79093 L p 0 .344 .78 r
F P
0 g
s
.3 .79093 m .21105 .73299 L .18526 .75783 L p 0 .344 .78 r
F P
0 g
s
.30866 .78714 m .3 .79093 L p .18476 .78729 L 0 .443 1 r
F P
0 g
s
.30866 .78714 m .30941 .71362 L .30078 .71812 L p 0 .084 .626 r
F P
0 g
s
.42338 .64567 m .31016 .64069 L .30155 .64587 L p 0 .455 1 r
F P
0 g
s
.31016 .64069 m .30155 .64587 L .30078 .71812 L p 0 .084 .626 r
F P
0 g
s
.26659 .41609 m .26638 .433 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
.22872 .43071 m .22897 .41375 L .26659 .41609 L p 0 .344 .78 r
F P
0 g
s
.26659 .41609 m .22897 .41375 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
.22872 .43071 m .26638 .433 L .26659 .41609 L p 0 .344 .78 r
F P
0 g
s
.26587 .47259 m .26602 .46126 L .29229 .4628 L p 0 .344 .78 r
F P
0 g
s
.29229 .4628 m .28091 .47346 L .26587 .47259 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .26602 .46126 L .29229 .4628 L p 0 .344 .78 r
F P
0 g
s
.28091 .47346 m .29229 .4628 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.30072 .45589 m .29229 .4628 L .28091 .47346 L p 0 .05 .1 r
F P
0 g
s
.53451 .65056 m .53464 .72218 L .54547 .71776 L p 0 .134 .679 r
F P
0 g
s
.54547 .71776 m .53464 .72218 L .53451 .65056 L p 0 .134 .679 r
F P
0 g
s
.1819 .52601 m .19344 .51526 L .20092 .50885 L p 0 .05 .1 r
F P
0 g
s
.21252 .49805 m .20092 .50885 L .19344 .51526 L p 0 .05 .1 r
F P
0 g
s
.26638 .433 m .26616 .44995 L .22846 .44771 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .22872 .43071 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.26638 .433 m .22872 .43071 L .22846 .44771 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .26616 .44995 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.8015 .33452 m .83031 .64205 L .80646 .63411 L 1 0 0 r
F
0 g
.82315 .65078 m
.83031 .64205 L
s
.7529 .3271 m .8015 .33452 L .80646 .63411 L .891 0 0 r
F
0 g
.8015 .33452 m
.82504 .34666 L
s
.19111 .41139 m .22897 .41375 L .23681 .40633 L p 0 .458 1 r
F P
0 g
s
.25582 .40753 m .24781 .41492 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .26602 .46126 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.2283 .45906 m .22846 .44771 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .27435 .4429 L .31216 .44517 L p 0 .458 1 r
F P
0 g
s
.27435 .4429 m .26616 .44995 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.31216 .44517 m .27435 .4429 L .26616 .44995 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .26616 .44995 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .22846 .44771 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.2283 .45906 m .26602 .46126 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.28091 .47346 m .28924 .46664 L .30072 .45589 L p 0 .05 .1 r
F P
0 g
s
.26602 .46126 m .26587 .47259 L .28091 .47346 L p 0 .344 .78 r
F P
0 g
s
.28924 .46664 m .28091 .47346 L .26587 .47259 L p 0 .458 1 r
F P
0 g
s
.1819 .52601 m .18928 .51969 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.18161 .54307 m .1819 .52601 L .18928 .51969 L p 0 .052 .589 r
F P
0 g
s
.20092 .50885 m .18928 .51969 L .1819 .52601 L p 0 .05 .1 r
F P
0 g
s
.26602 .46126 m .26587 .47259 L .22813 .47042 L p 0 .344 .78 r
F P
0 g
s
.22813 .47042 m .2283 .45906 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.26602 .46126 m .2283 .45906 L .22813 .47042 L p 0 .344 .78 r
F P
0 g
s
.22813 .47042 m .26587 .47259 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.53138 .63764 m .4332 .63322 L .43429 .33315 L p .847 0 0 r
F P
0 g
s
.43429 .33315 m .46464 .62529 L .4332 .63322 L .55 0 0 r
F
.43429 .33315 m .46522 .32104 L .46464 .62529 L F
0 g
.46519 .33532 m
.53088 .33992 L
s
.43429 .33315 m
.43429 .33315 L
s
.26522 .52375 m .30284 .52576 L .30266 .54282 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .30284 .52576 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.31122 .53666 m .3114 .51944 L .30284 .52576 L p 0 .084 .626 r
F P
0 g
s
.30284 .52576 m .30266 .54282 L .31122 .53666 L p 0 .084 .626 r
F P
0 g
s
.30266 .54282 m .30284 .52576 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.26537 .51236 m .26522 .52375 L .30284 .52576 L p 0 .344 .78 r
F P
0 g
s
.30284 .52576 m .29171 .51379 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .30284 .52576 L .3114 .51944 L p 0 .292 .96 r
F P
0 g
s
.26522 .52375 m .30284 .52576 L .3114 .51944 L p 0 .458 1 r
F P
0 g
s
.26522 .52375 m .26537 .51236 L .29171 .51379 L p 0 .344 .78 r
F P
0 g
s
.30284 .52576 m .26522 .52375 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.27344 .51739 m .3114 .51944 L .30284 .52576 L p 0 .458 1 r
F P
0 g
s
.22897 .41375 m .22872 .43071 L .19082 .4284 L p 0 .344 .78 r
F P
0 g
s
.19082 .4284 m .19111 .41139 L .22897 .41375 L p 0 .344 .78 r
F P
0 g
s
.22897 .41375 m .19111 .41139 L .19082 .4284 L p 0 .344 .78 r
F P
0 g
s
.19082 .4284 m .22872 .43071 L .22897 .41375 L p 0 .344 .78 r
F P
0 g
s
.26587 .47259 m .27407 .46575 L .28924 .46664 L p 0 .458 1 r
F P
0 g
s
.27407 .46575 m .26587 .47259 L .22813 .47042 L p 0 .458 1 r
F P
0 g
s
.28057 .50181 m .29171 .51379 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.3114 .51944 m .30016 .50735 L .29171 .51379 L p 0 .292 .96 r
F P
0 g
s
.26551 .50098 m .26537 .51236 L .29171 .51379 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .28057 .50181 L .26551 .50098 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .30016 .50735 L .28891 .49525 L p 0 .292 .96 r
F P
0 g
s
.28891 .49525 m .28057 .50181 L .29171 .51379 L p 0 .292 .96 r
F P
0 g
s
.18131 .56016 m .18161 .54307 L .18899 .53691 L p 0 .052 .589 r
F P
0 g
s
.18928 .51969 m .18899 .53691 L .18161 .54307 L p 0 .052 .589 r
F P
0 g
s
.26537 .51236 m .26551 .50098 L .28057 .50181 L p 0 .344 .78 r
F P
0 g
s
.27372 .4944 m .26551 .50098 L .28057 .50181 L p 0 .458 1 r
F P
0 g
s
.28057 .50181 m .28891 .49525 L .27372 .4944 L p 0 .458 1 r
F P
0 g
s
.20186 .20591 m .20232 .17797 L .20991 .16825 L p 0 .052 .589 r
F P
0 g
s
.265 .54086 m .30266 .54282 L .30247 .55992 L p 0 .344 .78 r
F P
0 g
s
.30266 .54282 m .265 .54086 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.31105 .55392 m .31122 .53666 L .30266 .54282 L p 0 .084 .626 r
F P
0 g
s
.30266 .54282 m .30247 .55992 L .31105 .55392 L p 0 .084 .626 r
F P
0 g
s
.30247 .55992 m .30266 .54282 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.26522 .52375 m .265 .54086 L .30266 .54282 L p 0 .344 .78 r
F P
0 g
s
.20991 .16825 m .3234 .17758 L .23418 .22319 L p 0 .344 .779 r
F P
0 g
s
.19111 .41139 m .19182 .36899 L .19931 .36113 L p 0 .052 .589 r
F P
0 g
s
.3234 .17758 m .32272 .24762 L .27816 .27075 L p 0 .344 .779 r
F P
0 g
s
.27816 .27075 m .23418 .22319 L .3234 .17758 L p 0 .344 .779 r
F P
0 g
s
.22872 .43071 m .22846 .44771 L .19053 .44545 L p 0 .344 .78 r
F P
0 g
s
.19053 .44545 m .19082 .4284 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
.22872 .43071 m .19082 .4284 L .19053 .44545 L p 0 .344 .78 r
F P
0 g
s
.19053 .44545 m .22846 .44771 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
.18723 .6409 m .17983 .64608 L .23674 .64853 L p 0 .455 1 r
F P
0 g
s
.23674 .64853 m .17983 .64608 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.23674 .64853 m .24466 .6434 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.18723 .6409 m .24466 .6434 L .23674 .64853 L p 0 .455 1 r
F P
0 g
s
.18899 .53691 m .1887 .55416 L .18131 .56016 L p 0 .052 .589 r
F P
0 g
s
.22771 .49889 m .26551 .50098 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.26537 .51236 m .26551 .50098 L .22771 .49889 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .26551 .50098 L .27372 .4944 L p 0 .458 1 r
F P
0 g
s
.30247 .55992 m .26478 .55801 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.265 .54086 m .26478 .55801 L .30247 .55992 L p 0 .344 .78 r
F P
0 g
s
.24585 .55705 m .30247 .55992 L .31105 .55392 L p 0 .458 1 r
F P
0 g
s
.31105 .55392 m .30247 .55992 L .26478 .55801 L p 0 .458 1 r
F P
0 g
s
.3106 .5972 m .31105 .55392 L .30247 .55992 L p 0 .084 .626 r
F P
0 g
s
.30247 .55992 m .30202 .6028 L .3106 .5972 L p 0 .084 .626 r
F P
0 g
s
.30202 .6028 m .30247 .55992 L .24585 .55705 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .2283 .45906 L .20175 .4575 L p 0 .344 .78 r
F P
0 g
s
.20175 .4575 m .19053 .44545 L .22846 .44771 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .23631 .44061 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .22846 .44771 L .19053 .44545 L p 0 .458 1 r
F P
0 g
s
.27435 .4429 m .23631 .44061 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.19803 .43831 m .19053 .44545 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .23631 .44061 L .19803 .43831 L p 0 .458 1 r
F P
0 g
s
.2283 .45906 m .22846 .44771 L .19053 .44545 L p 0 .344 .78 r
F P
0 g
s
.20763 .31012 m .20001 .31853 L .20186 .20591 L p 0 .052 .589 r
F P
0 g
s
.20186 .20591 m .20946 .19645 L .20763 .31012 L p 0 .052 .589 r
F P
0 g
s
.20991 .16825 m .20946 .19645 L .20186 .20591 L p 0 .052 .589 r
F P
0 g
s
.22754 .5103 m .26537 .51236 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.26537 .51236 m .22754 .5103 L .22771 .49889 L p 0 .344 .78 r
F P
0 g
s
.26522 .52375 m .26537 .51236 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .22754 .5103 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.17003 .79479 m .17054 .76589 L .17783 .7619 L p 0 .052 .589 r
F P
0 g
s
.20175 .4575 m .2283 .45906 L .22813 .47042 L p 0 .344 .78 r
F P
0 g
s
.19053 .44545 m .20175 .4575 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.21296 .46955 m .22813 .47042 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.2283 .45906 m .20175 .4575 L .21296 .46955 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .26522 .52375 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.26522 .52375 m .22737 .52173 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.3114 .51944 m .27344 .51739 L .26522 .52375 L p 0 .458 1 r
F P
0 g
s
.265 .54086 m .26522 .52375 L .22737 .52173 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .22737 .52173 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .26522 .52375 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.27344 .51739 m .26522 .52375 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.53477 .79435 m .54565 .79063 L .68395 .79509 L p 0 .443 1 r
F P
0 g
s
.65366 .7624 m .68395 .79509 L .54565 .79063 L closepath p 0 .344 .779 r
F P
0 g
s
.19111 .41139 m .1986 .40393 L .25582 .40753 L p 0 .458 1 r
F P
0 g
s
.19082 .4284 m .19111 .41139 L .1986 .40393 L p 0 .052 .589 r
F P
0 g
s
.22813 .47042 m .21296 .46955 L .20175 .4575 L p 0 .344 .78 r
F P
0 g
s
.22813 .47042 m .23598 .46354 L .27407 .46575 L p 0 .458 1 r
F P
0 g
s
.22068 .46265 m .23598 .46354 L .22813 .47042 L p 0 .458 1 r
F P
0 g
s
.22813 .47042 m .21296 .46955 L .22068 .46265 L p 0 .458 1 r
F P
0 g
s
.19931 .36113 m .1986 .40393 L .19111 .41139 L p 0 .052 .589 r
F P
0 g
s
.17983 .64608 m .18057 .60302 L .18797 .59743 L p 0 .052 .589 r
F P
0 g
s
.20763 .31012 m .2651 .31418 L .25696 .32251 L p 0 .456 1 r
F P
0 g
s
.25696 .32251 m .2651 .31418 L .32203 .3182 L p 0 .456 1 r
F P
0 g
s
.265 .54086 m .22711 .53889 L .22737 .52173 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .22711 .53889 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.17783 .7619 m .17732 .79108 L .17003 .79479 L p 0 .052 .589 r
F P
0 g
s
.24526 .60012 m .30202 .6028 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.31016 .64069 m .3106 .5972 L .30202 .6028 L p 0 .084 .626 r
F P
0 g
s
.30202 .6028 m .30155 .64587 L .31016 .64069 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .30202 .6028 L .24526 .60012 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .31016 .64069 L .25274 .63816 L p 0 .455 1 r
F P
0 g
s
.3106 .5972 m .31016 .64069 L .31893 .6354 L p 0 .084 .626 r
F P
0 g
s
.31016 .64069 m .31893 .6354 L .26099 .63283 L p 0 .455 1 r
F P
0 g
s
.30078 .71812 m .30941 .71362 L .31016 .64069 L p 0 .084 .626 r
F P
0 g
s
.30941 .71362 m .30078 .71812 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .31016 .64069 L .30941 .71362 L p 0 .084 .626 r
F P
0 g
s
.24466 .6434 m .30155 .64587 L .25658 .68917 L closepath p 0 .344 .78 r
F P
0 g
s
.25658 .68917 m .30155 .64587 L .24466 .6434 L closepath p 0 .344 .78 r
F P
0 g
s
.31016 .64069 m .30155 .64587 L .24466 .6434 L p 0 .455 1 r
F P
0 g
s
.31016 .64069 m .42338 .64567 L .43318 .64048 L p 0 .455 1 r
F P
0 g
s
.24466 .6434 m .25274 .63816 L .31016 .64069 L p 0 .455 1 r
F P
0 g
s
.43318 .64048 m .31893 .6354 L .31016 .64069 L p 0 .455 1 r
F P
0 g
s
.31893 .6354 m .31016 .64069 L .30941 .71362 L p 0 .084 .626 r
F P
0 g
s
.30941 .71362 m .31821 .70904 L .31893 .6354 L p 0 .084 .626 r
F P
0 g
s
.31821 .70904 m .30941 .71362 L .31016 .64069 L p 0 .084 .626 r
F P
0 g
s
.31016 .64069 m .31893 .6354 L .31821 .70904 L p 0 .084 .626 r
F P
0 g
s
.26099 .63283 m .25274 .63816 L .31016 .64069 L p 0 .455 1 r
F P
0 g
s
.31893 .6354 m .31016 .64069 L .25274 .63816 L p 0 .455 1 r
F P
0 g
s
.26099 .63283 m .31893 .6354 L .31893 .6354 L p 0 .344 .779 r
F P
0 g
s
.25274 .63816 m .26099 .63283 L .31893 .6354 L p 0 .455 1 r
F P
0 g
s
.18797 .59743 m .24526 .60012 L .24466 .6434 L p 0 .344 .78 r
F P
0 g
s
.24466 .6434 m .24526 .60012 L .18797 .59743 L p 0 .344 .78 r
F P
0 g
s
.24466 .6434 m .18723 .6409 L .18797 .59743 L p 0 .344 .78 r
F P
0 g
s
.18797 .59743 m .18723 .6409 L .24466 .6434 L p 0 .344 .78 r
F P
0 g
s
.20249 .63023 m .26099 .63283 L .26099 .63283 L p 0 .344 .779 r
F P
0 g
s
.21105 .73299 m .18723 .6409 L .24466 .6434 L p 0 .344 .78 r
F P
0 g
s
.24466 .6434 m .25658 .68917 L .21105 .73299 L p 0 .344 .78 r
F P
0 g
s
.24466 .6434 m .25274 .63816 L .19478 .63562 L p 0 .455 1 r
F P
0 g
s
.19478 .63562 m .18723 .6409 L .24466 .6434 L p 0 .455 1 r
F P
0 g
s
.25658 .68917 m .24466 .6434 L .18723 .6409 L p 0 .344 .78 r
F P
0 g
s
.25274 .63816 m .24466 .6434 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.18723 .6409 m .19478 .63562 L .25274 .63816 L p 0 .455 1 r
F P
0 g
s
.19478 .63562 m .25274 .63816 L .26099 .63283 L p 0 .455 1 r
F P
0 g
s
.26099 .63283 m .25274 .63816 L .19478 .63562 L p 0 .455 1 r
F P
0 g
s
.26099 .63283 m .20249 .63023 L .19478 .63562 L p 0 .455 1 r
F P
0 g
s
.19478 .63562 m .20249 .63023 L .26099 .63283 L p 0 .455 1 r
F P
0 g
s
.18723 .6409 m .21105 .73299 L .25658 .68917 L p 0 .344 .78 r
F P
0 g
s
.27317 .67949 m .22683 .72414 L .20249 .63023 L p 0 .344 .779 r
F P
0 g
s
.26099 .63283 m .27317 .67949 L p .20249 .63023 L 0 .344 .779 r
F P
0 g
s
.20249 .63023 m .26099 .63283 L .20249 .63023 L 0 .344 .779 r
F
.31893 .6354 m .27317 .67949 L .26099 .63283 L p F P
0 g
s
.26099 .63283 m .26099 .63283 L p .31893 .6354 L 0 .344 .779 r
F P
0 g
s
.24585 .55705 m .24526 .60012 L .30202 .6028 L p 0 .344 .78 r
F P
0 g
s
.59956 .70402 m .65366 .7624 L .54565 .79063 L p 0 .344 .779 r
F P
0 g
s
.1986 .40393 m .19832 .4211 L .19082 .4284 L p 0 .052 .589 r
F P
0 g
s
.19053 .44545 m .19082 .4284 L .19832 .4211 L p 0 .052 .589 r
F P
0 g
s
.21296 .46955 m .20175 .4575 L .20936 .45048 L p 0 .29 .961 r
F P
0 g
s
.20936 .45048 m .22068 .46265 L .21296 .46955 L p 0 .29 .961 r
F P
0 g
s
.32103 .42081 m .31233 .42812 L .31216 .44517 L p 0 .084 .626 r
F P
0 g
s
.42278 .79078 m .4131 .7945 L .3 .79093 L p 0 .443 1 r
F P
0 g
s
.27816 .27075 m .32272 .24762 L .32203 .3182 L closepath p 0 .344 .779 r
F P
0 g
s
.19053 .44545 m .19803 .43831 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.20175 .4575 m .19053 .44545 L .19803 .43831 L p 0 .29 .961 r
F P
0 g
s
.19803 .43831 m .20936 .45048 L .20175 .4575 L p 0 .29 .961 r
F P
0 g
s
.21252 .49805 m .22771 .49889 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.27372 .4944 m .23557 .49227 L .22771 .49889 L p 0 .458 1 r
F P
0 g
s
.20092 .50885 m .22754 .5103 L .22771 .49889 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .21252 .49805 L .20092 .50885 L p 0 .344 .78 r
F P
0 g
s
.21252 .49805 m .22771 .49889 L .23557 .49227 L p 0 .458 1 r
F P
0 g
s
.31105 .55392 m .25391 .551 L .24585 .55705 L p 0 .458 1 r
F P
0 g
s
.26478 .55801 m .27301 .55197 L .31105 .55392 L p 0 .458 1 r
F P
0 g
s
.27301 .55197 m .26478 .55801 L .22686 .55609 L p 0 .458 1 r
F P
0 g
s
.19832 .4211 m .19803 .43831 L .19053 .44545 L p 0 .052 .589 r
F P
0 g
s
.18928 .51969 m .20092 .50885 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .22737 .52173 L .18928 .51969 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .20092 .50885 L .21252 .49805 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .22754 .5103 L .20092 .50885 L p 0 .344 .78 r
F P
0 g
s
.31216 .44517 m .32086 .43802 L .32103 .42081 L p 0 .084 .626 r
F P
0 g
s
.32086 .43802 m .31216 .44517 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.27435 .4429 m .31216 .44517 L .32086 .43802 L p 0 .458 1 r
F P
0 g
s
.30655 .45111 m .32086 .43802 L .31216 .44517 L p 0 .05 .1 r
F P
0 g
s
.31216 .44517 m .30072 .45589 L .30655 .45111 L p 0 .05 .1 r
F P
0 g
s
.54565 .79063 m .54547 .71776 L .59956 .70402 L p 0 .344 .779 r
F P
0 g
s
.18797 .59743 m .18723 .6409 L .17983 .64608 L p 0 .052 .589 r
F P
0 g
s
.17983 .64608 m .18723 .6409 L .18526 .75783 L p 0 .052 .589 r
F P
0 g
s
.18526 .75783 m .17783 .7619 L .17983 .64608 L p 0 .052 .589 r
F P
0 g
s
.18928 .51969 m .22737 .52173 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.27344 .51739 m .23524 .51533 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.22711 .53889 m .22737 .52173 L .18928 .51969 L p 0 .344 .78 r
F P
0 g
s
.20092 .50885 m .18928 .51969 L .22737 .52173 L p 0 .344 .78 r
F P
0 g
s
.18928 .51969 m .22737 .52173 L .23524 .51533 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .23524 .51533 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.23524 .51533 m .22737 .52173 L .18928 .51969 L p 0 .458 1 r
F P
0 g
s
.23557 .49227 m .22024 .49142 L .21252 .49805 L p 0 .458 1 r
F P
0 g
s
.20092 .50885 m .21252 .49805 L .22024 .49142 L p 0 .05 .1 r
F P
0 g
s
.57989 .31457 m .7529 .3271 L .7571 .62926 L p .848 0 0 r
F P
0 g
s
.7529 .3271 m .80646 .63411 L .7571 .62926 L .891 0 0 r
F
0 g
.7529 .3271 m
.8015 .33452 L
s
.80646 .63411 m
.83031 .64205 L
s
.22711 .53889 m .18899 .53691 L .18928 .51969 L p 0 .344 .78 r
F P
0 g
s
.18928 .51969 m .18899 .53691 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.29228 .46415 m .30655 .45111 L .30072 .45589 L p 0 .05 .1 r
F P
0 g
s
.30072 .45589 m .28924 .46664 L .29228 .46415 L p 0 .05 .1 r
F P
0 g
s
.43318 .64048 m .54529 .64546 L .54547 .71776 L p 0 .344 .779 r
F P
0 g
s
.18928 .51969 m .20092 .50885 L .20854 .50232 L p 0 .05 .1 r
F P
0 g
s
.22024 .49142 m .20854 .50232 L .20092 .50885 L p 0 .05 .1 r
F P
0 g
s
.53138 .63764 m .46464 .62529 L .53541 .63668 L .538 0 0 r
F
0 g
.53088 .33992 m
.53138 .63603 L
s
.53138 .63764 m .4332 .63322 L .46464 .62529 L .538 0 0 r
F
0 g
.4332 .63322 m
.43429 .33315 L
s
.22686 .55609 m .23474 .55002 L .27301 .55197 L p 0 .458 1 r
F P
0 g
s
.28312 .40121 m .2448 .39877 L .23681 .40633 L p 0 .458 1 r
F P
0 g
s
.25582 .40753 m .26399 .39999 L .32119 .40363 L p 0 .458 1 r
F P
0 g
s
.28291 .41844 m .28312 .40121 L .32119 .40363 L p 0 .344 .779 r
F P
0 g
s
.1986 .40393 m .23681 .40633 L .2448 .39877 L p 0 .458 1 r
F P
0 g
s
.26399 .39999 m .25582 .40753 L .1986 .40393 L p 0 .458 1 r
F P
0 g
s
.2448 .39877 m .20624 .39632 L .1986 .40393 L p 0 .458 1 r
F P
0 g
s
.1986 .40393 m .20624 .39632 L .26399 .39999 L p 0 .458 1 r
F P
0 g
s
.2448 .39877 m .24456 .41606 L .20597 .41366 L p 0 .344 .779 r
F P
0 g
s
.24456 .41606 m .2448 .39877 L .28312 .40121 L p 0 .344 .779 r
F P
0 g
s
.27435 .4429 m .28271 .43571 L .32086 .43802 L p 0 .458 1 r
F P
0 g
s
.28271 .43571 m .27435 .4429 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.32086 .43802 m .28271 .43571 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .27435 .4429 L .28271 .43571 L p 0 .458 1 r
F P
0 g
s
.29228 .46415 m .28924 .46664 L .27407 .46575 L p 0 .458 1 r
F P
0 g
s
.27816 .27075 m .32203 .3182 L .2651 .31418 L closepath p 0 .344 .779 r
F P
0 g
s
.32203 .3182 m .32161 .36081 L .26455 .35699 L p 0 .344 .779 r
F P
0 g
s
.26455 .35699 m .2651 .31418 L .32203 .3182 L p 0 .344 .779 r
F P
0 g
s
.19651 .53063 m .18899 .53691 L .18928 .51969 L p 0 .052 .589 r
F P
0 g
s
.23524 .51533 m .1968 .51325 L .18928 .51969 L p 0 .458 1 r
F P
0 g
s
.18928 .51969 m .1968 .51325 L .23524 .51533 L p 0 .458 1 r
F P
0 g
s
.18928 .51969 m .1968 .51325 L .19651 .53063 L p 0 .052 .589 r
F P
0 g
s
.20854 .50232 m .1968 .51325 L .18928 .51969 L p 0 .05 .1 r
F P
0 g
s
.31995 .53038 m .32012 .51299 L .3114 .51944 L p 0 .084 .626 r
F P
0 g
s
.3114 .51944 m .31122 .53666 L .31995 .53038 L p 0 .084 .626 r
F P
0 g
s
.30016 .50735 m .3114 .51944 L .32012 .51299 L p 0 .292 .96 r
F P
0 g
s
.27344 .51739 m .3114 .51944 L .32012 .51299 L p 0 .458 1 r
F P
0 g
s
.3114 .51944 m .27344 .51739 L .28182 .5109 L p 0 .458 1 r
F P
0 g
s
.28182 .5109 m .32012 .51299 L .3114 .51944 L p 0 .458 1 r
F P
0 g
s
.53541 .63668 m .51911 .62077 L .5421 .63614 L .538 0 0 r
F
.53541 .63668 m .46464 .62529 L .51911 .62077 L F
0 g
.53138 .63764 m
.53541 .63668 L
s
.27407 .46575 m .27706 .46326 L .29228 .46415 L p 0 .458 1 r
F P
0 g
s
.23885 .46103 m .27706 .46326 L .27407 .46575 L p 0 .458 1 r
F P
0 g
s
.27407 .46575 m .23598 .46354 L .23885 .46103 L p 0 .458 1 r
F P
0 g
s
.32012 .51299 m .306 .5029 L .30016 .50735 L p 0 .292 .96 r
F P
0 g
s
.28891 .49525 m .30016 .50735 L .306 .5029 L p 0 .292 .96 r
F P
0 g
s
.23418 .22319 m .27816 .27075 L .2651 .31418 L p 0 .344 .779 r
F P
0 g
s
.19623 .54805 m .1887 .55416 L .18899 .53691 L p 0 .052 .589 r
F P
0 g
s
.18899 .53691 m .19651 .53063 L .19623 .54805 L p 0 .052 .589 r
F P
0 g
s
.306 .5029 m .29196 .49286 L .28891 .49525 L p 0 .292 .96 r
F P
0 g
s
.27672 .49201 m .27372 .4944 L .28891 .49525 L p 0 .458 1 r
F P
0 g
s
.28891 .49525 m .29196 .49286 L .27672 .49201 L p 0 .458 1 r
F P
0 g
s
.30078 .71812 m .30941 .71362 L .30866 .78714 L p 0 .084 .626 r
F P
0 g
s
.31821 .70904 m .30941 .71362 L .30866 .78714 L p 0 .084 .626 r
F P
0 g
s
.30866 .78714 m .31748 .78327 L .31821 .70904 L p 0 .084 .626 r
F P
0 g
s
.31748 .78327 m .30866 .78714 L .30941 .71362 L p 0 .084 .626 r
F P
0 g
s
.19235 .78342 m .20009 .77948 L .31748 .78327 L p 0 .443 1 r
F P
0 g
s
.31748 .78327 m .30866 .78714 L .19235 .78342 L p 0 .443 1 r
F P
0 g
s
.23418 .22319 m .20946 .19645 L .20991 .16825 L p 0 .344 .779 r
F P
0 g
s
.31978 .5478 m .31995 .53038 L .31122 .53666 L p 0 .084 .626 r
F P
0 g
s
.31122 .53666 m .31105 .55392 L .31978 .5478 L p 0 .084 .626 r
F P
0 g
s
.54965 .63617 m .58124 .62106 L .7571 .62926 L p .538 0 0 r
F P
0 g
s
.5421 .63614 m .58124 .62106 L .54965 .63617 L .538 0 0 r
F
0 g
.54925 .48571 m
.54964 .63323 L
s
.1986 .40393 m .19931 .36113 L .20694 .35312 L p 0 .052 .589 r
F P
0 g
s
.5421 .63614 m .51911 .62077 L .58124 .62106 L .538 0 0 r
F
0 g
.53541 .63668 m
.5421 .63614 L
s
.5421 .63614 m
.54965 .63617 L
s
.4332 .63322 m
.53138 .63764 L
s
.43291 .71344 m .54547 .71776 L .54565 .79063 L p 0 .344 .779 r
F P
0 g
s
.54547 .71776 m .43291 .71344 L .43318 .64048 L p 0 .344 .779 r
F P
0 g
s
.19551 .59173 m .18797 .59743 L .1887 .55416 L p 0 .052 .589 r
F P
0 g
s
.32161 .36081 m .32119 .40363 L .26399 .39999 L p 0 .344 .779 r
F P
0 g
s
.26399 .39999 m .26455 .35699 L .32161 .36081 L p 0 .344 .779 r
F P
0 g
s
.20946 .19645 m .23418 .22319 L .20763 .31012 L closepath p 0 .344 .779 r
F P
0 g
s
.2651 .31418 m .20763 .31012 L .23418 .22319 L p 0 .344 .779 r
F P
0 g
s
.23557 .49227 m .27372 .4944 L .27672 .49201 L p 0 .458 1 r
F P
0 g
s
.25391 .551 m .31105 .55392 L .31978 .5478 L p 0 .458 1 r
F P
0 g
s
.31978 .5478 m .31105 .55392 L .27301 .55197 L p 0 .458 1 r
F P
0 g
s
.31936 .5915 m .31978 .5478 L .31105 .55392 L p 0 .084 .626 r
F P
0 g
s
.31105 .55392 m .3106 .5972 L .31936 .5915 L p 0 .084 .626 r
F P
0 g
s
.23631 .44061 m .24432 .43338 L .28271 .43571 L p 0 .458 1 r
F P
0 g
s
.24432 .43338 m .23631 .44061 L .19803 .43831 L p 0 .458 1 r
F P
0 g
s
.28271 .43571 m .24432 .43338 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.20569 .43103 m .19803 .43831 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .24432 .43338 L .20569 .43103 L p 0 .458 1 r
F P
0 g
s
.29228 .46415 m .27706 .46326 L .27988 .44952 L p 0 .388 .894 r
F P
0 g
s
.27988 .44952 m .30655 .45111 L .29228 .46415 L p 0 .388 .894 r
F P
0 g
s
.18476 .78729 m .17732 .79108 L .17783 .7619 L p 0 .052 .589 r
F P
0 g
s
.17783 .7619 m .18526 .75783 L .18476 .78729 L p 0 .052 .589 r
F P
0 g
s
.32012 .51299 m .28182 .5109 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.23524 .51533 m .27344 .51739 L .28182 .5109 L p 0 .458 1 r
F P
0 g
s
.27344 .51739 m .23524 .51533 L .24327 .5088 L p 0 .458 1 r
F P
0 g
s
.24327 .5088 m .28182 .5109 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.19832 .4211 m .1986 .40393 L .20624 .39632 L p 0 .052 .589 r
F P
0 g
s
.2235 .46013 m .23885 .46103 L .23598 .46354 L p 0 .458 1 r
F P
0 g
s
.23598 .46354 m .22068 .46265 L .2235 .46013 L p 0 .458 1 r
F P
0 g
s
.20694 .35312 m .20624 .39632 L .1986 .40393 L p 0 .052 .589 r
F P
0 g
s
.27706 .46326 m .23885 .46103 L .24158 .44724 L p 0 .388 .894 r
F P
0 g
s
.24158 .44724 m .27988 .44952 L .27706 .46326 L p 0 .388 .894 r
F P
0 g
s
.19478 .63562 m .18723 .6409 L .18797 .59743 L p 0 .052 .589 r
F P
0 g
s
.18797 .59743 m .19551 .59173 L .19478 .63562 L p 0 .052 .589 r
F P
0 g
s
.2651 .31418 m .26455 .35699 L .20694 .35312 L p 0 .344 .779 r
F P
0 g
s
.20694 .35312 m .20763 .31012 L .2651 .31418 L p 0 .344 .779 r
F P
0 g
s
.32086 .43802 m .30655 .45111 L .27988 .44952 L p 0 .388 .894 r
F P
0 g
s
.27672 .49201 m .29196 .49286 L .306 .5029 L p 0 .265 .577 r
F P
0 g
s
.31893 .6354 m .31936 .5915 L .3106 .5972 L p 0 .084 .626 r
F P
0 g
s
.20624 .39632 m .20597 .41366 L .19832 .4211 L p 0 .052 .589 r
F P
0 g
s
.19803 .43831 m .19832 .4211 L .20597 .41366 L p 0 .052 .589 r
F P
0 g
s
.46522 .32104 m .51911 .62077 L .46464 .62529 L .726 0 0 r
F
.46522 .32104 m .51879 .31414 L .51911 .62077 L F
0 g
.43429 .33315 m
.46522 .32104 L
s
.3 .79093 m .30866 .78714 L .42278 .79078 L p 0 .443 1 r
F P
0 g
s
.2235 .46013 m .22068 .46265 L .20936 .45048 L p 0 .29 .961 r
F P
0 g
s
.32103 .42081 m .32086 .43802 L .28271 .43571 L p 0 .344 .779 r
F P
0 g
s
.28271 .43571 m .28291 .41844 L .32103 .42081 L p 0 .344 .779 r
F P
0 g
s
.43265 .78698 m .42278 .79078 L .30866 .78714 L p 0 .443 1 r
F P
0 g
s
.19803 .43831 m .20569 .43103 L .24432 .43338 L p 0 .458 1 r
F P
0 g
s
.20569 .43103 m .21462 .44563 L .20936 .45048 L p 0 .29 .961 r
F P
0 g
s
.20936 .45048 m .19803 .43831 L .20569 .43103 L p 0 .29 .961 r
F P
0 g
s
.20936 .45048 m .21462 .44563 L .2235 .46013 L p 0 .29 .961 r
F P
0 g
s
.27672 .49201 m .23844 .48986 L .23557 .49227 L p 0 .458 1 r
F P
0 g
s
.22024 .49142 m .23557 .49227 L .23844 .48986 L p 0 .458 1 r
F P
0 g
s
.31978 .5478 m .26212 .54482 L .25391 .551 L p 0 .458 1 r
F P
0 g
s
.27301 .55197 m .2814 .54582 L .31978 .5478 L p 0 .458 1 r
F P
0 g
s
.19623 .54805 m .25391 .551 L .26212 .54482 L p 0 .458 1 r
F P
0 g
s
.2814 .54582 m .27301 .55197 L .23474 .55002 L p 0 .458 1 r
F P
0 g
s
.20597 .41366 m .20569 .43103 L .19803 .43831 L p 0 .052 .589 r
F P
0 g
s
.54565 .79063 m .43265 .78698 L .43291 .71344 L p 0 .344 .779 r
F P
0 g
s
.306 .5029 m .27926 .50142 L .27672 .49201 L p 0 .265 .577 r
F P
0 g
s
.23844 .48986 m .27672 .49201 L .27926 .50142 L p 0 .265 .577 r
F P
0 g
s
.27988 .44952 m .28271 .43571 L .32086 .43802 L p 0 .388 .894 r
F P
0 g
s
.21105 .73299 m .18526 .75783 L .18723 .6409 L closepath p 0 .344 .78 r
F P
0 g
s
.18723 .6409 m .18526 .75783 L .21105 .73299 L closepath p 0 .344 .78 r
F P
0 g
s
.19284 .75367 m .18526 .75783 L .18723 .6409 L p 0 .052 .589 r
F P
0 g
s
.18723 .6409 m .19478 .63562 L .19284 .75367 L p 0 .052 .589 r
F P
0 g
s
.26455 .35699 m .26399 .39999 L .20624 .39632 L p 0 .344 .779 r
F P
0 g
s
.20624 .39632 m .20694 .35312 L .26455 .35699 L p 0 .344 .779 r
F P
0 g
s
.21381 .4978 m .20854 .50232 L .22024 .49142 L p 0 .05 .1 r
F P
0 g
s
.23844 .48986 m .22306 .489 L .22024 .49142 L p 0 .458 1 r
F P
0 g
s
.22024 .49142 m .22306 .489 L .21381 .4978 L p 0 .05 .1 r
F P
0 g
s
.28182 .5109 m .24327 .5088 L .23524 .51533 L p 0 .458 1 r
F P
0 g
s
.1968 .51325 m .23524 .51533 L .24327 .5088 L p 0 .458 1 r
F P
0 g
s
.24327 .5088 m .23524 .51533 L .1968 .51325 L p 0 .458 1 r
F P
0 g
s
.28271 .43571 m .27988 .44952 L .24158 .44724 L p 0 .388 .894 r
F P
0 g
s
.4332 .63322 m
.46464 .62529 L
s
.31893 .6354 m .43318 .64048 L .43291 .71344 L p 0 .344 .779 r
F P
0 g
s
.28312 .40121 m .28291 .41844 L .24456 .41606 L p 0 .344 .779 r
F P
0 g
s
.24158 .44724 m .23885 .46103 L .2235 .46013 L p 0 .388 .894 r
F P
0 g
s
.28182 .5109 m .27926 .50142 L .306 .5029 L p 0 .265 .577 r
F P
0 g
s
.306 .5029 m .32012 .51299 L .28182 .5109 L p 0 .265 .577 r
F P
0 g
s
.1968 .51325 m .20854 .50232 L .21381 .4978 L p 0 .05 .1 r
F P
0 g
s
.28291 .41844 m .28271 .43571 L .24432 .43338 L p 0 .344 .779 r
F P
0 g
s
.24432 .43338 m .24456 .41606 L .28291 .41844 L p 0 .344 .779 r
F P
0 g
s
.26212 .54482 m .20391 .54181 L .19623 .54805 L p 0 .458 1 r
F P
0 g
s
.23474 .55002 m .24278 .54382 L .2814 .54582 L p 0 .458 1 r
F P
0 g
s
.24278 .54382 m .23474 .55002 L .19623 .54805 L p 0 .458 1 r
F P
0 g
s
.19623 .54805 m .20391 .54181 L .24278 .54382 L p 0 .458 1 r
F P
0 g
s
.19623 .54805 m .20391 .54181 L .2032 .58592 L p 0 .052 .589 r
F P
0 g
s
.2235 .46013 m .21462 .44563 L .24158 .44724 L p 0 .388 .894 r
F P
0 g
s
.27926 .50142 m .24084 .49929 L .23844 .48986 L p 0 .265 .577 r
F P
0 g
s
.23844 .48986 m .24084 .49929 L .21381 .4978 L p 0 .265 .577 r
F P
0 g
s
.21381 .4978 m .22306 .489 L .23844 .48986 L p 0 .265 .577 r
F P
0 g
s
.24158 .44724 m .24432 .43338 L .28271 .43571 L p 0 .388 .894 r
F P
0 g
s
.24327 .5088 m .24084 .49929 L .27926 .50142 L p 0 .265 .577 r
F P
0 g
s
.27926 .50142 m .28182 .5109 L .24327 .5088 L p 0 .265 .577 r
F P
0 g
s
.20419 .52423 m .19651 .53063 L .1968 .51325 L p 0 .052 .589 r
F P
0 g
s
.24327 .5088 m .20447 .50669 L .1968 .51325 L p 0 .458 1 r
F P
0 g
s
.1968 .51325 m .20447 .50669 L .24327 .5088 L p 0 .458 1 r
F P
0 g
s
.1968 .51325 m .20447 .50669 L .20419 .52423 L p 0 .052 .589 r
F P
0 g
s
.21381 .4978 m .20447 .50669 L .1968 .51325 L p 0 .05 .1 r
F P
0 g
s
.24432 .43338 m .24158 .44724 L .21462 .44563 L p 0 .388 .894 r
F P
0 g
s
.28182 .5109 m .32012 .51299 L .31995 .53038 L p 0 .344 .779 r
F P
0 g
s
.20597 .41366 m .20624 .39632 L .2448 .39877 L p 0 .344 .779 r
F P
0 g
s
.20391 .54181 m .19623 .54805 L .19651 .53063 L p 0 .052 .589 r
F P
0 g
s
.19651 .53063 m .20419 .52423 L .20391 .54181 L p 0 .052 .589 r
F P
0 g
s
.30941 .71362 m .31821 .70904 L .31748 .78327 L p 0 .084 .626 r
F P
0 g
s
.28161 .52834 m .31995 .53038 L .31978 .5478 L p 0 .344 .779 r
F P
0 g
s
.31995 .53038 m .28161 .52834 L .28182 .5109 L p 0 .344 .779 r
F P
0 g
s
.31821 .70904 m .43291 .71344 L .43265 .78698 L p 0 .344 .779 r
F P
0 g
s
.43291 .71344 m .31821 .70904 L .31893 .6354 L p 0 .344 .779 r
F P
0 g
s
.24456 .41606 m .24432 .43338 L .20569 .43103 L p 0 .344 .779 r
F P
0 g
s
.20569 .43103 m .20597 .41366 L .24456 .41606 L p 0 .344 .779 r
F P
0 g
s
.2032 .58592 m .19551 .59173 L .19623 .54805 L p 0 .052 .589 r
F P
0 g
s
.21462 .44563 m .20569 .43103 L .24432 .43338 L p 0 .388 .894 r
F P
0 g
s
.31978 .5478 m .2814 .54582 L .28161 .52834 L p 0 .344 .779 r
F P
0 g
s
.26212 .54482 m .31978 .5478 L .31936 .5915 L p 0 .344 .779 r
F P
0 g
s
.7571 .62926 m .58124 .62106 L .57989 .31457 L p .848 0 0 r
F P
0 g
s
.7571 .62926 m
.80646 .63411 L
s
.7529 .3271 m
.7571 .62926 L
s
.72124 .64393 m
.7571 .62926 L
s
.51879 .31414 m .57989 .31457 L .58124 .62106 L .811 0 0 r
F
.24084 .49929 m .24327 .5088 L .20447 .50669 L p 0 .265 .577 r
F P
0 g
s
.20447 .50669 m .21381 .4978 L .24084 .49929 L p 0 .265 .577 r
F P
0 g
s
.18526 .75783 m .19284 .75367 L .19235 .78342 L p 0 .052 .589 r
F P
0 g
s
.19235 .78342 m .18476 .78729 L .18526 .75783 L p 0 .052 .589 r
F P
0 g
s
.51879 .31414 m .58124 .62106 L .51911 .62077 L .811 0 0 r
F
0 g
.46522 .32104 m
.51879 .31414 L
s
.54965 .63617 m
.58124 .62106 L
s
.57989 .31457 m
.58124 .62106 L
s
.51879 .31414 m
.57989 .31457 L
s
.24327 .5088 m .28182 .5109 L .28161 .52834 L p 0 .344 .779 r
F P
0 g
s
.20249 .63023 m .19478 .63562 L .19551 .59173 L p 0 .052 .589 r
F P
0 g
s
.19551 .59173 m .2032 .58592 L .20249 .63023 L p 0 .052 .589 r
F P
0 g
s
.24302 .5263 m .28161 .52834 L .2814 .54582 L p 0 .344 .779 r
F P
0 g
s
.28161 .52834 m .24302 .5263 L .24327 .5088 L p 0 .344 .779 r
F P
0 g
s
.18476 .78729 m .19235 .78342 L .30866 .78714 L p 0 .443 1 r
F P
0 g
s
.26155 .58872 m .31936 .5915 L .31893 .6354 L p 0 .344 .779 r
F P
0 g
s
.31936 .5915 m .26155 .58872 L .26212 .54482 L p 0 .344 .779 r
F P
0 g
s
.30866 .78714 m .31748 .78327 L .43265 .78698 L p 0 .443 1 r
F P
0 g
s
.43265 .78698 m .31748 .78327 L .31821 .70904 L p 0 .344 .779 r
F P
0 g
s
.2814 .54582 m .24278 .54382 L .24302 .5263 L p 0 .344 .779 r
F P
0 g
s
.20057 .74944 m .19284 .75367 L .19478 .63562 L p 0 .052 .589 r
F P
0 g
s
.19478 .63562 m .20249 .63023 L .20057 .74944 L p 0 .052 .589 r
F P
0 g
s
.20447 .50669 m .24327 .5088 L .24302 .5263 L p 0 .344 .779 r
F P
0 g
s
.31893 .6354 m .31821 .70904 L .27317 .67949 L closepath p 0 .344 .779 r
F P
0 g
s
.20391 .54181 m .26212 .54482 L .26155 .58872 L p 0 .344 .779 r
F P
0 g
s
.31893 .6354 m .26099 .63283 L .26155 .58872 L p 0 .344 .779 r
F P
0 g
s
.20419 .52423 m .24302 .5263 L .24278 .54382 L p 0 .344 .779 r
F P
0 g
s
.24302 .5263 m .20419 .52423 L .20447 .50669 L p 0 .344 .779 r
F P
0 g
s
.24278 .54382 m .20391 .54181 L .20419 .52423 L p 0 .344 .779 r
F P
0 g
s
.2032 .58592 m .26155 .58872 L .26099 .63283 L p 0 .344 .779 r
F P
0 g
s
.26155 .58872 m .2032 .58592 L .20391 .54181 L p 0 .344 .779 r
F P
0 g
s
.22683 .72414 m .27317 .67949 L .31821 .70904 L p 0 .344 .779 r
F P
0 g
s
.31821 .70904 m .31748 .78327 L .22683 .72414 L p 0 .344 .779 r
F P
0 g
s
.46464 .62529 m
.51911 .62077 L
s
.26099 .63283 m .20249 .63023 L .2032 .58592 L p 0 .344 .779 r
F P
0 g
s
.19235 .78342 m .19284 .75367 L .20057 .74944 L p 0 .052 .589 r
F P
0 g
s
.20057 .74944 m .20009 .77948 L .19235 .78342 L p 0 .052 .589 r
F P
0 g
s
.20057 .74944 m .22683 .72414 L .31748 .78327 L p 0 .344 .779 r
F P
0 g
s
.31748 .78327 m .20009 .77948 L .20057 .74944 L p 0 .344 .779 r
F P
0 g
s
.20249 .63023 m .22683 .72414 L .20057 .74944 L closepath p 0 .344 .779 r
F P
0 g
s
.51911 .62077 m
.58124 .62106 L
s
[ .01 .01 ] 0 setdash
.2211 .11645 m
.87617 .17312 L
s
.87617 .17312 m
.88929 .80284 L
s
.88929 .80284 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.14199 .22149 m
.13013 .8214 L
s
.13013 .8214 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.2211 .11645 m
.14199 .22149 L
s
.003 w
[ ] 0 setdash
.87617 .17312 m
.88929 .80284 L
s
.25 Mabswid
.87676 .20145 m
.87054 .20093 L
s
gsave
.88922 .2025 -61 -10.8695 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87967 .34094 m
.87344 .34049 L
s
gsave
.89214 .34183 -61 -10.9597 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.88262 .48259 m
.87638 .48221 L
s
gsave
.8951 .48333 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88562 .62646 m
.87937 .62616 L
s
gsave
.8981 .62705 -61 -11.1446 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88866 .7726 m
.88241 .77238 L
s
gsave
.90115 .77303 -61 -11.2392 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87734 .22918 m
.8736 .22887 L
s
.87792 .25699 m
.87418 .25669 L
s
.8785 .28489 m
.87476 .2846 L
s
.87908 .31287 m
.87535 .31259 L
s
.88026 .36909 m
.87652 .36883 L
s
.88084 .39733 m
.8771 .39708 L
s
.88143 .42566 m
.87769 .42542 L
s
.88203 .45408 m
.87828 .45385 L
s
.88322 .51118 m
.87947 .51097 L
s
.88381 .53987 m
.88007 .53966 L
s
.88441 .56864 m
.88067 .56844 L
s
.88501 .5975 m
.88127 .59732 L
s
.88622 .6555 m
.88248 .65533 L
s
.88683 .68464 m
.88308 .68448 L
s
.88744 .71387 m
.88369 .71372 L
s
.88805 .74319 m
.8843 .74305 L
s
.87619 .17381 m
.87245 .17349 L
s
.88928 .80211 m
.88553 .80198 L
s
gsave
.95749 .48707 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{374, 374},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005f0001MQ000`40O003h00OogooMgoo003oOomg
Ool00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00
ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003oOomg
Ool00<]oo`<00:Qoo`00c7oo00<007ooOol0Ygoo003<Ool00`00Oomoo`2WOol00<aoo`03001oogoo
0:Moo`00bgoo00<007oo0000Z7oo003;Ool00`00Ool0002XOol00<]oo`04001oogoo002WOol00<Yo
o`03001oogoo009oo`03001oogoo0:Aoo`00bGoo0`000Woo0`00YGoo003oOomgOol00?moogMoo`00
ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo001/Ool3003oOol8Ool006]oo`05001oogooOol0
003oOol7Ool006]oo`05001oogooOol0003oOol7Ool006]oo`05001oogooOol0003oOol7Ool006]o
o`05001oogooOol0003oOol7Ool006]oo`05001oogooOol0000^Ool30004Ool3003>Ool006]oo`05
001oogooOol0000aOol01000Oomoo`000goo00<007ooOol0bgoo001[Ool01@00Oomoogoo0000<Woo
00<007oo00000goo00<007ooOol0bgoo001/Ool3000cOol00`00Ool00003Ool00`00Oomoo`3;Ool0
0:9oo`03001oo`0000=oo`03001oogoo02Ioo`<000=oo`<000=oo`<009Ioo`00XGoo00@007ooOol0
00=oo`03001oogoo02Moo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`2COol009mo
o`8000=oo`05001oogooOol0000YOol01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol0
Tgoo001BOol70016Ool00`00Oomoo`02Ool01@00Oomoogoo0000:Goo00D007ooOomoo`0000=oo`03
001oo`0000=oo`03001oogoo09=oo`00DGoo0P001Goo3000?7oo0`000Woo0`00:Woo00D007ooOomo
o`0000=oo`03001oo`0000=oo`03001oogoo09=oo`00DGoo0P001Goo00<007ooOol027oo3@00HWoo
00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo025oo`<0009oo`<000Aoo`<006=oo`00
D7oo00<007ooOol047oo00<007ooOol027oo00<007oo00002`00EWoo00D007ooOomoo`0000=oo`03
001oo`0000=oo`03001oogoo029oo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`1POol0
06ioo`03001oogoo00Qoo`03001oo`0000`004Uoo`8000=oo`07001oogooOol007oo00000goo00<0
07ooOol08Woo00<007ooOol01Goo00<007oo00000goo00<007ooOol0H7oo001BOol00`00Oomoo`0I
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0;0010Ool00`00Oomoo`02Ool30003Ool3
000UOol00`00Oomoo`05Ool00`00Ool00003Ool00`00Oomoo`1POol004eoo`03001oogoo009oo`03
001oogoo02moo`03001oogoo00Qoo`03001oogoo00`006Moo`03001oogoo00Eoo`03001oo`0000=o
o`03001oogoo01moo`D0009oo`<000=oo`<0035oo`00C7oo00<007ooOol00goo00<007ooOol0>Woo
00<007ooOol01goo00<007ooOol00Woo3000Fgoo00<007ooOol017oo00@007ooOol000=oo`03001o
ogoo021oo`06001oogoo001oo`000goo00<007oo00000goo00<007ooOol0;Woo001<Ool00`00Oomo
o`03Ool00`00Oomoo`14Ool00`00Oomoo`08Ool00`00Oomoo`03Ool;001@Ool00`00Oomoo`02Ool2
0003Ool01@00Oomoogoo00008goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo02io
o`00Bgoo00<007ooOol017oo00<007ooOol0Cgoo00<007ooOol027oo00<007ooOol00goo3000@goo
0P0017oo00<007ooOol00Woo00D007ooOomoo`0002Aoo`04001oogoo0003Ool00`00Ool00003Ool0
0`00Oomoo`0^Ool00;Uoo`03001oogoo00Eoo`/003Uoo`03001oogoo00=oo`<0009oo`<002Ioo`03
001oo`0000=oo`03001oo`0000=oo`03001oogoo02ioo`00a7oo00<007ooOol017oo3@00HGoo00<0
07oo00000goo00<007oo00000goo00<007ooOol0;Woo0019Ool00`00Oomoo`22Ool00`00Oomoo`07
Ool<001EOol00`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0^Ool004Qoo`03001oogoo00Mo
o`03001oogoo08Aoo`03001oogoo00Eoo`l004Eoo`07001oogooOol007oo00000goo00<007oo0000
0goo00<007ooOol0;Woo0018Ool00`00Oomoo`07Ool00`00Oomoo`24Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Ool0000;000kOol30003Ool30003Ool3000aOol004Moo`03001oogoo00Qoo`03
001oogoo09Qoo`03001oogoo00Qoo`03001oogoo00`006moo`00DWoo00<007ooOol0Xgoo00<007oo
Ool01goo00@007ooOomoo``006Aoo`00DWoo00<007ooOol0[Goo00<007ooOol01goo00<007ooOol0
0goo3000F7oo0014Ool00`00Oomoo`35Ool00`00Oomoo`07Ool00`00Oomoo`04Ool<001=Ool004=o
o`03001oogoo00Qoo`H00<aoo`03001oogoo00Ioo``0045oo`00@goo00<007ooOol01goo0P000`5h
00<0005h00002@00c7oo00<007ooOol01Woo3P00=Goo0012Ool00`00Oomoo`07Ool00`0003800003
0GP00`000GP1N0090GP;003;Ool00`00Oomoo`07Ool00`00Ool00006000_Ool004aoo`030000<P00
00<1N0030001N05h01@1N0X00<]oo`03001oogoo00=oo`<002moo`00Bgoo00@0000b038000<1N003
0001N05h01h1N0`00;moo`03001oogoo00Eoo`03001oogoo02eoo`00@7oo00<007ooOol01goo0P00
0P0b00D0005h0GP1N00002<1N0<000H1N0h00;Uoo`03001oogoo02eoo`00?goo00<007ooOol01goo
00<0000b00000P0b00<0005h0GP08`5h0P000P5h00<0005h0GP04P5h3P00YWoo00<007ooOol00Woo
00<007ooOol0;Goo000oOol00`00Oomoo`06Ool010000380<P000P0b00<0005h0GP08@5h0P00105h
00<0005h0GP0805h3000V7oo0P001Goo00<007ooOol0;Goo000nOol00`00Oomoo`06Ool200020380
10000380<P008@5h0P001P5h00<0005h0GP09`5h00<0005h0GP00P5h2P00SGoo00<007ooOol01Goo
00<007ooOol0;Goo0016Ool00`0003800002038010000380<P000`5h00<0005h0GP06@5h0P00205h
00<0005h0GP09`5h00<0005h0GP0305h2P00Rgoo00<007ooOol0;Goo0016Ool00`00038000020380
10000380<P000`5h00<0005h0GP05`5h0P002P5h00<0005h0GP09`5h00<0005h0GP05P5h2P00MWoo
00<007ooOol027oo00<007ooOol0;Goo000lOol00`00Oomoo`06Ool010000380<P000P0b00@0000b
03800081N0030001N05h01H1N08000`1N0030001N05h02L1N0030001N05h0201N0`006Qoo`8000]o
o`03001oogoo02eoo`00>goo00<007ooOol01Woo0P000P0b00D0000b0380000b00<000030GP0005h
01D1N08000h1N0030001N05h02L1N0030001N05h02D1N0030001N00000800081N0`005]oo`03001o
ogoo00Uoo`<000moo`<000=oo`<000=oo`<0015oo`00>Woo00<007ooOol01goo0P000P0b00<0000b
03800P0000<0<P000GP00P00505h0P00405h00<0005h0GP09`5h00<0005h0GP09@5h00<0005h0GP0
0P5h0`002`5h3@00G7oo0P003goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo00io
o`00>Goo00<007ooOol01goo00<0000b00000P0b00@0000b03800080<P040001N05h000B0GP2000B
0GP00`000GP1N00W0GP00`000GP1N00U0GP00`000GP1N0050GP2000F0GP<000oOol00`00Oomoo`0>
Ool00`00Oomoo`0>Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol03Woo0013Ool0
0`000380000203801000038000000P0b00D0005h0GP1N00000l1N08001@1N0030001N05h02L1N003
0001N05h02D1N0030001N05h00L1N0<001l1N0d0031oo`80015oo`03001oogoo00Eoo`L0009oo`05
001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0>Ool004=oo`030000<P000080<P800005
0380000b038000020GP2000=0GP2000F0GP00`000GP1N00W0GP00`000GP1N00U0GP00`000GP1N00:
0GP3000Q0GP00`000GP1N0050GP7000XOol00`00Oomoo`0AOol00`00Oomoo`0>Ool01@00Oomoogoo
00000goo00<007oo00000goo00<007ooOol03Woo000gOol00`00Oomoo`09Ool00`00038000020382
00001@0b0000<P0b00000P5h00<0005h00002P5h0P00605h00<0005h0GP09`5h00<0005h0GP09@5h
00<0005h0GP03@5h0`007@5h00<0005h0GP0305h00<007ooOol0>Woo0P003goo00D007ooOomoo`00
00=oo`03001oo`0000=oo`03001oogoo00ioo`00=Woo00<007ooOol02Woo00<0000b00000P0b00@0
000b03800080<P040001N05h00020GP00`000GP1N0050GP2000J0GP00`000GP1N00W0GP00`000GP1
N00U0GP00`000GP1N00@0GP3000I0GP00`000GP1N00=0GP00`00Oomoo`0SOol00`00Oomoo`0DOol2
000?Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol03Woo000fOol00`00Oomoo`0:
Ool010000380000b0P000P0b00@0000b03800081N0050001N05h0GP000040GP2000L0GP00`000GP1
N00W0GP00`000GP1N00U0GP00`000GP1N00C0GP3000E0GP00`000GP1N00>0GP00`00Oomoo`0QOol2
000GOol2000>Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00ioo`00=7oo0P000Woo
0P002Goo00H0000b0000000b0002038010000380<P000P5h00<0005h0GP00P5h00@0005h000001h1
N0030001N05h02L1N0030001N05h02D1N0030001N05h01H1N0<00141N0030001N05h00l1N003001o
ogoo021oo`03001oogoo01Moo`8000moo`03001oogoo009oo`<000=oo`<0015oo`00=7oo00<007oo
Ool00goo0P000goo1@0000D0<P000380<P000080<P040000<P0b00080GP00`000GP1N00N0GP00`00
0GP1N00W0GP00`000GP1N00U0GP00`000GP1N00I0GP2000>0GP00`000GP1N00@0GP00`00Oomoo`0j
Ool2000^Ool003Aoo`03001oogoo00aoo`<00080<P040000<P0b000203800`000GP1N0060GP2000O
0GP00`000GP1N00W0GP00`000GP1N00U0GP00`000GP1N00K0GP3000:0GP00`000GP1N00A0GP00`00
Oomoo`0jOol00`00Oomoo`0]Ool003Aoo`03001oogoo00aoo`<00080<P040000<P0b000203800`00
0GP1N0050GP010000GP1N0007P5h00<0005h0GP09`5h00<0005h0GP09@5h00<0005h0GP07P5h0`00
1P5h00<0005h0GP04P5h00<007ooOol07Goo00<007ooOol06Goo0`00;Woo000dOol00`00Oomoo`0<
Ool00`0003800002038010000380<P000P0b00@0005h0GP000@1N0050001N05h0GP0000M0GP00`00
0GP1N00W0GP00`000GP1N00V0GP00`000GP1N00P0GP300020GP00`000GP1N00C0GP00`00Oomoo`0K
Ool2000MOol2000^Ool004=oo`030000<P000080<P040000<P0b0002038010000GP1N000105h00<0
005h0GP00P5h00<0005h0GP06P5h00<0005h0GP09`5h00<0005h0GP09P5h00<0005h0GP08`5h0P00
5P5h00<007ooOol06Woo00<007ooOol07Goo0P00;Woo0013Ool00`0003800002038010000380<P00
0P0b00@0005h0GP000<1N0030001N05h00@1N0030001N05h01T1N0030001N05h02L1N0030001N05h
02H1N0030001N05h02<1N0030001N00001D1N003001oogoo03]oo`03001oogoo02aoo`00@goo00<0
000b00000P0b00@0000b03800080<P040001N05h00030GP00`000GP1N0050GP00`000GP1N00H0GP0
0`000GP1N00W0GP00`000GP1N00V0GP00`000GP1N00R0GP010000GP1N0005@5h00<007ooOol05Woo
00<007ooOol08Woo00<007ooOol0;7oo000dOol00`00Oomoo`0<Ool00`0003800002038010000380
<P000P0b00<0005h0GP0105h00<0005h0GP01P5h00<0005h0GP05`5h00<0005h0GP09`5h00<0005h
0GP09P5h00<0005h0GP08@5h00<0005h0GP00P5h00<0005h0GP04P5h00<007ooOol057oo0P009Goo
00<007ooOol0;7oo000dOol00`00Oomoo`0<Ool00`0003800002038010000380<P000P0b00<0005h
0GP00`5h00<0005h0GP0205h00<0005h0GP05P5h00<0005h0GP09`5h00<0005h0GP09P5h00<0005h
0GP0805h00<0005h0GP00`5h00<0005h0GP04P5h00<007ooOol04goo00<007ooOol09Goo00<007oo
Ool0;7oo000dOol00`00Oomoo`0<Ool00`0003800002038010000380<P000P0b00<0005h0GP00`5h
00<0005h0GP0205h00<0005h0GP05@5h20008`5h00<0005h0GP09P5h00<0005h0GP07P5h0P001`5h
00<0005h0GP04@5h00<007ooOol0>goo00<007ooOol0;7oo000dOol00`00Oomoo`0<Ool00`000380
0002038010000380<P000P0b00@0005h0GP00081N0030001N05h00T1N0030001N05h0181N0800003
0GP0005h00D1N0h001D1N0030001N05h02H1N0030001N05h01d1N0030001N05h00L1N0030001N05h
0141N003001oogoo011oo`03001oogoo02Qoo`03001oogoo02aoo`00@goo00<0000b00000P0b00H0
000b0380000b00030GP010000GP1N000305h00<0005h0GP03`5h0P000`5h00<0005h0GP04P5h3P00
1`5h00<0005h0GP09P5h00<0005h0GP0705h00<0005h0GP02@5h00<0005h0GP0405h00<007ooOol0
3Woo0P00:goo00<007ooOol0;7oo0013Ool00`000380000203801P000380<P00038000<1N0030001
N00000h1N0030001N05h00`1N08000D1N0030001N05h0201N0h00281N0030001N05h01/1N0030001
N05h00X1N0030001N05h0101N003001oogoo00eoo`03001oogoo02Yoo`8002ioo`00@goo00<0000b
00000P0b00H0000b0380000b00030GP00`000GP0000?0GP00`000GP1N0090GP200070GP00`000GP1
N00W0GP00`000GP1N0040GP>000D0GP00`000GP1N00J0GP00`000GP1N00<0GP00`000GP1N00?0GP0
0`00Oomoo`0kOol00`00Oomoo`0/Ool003Aoo`03001oogoo00aoo`030000<P000080<P030000<P00
0080<P070001N05h0GP0005h0000405h00<0005h0GP01P5h0P002@5h00<0005h0GP09`5h00<0005h
0GP04P5h3P001P5h00<0005h0GP06@5h00<0005h0GP03P5h00<0005h0GP03P5h00<007ooOol02Woo
00<007ooOol0;Woo00<007ooOol0;7oo000dOol00`00Oomoo`0<Ool00`000380000203800`000380
000203800`000GP1N0020GP00`000GP1N00@0GP00`000GP1N0030GP2000;0GP00`000GP1N00W0GP0
0`000GP1N00P0GP8000I0GP00`000GP1N00?0GP00`000GP1N00>0GP00`00Oomoo`08Ool2000aOol0
0`00Oomoo`0/Ool003Aoo`03001oogoo00aoo`030000<P000080<P030000<P000080<P030001N05h
0081N0030001N05h0141N0030001N05h008000d1N0030001N05h02L1N0030001N05h02H1N0030001
N000008001D1N0030001N05h0141N0030001N05h00d1N0@0009oo`D003=oo`03001oogoo02aoo`00
=7oo00<007ooOol037oo00<0000b00000P0b00<0000b00000P0b00<0005h0GP00P5h00<0005h0GP0
4P5h0P003`5h00<0005h0GP09`5h00<0005h0GP09P5h00<0005h0GP00P5h0P004P5h00<0005h0GP0
4P5h00<0005h0GP03@5h00<007ooOol01goo00<007ooOol0<Goo00<007ooOol0;7oo000dOol00`00
Oomoo`0<Ool01@000380000b00000P0b00@0000b038000<1N0030001N05h01<1N08000l1N0030001
N05h02L1N0030001N05h02H1N0030001N05h00@1N0<000d1N08001H1N0030001N05h00`1N003001o
ogoo00Moo`03001oogoo035oo`03001oogoo02aoo`00@goo00D0000b0000<P000080<P040000<P0b
00030GP00`000GP1N00B0GP010000GP1N0003P5h00<0005h0GP09`5h00<0005h0GP09P5h00<0005h
0GP01`5h0`002@5h00<0005h0GP05P5h00<0005h0GP0305h00<007ooOol01goo00<007ooOol0<Goo
00<007ooOol0;7oo0013Ool01@000380000b00000P0b00@0000b038000<1N0030001N05h0181N005
0001N05h0GP0000=0GP00`000GP1N00W0GP00`000GP1N00V0GP00`000GP1N00:0GP200060GP00`00
0GP1N00H0GP00`000GP1N00;0GP00`00Oomoo`07Ool00`00Oomoo`0aOol00`00Oomoo`0/Ool003Ao
o`03001oogoo00aoo`050000<P0003800002038010000380<P000P5h0P00505h00<0005h0GP00P5h
00<0005h0GP02P5h00<0005h0GP09`5h00<0005h0GP09P5h00<0005h0GP0305h0`000P5h00<0005h
0GP06P5h00<0005h0GP02P5h00<007ooOol01goo00<007ooOol0<Goo00<007ooOol0;7oo000dOol0
0`00Oomoo`0<Ool01@000380000b00000P0b00@0000b03800081N0030001N05h01<1N0030001N05h
00<1N0030001N05h00T1N0030001N05h02L1N0030001N05h02H1N0030001N05h00l1N08001d1N003
0001N05h00X1N003001oogoo03]oo`03001oogoo02aoo`00=7oo00<007ooOol037oo00D0000b0000
<P000080<P040000<P0b00020GP00`000GP1N00B0GP00`000GP1N0050GP00`000GP1N0080GP00`00
0GP1N00W0GP00`000GP1N00V0GP00`000GP1N00?0GP00`000GP0000M0GP00`000GP1N0090GP00`00
Oomoo`0jOol2000^Ool003Aoo`03001oogoo00]oo`060000<P0b0000<P000P0b00H0000b0380005h
000E0GP00`000GP1N0060GP00`000GP1N0070GP00`000GP1N00W0GP00`000GP1N00V0GP00`000GP1
N00>0GP010000GP1N0007@5h00<0005h0GP02@5h00<007ooOol01goo00<007ooOol0<Goo00<007oo
Ool0;7oo000dOol00`00Oomoo`0;Ool01P000380<P0003800080<P080000<P0b0001N0000GP001<1
N0030001N05h00L1N0030001N05h00H1N0030001N05h02H1N0030001N05h02L1N0030001N05h00d1
N0030001N05h0081N0030001N05h01/1N0030001N05h00P1N003001oogoo00Moo`03001oogoo035o
o`03001oogoo02aoo`00@Woo00H0000b0380000b0002038020000380<P000GP0005h000B0GP00`00
0GP1N0080GP00`000GP1N0060GP00`000GP1N00V0GP00`000GP1N00W0GP00`000GP1N00<0GP00`00
0GP1N0030GP00`000GP1N00K0GP00`000GP1N0080GP00`00Oomoo`07Ool00`00Oomoo`0aOol00`00
Oomoo`0/Ool0049oo`060000<P0b0000<P000P0b00P0000b0380005h0001N0004P5h00<0005h0GP0
2@5h00<0005h0GP01@5h00<0005h0GP09P5h00<0005h0GP09`5h00<0005h0GP02`5h00<0005h0GP0
1@5h00<0005h0GP06`5h00<0005h0GP01`5h00<007ooOol01goo00<007ooOol0<Goo00<007ooOol0
;7oo0012Ool01P000380<P0003800080<P030000<P0b00800081N0030001N05h0101N0030001N05h
00X1N0030001N05h00@1N0030001N05h02H1N0030001N05h02L1N0030001N05h00X1N0030001N05h
00H1N0030001N05h01/1N0030001N05h00L1N003001oogoo00Moo`03001oogoo035oo`03001oogoo
02aoo`00=7oo00<007ooOol02goo00H0000b0380000b000203800`000380<P0200020GP00`000GP1
N00?0GP00`000GP1N00<0GP00`000GP1N0030GP00`000GP1N00V0GP00`000GP1N00W0GP00`000GP1
N0090GP00`000GP1N0080GP00`000GP1N00K0GP00`000GP1N0060GP00`00Oomoo`0kOol00`00Oomo
o`0/Ool003Aoo`03001oogoo00]oo`060000<P0b0000<P000P0b00<0000b03800P00505h00<0005h
0GP03@5h00<0005h0GP00P5h00<0005h0GP09P5h00<0005h0GP09`5h00<0005h0GP0205h00<0005h
0GP02P5h00<0005h0GP06`5h00<0005h0GP01@5h00<007ooOol0>goo00<007ooOol0;7oo000dOol0
0`00Oomoo`0;Ool01P000380<P0003800080<P040000<P0b000E0GP00`000GP1N00>0GP01@000GP1
N05h0000:05h00<0005h0GP09`5h00<0005h0GP01`5h00<0005h0GP02`5h00<0005h0GP06`5h00<0
005h0GP01@5h00<007ooOol0>goo00<007ooOol0;7oo000dOol00`00Oomoo`0;Ool01P000380<P00
03800080<P030000<P0b00H00101N0030001N05h00l1N0040001N05h000X0GP00`000GP1N00W0GP0
0`000GP1N0060GP00`000GP1N00=0GP00`000GP1N00K0GP00`000GP1N0040GP00`00Oomoo`07Ool0
0`00Oomoo`0aOol00`00Oomoo`0/Ool003Aoo`03001oogoo00]oo`060000<P0b0000<P000P0b00@0
000b000000<1N0030001N00000T000D1N0030001N05h0141N0030001N00002P1N0030001N05h02L1
N0030001N05h00D1N0030001N05h00h1N0030001N05h01/1N0030001N05h00@1N003001oogoo00Mo
o`03001oogoo031oo`8002ioo`00@Woo00H0000b0380000b0002038200000`0b0001N0020GP00`00
0GP1N0090GP@000:0GP2000X0GP00`000GP1N00I0GPR00060GP00`000GP1N00K0GP00`000GP1N003
0GP00`00Oomoo`07Ool00`00Oomoo`0aOol00`00Oomoo`0/Ool0049oo`060000<P0b0000<P000P0b
00@0000b038000<1N0030001N05h00h1N0030001N05h00P1N1800281N0030001N05h00l1N0X000AL
01MT0003001/06`000A/00d001L1N0030001N05h00<1N003001oogoo00Moo`03001oogoo035oo`03
001oogoo02aoo`00=7oo00<007ooOol02goo00L0000b0380000b0000<P02000203801@000GP1N05h
0000405h00<0005h0GP04`5h00<0007O0Ml0107O3P00505h00<0005h0GP0205h1`003U`05f@000<0
06`0K0004F`03000305h00<0005h0GP00P5h00<007ooOol01goo00<007ooOol0<Goo00<007ooOol0
;7oo000dOol00`00Oomoo`0;Ool01@000380<P0003800P0000D0<P000380<P0001@1N0030001N05h
01<1N0030001g`7O0181g`h000H1N0030001N05h00H1N0800003A01L05`0019L01MT0003001/06`0
01e/00h000<1N003001oogoo03]oo`03001oogoo02aoo`00=7oo00<007ooOol02goo00H0000b0380
000b0002038010000380<P00505h00<0005h0GP04`5h00<0007O0Ml0807O3`000d@055`05f@000<0
06`0K000:V`03@00=Goo00<007ooOol0;7oo000dOol00`00Oomoo`0;Ool00`000380<P0300020380
10000380<P00505h00<0005h0GP04`5h00<0007O0Ml03P005`7O00<0007O0Ml00P7O0`001D@055`0
5f@000<006`0K000=f`02`00:Woo00<007ooOol0;7oo000dOol00`00Oomoo`0;Ool00`000380<P03
0002038010000380<P000`5h00<0005h0GP03P5h00<0005h0GP04`5h00<0007O0Ml03P7O3P00207O
00<0007O0Ml00`0024@055`05f@000<006`0K000?F`000<00700L0000W002@008Goo00<007ooOol0
;7oo0012Ool01P000380<P0003800080<P040000<P0b00030GP00`000GP1N00>0GP00`000GP1N00C
0GP00`000Ml1g`0L0Ml800020Ml2000:A00DG00GI0000`00K01/000mK0000`00L01`000;L005000L
Ool2000]Ool0049oo`060000<P000000<P000P0b00@0000b038000<1N0030001N05h00h1N0030001
N05h01<1N0h001L1g`030001g`7O008000]401AL01MT0003001/06`003e/0003001`0700011`0080
01Yoo`8000ioo`<000Aoo`<001Eoo`00@Woo0P0000@0<P0003800080<P040000<P0b00030GP00`00
0GP1N00>0GP00`000GP1N00B0GP00`000Ml1g`0<0Ml>00070Ml200001@7O0000020000002d@055`0
5f@000<006`0K000?F`000<00700L00047000W`00P0067oo0P004Goo00@007ooOol000=oo`03001o
ogoo019oo`00=7oo00<007ooOol02goo00H0000b0380000b0002038010000380<P000`5h00<0005h
0GP03P5h00<0005h0GP04P5h00<0007O0Ml06P7O1`000P7O0P000R0000<004@0A0002D@055`05f@0
00<006`0K000?F`000<00700L000470017`00P0057oo10004Woo00<007oo00000goo00<007ooOol0
4Woo000dOol00`00Oomoo`0;Ool01P000380<P0003800080<P040000<P0b000D0GP00`000GP1N00B
0GP<000F0Ml010000Ml1g`00120000<004@0A0002D@055`05f@000<006`0K000?F`000<00700L000
47001W`00P0057oo0P001Woo1`001Goo00<007oo00000goo00<007ooOol04Woo000cOol00`00Oomo
o`0<Ool01P000380<P0003800080<P040000<P0b000D0GP00`000GP1N00B0GP00`000Ml1g`090Ml>
00070Ml010000Ml1g`001B0000<004@0A0002D@055`05f@000<006`0K000?F`000<00700L0004700
27`000<007ooOol04Goo00<007ooOol04Goo00<007oo00000goo00<007ooOol04Woo000cOol00`00
Oomoo`0<Ool01P000380<P0003800080<P040000<P0b000D0GP00`000GP1N00B0GP00`000Ml1g`0G
0Ml:000680000`00A0140009A00DG00GI0000`00K01/000mK0000`00L01`000@L009O00COol00`00
Oomoo`0@Ool01000Oomoo`000goo00<007ooOol04Woo000cOol00`00Oomoo`0<Ool01P000380<P00
03800080<P030000<P0b00H000l1N0030001N05h0181N0T001H1g`040001g`00000780000`00A014
0009A00DG00GI0000`00K01/000mK0000`00L01`000@L009O00COol2000?Ool20003Ool01@00Oomo
ogoo000057oo0012Ool00`000380000203801@000380<P0003800P000`5h00<0005h00002@001@5h
00<0005h0GP04P5h00<007ooOol01Woo3P001`7O00<0007O00002B0000<004@0A0002D@055`05f@0
00<006`0K000?F`000<00700L00047002G`04goo0P003goo00<007ooOol00Woo00D007ooOomoo`00
01Aoo`00@Woo00<0000b00000P0b00<0000b03800P0000<0<P000GP00P5h00<0005h0GP02@5h4000
2P5h00<007ooOol057oo2@002R0000<004@0A0002D@055`05f@000<006`0K000?F`000<00700L000
47002G`04goo0P0047oo0`000Woo0`005Goo000cOol00`00Oomoo`0<Ool00`000380000203801000
0380<P000P0b00D0005h0GP1N0000101N0030001N05h00P1N0/001aoo`8000/P0003001404@000U4
01AL01MT0003001/06`003e/0003001`0700011`00Ul01=oo`8002eoo`00<goo00<007ooOol037oo
00<0000b00000P0b00@0000b00000080<P030001N05h0181N0030001N05h0181N003001oogoo01Uo
o`03000P020000/P0003001404@000U401AL01MT0003001/06`003e/0003001`0700011`00Ul01Ao
o`03001oogoo02]oo`00<goo00<007ooOol037oo00<0000b00000P0b0P0000D0<P000380<P0001@1
N0030001N05h0181N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/
06`003e/0003001`0700011`00Ul01Aoo`03001oogoo02]oo`00<goo00<007ooOol037oo00<0000b
00000P0b00@0000b03800080<P030001N05h0181N0030001N05h0181N003001oogoo01Uoo`03000P
020000/P0003001404@000U401AL01MT0003001/06`003e/0003001`0700011`00Ul019oo`<002eo
o`00<goo00<007ooOol037oo00@0000b0000<P800080<P040000<P0b00020GP00`000GP1N00?0GP0
0`000GP1N00B0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/
000mK0000`00L01`000@L009O00DOol00`00Oomoo`0[Ool0049oo`060000<P000000<P000P0b00<0
000b00000`5h00<0005h0GP03`5h00<0005h0GP04P5h00<007ooOol06Goo00<0020080002b0000<0
04@0A0002D@055`05f@000<006`0K000?F`000<00700L00047002G`057oo00<007ooOol0:goo0012
Ool00`000380000203801P000380<P00038000<1N0030001N05h00l1N0030001N05h0181N003001o
ogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003e/0003001`0700011`
00Ul01Aoo`03001oogoo02]oo`00@Woo0`000P0b00H0000b0380000b00030GP00`000GP1N00?0GP0
0`000GP1N00B0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/
000mK0000`00L01`000@L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo00aoo`<00080<P06
0000<P0b0000<P000`5h00<0005h0GP03`5h00<0005h0GP04P5h00<007ooOol06Goo00<002008000
2b0000<004@0A0002D@055`05f@000<006`0K000?F`000<00700L00047002G`057oo00<007ooOol0
:goo000cOol00`00Oomoo`0<Ool00`000380000203801P000380<P00038001D1N0030001N05h0181
N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003e/0003001`
0700011`00Ul01Aoo`03001oogoo02]oo`00<goo00<007ooOol037oo00<0000b00000P0b00H0000b
0380000b000E0GP00`000GP1N00B0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00D
G00GI0000`00K01/000mK0000`00L01`000@L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo
00aoo`030000<P000080<P060000<P0b0000<P000`5h00<0005h0GP03`5h00<0005h0GP04P5h00<0
07ooOol06Goo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?F`000<00700L000
47002G`057oo00<007ooOol0:goo000cOol00`00Oomoo`0<Ool00`000380000203801P000380<P00
038000<1N0030001N05h00l1N0030001N05h0181N003001oogoo01Uoo`03000P020000/P00030014
04@000U401AL01MT0003001/06`003e/0003001`0700011`00Ul01Aoo`03001oogoo02]oo`00@Woo
00<0000b00000P0b00D0000b0380000b00P000h1N0030001N05h0181N003001oogoo01Uoo`03000P
020000/P0003001404@000U401AL01MT0003001/06`003e/0003001`0700011`00Ul01Aoo`03001o
ogoo02]oo`00@Woo00<0000b00000P0b00<0000b03800`000`5h00@0005h0GP1N0T000D1N0030001
N05h0181N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003e/
0003001`0700011`00Ul01=oo`8002eoo`00<goo00<007ooOol037oo00<0000b00000P0b00<0000b
03800`000`5h00<0005h0GP0205h00<0005h00003`002P5h00<007ooOol06Goo00<0020080002b00
00<004@0A0002D@055`05f@000<006`0K000?F`000<00700L00047002G`057oo00<007ooOol0:goo
000cOol00`00Oomoo`0<Ool00`000380000203801P000380<P00038000h1N0030001N05h00/1N004
0001N05h0GP;000KOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000mK0000`00
L01`000@L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo00]oo`040000<P0b000203801P00
03800000038000h1N0030001N05h00/1N0030001N05h00/1N003001oogoo01Uoo`03000P020000/P
0003001404@000U401AL01MT0003001/06`003i/0003001`070000m`00Ul01Aoo`03001oogoo02]o
o`00<goo00<007ooOol02goo00@0000b03800080<P8000040380000b000>0GP00`000GP1N00;0GP0
0`000GP1N00;0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/
000nK0000`00L01`000?L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo00]oo`040000<P0b
000203801P000380<P00038000<1N0030001N05h00P1N0030001N05h00/1N0030001N05h00/1N003
001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003i/0003001`0700
00m`00Ul01Aoo`03001oogoo02]oo`00@Goo00D0000b0380000b008000040380000b038800070GP0
0`000GP1N00;0GP00`000GP1N00;0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00D
G00GI0000`00K01/000nK0000`00L01`000?L009O00DOol00`00Oomoo`0[Ool0045oo`030000<P0b
008000050380000b0000<P0200030GP010000GP1N05h3P001`5h00<0005h0GP02`5h00<007ooOol0
6Goo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L0003g002G`0
57oo00<007ooOol0:goo0011Ool010000380<P000P0b00H0000b0000000b00030GP00`000GP1N008
0GP00`000GP1N0040GPF000KOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000n
K0000`00L01`000?L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo00]oo`@00080<P030000
<P000080<P050001N05h0GP0000:0GP00`000GP1N00;0GP00`000GP1N00;0GP00`00Oomoo`0IOol0
0`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`000?L009O00DOol0
0`00Oomoo`0[Ool003=oo`03001oogoo00]oo`040000<P0b00020383000203800`000GP1N00<0GP0
0`000GP1N00;0GP00`000GP1N00;0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00D
G00GI0000`00K01/000nK0000`00L01`000?L009O00COol2000]Ool003=oo`03001oogoo00]oo`04
0000<P0b000203800`000380000203800`000GP1N00<0GP00`000GP1N00;0GP00`000GP1N00;0GP0
0`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`
000?L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo00]oo`050000<P0b0000<P020000100b
0000<P0b20001`5h00<0005h0GP02`5h00<0005h0GP02`5h00<007ooOol06Goo00<0020080002b00
00<004@0A0002D@055`05f@000<006`0K000?V`000<00700L0003g002G`057oo00<007ooOol0:goo
0011Ool00`000380<P020000200b0000<P000380004n00020I`010000I`1W06L3P001`5h00<0005h
0GP02`5h00<007ooOol06Goo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?V`0
00<00700L0003g002G`057oo00<007ooOol0:goo0011Ool010000380<P000P0b00@0000b00000081
?P040001W06L000:0I`00`000I`1W0040I`>00070GP00`00Oomoo`0IOol00`00800P000;80000`00
A0140009A00DG00GI0000`00K01/000nK0000`00L01`000?L009O00DOol00`00Oomoo`0[Ool0045o
o`040000<P00000203800`00038000040Ch00`000I`0000:0I`00`000I`1W00;0I`00`000I`1W004
0I`8000KOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`000?
L009O00DOol00`00Oomoo`0[Ool003=oo`03001oogoo00]oo`8000040380000b038200000`4n0001
?P030Ch200090I`00`000I`1W00<0I`00`000I`1W00:0I`00`00Oomoo`0JOol00`00800P000;8000
0`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`000?L009O00DOol00`00Oomoo`0[Ool0
03=oo`03001oogoo00]oo`040000<P0b0002038200020Ch01@000Ch1?P4n00002P6L00<0006L0I`0
2`6L00<0006L0I`02P6L00<007ooOol06goo00<0020080002b0000<004@0A0002D@055`05f@000<0
06`0K000?V`000<00700L0003g002G`057oo00<007ooOol0:goo000cOol00`00Oomoo`0;Ool01000
0380<P000P0b00<0004n0Ch00P4n00@0004n0Ch1?Q4000L1W0030001W06L00T1W003001oogoo01ao
o`03000P020000/P0003001404@000U401AL01MT0003001/06`003i/0003001`070000m`00Ul01Ao
o`03001oogoo02]oo`00<goo00<007ooOol02goo00<0000b03800`0000<1?P000Ch00`4n00D0004n
0001?P0000P1W0030001W06L00@1W0`000H1W003001oogoo01eoo`03000P020000/P0003001404@0
00U401AL01MT0003001/06`003i/0003001`070000m`00Ul01Aoo`03001oogoo02]oo`00<goo00<0
07ooOol02goo00@0000b038000@1?P030001?P4n0081?P040001?P0000080I`00`000I`1W00;0I`0
0`000I`1W0020I`6000POol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK000
0`00L01`000?L009O00DOol00`00Oomoo`0[Ool0045oo`050000<P000Ch000040Ch01@000Ch00000
0Ch00P0000<1?P000I`01@6L00<0006L0I`0306L00<0006L0I`01P6L00<007ooOol07goo00<00200
80002b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L0003g002G`04goo0P00;Goo
0011Ool200030Ch00`000Ch1?P020Ch00`000Ch1?P020Ch00`000Ch000060I`00`000I`1W00;0I`0
0`000I`1W0060I`00`00Oomoo`0POol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/
000nK0000`00L01`000?L009O00DOol00`00Oomoo`0[Ool0045oo`030001?P4n0081?P070001?P4n
0Ch0004n00000`4n0P0000<1?P0000002`001`6L00<0006L0I`01@6L00<007ooOol08Goo00<00200
80000R0000=/020080001R0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L0003g00
2G`057oo0P00;7oo000cOol00`00Oomoo`0<Ool200030Ch00`000Ch000030Ch01@000Ch1?P000Ch0
3@0000<1g`0000002000106L00<007ooOol08Woo00<0020080002b0000<004@0A0002D@055`05f@0
00<006`0K000?V`000<00700L0003g002G`057oo0P00;7oo000cOol00`00Oomoo`0>Ool200020Ch0
0`000Ch1?P020Ch01@000Ch1?P4n00001@7O00<0007O0Ml01@7O20000`7O10009Goo00<002008000
2b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L0003g002G`057oo00<007ooOol0
:goo000cOol00`00Oomoo`0@Ool200000`4n0001?P030Ch00`000Ch000050Ml00`000Ml1g`0<0Ml0
10000Ml1g`7O10009Woo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?V`000<0
0700L0003g002G`057oo00<007ooOol0:goo000cOol00`00Oomoo`0AOol010000Ch1?P00104n3@00
207O00<0007O0Ml00P7O0P00:7oo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000
?V`000<00700L0003g002G`057oo00<007ooOol0:goo0018Ool200000`4n0001?P020000107O0001
g`7O0P001`7O3@00:Woo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?V`000<0
0700L0003g002G`057oo0P00;7oo001:Ool00`000Ch0000<00080Ml200040Ml00`00Oomoo`0YOol0
0`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`000?L009O00DOol2
000/Ool004]oo`d000030Ml0000000P000<1g`03001oogoo02Yoo`03000P020000<P0003K00P0200
00DP0003001404@000U401AL01MT0003001/06`003i/0003001`070000m`00Ul01Aoo`8000Ioo`<0
02=oo`00<goo00<007ooOol06Woo00<007ooOol01Goo20000`7O0`00;Goo00<0020080002b0000<0
04@0A0002D@055`05f@000<006`0K000?V`000<00700L0003g002G`04Woo10001Goo00D007ooOomo
o`0001=oo`L000Qoo`00<goo00<007ooOol0GGoo00<0020080002b0000<004@0A0002D@055`05f@0
00<006`0K000?V`000<00700L0003g002G`057oo0P001Goo00D007ooOomoo`0001Aoo`03001oogoo
009oo`03001oogoo00Ioo`00<Woo00<007ooOol0GWoo00<0020080002b0000<004@0A0002D@055`0
5f@000<006`0K000?V`000<00700L000470027`057oo00<007ooOol017oo00D007ooOomoo`0001Ao
o`03001oogoo009oo`03001oogoo00Ioo`00<Woo00<007ooOol07Woo3@00<goo00<0020080002b00
00<004@0A0002D@055`05f@000<006`0K000?V`000<00700L000470027`05Goo00<007ooOol00goo
00D007ooOomoo`0001Eoo`03001oogoo00Yoo`00<Woo00<007ooOol06goo00<007oo00001@4B00<0
004B0A801@4B3@009Woo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?V`000<0
0700L000470027`05Goo00<007ooOol00goo00D007ooOomoo`0001Ioo`03001oogoo00Uoo`00D7oo
0P001P4B00<0004B0A80304B00<0004B0A800`4B0P0097oo00<0020080002b0000<004@0A0002D@0
55`05f@000<006`0K000?V`000<00700L000470027`05Goo00<007ooOol00goo00D007ooOomoo`00
01Ioo`03001oogoo00Uoo`00Cgoo1@001@4B00<0004B0A802`4B00<0004B0A801@4B00<007ooOol0
8Goo00<002008000120000=/02008000120000<004@0A0002D@055`05f@000<006`0K000?V`000<0
0700L00047002G`057oo00<007ooOol00goo00D007ooOomoo`0001Moo`03001oogoo00Qoo`00CWoo
00<0004B00000`4B3@001`4B00<0004B0A801@4B0P008Goo00<0020080002b0000<004@0A0002D@0
55`05f@000<006`0K000?V`000<00700L00047002G`057oo00<007ooOol017oo0`005Goo00D007oo
Oomoo`0000Uoo`00<Woo00<007ooOol05goo0P002`4B00<0004B0A801@4B4P0087oo00<002008000
2b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L00047002G`057oo00<007ooOol0
77oo1P0027oo000bOol00`00Oomoo`0FOol800070A800`000A814P0;0A800`000A814P080A800`00
Oomoo`0MOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`000@
L009O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo01Eoo`<000H1N0l000L14P0300014P4B00P1
4P8001eoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003i/0003001`0700011`
00Ul01Aoo`03001oogoo02Yoo`00<Woo00<007ooOol057oo0P0000<0<P000GP00P5h00<0005h0GP0
1`5h00<0005h0GP01@5h3P001P4B00<007ooOol06Woo00<0020080002b0000<004@0A0002D@055`0
5f@000<006`0K000?V`000<00700L00047002G`04goo0P00;7oo0018Ool2000203801@000GP1N05h
00002@5h00<0005h0GP0305h00<0005h0GP0105h20006goo00<0020080002b0000<004@0A0002D@0
55`05f@000<006`0K000?V`000<00700L00047002G`057oo00<007ooOol0:Woo0017Ool300020380
1@000GP1N05h00002@5h00<0005h0GP0305h00<0005h0GP02`5h00<007ooOol06Goo00<002008000
1B0000=/020080000b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L00047002G`0
57oo00<007ooOol0:Woo0016Ool010000380<P000P0b00D0005h0GP1N00000T1N0030001N05h00`1
N0030001N05h00/1N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/
06`003i/0003001`0700011`00Ul01Aoo`03001oogoo02Yoo`00<Woo00<007ooOol047oo0P000P0b
00@0000b038000<1N0030001N05h00L1N0030001N05h00`1N0030001N05h00/1N003001oogoo01Uo
o`03000P020000/P0003001404@000U401AL01MT0003001/06`003i/0003001`0700011`00Ul01Ao
o`03001oogoo02Yoo`00<Woo00<007ooOol03goo00<0000b00000P0b00<0000b03801`001`5h00<0
005h0GP0305h00<0005h0GP02`5h00<007ooOol06Goo00<0020080002b0000<004@0A0002D@055`0
5f@000<006`0K000?V`000<00700L00047002G`057oo00<007ooOol0:Woo000bOol00`00Oomoo`0>
Ool010000380<P000P0b10001P5h3`001`5h00<0005h0GP02`5h00<007ooOol06Goo00<002008000
2b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L00047002G`057oo00<007ooOol0
:Woo000bOol00`00Oomoo`0=Ool20002038010000380<P000P0b00<0005h0GP02`5h00<0005h0GP0
1@5h5P006goo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?V`000<00700L000
47002G`057oo00<007ooOol0:Woo000bOol00`00Oomoo`0<Ool00`00038000020380100003800000
0P0b00D0005h0GP1N00000T1N0030001N05h00`1N0030001N05h00/1N003001oogoo01Uoo`03000P
020000/P0003001404@000U401AL01MT0003001/06`003i/0003001`0700011`00Ul01Aoo`03001o
ogoo02Yoo`00@Goo00<0000b00000P0b0P0000D0<P000380<P0000<1N0030001N05h00L1N0030001
N05h00`1N0030001N05h00/1N003001oogoo01Uoo`03000P020000HP0003K00P0200008P00030014
04@000U401AL01MT0003001/06`003i/0003001`0700011`00Ul01Aoo`03001oogoo02Yoo`00@Goo
00<0000b00000P0b00@0000b03800080<P050001N05h0GP000090GP00`000GP1N00;0GP00`000GP1
N00<0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK000
0`00L01`000@L009O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo00aoo`030000<P0000<00080
<P040000<P0b00030GP00`000GP1N0070GP00`000GP1N00;0GP00`000GP1N00<0GP00`00Oomoo`0I
Ool00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000nK0000`00L01`000@L009O00C
Ool2000/Ool0039oo`03001oogoo00aoo`030000<P000080<P040000<P0b0002038E00070GP00`00
0GP1N00<0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000n
K0000`00L01`000@L009O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo00aoo`<00080<P030000
<P0b00@000X1N1T000L1N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003
001/06`003i/0003001`0700011`00Ul01Aoo`03001oogoo02Yoo`00<Woo00<007ooOol037oo00<0
000b00000P0b00@0000b03800080<P030001N05h0181N0030001N05h00P1N0`001]oo`03000P0200
00/P0003001404@000U401AL01MT0003001/06`003i/0003001`0700011`00Ul01Aoo`03001oogoo
02Yoo`00<Woo00<007ooOol037oo00<0000b00000P0b10000P0b00@0005h0GP00141N0030001N05h
01<1N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003i/0003
001`0700011`00Ul01Aoo`03001oogoo02Yoo`00@Goo00<0000b00000P0b00@0000b03800080<P04
0001N05h000A0GP00`000GP1N00C0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00D
G00GI0000`00K01/000nK0000`00L01`000@L009O00DOol00`00Oomoo`0ZOol0045oo`030000<P00
00<00080<P040000<P0b00020GP00`000GP1N00?0GP00`000GP1N00C0GP00`00Oomoo`0IOol00`00
800P000780001F`0800P020000002d@055`05f@000<006`0K000?f`000<00700L0003g002G`057oo
00<007ooOol0:Woo0010Ool010000380<P000P0b00@0000b03800080<P040001N05h000A0GP00`00
0GP1N00C0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000o
K0000`00L01`000?L009O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo00]oo`040000<P000002
038010000380<P000P0b00@0005h0GP00141N0030001N05h01<1N003001oogoo01Uoo`03000P0200
00/P0003001404@000U401AL01MT0003001/06`003m/0003001`070000m`00Ul01Aoo`03001oogoo
02Yoo`00<Woo00<007ooOol02goo0P0000D0<P000380<P000080<P030000<P0001D1N0030001N05h
01<1N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`003m/0003
001`070000m`00Ul01Aoo`03001oogoo02Yoo`00<Woo00<007ooOol02goo00@0000b03800080<P06
0000<P0b0000<P005@5h00<0005h0GP04`5h00<007ooOol06Goo00<0020080002b0000<004@0A000
2D@055`05f@000<006`0K000?f`000<00700L0003g002G`057oo00<007ooOol0:Woo000bOol00`00
Oomoo`0;Ool010000380<P000P0b00<0000b00000P0b00<0005h0GP04`5h00<0005h0GP04`5h00<0
07ooOol06Goo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?f`000<00700L000
3g002G`04goo0P00;7oo000bOol00`00Oomoo`0;Ool010000380<P000P0b00<0000b00000P0b00D0
005h0GP1N0000141N0030001N05h01<1N003001oogoo01Uoo`03000P020000/P0003001404@000U4
01AL01MT0003001/06`003m/0003001`070000m`00Ul01Aoo`03001oogoo02Yoo`00@7oo00@0000b
03800080<P030000<P000080<P050001N05h0GP0000A0GP00`000GP1N00C0GP00`00Oomoo`0IOol0
0`00800P0008800016`0800P00002d@055`05f@000<006`0K000?f`000<00700L0003g002G`057oo
00<007ooOol0:Woo0010Ool010000380<P000P0b00<0000b00000P0b00D0005h0GP1N0000141N003
0001N05h01<1N003001oogoo01Uoo`03000P020000/P0003001404@000U401AL01MT0003001/06`0
03m/0003001`070000m`00Ul01Aoo`03001oogoo02Yoo`00<Woo00<007ooOol02goo00@0000b0380
0080<P030000<P000080<P050001N05h0GP0000A0GP00`000GP1N00C0GP00`00Oomoo`0IOol00`00
800P000;80000`00A0140009A00DG00GI0000`00K01/000oK0000`00L01`000?L009O00DOol00`00
Oomoo`0ZOol0039oo`03001oogoo00]oo`040000<P0b000203800`000380000203800`000GP1N00C
0GP00`000GP1N00C0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00
K01/000oK0000`00L01`000?L009O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo00]oo`040000
<P0b000203800`0003800002038;000;0GP00`000GP1N00C0GP00`00Oomoo`0IOol00`00800P000;
80000`00A0140009A00DG00GI0000`00K01/000oK0000`00L01`000?L009O00DOol00`00Oomoo`0Z
Ool0039oo`03001oogoo00]oo`040000<P0b000203800`0003800003000:0GPF000;0GP00`00Oomo
o`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000oK0000`00L01`000?L009
O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo00]oo`040000<P0b000203800`00038000020380
1@000GP1N05h00004@5h00<0005h0GP0205h30006goo00<0020080002b0000<004@0A0002D@055`0
5f@000<006`0K000?f`000<00700L0003g002G`057oo00<007ooOol0:Woo0010Ool010000380<P00
0P0b0`000P0b00D0005h0GP1N0000141N0030001N05h01<1N003001oogoo01Uoo`03000P020000/P
0003001404@000U401AL01MT0003001/06`003m/0003001`070000m`00Ul01Aoo`8002]oo`00@7oo
00@0000b03800080<P030000<P000080<P050001N05h0GP0000A0GP00`000GP1N00C0GP00`00Oomo
o`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000oK0000`00L01`000?L009
O00COol3000[Ool0041oo`030000<P0b00@000050380000b038000030GP00`000GP1N00?0GP00`00
0GP1N00C0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000o
K0000`00L01`000?L009O00DOol2000[Ool0039oo`03001oogoo00]oo`040000<P0b000203800`00
0380000203801@000GP1N05h00004@5h00<0005h0GP04`5h00<007ooOol06Goo00<0020080002b00
00<004@0A0002D@055`05f@000<006`0K000?f`000<00700L0003g002G`057oo0P00:goo000bOol0
0`00Oomoo`0;Ool4000203800`000380000203800`000GP1N00C0GP00`000GP1N00C0GP00`00Oomo
o`0IOol00`00800P000;80000`00A0140009A00DG00GI0000`00K01/000oK0000`00L01`000?L009
O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo00]oo`040000<P0b000203800`00038000020380
0`000GP1N00C0GP00`000GP1N00C0GP00`00Oomoo`0IOol00`00800P000;80000`00A0140009A00D
G00GI0000`00K01/000oK0000`00L01`000?L009O00DOol00`00Oomoo`0ZOol0039oo`03001oogoo
00]oo`040000<P0b000203800`000380000203801@000GP1N05h00004@5h00<0005h0GP04`5h00<0
07ooOol06Goo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000?f`000<00700L000
3g002G`057oo00<007ooOol0:Woo000bOol00`00Oomoo`0;Ool010000380<P000P0b00<0000b0000
0P0b00D0005h0GP1N0000141N0030001N05h01<1N003001oogoo01Uoo`03000P020000/P00030014
04@000U401AL01MT0003001/06`003m/0003001`070000m`00Ul01Aoo`8002]oo`00@7oo00@0000b
03800080<P030000<P000080<P050001N05h0GP0000A0GP00`000GP1N00B0GP00`00Oomoo`0JOol0
0`00800P000;80000`00A0140009A00DG00GI0000`00K01/000oK0000`00L01`000?L009O00EOol0
0`00Oomoo`0YOol0041oo`040000<P0b000203800`000380000203801@000GP1N05h00004@5h00<0
005h0GP04P5h00<007ooOol06Woo00<0020080002b0000<004@0A0002D@055`05f@000<006`0K000
?f`000<00700L0003g002G`05Goo00<007ooOol0:Goo000aOol00`00Oomoo`0<Ool01P000380<P00
03800080<P040000<P0b00030GP00`000GP1N00?0GP00`000GP1N00B0GP00`00Oomoo`0JOol00`00
800P000;80000`00A0140009A00@G00V000gK0000`00L01`000?L009O00EOol00`00Oomoo`0YOol0
035oo`03001oogoo00aoo`060000<P0b0000<P000P0b00@0000b038001D1N0030001N05h0181N003
001oogoo01Yoo`03000P020000/P0003001404@000U400IL00X001U4008000]401H0025/0003001`
070000m`00Ul01Eoo`03001oogoo00=oo`<000Aoo`<001aoo`00<Goo00<007ooOol037oo00H0000b
0380000b0002038010000380<P005@5h00<0005h0GP04P5h00<007ooOol06Woo00<0020080002b00
00<004@0A00024@01`008D@00P008d@05P002f`000<00700L0003g002G`04goo0`0027oo00@007oo
Ool000=oo`03001oogoo01Uoo`00<Goo00<007ooOol037oo00H0000b0380000b0002038010000380
<P005@5h00<0005h0GP04P5h00<007ooOol06Woo00<0020080002b0000<004@0A00014@010009T@0
0P00>d@040003G002G`05Goo00<007ooOol01goo00<007oo00000goo00<007ooOol06Goo000aOol0
0`00Oomoo`0<Ool01P000380<P0003800080<P030000<P0b00/000/1N0030001N05h0181N003001o
ogoo01Yoo`03000P020000/P0003001404@000@002Q4008003Y40003001404@000Q4008000I400T0
00A`00Ul01Eoo`03001oogoo00Moo`03001oo`0000=oo`03001oogoo01Uoo`00@7oo00H0000b0380
000b0002038400030GP00`000GP1N0040GPF000:0GP2000KOol00`00800P000;800C000IA0030015
A002000AA0060007O00EOol00`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`0IOol0041oo`06
0000<P0b0000<P000P0b00<0000b03800P000P5h00<0005h0GP03`5h00<0005h0GP0205h80001goo
00<0020080002B000P004d@09000>d@00P006D@00`0017`05Goo00<007ooOol01Woo00@007ooOol0
00=oo`03001oogoo01Uoo`00@7oo00D0000b0380000b00@00080<P800081N0030001N05h00l1N003
0001N05h0141N08001D1N20001Q40080000309D0002E0080U@030001N05h00X1N1D002A4008001i4
00<00003O01oogoo01=oo`03001oogoo00Aoo`8000=oo`05001oogooOol0000KOol0035oo`03001o
ogoo00aoo`060000<P0b0000<P000P0b00<0000b03800P000P5h00<0005h0GP0405h00<0005h0GP0
3`5h00<0005h0000:P5h00<0005h0GP0205h5@0000=4000000000`2E00D0002E09D0U@0001l1N003
0001N00001D000a4008002=4008001Aoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0
000KOol0035oo`03001oogoo00aoo`030000<P0b00<00080<P030000<P0b008001D1N0030001N05h
00h1N0040001N05h000Z0GP00`000GP1N00M0GPB000H0GP00`000GP1N00E0GP>000SA0000`00Oomo
o`0COol00`00Oomoo`05Ool30002Ool3000LOol0035oo`03001oogoo00aoo`@000050380000b0380
000203800`000GP0000D0GP00`000GP1N00=0GP01@000GP1N05h0000:P5h00<0005h0GP09`5h0P00
1P5h4000205h00<0005h0GP07@5h00@00300<00`01<001940003001oogoo01=oo`03001oogoo02Uo
o`00<Goo00<007ooOol037oo00H0000b0380000b0002038020000380<P000GP0005h000B0GP00`00
0GP1N00<0GP00`000GP1N0020GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP0000E0GPH000@
0GP4000CA00B000FOol00`00Oomoo`0YOol0041oo`060000<P0b0000<P000P0b00P0000b0380005h
0001N0004`5h00<0005h0GP02P5h00<0005h0GP00`5h00<0005h0GP0:05h00<0005h0GP09`5h00@0
005h0GP001/1N0030001N05h00h1N14001i40003=01404@0009400<001Qoo`03001oogoo02Uoo`00
@7oo00H0000b0380000b0002038020000380<P000GP0005h000C0GP00`000GP1N0090GP00`000GP1
N0040GP00`000GP1N00X0GP00`000GP1N00W0GP01@000GP1N05h00006P5h00<0005h0GP07@5h0P00
5D@000<d04@0A00024@00`006Woo0P00:goo0010Ool01P000380<P0003800080<P040000<P0b0002
0GP2000C0GP00`000GP1N0070GP200070GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N002
0GP00`000GP1N00F0GP00`000GP1N00N0GP2000<A0000f`0A014000?A002000NOol00`00Oomoo`0Y
Ool0035oo`03001oogoo00aoo`060000<P0b0000<P000P0b00@0000b03800081N08001<1N0030001
N05h00H1N0030001N05h00L1N0030001N05h02P1N0030001N05h02L1N0030001N05h0081N0030001
N05h01H1N0030001N05h01d1N0030001N00001]400<0021oo`03001oogoo02Uoo`00<Goo00<007oo
Ool037oo00H0000b0380000b0002038010000380<P000P5h00<0005h0GP04`5h00<0005h0GP0105h
00<0005h0GP0205h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP00`5h00<0005h0GP0505h
00<0005h0GP07P5h00<0005h000064@00`008goo00<007ooOol0:Goo000aOol00`00Oomoo`0<Ool0
1P000380<P0003800080<P040000<P0b00020GP00`000GP1N00C0GP00`000GP1N0030GP00`000GP1
N0090GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N0040GP00`000GP1N00B0GP00`000GP1
N00N0GP00`000GP1N006000@A003000VOol00`00Oomoo`0YOol0035oo`03001oogoo00aoo`060000
<P0b0000<P000P0b00@0000b038000<1N0030001N05h0181N0030001N05h0081N0030001N05h00X1
N0030001N05h02P1N0030001N05h02L1N0030001N05h00D1N0030001N05h0141N0030001N05h01d1
N0050001N05h0GP00003A00B000YOol00`00Oomoo`0YOol0035oo`03001oogoo00aoo`060000<P0b
0000<P000P0b00@0000b038000<1N0030001N05h0181N0050001N05h0GP0000=0GP00`000GP1N00X
0GP00`000GP1N00W0GP00`000GP1N0060GP00`000GP1N00?0GP00`000GP1N00N0GP01@000GP1N05h
00003T@01000;7oo00<007ooOol0:Goo0010Ool01P000380<P0003800080<P040000<P0b00030GP0
0`000GP1N00C0GP00`000GP0000>0GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N0070GP0
0`000GP1N00>0GP00`000GP1N00M0GP00`000GP1N0020GP00`00A0140008A004000`Ool00`00Oomo
o`0YOol0041oo`060000<P0b0000<P000P0b00@0000b038000<1N0030001N05h01<1N08000l1N003
0001N05h02P1N0030001N05h02L1N0030001N05h00P1N0030001N05h00`1N0030001N05h01h1N003
0001N05h0081N0/003Aoo`03001oogoo02Uoo`00@7oo00H0000b0380000b0002038010000380<P00
0`5h0P00505h00<0005h0GP03P5h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP02@5h00<0
005h0GP02P5h00<0005h0GP07P5h00<0005h0GP00`5h00<007ooOol01goo00<007ooOol0<Woo00<0
07ooOol0:Goo000aOol00`00Oomoo`0<Ool01P000380<P0003800080<P040000<P0b00030GP2000C
0GP010000GP000003P5h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP02P5h00<0005h0GP0
2@5h00<0005h0GP07P5h00<0005h0GP00`5h00<007ooOol0?7oo00<007ooOol0:Goo000aOol00`00
Oomoo`0<Ool01P000380<P0003800080<P040000<P0b00040GP00`000GP1N00@0GP00`000GP1N002
0GP00`000GP1N00;0GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N00;0GP00`000GP1N007
0GP00`000GP1N00N0GP00`000GP1N0040GP00`00Oomoo`0kOol2000[Ool0035oo`03001oogoo00ao
o`060000<P0b0000<P000P0b00@0000b038000@1N0030001N05h00l1N0030001N05h00@1N08000/1
N0030001N05h02P1N0030001N05h02L1N0030001N05h00`1N0030001N05h00H1N0030001N05h01d1
N0030001N05h00D1N003001oogoo03aoo`03001oogoo02Uoo`00<Goo00<007ooOol037oo00H0000b
0380000b000203800`00038000040GP00`000GP0000?0GP00`000GP1N0070GP00`000GP1N0080GP0
0`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N00<0GP00`000GP1N0050GP00`000GP1N00N0GP0
0`000GP1N0050GP00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`0YOol0041oo`060000<P0b
0000<P000P0b00<0000b0000105h00<0005h00003P5h00<0005h0GP02@5h0P00205h00<0005h0GP0
:05h00<0005h0GP09`5h00<0005h0GP03@5h00<0005h0GP00`5h00<0005h0GP07P5h00<0005h0GP0
1P5h00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0:Goo0010Ool020000380<P000380000b
000203800`000GP1N0020GP00`000GP0000=0GP00`000GP1N00<0GP200060GP00`000GP1N00X0GP0
0`000GP1N00W0GP00`000GP1N00>0GP00`000GP1N0020GP00`000GP1N00N0GP00`000GP1N0060GP0
0`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`0YOol0041oo`080000<P0b0000<P0003800080
<P030001N05h0081N0030001N00000`1N0030001N05h00l1N0030001N05h00<1N0030001N05h02P1
N0030001N05h02L1N0030001N05h00l1N0040001N05h000P0GP00`000GP1N0070GP00`00Oomoo`07
Ool00`00Oomoo`0bOol00`00Oomoo`0YOol0035oo`03001oogoo00aoo`080000<P0b0000<P000380
0080<P030001N05h0081N0040001N05h000:0GP00`000GP1N00A0GP200030GP00`000GP1N00X0GP0
0`000GP1N00W0GP00`000GP1N00@0GP00`000GP0000O0GP00`000GP1N0080GP00`00Oomoo`0lOol0
0`00Oomoo`0YOol0035oo`03001oogoo00aoo`030000<P000080<P030000<P000080<P030001N05h
00D1N0030001N05h00L1N0030001N05h01@1N0040001N05h000Z0GP00`000GP1N00W0GP00`000GP1
N00@0GP2000P0GP00`000GP1N0080GP00`00Oomoo`0lOol00`00Oomoo`0YOol0035oo`03001oogoo
00aoo`030000<P000080<P030000<P000080<P030001N05h00D1N0030001N05h00H1N0030001N05h
01H1N0<002X1N0030001N05h02L1N0030001N05h00`1N0@00081N0030001N05h01`1N0030001N05h
00T1N003001oogoo03aoo`03001oogoo02Uoo`00<Goo00<007ooOol02goo00@0000b03800080<P03
0000<P000080<P030001N05h00D1N0030001N05h00D1N0030001N05h01T1N0/00201N0030001N05h
02L1N0030001N05h00P1N0@000L1N0030001N05h01/1N0030001N05h00T1N003001oogoo00Moo`03
001oogoo039oo`03001oogoo02Uoo`00<Goo00<007ooOol02goo00@0000b03800080<P030000<P00
0080<P030001N05h0081N0050001N05h0GP000050GP00`000GP1N00J0GP00`000GP1N0080GPF000:
0GP00`000GP1N00W0GP00`000GP1N0040GP4000<0GP00`000GP1N00I0GP00`000GP1N00:0GP00`00
Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`0YOol003moo`040000<P0b000203800`0003800002
03800`000GP1N0020GP01@000GP1N05h0000105h00<0005h0GP06`5h00<0005h0GP07P5h7`005@5h
00<0005h0GP010004@5h00<0005h0GP0605h00<0005h0GP02P5h00<007ooOol01goo00<007ooOol0
<Goo0`00:Woo000oOol010000380<P000P0b00<0000b00000P0b00D0005h0GP1N00000@1N0050001
N05h0GP0000N0GP00`000GP1N00X0GP00`000GP1N00B0GPH000F0GP00`000GP1N00F0GP00`000GP1
N00;0GP00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`0YOol003moo`040000<P0b00020380
0`000380000203801@000GP1N05h0000105h00@0005h0GP001l1N0030001N05h02P1N0030001N05h
02L1N0030001N05h01H1N0030001N05h01D1N0030001N05h00`1N003001oogoo00Moo`03001oogoo
039oo`8002Yoo`00<Goo00<007ooOol02goo00@0000b03800080<P030000<P000080<P030001N05h
00L1N0800201N0030001N05h02P1N0030001N05h02L1N0030001N05h01L1N0030001N05h01@1N003
0001N05h00`1N003001oogoo03aoo`8002Yoo`00<Goo00<007ooOol02goo00@0000b03800080<P03
0000<P000080<P030001N05h00L1N0030001N05h01l1N0030001N05h02P1N0030001N05h02L1N003
0001N05h01P1N0030001N05h0181N0030001N05h00d1N003001oogoo03aoo`03001oogoo02Uoo`00
<Goo00<007ooOol02goo00@0000b03800080<P030000<P000080<P030001N05h00H1N0040001N000
000O0GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N00I0GP00`000GP1N00A0GP00`000GP1
N00=0GP00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`0YOol0035oo`03001oogoo00]oo`04
0000<P0b000203800`000380000203801@000GP1N05h00000`5h00<0005h0GP00P5h00<0005h0GP0
705h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP06P5h00<0005h0GP03`5h00<0005h0GP0
3P5h00<007ooOol01goo00<007ooOol0<Woo00<007ooOol0:Goo000oOol010000380<P000P0b00<0
000b00000P0b00D0005h0GP1N0000081N0030001N05h00@1N08001`1N0030001N05h02P1N0030001
N05h02L1N0030001N05h01/1N0030001N05h00d1N0030001N05h00l1N003001oogoo00Moo`03001o
ogoo039oo`8002Yoo`00?goo00@0000b03800080<P030000<P000080<P070001N05h0GP0005h0000
2@5h00<0005h0GP06@5h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP0705h00<0005h0GP0
305h00<0005h0GP03`5h00<007ooOol01goo00<007ooOol0<Woo0P00:Woo000oOol010000380<P00
0P0b00<0000b00000P0b00@0005h0GP1N08000/1N08001T1N0030001N05h02P1N0030001N05h02L1
N0030001N05h01d1N0030001N05h00X1N0030001N05h0101N003001oogoo00Moo`03001oogoo039o
o`8002Yoo`00<Goo00<007ooOol02goo00@0000b03800080<P030000<P000080<P030001N05h0080
00h1N08001L1N0030001N05h02P1N0030001N05h02L1N0030001N05h01h1N0030001N05h00T1N003
0001N05h0101N003001oogoo03eoo`03001oogoo02Qoo`00<Goo00<007ooOol02goo00@0000b0380
0080<P030000<P000080<P030001N0000181N0030001N05h01@1N0030001N05h02P1N0030001N05h
02L1N0030001N05h01l1N0030001N05h00L1N0030001N05h0141N003001oogoo03]oo`<002Yoo`00
<Goo00<007ooOol02goo00@0000b03800080<P030000<P000080<P8001@1N08001@1N0030001N05h
02P1N0030001N05h02L1N0030001N05h0201N0030001N05h00H1N0030001N05h0141N003001oogoo
03eoo`03001oogoo02Qoo`00<Goo00<007ooOol02goo00@0000b03800080<P030000<P000080<P03
0001N05h01D1N0030001N05h0141N0030001N05h02P1N0030001N05h02L1N0030001N05h0201N003
0001N05h00D1N0030001N05h0181N003001oogoo00Moo`03001oogoo03=oo`03001oogoo02Qoo`00
<Goo00<007ooOol02goo00@0000b03800080<P030000<P0000<000<1N0030001N05h0181N0800141
N0030001N05h02P1N0030001N05h02L1N0030001N05h0241N0030001N05h00<1N0030001N05h01<1
N003001oogoo00Moo`03001oogoo03=oo`03001oogoo02Qoo`00?goo00@0000b03800080<P030000
<P000080<P050001N05h0GP0000F0GP00`000GP1N00>0GP00`000GP1N00X0GP00`000GP1N00W0GP0
0`000GP1N00R0GP00`000GP1N0020GP00`000GP1N00C0GP00`00Oomoo`07Ool00`00Oomoo`0cOol0
0`00Oomoo`0XOol003moo`040000<P0b00020383000203801@000GP1N05h00005`5h0P003P5h00<0
005h0GP0:05h00<0005h0GP09`5h00<0005h0GP08`5h00@0005h0GP001H1N003001oogoo00Qoo`03
001oogoo039oo`03001oogoo02Qoo`00?goo00<0000b0380100000D0<P000380<P0000<1N0030001
N05h01L1N0030001N05h00/1N0030001N05h02P1N0030001N05h02L1N0030001N05h02@1N0030001
N00001H1N003001oogoo00Qoo`03001oogoo039oo`03001oogoo02Qoo`00<7oo00<007ooOol037oo
00@0000b00000080<P030000<P000080<P030001N05h01`1N08000/1N0030001N05h02P1N0030001
N05h02L1N0030001N05h02@1N08001L1N003001oogoo03eoo`03001oogoo02Qoo`00<7oo00<007oo
Ool037oo0P0000L0<P000380<P000380000203800`000GP1N00N0GP00`000GP1N0080GP00`000GP1
N00X0GP00`000GP1N00W0GP00`000GP1N00P0GP400020GP00`000GP1N00D0GP00`00Oomoo`0mOol0
0`00Oomoo`0XOol0031oo`03001oogoo00aoo`040000<P0b000203800`000380000203800`000GP1
N00O0GP200080GP00`000GP1N00X0GP00`000GP1N00W0GP00`000GP1N00L0GP400070GP00`000GP1
N00C0GP00`00Oomoo`08Ool00`00Oomoo`0bOol00`00Oomoo`05Ool30003Ool30003Ool3000DOol0
031oo`03001oogoo00aoo`040000<P0b000203800`000380000203801@000GP1N05h00007`5h0P00
1P5h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP0605h1000305h00<0005h0GP04P5h00<0
07ooOol027oo00<007ooOol0<Woo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001oo`0000=o
o`03001oogoo015oo`00?goo00H0000b0380000b0002038010000380<P000`5h00<0005h0GP07`5h
00<0005h0GP00`5h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP0505h10004@5h00<0005h
0GP04@5h00<007ooOol027oo00<007ooOol0<7oo0`0027oo00D007ooOomoo`0000=oo`03001oo`00
00=oo`03001oogoo015oo`00?goo00H0000b0380000b0002038010000380<P000`5h00<0005h0GP0
805h0P000`5h00<0005h0GP0:05h00<0005h0GP09`5h00<0005h0GP0405h10005P5h00<0005h0GP0
405h00<007ooOol027oo00<007ooOol0<Woo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001o
o`0000=oo`03001oogoo015oo`00?goo00H0000b0380000b000203800`000380<P0;000N0GP01000
0GP1N000:P5h00<0005h0GP09`5h00<0005h0GP0305h10006`5h00<0005h0GP03`5h00<007ooOol0
27oo00<007ooOol0<Woo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001o
ogoo015oo`00<7oo00<007ooOol037oo00H0000b0380000b0002038300040Ml00`000Ml1g`0J0009
0GP3000Z0GP00`000GP1N00W0GP00`000GP1N0080GP4000P0GP00`000GP1N00>0GP00`00Oomoo`0m
Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol04Goo000`Ool0
0`00Oomoo`0<Ool01`000380<P000380000b01L000D1g`<000<1gb@001D1N0030001N05h02L1N003
0001N05h00@1N0@002D1N0030001N05h00d1N003001oogoo03eoo`03001oogoo00Ioo`05001oogoo
Ool00003Ool00`00Ool00003Ool00`00Oomoo`0AOol0031oo`03001oogoo00aoo`050000<P0b0000
<P0200050Ml00`000Ml1g`0?0MlH000;0Ml300030Ml400020MlZ000E0GP00`000GP1N004000Z0GP0
0`000GP1N00<0GP00`00Oomoo`0mOol00`00Oomoo`05Ool20003Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo015oo`00<7oo00<007ooOol037oo00<0000b03800P000`7O00<0007O0Ml01@7O2`00
5`7O0P005@7O80000`7O1@000P7O9P009@5h00<0005h0GP02`5h00<007ooOol027oo00<007ooOol0
<Woo00<007ooOol01Woo00<007ooOol00Woo0`000goo0`0057oo000`Ool00`00Oomoo`0<Ool00`00
0380000E000>0MlP000F0Ml2000;0MlE00040Ml500030Ml400030Ml500030MlJ000<0GP00`000GP1
N00:0GP00`00Oomoo`08Ool00`00Oomoo`0bOol00`00Oomoo`0XOol003mooaD000<1gbX000@1gbX0
00h1g``001H1g`D000<1g`@000<1gah000Yoo`03001oogoo039oo`03001oogoo02Qoo`00E7oo8000
3@7O:P00107O5`006`7O8@000P7O1`0000=oo`0000000`000Woo1@000goo0P00;Woo00<007ooOol0
:7oo000`Ool00`00Oomoo`0=Ool2000bOolB000>0Ml2000E0MlG000>0MlJ000>0Ml200070Ml8000=
Ool00`00Oomoo`04Ool20003Ool50003Ool40003Ool50003Ool2000=Ool01000Oomoo`00:Woo000`
Ool00`00Oomoo`0:Ool30019OolN000F0Ml2000=0MlI00050MlK000fOol20003Ool50002Ool5000Z
Ool0031oo`03001oogoo07AooaH002P1ga`0049oo`03001oo`0000@002aoo`00<7oo00<007ooOol0
1goo00<007ooOol0Ugoo7`00207O0P006Goo00<007ooOol09Woo00<007oo00000`00<Goo000`Ool0
0`00Oomoo`05Ool2002iOol8000KOol00`00Oomoo`0ROol00`00Ool00005000cOol003Moo`03001o
ogoo0=aoo`03001oogoo01ioo`03001oo`0000@003Qoo`00<goo00<007ooOol0h7oo00<007ooOol0
5Woo00@007ooOomoo`T003Yoo`00<Goo0P00hgoo00<007ooOol05Woo00<007oo00000`00@Goo000`
Ool50002Ool50003Ool5003WOol00`00Ool000030015Ool004Ioo`D000=oo`D0009oo`D000=oo`@0
00=oo`800<9oo`D004Uoo`00IWoo0`000goo10000goo1@000goo10000goo1@000Woo0P00TGoo00D0
07ooOomoo`0000=oo`D004eoo`00Rgoo0`000goo1@000Woo1@000goo1@000Woo1@00JWoo00<007oo
Ool00goo00@007ooOomoo`H0051oo`00[goo10000goo1@000goo10000goo1@000goo0P00Agoo00@0
07ooOol0009oo`D005Eoo`00cgoo0P000goo1@000goo10000goo1@000Woo1@000goo0P008Woo00<0
07ooOol01P007goo0`0017oo0`00;Woo003dOol30002Ool50003Ool50002Ool50003Ool40002Ool4
000WOol01000Oomoo`000goo00<007ooOol0:goo003oOom3Ool00`00Ool00003Ool00`00Oomoo`0[
Ool00?mood=oo`03001oo`0000=oo`03001oogoo02]oo`00ogoo@goo00<007oo00000goo00<007oo
Ool0:goo003oOol^Ool3000AOol01000Oomoo`000goo00<007ooOol0:goo003oOol]Ool01@00Oomo
ogoo00003Woo0P000goo00D007ooOomoo`0002eoo`00ogoo;Goo00D007ooOomoo`0000ioo`03001o
ogoo009oo`05001oogooOol0000]Ool00?moobeoo`05001oogooOol0000?Ool30002Ool3000^Ool0
0?moobeoo`05001oogooOol00015Ool00?mooaaoo`<000Aoo`<000Moo`05001oogooOol00015Ool0
0?mooamoo`04001oogoo0003Ool00`00Oomoo`04Ool01@00Oomoogoo0000AGoo003oOolPOol00`00
Ool00003Ool00`00Oomoo`04Ool01@00Oomoogoo0000AGoo003oOolDOol70005Ool00`00Ool00003
Ool00`00Oomoo`05Ool30016Ool00?moob1oo`03001oo`0000=oo`03001oogoo04ioo`00ogoo7goo
00@007ooOol000=oo`03001oogoo04ioo`00ogoo7Goo0P000goo00D007ooOomoo`00051oo`00ogoo
7Goo00<007ooOol00Woo00D007ooOomoo`00051oo`00ogoo7Woo0`000Woo0`00DGoo003oOomgOol0
0?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogoo
Mgoo003oOol[Ool30002Ool30014Ool00?moobaoo`03001oogoo009oo`03001oogoo04=oo`00ogoo
;Goo00@007ooOol004Ioo`00ogoo;Woo0P00Agoo003oOol_Ool00`00Oomoo`15Ool00?moobioo`80
04Moo`00ogoo;Goo00@007ooOol004Ioo`00ogoo;7oo00<007ooOol00Woo00<007ooOol0@goo003o
Ool[Ool30002Ool30014Ool00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003o
OomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMo
o`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00ogooMgoo003o
OomgOol00?moogMoo`00ogooMgoo003oOomgOol00?moogMoo`00\
\>"],
  ImageRangeCache->{{{0, 373}, {373, 0}} -> {-5.00005*^-06, -5.00005*^-06, 
  0.00268099, 0.00268099}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetic Field Plots ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here are a few plots of field and field integrals in the gap. Note that \
the plot is made by calling  \"radFldLst \" followed by a \"ListPlot\". The \
same result can be obtained by calling \"radFld\" followed by \"Plot\" but it \
would be significantly slower because of the large number of  calls made to  \
Mathlink . The mathlink protocol used by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is responsible  for the data exchange between the Kernel and Radia.exe \
processes. It is rather slow (dependening on platforms).  It is also much \
easier to control the number of points  used in the graphichs when calling \
\"radFldLst\" rather than \"radFld\". Each graph corresponds to the field \
created by the whole steerer. It is possible to compute separately the \
contribution from the coil or from the iron. To do so, one simply needs to \
replace ob=t by ob=coil or ob=g. It is also possible to compute the \
contribution from each part of the iron circuit g1,g2...g6. To do so,  one \
would use ob=g1 or ob=g2 etc.. However, one should remember that the \
symmetries has been assigned to the container g and not to each element \
g1,g2..g6 therefore the field from each element must be multiplied by 2 x 2 = \
4. One should remember that even though the field  from the whole steerer is \
the sum of the field from the coil + 4 times the field from g1+g2+...g6,  the \
magnetization of any element gi depends on the magnetization of all the other \
elements. It is nevertheless quite interesting to see which part of the \
magnetized iron circuit contributes the most to the field in the gap and what \
is its field gradient. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ob = t; y = 1; z = 1; xmax = 30; Nn = 40; \nRadPlotOptions[\ ]; \n
    bz = radFldLst[ob, "\<Bz\>", {\(-xmax\), y, z}, {xmax, y, z}, Nn, 
        "\<arg\>", \(-xmax\)]; \n
    ListPlot[\ bz, PlotJoined \[Rule] True, \n
      FrameLabel
         -> {"\<X [mm]\>", "\<Bz [T]\>", "\<Y = 1 mm, Z = 1 mm\>", "\<\>"}]; 
    \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.015873 -0.244631 3.23324 [
[.02381 -0.0125 -12.5 -15 ]
[.02381 -0.0125 12.5 0 ]
[.18254 -0.0125 -12.5 -15 ]
[.18254 -0.0125 12.5 0 ]
[.34127 -0.0125 -12.5 -15 ]
[.34127 -0.0125 12.5 0 ]
[.5 -0.0125 -5 -15 ]
[.5 -0.0125 5 0 ]
[.65873 -0.0125 -8 -15 ]
[.65873 -0.0125 8 0 ]
[.81746 -0.0125 -8 -15 ]
[.81746 -0.0125 8 0 ]
[.97619 -0.0125 -8 -15 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.5 -30 ]
[.5 -0.0125 21.5 -15 ]
[-0.0125 .07869 -19 -7.5 ]
[-0.0125 .07869 0 7.5 ]
[-0.0125 .15952 -31 -7.5 ]
[-0.0125 .15952 0 7.5 ]
[-0.0125 .24035 -25 -7.5 ]
[-0.0125 .24035 0 7.5 ]
[-0.0125 .32119 -31 -7.5 ]
[-0.0125 .32119 0 7.5 ]
[-0.0125 .40202 -19 -7.5 ]
[-0.0125 .40202 0 7.5 ]
[-0.0125 .48285 -31 -7.5 ]
[-0.0125 .48285 0 7.5 ]
[-0.0125 .56368 -25 -7.5 ]
[-0.0125 .56368 0 7.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -67 -7.5 ]
[-0.01875 .30902 -31 7.5 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -54.5 0 ]
[.5 .63053 54.5 15 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.00264 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .07869 m
1 .07869 L
s
0 .15952 m
1 .15952 L
s
0 .24035 m
1 .24035 L
s
0 .32119 m
1 .32119 L
s
0 .40202 m
1 .40202 L
s
0 .48285 m
1 .48285 L
s
0 .56368 m
1 .56368 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(30) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.5 -34 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.625000 moveto
(@) show
78.562500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.312500 14.625000 moveto
(D) show
101.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
0 .07869 m
.00625 .07869 L
s
gsave
-0.0125 .07869 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .15952 m
.00625 .15952 L
s
gsave
-0.0125 .15952 -92 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.125) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .24035 m
.00625 .24035 L
s
gsave
-0.0125 .24035 -86 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .32119 m
.00625 .32119 L
s
gsave
-0.0125 .32119 -92 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.175) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .40202 m
.00625 .40202 L
s
gsave
-0.0125 .40202 -80 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .48285 m
.00625 .48285 L
s
gsave
-0.0125 .48285 -92 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.225) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .56368 m
.00625 .56368 L
s
gsave
-0.0125 .56368 -86 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .01403 m
.00375 .01403 L
s
0 .03019 m
.00375 .03019 L
s
0 .04636 m
.00375 .04636 L
s
0 .06253 m
.00375 .06253 L
s
0 .09486 m
.00375 .09486 L
s
0 .11103 m
.00375 .11103 L
s
0 .12719 m
.00375 .12719 L
s
0 .14336 m
.00375 .14336 L
s
0 .17569 m
.00375 .17569 L
s
0 .19186 m
.00375 .19186 L
s
0 .20802 m
.00375 .20802 L
s
0 .22419 m
.00375 .22419 L
s
0 .25652 m
.00375 .25652 L
s
0 .27269 m
.00375 .27269 L
s
0 .28885 m
.00375 .28885 L
s
0 .30502 m
.00375 .30502 L
s
0 .33735 m
.00375 .33735 L
s
0 .35352 m
.00375 .35352 L
s
0 .36968 m
.00375 .36968 L
s
0 .38585 m
.00375 .38585 L
s
0 .41818 m
.00375 .41818 L
s
0 .43435 m
.00375 .43435 L
s
0 .45052 m
.00375 .45052 L
s
0 .46668 m
.00375 .46668 L
s
0 .49901 m
.00375 .49901 L
s
0 .51518 m
.00375 .51518 L
s
0 .53135 m
.00375 .53135 L
s
0 .54751 m
.00375 .54751 L
s
0 .57984 m
.00375 .57984 L
s
0 .59601 m
.00375 .59601 L
s
0 .61218 m
.00375 .61218 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -128 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
79.312500 14.625000 moveto
(@) show
83.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 14.625000 moveto
(D) show
94.500000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -115.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
85.437500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
94.437500 14.625000 moveto
(mm) show
113.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
119.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
129.375000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
140.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
149.187500 14.625000 moveto
(mm) show
167.937500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.99375 .07869 m
1 .07869 L
s
.99375 .15952 m
1 .15952 L
s
.99375 .24035 m
1 .24035 L
s
.99375 .32119 m
1 .32119 L
s
.99375 .40202 m
1 .40202 L
s
.99375 .48285 m
1 .48285 L
s
.99375 .56368 m
1 .56368 L
s
.125 Mabswid
.99625 .01403 m
1 .01403 L
s
.99625 .03019 m
1 .03019 L
s
.99625 .04636 m
1 .04636 L
s
.99625 .06253 m
1 .06253 L
s
.99625 .09486 m
1 .09486 L
s
.99625 .11103 m
1 .11103 L
s
.99625 .12719 m
1 .12719 L
s
.99625 .14336 m
1 .14336 L
s
.99625 .17569 m
1 .17569 L
s
.99625 .19186 m
1 .19186 L
s
.99625 .20802 m
1 .20802 L
s
.99625 .22419 m
1 .22419 L
s
.99625 .25652 m
1 .25652 L
s
.99625 .27269 m
1 .27269 L
s
.99625 .28885 m
1 .28885 L
s
.99625 .30502 m
1 .30502 L
s
.99625 .33735 m
1 .33735 L
s
.99625 .35352 m
1 .35352 L
s
.99625 .36968 m
1 .36968 L
s
.99625 .38585 m
1 .38585 L
s
.99625 .41818 m
1 .41818 L
s
.99625 .43435 m
1 .43435 L
s
.99625 .45052 m
1 .45052 L
s
.99625 .46668 m
1 .46668 L
s
.99625 .49901 m
1 .49901 L
s
.99625 .51518 m
1 .51518 L
s
.99625 .53135 m
1 .53135 L
s
.99625 .54751 m
1 .54751 L
s
.99625 .57984 m
1 .57984 L
s
.99625 .59601 m
1 .59601 L
s
.99625 .61218 m
1 .61218 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 -0.00214 m
1 -0.00214 L
s
.5 0 m
.5 .61803 L
s
.002 w
.02381 .01472 m
.04823 .04872 L
.07265 .08867 L
.09707 .13563 L
.12149 .19081 L
.14591 .25526 L
.17033 .32926 L
.19475 .41059 L
.21917 .49106 L
.24359 .5553 L
.26801 .59183 L
.29243 .60332 L
.31685 .60069 L
.34127 .5943 L
.36569 .58907 L
.39011 .5861 L
.41453 .58533 L
.43895 .58632 L
.46337 .58822 L
.48779 .58979 L
.51221 .58979 L
.53663 .58822 L
.56105 .58632 L
.58547 .58533 L
.60989 .5861 L
.63431 .58907 L
.65873 .5943 L
.68315 .60069 L
.70757 .60332 L
.73199 .59183 L
.75641 .5553 L
.78083 .49106 L
.80525 .41059 L
.82967 .32926 L
.85409 .25526 L
.87851 .19081 L
.90293 .13563 L
.92735 .08867 L
.95177 .04872 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{412, 254.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006L0000oQ000`40O003h00OogooWGoo003oOonM
Ool00?mooieoo`00jWoo0`0057oo0`00V7oo003ZOol00`00Oomoo`0FOol00`00Oomoo`2FOol00=io
o`<0009oo`<000Aoo`03001oogoo00<00004Ool00000Ool5000017oo000007oo0P0017oo00<007oo
Ool0UWoo003OOol00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`2FOol00>1oo`04001oogoo0006Ool0
1@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomo
o`2FOol00>5oo`8000Moo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo09Ioo`00hWoo00<007ooOol01Goo00@007ooOomoo`800005Ool00000
Ool00002Ool200001Goo000007oo00001Goo00<007ooOol0UWoo003QOol20007Ool00`00Oomoo`02
00001Goo001oogoo00000Woo0P0000Eoo`00Oomoo`0000Ioo`03001oogoo09Ioo`00h7oo00@007oo
Ool000Ioo`03001oogoo01Ioo`03001oogoo09Ioo`00ggoo00<007ooOol00Woo00<007ooOol00goo
0`0057oo0`00V7oo003NOol30002Ool3002fOol00?mooieoo`00ogooWGoo003oOonMOol00?mooieo
o`00ogooWGoo003oOonMOol005Eoo`@000=oo`<002Uoo`D0009oo`<002]oo`<000=oo`<002Uoo`<0
02ioo`<000=oo`<002Uoo`D0009oo`<002Yoo`@000=oo`<000aoo`00FGoo00<007oo00000goo00<0
07ooOol09goo00H007ooOol007oo0003Ool00`00Oomoo`0YOol01@00Oomoogoo00000goo00<007oo
Ool09Goo00D007ooOomoo`0002ioo`05001oogooOol00003Ool00`00Oomoo`0WOol01P00Oomoo`00
Ool000=oo`03001oogoo02]oo`03001oo`0000=oo`03001oogoo00Uoo`00FGoo00<007oo00000goo
00<007ooOol0:7oo00D007ooOomoo`0000=oo`03001oogoo02Uoo`05001oogooOol00003Ool00`00
Oomoo`0UOol01@00Oomoogoo0000;Woo00D007ooOomoo`0000=oo`03001oogoo02Qoo`05001oogoo
Ool00003Ool00`00Oomoo`0[Ool00`00Ool00003Ool00`00Oomoo`09Ool004ioo`L000Aoo`03001o
o`0000=oo`03001oogoo01moo`L000=oo`04001oogoo0003Ool00`00Oomoo`0OOol70003Ool01@00
Oomoogoo00000goo00<007ooOol09Goo00D007ooOomoo`0002ioo`05001oogooOol00003Ool00`00
Oomoo`0YOol01000Oomoo`000goo00<007ooOol0:goo00<007oo00000goo00<007ooOol02Goo001G
Ool20002Ool01@00Oomoogoo0000;7oo00<007oo00000goo00<007ooOol0:Goo00D007ooOomoo`00
00=oo`03001oogoo02Eoo`05001oogooOol0000^Ool01@00Oomoogoo00000goo00<007ooOol0:Woo
00<007oo00000goo00<007ooOol0:Goo0P000Woo00D007ooOomoo`0000]oo`00F7oo00@007ooOol0
00=oo`03001oogoo02Yoo`03001oo`0000=oo`03001oogoo02Uoo`05001oogooOol00003Ool00`00
Oomoo`0UOol01@00Oomoogoo0000;Woo00D007ooOomoo`0000=oo`03001oogoo02Yoo`03001oo`00
00=oo`03001oogoo02Yoo`04001oogoo0003Ool00`00Oomoo`09Ool005Uoo`03001oo`0000=oo`03
001oogoo02Yoo`03001oo`0000=oo`03001oogoo02Uoo`05001oogooOol00003Ool00`00Oomoo`0U
Ool01@00Oomoogoo0000;Woo00D007ooOomoo`0000=oo`03001oogoo02Yoo`03001oo`0000=oo`03
001oogoo02]oo`03001oo`0000=oo`03001oogoo00Uoo`00EGoo00L007ooOomoo`00Ool00003Ool0
0`00Oomoo`0VOol01`00Oomoogoo001oo`0000=oo`03001oogoo02Qoo`8000=oo`05001oogooOol0
000WOol01@00Oomoogoo0000;Goo0P000goo00D007ooOomoo`0002Qoo`07001oogooOol007oo0000
0goo00<007ooOol09goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`09Ool005Ioo`<000=oo`<0
02Yoo`<000=oo`<002aoo`03001oogoo009oo`<002Uoo`<002moo`03001oogoo009oo`<002Yoo`<0
00=oo`<002]oo`<000=oo`<000aoo`00ogooWGoo003oOonMOol00?mooieoo`00ogooWGoo001?Oooo
00160008Ool004moool004H000Qoo`00Cgoo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0
1Woo001?Ool00`00Oomoo`05Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol00`00Oomoo`0`Ool00`00
Oomoo`0aOol00`00Oomoo`0`Ool00`00Oomoo`0aOol00`00Oomoo`04Ool00`00Oomoo`06Ool004mo
o`03001oogoo03Qoo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031o
o`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<03gooOol0<Goo00<03goo
Ool0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol0>7oo00<007ooOol01Woo001?Ool3
0005Ool00`00Oomoo`0`Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomo
o`0`Ool00`0?Oomoo`0aOol00`00Oomoo`03Ool20008Ool004moo`03001oogoo00Ioo`03001oogoo
02moo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo
031oo`03001oogoo00Eoo`03001oogoo00Ioo`00Cgoo00<007ooOol01Woo00<007ooOol0;goo00<0
3gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol0<7oo00<0
07ooOol01Goo00<007ooOol01Woo001?Ool00`00Oomoo`07Ool00`00Oomoo`0^Ool00`0?Oomoo`0a
Ool00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0_Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool004moo`03001oogoo00Qoo`03001oogoo02eoo`0300moogoo035oo`0300mo
ogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo02ioo`03001oogoo00Moo`03001o
ogoo00Ioo`00Cgoo0`002Goo00<007ooOol0;7oo00<03gooOol0<Goo00<03gooOol0<7oo00<007oo
Ool0<Goo00<03gooOol0<7oo00<03gooOol0;Goo00<007ooOol01goo0P0027oo001?Ool00`00Oomo
o`09Ool00`00Oomoo`0/Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomo
o`0`Ool00`0?Oomoo`0]Ool00`00Oomoo`08Ool00`00Oomoo`06Ool004moo`03001oogoo00Yoo`03
001oogoo02]oo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`03
00moogoo02aoo`03001oogoo00Uoo`03001oogoo00Ioo`00Cgoo00<007ooOol02goo00<007ooOol0
:Woo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol0
:goo00<007ooOol02Woo00<007ooOol01Woo001?Ool00`00Oomoo`0<Ool00`00Oomoo`0YOol00`0?
Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0ZOol00`00
Oomoo`0;Ool00`00Oomoo`06Ool004moo`<000aoo`03001oogoo02Uoo`0300moogoo035oo`0300mo
ogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo02Yoo`03001oogoo00Yoo`8000Qo
o`00Cgoo00<007ooOol03Goo00<007ooOol0:7oo00<03gooOol0<Goo00<03gooOol0<7oo00<007oo
Ool0<Goo00<03gooOol0<7oo00<03gooOol0:Goo00<007ooOol037oo00<007ooOol01Woo001?Ool0
0`00Oomoo`0>Ool00`00Oomoo`0WOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol0
0`0?Oomoo`0`Ool00`0?Oomoo`0XOol00`00Oomoo`0=Ool00`00Oomoo`06Ool004moo`03001oogoo
00ioo`03001oogoo02Moo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo
031oo`0300moogoo02Qoo`03001oogoo00eoo`03001oogoo00Ioo`00Cgoo00<007ooOol03goo00<0
07ooOol09Woo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<0
3gooOol09goo00<007ooOol03Woo00<007ooOol01Woo001?Ool3000?Ool00`00Oomoo`0VOol00`0?
Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0WOol00`00
Oomoo`0=Ool20008Ool004moo`03001oogoo011oo`03001oogoo02Eoo`0300moogoo035oo`0300mo
ogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo02Ioo`03001oogoo00moo`03001o
ogoo00Ioo`00Cgoo00<007ooOol04Goo00<007ooOol097oo00<03gooOol0<Goo00<03gooOol0<7oo
00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol09Goo00<007ooOol047oo00<007ooOol01Woo
000kOol30003Ool00`00Oomoo`030008Ool00`00Oomoo`0AOol00`00Oomoo`0TOol00`0?Oomoo`0a
Ool00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0UOol00`00Oomoo`0@
Ool00`00Oomoo`06Ool003Yoo`05001oogooOol00006Ool00`00Oomoo`07Ool00`00Oomoo`0BOol0
0`00Oomoo`0SOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool0
0`0?Oomoo`0TOol00`00Oomoo`0AOol00`00Oomoo`06Ool003Yoo`05001oogooOol00006Ool00`00
Oomoo`07Ool00`00Oomoo`0COol00`00Oomoo`0ROol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00
Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0SOol00`00Oomoo`0BOol00`00Oomoo`06Ool003Yo
o`05001oogooOol00006Ool00`00Oomoo`07Ool3000C00l00`0000l03`2900l00`0000l03`2:00l0
0`0000l03`0@00l30008Ool003Yoo`05001oogooOol00006Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`0QOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`
Ool00`0?Oomoo`0ROol00`00Oomoo`0COol00`00Oomoo`06Ool003Yoo`05001oogooOol00006Ool0
0`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`0QOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool0
0`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0ROol00`00Oomoo`0COol00`00Oomoo`06Ool0
03Yoo`05001oogooOol00006Ool00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`0POol00`0?
Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0QOol00`00
Oomoo`0DOol00`00Oomoo`06Ool003Yoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0FOol0
0`00Oomoo`0OOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool0
0`0?Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`06Ool003]oo`<000Moo`03001oogoo00Moo`<0
01Ioo`03001oogoo01moo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo
031oo`0300moogoo021oo`03001oogoo01Aoo`8000Qoo`00Cgoo00<007ooOol05goo00<007ooOol0
7Woo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol0
7goo00<007ooOol05Woo00<007ooOol01Woo001?Ool00`00Oomoo`0GOol00`00Oomoo`0NOol00`0?
Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0OOol00`00
Oomoo`0FOol00`00Oomoo`06Ool004moo`03001oogoo01Qoo`03001oogoo01eoo`0300moogoo035o
o`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo01ioo`03001oogoo01Mo
o`03001oogoo00Ioo`00Cgoo00<007ooOol067oo00<007ooOol07Goo00<03gooOol0<Goo00<03goo
Ool0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol07Woo00<007ooOol05goo00<007oo
Ool01Woo001?Ool3000IOol00`00Oomoo`0LOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomo
o`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0MOol00`00Oomoo`0GOol20008Ool004moo`03001oogoo
01Uoo`03001oogoo01aoo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo
031oo`0300moogoo01eoo`03001oogoo01Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol06Woo00<0
07ooOol06goo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<0
3gooOol077oo00<007ooOol06Goo00<007ooOol01Woo001?Ool00`00Oomoo`0JOol00`00Oomoo`0K
Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0L
Ool00`00Oomoo`0IOol00`00Oomoo`06Ool004moo`03001oogoo01]oo`03001oogoo01Yoo`0300mo
ogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo01]oo`03001o
ogoo01Yoo`03001oogoo00Ioo`00Cgoo0`006goo00<007ooOol06Woo00<03gooOol0<Goo00<03goo
Ool0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol06goo00<007ooOol06Goo0P0027oo
001?Ool00`00Oomoo`0LOol00`00Oomoo`0IOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomo
o`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`06Ool004moo`03
001oogoo01aoo`03001oogoo01Uoo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`03
00moogoo031oo`0300moogoo01Yoo`03001oogoo01]oo`03001oogoo00Ioo`00Cgoo00<007ooOol0
7Goo00<007ooOol067oo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0
<7oo00<03gooOol06Goo00<007ooOol077oo00<007ooOol01Woo001?Ool00`00Oomoo`0MOol00`00
Oomoo`0HOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?
Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`06Ool004moo`03001oogoo01ioo`03001oogoo01Mo
o`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo01Qo
o`03001oogoo01eoo`03001oogoo00Ioo`00Cgoo0`007Woo00<007ooOol05goo00<03gooOol0<Goo
00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol067oo00<007ooOol077oo
0P0027oo001?Ool00`00Oomoo`0OOol00`00Oomoo`0FOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool0
0`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0GOol00`00Oomoo`0NOol00`00Oomoo`06Ool0
04moo`03001oogoo01moo`03001oogoo01Ioo`0300moogoo035oo`0300moogoo031oo`03001oogoo
035oo`0300moogoo031oo`0300moogoo01Moo`03001oogoo01ioo`03001oogoo00Ioo`00;goo0`00
0goo00<007ooOol00`000Woo1@0000Aoo`00000000Uoo`03001oogoo021oo`03001oogoo01Eoo`03
00moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo01Ioo`03
001oogoo01moo`03001oogoo00Ioo`00;Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`06Ool00`00Oomoo`0POol00`00Oomoo`0EOol00`0?Oomoo`0aOol00`0?
Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0FOol00`00Oomoo`0OOol00`00
Oomoo`06Ool002ioo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool3000Q00l00`0000l03`1k00l00`0000l03`1l00l00`0000l03`0N00l30008Ool002ioo`05
001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0Q
Ool00`00Oomoo`0DOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`
Ool00`0?Oomoo`0EOol00`00Oomoo`0POol00`00Oomoo`06Ool002ioo`05001oogooOol00006Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0QOol00`00Oomoo`0DOol0
0`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0EOol0
0`00Oomoo`0POol00`00Oomoo`06Ool002ioo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Oomoo`0COol00`0?Oomoo`0aOol00`0?
Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0DOol00`00Oomoo`0QOol00`00
Oomoo`06Ool002ioo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`020009Ool00`00
Oomoo`0ROol00`00Oomoo`0COol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?
Oomoo`0`Ool00`0?Oomoo`0DOol00`00Oomoo`0QOol00`00Oomoo`06Ool002ioo`05001oogooOol0
0005Ool20003Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`008goo00<007ooOol04Woo00<0
3gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol04goo00<0
07ooOol08Goo0P0027oo000_Ool30007Ool00`00Oomoo`02Ool30004Ool30007Ool00`00Oomoo`0S
Ool00`00Oomoo`0BOol00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`
Ool00`0?Oomoo`0COol00`00Oomoo`0ROol00`00Oomoo`06Ool004moo`03001oogoo02Aoo`03001o
ogoo015oo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300mo
ogoo019oo`03001oogoo02=oo`03001oogoo00Ioo`00Cgoo00<007ooOol097oo00<007ooOol04Goo
00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol04Woo
00<007ooOol08goo00<007ooOol01Woo001?Ool00`00Oomoo`0UOol00`00Oomoo`0@Ool00`0?Oomo
o`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0AOol00`00Oomo
o`0TOol00`00Oomoo`06Ool004moo`<002Eoo`03001oogoo011oo`0300moogoo035oo`0300moogoo
031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo015oo`03001oogoo02=oo`8000Qoo`00
Cgoo00<007ooOol09Goo00<007ooOol047oo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0
<Goo00<03gooOol0<7oo00<03gooOol04Goo00<007ooOol097oo00<007ooOol01Woo001?Ool00`00
Oomoo`0VOol00`00Oomoo`0?Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?
Oomoo`0`Ool00`0?Oomoo`0@Ool00`00Oomoo`0UOol00`00Oomoo`06Ool004moo`03001oogoo02Io
o`03001oogoo00moo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031o
o`0300moogoo011oo`03001oogoo02Eoo`03001oogoo00Ioo`00Cgoo00<007ooOol09goo00<007oo
Ool03Woo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03goo
Ool03goo00<007ooOol09Woo00<007ooOol01Woo001?Ool00`00Oomoo`0WOol00`00Oomoo`0>Ool0
0`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0?Ool0
0`00Oomoo`0VOol00`00Oomoo`06Ool004moo`<002Moo`03001oogoo00ioo`0300moogoo035oo`03
00moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo00moo`03001oogoo02Eoo`80
00Qoo`00Cgoo00<007ooOol0:7oo00<007ooOol03Goo00<03gooOol0<Goo00<03gooOol0<7oo00<0
07ooOol0<Goo00<03gooOol0<7oo00<03gooOol03Woo00<007ooOol09goo00<007ooOol01Woo001?
Ool00`00Oomoo`0XOol00`00Oomoo`0=Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0a
Ool00`0?Oomoo`0`Ool00`0?Oomoo`0>Ool00`00Oomoo`0WOol00`00Oomoo`06Ool004moo`03001o
ogoo02Qoo`03001oogoo00eoo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300mo
ogoo031oo`0300moogoo00ioo`03001oogoo02Moo`03001oogoo00Ioo`00Cgoo00<007ooOol0:Goo
00<007ooOol037oo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo
00<03gooOol03Goo00<007ooOol0:7oo00<007ooOol01Woo001?Ool3000YOol00`00Oomoo`0<Ool0
0`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0=Ool0
0`00Oomoo`0WOol20008Ool004moo`03001oogoo02Yoo`03001oogoo00]oo`0300moogoo035oo`03
00moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo00aoo`03001oogoo02Uoo`03
001oogoo00Ioo`00Cgoo00<007ooOol0:Woo00<007ooOol02goo00<03gooOol0<Goo00<03gooOol0
<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol037oo00<007ooOol0:Goo00<007ooOol0
1Woo000eOol30003Ool00`00Oomoo`030002Ool30009Ool00`00Oomoo`0ZOol00`00Oomoo`0;Ool0
0`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0<Ool0
0`00Oomoo`0YOol00`00Oomoo`06Ool003Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool00`00Oomoo`0[Ool00`00Oomoo`0:Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00
Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0;Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool003Ao
o`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool3000[00l00`0000l03`1a00l0
0`0000l03`1b00l00`0000l03`0X00l30008Ool003Aoo`05001oogooOol00006Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`0[Ool00`00Oomoo`0:Ool00`0?Oomoo`0aOol00`0?Oomoo`0`
Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0;Ool00`00Oomoo`0ZOol00`00Oomoo`06
Ool003Aoo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0/Ool0
0`00Oomoo`09Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool0
0`0?Oomoo`0:Ool00`00Oomoo`0[Ool00`00Oomoo`06Ool003Aoo`05001oogooOol00006Ool00`00
Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool00`00Oomoo`09Ool00`0?Oomoo`0aOol00`0?
Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`0:Ool00`00Oomoo`0[Ool00`00
Oomoo`06Ool003Aoo`05001oogooOol00006Ool00`00Oomoo`02Ool20009Ool00`00Oomoo`0]Ool0
0`00Oomoo`08Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool0
0`0?Oomoo`09Ool00`00Oomoo`0/Ool00`00Oomoo`06Ool003Aoo`05001oogooOol00005Ool20004
Ool00`00Oomoo`08Ool3000]Ool00`00Oomoo`08Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00
Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`09Ool00`00Oomoo`0[Ool20008Ool003Eoo`<000Mo
o`03001oogoo00=oo`<000Moo`03001oogoo02eoo`03001oogoo00Qoo`0300moogoo035oo`0300mo
ogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo00Uoo`03001oogoo02aoo`03001o
ogoo00Ioo`00Cgoo00<007ooOol0;Woo00<007ooOol01goo00<03gooOol0<Goo00<03gooOol0<7oo
00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol027oo00<007ooOol0;Goo00<007ooOol01Woo
001?Ool00`00Oomoo`0^Ool00`00Oomoo`07Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomo
o`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`08Ool00`00Oomoo`0]Ool00`00Oomoo`06Ool004moo`03
001oogoo02ioo`03001oogoo00Moo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`03
00moogoo031oo`0300moogoo00Qoo`03001oogoo02eoo`03001oogoo00Ioo`00Cgoo00<007ooOol0
;goo00<007ooOol01Woo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0
<7oo00<03gooOol01goo00<007ooOol0;Woo00<007ooOol01Woo001?Ool3000_Ool00`00Oomoo`06
Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`07
Ool00`00Oomoo`0]Ool20008Ool004moo`03001oogoo02moo`03001oogoo00Ioo`0300moogoo035o
o`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo00Moo`03001oogoo02io
o`03001oogoo00Ioo`00Cgoo00<007ooOol0<7oo00<007ooOol01Goo00<03gooOol0<Goo00<03goo
Ool0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol01Woo00<007ooOol0;goo00<007oo
Ool01Woo001?Ool00`00Oomoo`0`Ool00`00Oomoo`05Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool0
0`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`06Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool0
04moo`03001oogoo031oo`03001oogoo00Eoo`0300moogoo035oo`0300moogoo031oo`03001oogoo
035oo`0300moogoo031oo`0300moogoo00Ioo`03001oogoo02moo`03001oogoo00Ioo`00Cgoo0`00
<Goo00<007ooOol017oo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0
<7oo00<03gooOol01Goo00<007ooOol0;goo0P0027oo001?Ool00`00Oomoo`0aOol00`00Oomoo`04
Ool00`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`05
Ool00`00Oomoo`0`Ool00`00Oomoo`06Ool001Uoo`<000Uoo`<002Moo`03001oogoo035oo`03001o
ogoo00Aoo`0300moogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300mo
ogoo00Eoo`03001oogoo031oo`03001oogoo00Ioo`006Goo00<007ooOol02goo00<007ooOol09Goo
00<007ooOol0<Woo00<007ooOol00goo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo
00<03gooOol0<7oo00<03gooOol017oo00<007ooOol0<Goo00<007ooOol01Woo0008Ool60002Ool5
0004Ool00`00Oomoo`03Ool30005Ool00`00Oomoo`0UOol00`00Oomoo`0bOol00`00Oomoo`03Ool0
0`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`04Ool0
0`00Oomoo`0aOol00`00Oomoo`06Ool000Uoo`03001oogoo009oo`04001oogoo0002Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0UOol3000bOol00`00Oomoo`03Ool0
0`0?Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`04Ool0
0`00Oomoo`0`Ool20008Ool000Uoo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`0cOol00`00Oomoo`02Ool00`0?Oomoo`0a
Ool00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`03Ool00`00Oomoo`0b
Ool00`00Oomoo`06Ool000Uoo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`0cOol00`00Oomoo`02Ool00`0?Oomoo`0aOol0
0`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`03Ool00`00Oomoo`0bOol0
0`00Oomoo`06Ool000Uoo`D0009oo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool30003Ool00`00Oomoo`030004Ool01000Oomoogoo0`002Goo00<007ooOol0<goo
00<007ooOol00Woo00<03gooOol0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo
00<03gooOol00goo00<007ooOol0<Woo00<007ooOol01Woo0009Ool01@00Oomoogoo00000Woo1@00
17oo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`0000Ioo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo03Aoo`05001oogooOol03`0cOol0
0`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?Oomoo`02Ool00`00Oomoo`0cOol0
0`00Oomoo`06Ool000Uoo`05001oogooOol0000;Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo
0`00=00?00<0000?00l0J00?00<0000?00l0J@0?00<0000?00l0<@0?0`0027oo0009Ool01@00Oomo
ogoo00002goo0`0000Eoo`00Oomoo`00009oo`03001oo`00008000Ioo`05001oogooOol00006Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0dOol01@00Oomoogoo00l0
<goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03gooOol00Woo00<007ooOol0
<goo00<007ooOol01Woo0008Ool5000@Ool7000:Ool01@00Oomoogoo00001Woo00<007ooOol017oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol0=Goo00@007ooOol03c=oo`0300moogoo031o
o`03001oogoo035oo`0300moogoo031oo`0500moogooOol0000fOol00`00Oomoo`06Ool002ioo`05
001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0e
Ool01000Oomoo`0?<goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00D03gooOomo
o`0003Ioo`03001oogoo00Ioo`00;Woo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oogoo
008000Uoo`03001oogoo03Eoo`04001oogoo00lcOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?
Oomoo`0`Ool01@0?Oomoogoo0000=Woo00<007ooOol01Woo000^Ool01@00Oomoogoo00001Goo0P00
0goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<003Ioo`03001oo`0?03=oo`0300moogoo031o
o`03001oogoo035oo`0300moogoo031oo`0400moogoo000fOol20008Ool002moo`<000Moo`03001o
ogoo009oo`@000=oo`<000Moo`03001oogoo03Ioo`03001oo`0?03=oo`0300moogoo031oo`03001o
ogoo035oo`0300moogoo031oo`0400moogoo000gOol00`00Oomoo`06Ool004moo`03001oogoo03Io
o`03001oo`0?03=oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0400moogoo000g
Ool00`00Oomoo`06Ool004moo`03001oogoo03Ioo`03001oo`0?03=oo`0300moogoo031oo`03001o
ogoo035oo`0300moogoo031oo`0300moo`0003Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0=goo
00<0000?Ool0<Woo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<03goo0000>7oo
00<007ooOol01Woo001?Ool00`00Oomoo`0gOol00`0000moo`0bOol00`0?Oomoo`0`Ool00`00Oomo
o`0aOol00`0?Oomoo`0`Ool00`0?Ool0000hOol00`00Oomoo`06Ool004moo`<003Moo`0300003goo
039oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moo`0003Moo`8000Qoo`00
Cgoo00<007ooOol0=goo00<0000?Ool0<Woo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0
<7oo00<03`00Ool0>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0hOol00`00Oomoo`0aOol00`0?
Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`0?001oo`0hOol00`00Oomoo`06Ool004mo
o`03001oogoo03Qoo`03001oogoo035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo031o
o`0300l007oo03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<007ooOol0<Goo00<03goo
Ool0<7oo00<007ooOol0<Goo00<03gooOol0<7oo00<007ooOol0>7oo00<007ooOol01Woo001?Ool3
000hOol00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0`Ool00`00Oomo
o`0gOol20008Ool004moo`03001oogoo03Qoo`0300l007oo035oo`0300moogoo031oo`03001oogoo
035oo`0300moogoo031oo`03001oogoo03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<0
3`00Ool0<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0;goo00<0000?Ool0>Goo00<0
07ooOol01Woo001?Ool00`00Oomoo`0hOol00`0?001oo`0aOol00`0?Oomoo`0`Ool00`00Oomoo`0a
Ool00`0?Oomoo`0_Ool00`0000moo`0iOol00`00Oomoo`06Ool004moo`03001oogoo03Qoo`0300mo
o`00035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo02moo`0300003goo03Uoo`03001o
ogoo00Ioo`00Cgoo0`00>7oo00<03goo0000<Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03goo
Ool0;Woo00<007oo00l0>Goo0P0027oo001?Ool00`00Oomoo`0hOol00`0?Ool0000aOol00`0?Oomo
o`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0^Ool00`00Ool03`0jOol00`00Oomoo`06Ool004moo`03
001oogoo03Qoo`0300moo`00035oo`0300moogoo031oo`03001oogoo035oo`0300moogoo02ioo`03
001oo`0?03Yoo`03001oogoo00Ioo`00>goo0`000goo00<007oo000010001goo00<007ooOol0>7oo
00@03gooOol0031oo`0300moogoo031oo`03001oogoo035oo`0300moogoo02ioo`03001oo`0?03Yo
o`03001oogoo00Ioo`00>Woo00D007ooOomoo`0000Eoo`04001oogoo0007Ool00`00Oomoo`0hOol0
100?Oomoo`00<7oo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0;Goo00@007ooOol03cYo
o`03001oogoo00Ioo`00>Woo00D007ooOomoo`0000Ioo`03001oogoo00Moo`<003/03`0300003`0?
06403`0300003`0?06403`0300003`0?03T03`<000Qoo`00>Woo00D007ooOomoo`0000Moo`03001o
ogoo00Ioo`03001oogoo03Qoo`0400moogoo000`Ool00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?
Oomoo`0]Ool01000Oomoo`0?>Woo00<007ooOol01Woo000jOol01@00Oomoogoo000027oo00<007oo
Ool01Goo00<007ooOol0>7oo00D03gooOomoo`0002moo`0300moogoo031oo`03001oogoo035oo`03
00moogoo02aoo`05001oogooOol03`0jOol00`00Oomoo`06Ool003Yoo`05001oogooOol00008Ool0
0`00Oomoo`05Ool00`00Oomoo`0hOol01@0?Oomoogoo0000;goo00<03gooOol0<7oo00<007ooOol0
<Goo00<03gooOol0;7oo00D007ooOomoo`0?03Yoo`03001oogoo00Ioo`00>Woo00D007ooOomoo`00
00Qoo`03001oogoo00Eoo`03001oogoo03Qoo`0500moogooOol0000_Ool00`0?Oomoo`0`Ool00`00
Oomoo`0aOol00`0?Oomoo`0/Ool01@00Oomoogoo00l0>Woo00<007ooOol01Woo000jOol01@00Oomo
ogoo000017oo00D007ooOomoo`0000Moo`03001oogoo03Qoo`0300moogoo009oo`03001oogoo02ao
o`0300moogoo031oo`03001oogoo035oo`0300moogoo02]oo`03001oogoo009oo`0300moogoo03Qo
o`03001oogoo00Ioo`00>goo0`001Woo0`0027oo0`00>7oo00<03gooOol00Woo00<007ooOol0;7oo
00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0:goo00<007ooOol00Woo00<03gooOol0=goo
0P0027oo001?Ool00`00Oomoo`0hOol00`0?Oomoo`02Ool00`00Oomoo`0/Ool00`0?Oomoo`0`Ool0
0`00Oomoo`0aOol00`0?Oomoo`0[Ool00`00Oomoo`02Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool0
04moo`03001oogoo03Qoo`0300moogoo00=oo`03001oogoo02]oo`0300moogoo031oo`03001oogoo
035oo`0300moogoo02Yoo`03001oogoo00=oo`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo00<0
07ooOol0>7oo00<03gooOol00goo00<007ooOol0:goo00<03gooOol0<7oo00<007ooOol0<Goo00<0
3gooOol0:Woo00<007ooOol00goo00<03gooOol0>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0h
Ool00`0?Oomoo`03Ool00`00Oomoo`0[Ool00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0Z
Ool00`00Oomoo`03Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool004moo`<003Qoo`0300moogoo00=o
o`03001oogoo02]oo`0300moogoo031oo`03001oogoo035oo`0300moogoo02Yoo`03001oogoo00=o
o`0300moogoo03Moo`8000Qoo`00Cgoo00<007ooOol0>7oo00<03gooOol017oo00<007ooOol0:Woo
00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0:Goo00<007ooOol017oo00<03gooOol0>7oo
00<007ooOol01Woo001?Ool00`00Oomoo`0hOol00`0?Oomoo`04Ool00`00Oomoo`0ZOol00`0?Oomo
o`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0YOol00`00Oomoo`04Ool00`0?Oomoo`0hOol00`00Oomo
o`06Ool004moo`03001oogoo03Qoo`0300moogoo00Aoo`03001oogoo02Yoo`0300moogoo031oo`03
001oogoo035oo`0300moogoo02Uoo`03001oogoo00Aoo`0300moogoo03Qoo`03001oogoo00Ioo`00
Cgoo00<007ooOol0>7oo00<03gooOol01Goo00<007ooOol0:Goo00<03gooOol0<7oo00<007ooOol0
<Goo00<03gooOol0:7oo00<007ooOol01Goo00<03gooOol0>7oo00<007ooOol01Woo001?Ool3000h
Ool00`0?Oomoo`05Ool00`00Oomoo`0YOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0X
Ool00`00Oomoo`05Ool00`0?Oomoo`0gOol20008Ool004moo`03001oogoo03Qoo`0300moogoo00Eo
o`03001oogoo02Uoo`0300moogoo031oo`03001oogoo035oo`0300moogoo02Qoo`03001oogoo00Eo
o`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<03gooOol01Woo00<007oo
Ool0:7oo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol09goo00<007ooOol01Woo00<03goo
Ool0>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0hOol00`0?Oomoo`06Ool00`00Oomoo`0XOol0
0`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0WOol00`00Oomoo`06Ool00`0?Oomoo`0hOol0
0`00Oomoo`06Ool004moo`03001oogoo03Qoo`0300moogoo00Ioo`03001oogoo02Qoo`0300moogoo
031oo`03001oogoo035oo`0300moogoo02Moo`03001oogoo00Ioo`0300moogoo03Qoo`03001oogoo
00Ioo`00Cgoo0`00>7oo00<03gooOol01goo00<007ooOol09goo00<03gooOol0<7oo00<007ooOol0
<Goo00<03gooOol09Woo00<007ooOol01goo00<03gooOol0=goo0P0027oo001?Ool00`00Oomoo`0h
Ool00`0?Oomoo`07Ool00`00Oomoo`0WOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0V
Ool00`00Oomoo`07Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool004moo`03001oogoo03Qoo`0300mo
ogoo00Moo`03001oogoo02Moo`0300moogoo031oo`03001oogoo035oo`0300moogoo02Ioo`03001o
ogoo00Moo`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<03gooOol01goo
00<007ooOol09goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol09Woo00<007ooOol01goo
00<03gooOol0>7oo00<007ooOol01Woo000_Ool30003Ool00`00Ool0000400000goo000000030000
17oo000000002Goo00<007ooOol0>7oo00<03gooOol027oo00<007ooOol09Woo00<03gooOol0<7oo
00<007ooOol0<Goo00<03gooOol09Goo00<007ooOol027oo00<03gooOol0>7oo00<007ooOol01Woo
000^Ool01@00Oomoogoo00001Goo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`06Ool0
0`00Oomoo`0hOol00`0?Oomoo`08Ool00`00Oomoo`0VOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol0
0`0?Oomoo`0UOol00`00Oomoo`08Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool002ioo`05001oogoo
Ool00006Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool3001300l00`0000l03`1I
00l00`0000l03`1I00l00`0000l03`1100l30008Ool002ioo`05001oogooOol00007Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0hOol00`0?Oomoo`09Ool00`00Oomo
o`0UOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0TOol00`00Oomoo`09Ool00`0?Oomo
o`0hOol00`00Oomoo`06Ool002ioo`05001oogooOol00008Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`0hOol00`0?Oomoo`09Ool00`00Oomoo`0UOol00`0?Oomoo`0`
Ool00`00Oomoo`0aOol00`0?Oomoo`0TOol00`00Oomoo`09Ool00`0?Oomoo`0hOol00`00Oomoo`06
Ool002ioo`05001oogooOol00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`0hOol00`0?Oomoo`09Ool00`00Oomoo`0UOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol0
0`0?Oomoo`0TOol00`00Oomoo`09Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool002ioo`05001oogoo
Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`020009Ool00`00Oomoo`0hOol00`0?Oomoo`0:Ool0
0`00Oomoo`0TOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0SOol00`00Oomoo`0:Ool0
0`0?Oomoo`0hOol00`00Oomoo`06Ool002ioo`05001oogooOol00004Ool01`00Oomoogoo001oo`00
00=oo`04001oogoo000:Ool3000hOol00`0?Oomoo`0:Ool00`00Oomoo`0TOol00`0?Oomoo`0`Ool0
0`00Oomoo`0aOol00`0?Oomoo`0SOol00`00Oomoo`0:Ool00`0?Oomoo`0gOol20008Ool002moo`<0
00Ioo`<000=oo`<000Aoo`<000Moo`03001oogoo03Qoo`0300moogoo00]oo`03001oogoo02=oo`03
00moogoo031oo`03001oogoo035oo`0300moogoo02=oo`03001oogoo00Yoo`0300moogoo03Qoo`03
001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<03gooOol02goo00<007ooOol08goo00<03gooOol0
<7oo00<007ooOol0<Goo00<03gooOol08Woo00<007ooOol02goo00<03gooOol0>7oo00<007ooOol0
1Woo001?Ool00`00Oomoo`0hOol00`0?Oomoo`0;Ool00`00Oomoo`0SOol00`0?Oomoo`0`Ool00`00
Oomoo`0aOol00`0?Oomoo`0ROol00`00Oomoo`0;Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool004mo
o`03001oogoo03Qoo`0300moogoo00aoo`03001oogoo029oo`0300moogoo031oo`03001oogoo035o
o`0300moogoo029oo`03001oogoo00]oo`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo0`00>7oo
00<03gooOol037oo00<007ooOol08Woo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol08Goo
00<007ooOol037oo00<03gooOol0=goo0P0027oo001?Ool00`00Oomoo`0hOol00`0?Oomoo`0<Ool0
0`00Oomoo`0ROol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0QOol00`00Oomoo`0<Ool0
0`0?Oomoo`0hOol00`00Oomoo`06Ool004moo`03001oogoo03Qoo`0300moogoo00eoo`03001oogoo
025oo`0300moogoo031oo`03001oogoo035oo`0300moogoo025oo`03001oogoo00aoo`0300moogoo
03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<03gooOol03Goo00<007ooOol08Goo00<0
3gooOol0<7oo00<007ooOol0<Goo00<03gooOol087oo00<007ooOol03Goo00<03gooOol0>7oo00<0
07ooOol01Woo001?Ool00`00Oomoo`0hOol00`0?Oomoo`0>Ool00`00Oomoo`0POol00`0?Oomoo`0`
Ool00`00Oomoo`0aOol00`0?Oomoo`0POol00`00Oomoo`0=Ool00`0?Oomoo`0hOol00`00Oomoo`06
Ool004moo`<003Qoo`0300moogoo00ioo`03001oogoo021oo`0300moogoo031oo`03001oogoo035o
o`0300moogoo021oo`03001oogoo00eoo`0300moogoo03Moo`8000Qoo`00Cgoo00<007ooOol0>7oo
00<03gooOol03Woo00<007ooOol087oo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol07goo
00<007ooOol03Woo00<03gooOol0>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0hOol00`0?Oomo
o`0?Ool00`00Oomoo`0OOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0OOol00`00Oomo
o`0>Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool004moo`03001oogoo03Qoo`0300moogoo00moo`03
001oogoo01moo`0300moogoo031oo`03001oogoo035oo`0300moogoo01moo`03001oogoo00ioo`03
00moogoo03Qoo`03001oogoo00Ioo`00Cgoo00<007ooOol0>7oo00<03gooOol03goo00<007ooOol0
7goo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol07Woo00<007ooOol03goo00<03gooOol0
>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0hOol00`0?Oomoo`0@Ool00`00Oomoo`0NOol00`0?
Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0NOol00`00Oomoo`0?Ool00`0?Oomoo`0hOol00`00
Oomoo`06Ool004moo`<003Qoo`0300moogoo011oo`03001oogoo01ioo`0300moogoo031oo`03001o
ogoo035oo`0300moogoo01ioo`03001oogoo00moo`0300moogoo03Moo`8000Qoo`00Cgoo00<007oo
Ool0>7oo00<03gooOol04Goo00<007ooOol07Goo00<03gooOol0<7oo00<007ooOol0<Goo00<03goo
Ool07Goo00<007ooOol047oo00<03gooOol0>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0hOol0
0`0?Oomoo`0AOol00`00Oomoo`0MOol00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`0MOol0
0`00Oomoo`0@Ool00`0?Oomoo`0hOol00`00Oomoo`06Ool003Eoo`<000=oo`03001oo`0000@00004
Ool000000009Ool00`00Oomoo`0hOol00`0?Oomoo`0BOol00`00Oomoo`0LOol00`0?Oomoo`0`Ool0
0`00Oomoo`0aOol00`0?Oomoo`0LOol00`00Oomoo`0AOol00`0?Oomoo`0hOol00`00Oomoo`06Ool0
03Aoo`05001oogooOol00005Ool01000Oomoo`0017oo00<007ooOol01Woo00<007ooOol0>7oo00<0
3gooOol04Woo00<007ooOol077oo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol077oo00<0
07ooOol04Goo00<03gooOol0>7oo00<007ooOol01Woo000dOol01@00Oomoogoo00001Woo00<007oo
Ool01Goo00<007ooOol01Goo0`00CP0?00<0000?00l0CP0?00<0000?00l0C`0?00<0000?00l0B`0?
0`0027oo000dOol01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
>7oo00<03gooOol057oo00<007ooOol06Woo00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol0
6Woo00<007ooOol04goo00<03gooOol0>7oo00<007ooOol01Woo000dOol01@00Oomoogoo000027oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol0>7oo00<03gooOol057oo00<007ooOol06Woo
00<03gooOol0<7oo00<007ooOol0<Goo00<03gooOol06Woo00<007ooOol04goo00<03gooOol0>7oo
00<007ooOol01Woo000dOol01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0>7oo00<03gooOol05Goo00<007ooOol06Goo00<03gooOol0<7oo00<007ooOol0<Goo00<0
3gooOol06Goo00<007ooOol057oo00<03gooOol0>7oo00<007ooOol01Woo000dOol01@00Oomoogoo
000027oo00<007ooOol00P002Goo00<007ooOol0>7oo00<03gooOol05Woo00<007ooOol067oo00<0
3gooOol0<7oo00<007ooOol0<Goo00<03gooOol067oo00<007ooOol05Goo00<03gooOol0>7oo00<0
07ooOol01Woo000dOol01@00Oomoogoo000017oo00D007ooOomoo`00009oo`03001oogoo00Qoo`<0
03Qoo`0300moogoo01Ioo`03001oogoo01Qoo`0300moogoo031oo`03001oogoo035oo`0300moogoo
01Qoo`03001oogoo01Eoo`0300moogoo03Moo`8000Qoo`00=Goo0`001Woo0`0017oo0`001goo00<0
07ooOol0>7oo00<03gooOol05goo00<007ooOol05goo00<03gooOol0<7oo00<007ooOol0<Goo00<0
3gooOol05goo00<007ooOol05Woo00<03gooOol0>7oo00<007ooOol01Woo001?Ool00`00Oomoo`0h
Ool00`0?Oomoo`0HOol00`00Oomoo`0FOol00`0?Oomoo`0:OolG000?Ool00`00Oomoo`0>OolG000<
Ool00`0?Oomoo`0FOol00`00Oomoo`0GOol00`0?Oomoo`0hOol00`00Oomoo`06Ool004moo`03001o
ogoo03Qoo`0300moogoo01Qoo`03001oogoo01Ioo`0300moogoo00Aoo`H001Moob0001Moo`H000Io
o`0300moogoo01Ioo`03001oogoo01Moo`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo00<007oo
Ool0>7oo00<03gooOol06Goo00<007ooOol05Goo00<03gooOol01000;7oo00<007ooOol0:goo1000
0Woo00<03gooOol05Goo00<007ooOol067oo00<03gooOol0>7oo00<007ooOol01Woo001?Ool3000h
Ool00`0?Oomoo`0JOol2000DOol4000`Ool00`00Oomoo`0_Ool4000DOol2000KOol00`0?Oomoo`0g
Ool20008Ool004moo`03001oogoo03Qoo`0300moogoo01aoo`8000ioo`@00003Ool03goo035oo`03
001oogoo035oo`0300moo`0000<000ioo`8001eoo`0300moogoo03Qoo`03001oogoo00Ioo`00Cgoo
00<007ooOol0>7oo00<03gooOol07Woo0P001Woo1P001Goo00<03gooOol0<7oo00<007ooOol0<Goo
00<03gooOol00goo1P001Woo0P007goo00<03gooOol0>7oo00<007ooOol01Woo001?Ool00`00Oomo
o`0hOol00`0?Oomoo`0POol6000;Ool00`0?Oomoo`0`Ool00`00Oomoo`0aOol00`0?Oomoo`09Ool6
000QOol00`0?Oomoo`0hOol00`00Oomoo`06Ool004moo`03001oogoo03Qoo`0300moogoo035oo`03
00moogoo031oo`03001oogoo035oo`0300moogoo031oo`0300moogoo03Qoo`03001oogoo00Ioo`00
Cgoo00<007ooOol01Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0
<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol017oo00<007ooOol01Woo001?Ool30005
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`03Ool20008Ool004moool004H000Qoo`00ogooWGoo003oOonMOol00?mooieoo`00
ogooWGoo003oOonMOol00?mooieoo`00ogooWGoo003_Ool00`00Oomoo`2ZOol00?1oo`03001oogoo
0:Uoo`00_goo0`004Woo0`001Goo0`0000Aoo`00001oo`D00004Ool00000Ool200000goo00000004
Ool7000?Ool30005Ool3000017oo000007oo1@0000Aoo`00001oo`8007Moo`00`7oo00<007ooOol0
1goo1`0017oo00<007ooOol01Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`002Goo
00<007ooOol00Woo00<007ooOol00Woo1`001Goo00<007ooOol01Goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`00N7oo0030Ool00`00Oomoo`0BOol00`00Oomoo`05Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomo
o`05Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo001hOol00<1oo`03001oogoo019o
o`03001oogoo00Eoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Yoo`03001oogoo
019oo`03001oogoo00Eoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol007Qoo`00_goo
00<007oo000027oo1`0017oo00<007ooOol01Goo0P0000Eoo`00001oo`00009oo`800005Ool00000
Ool0000;Ool00`00Oomoo`05Ool70005Ool00`00Oomoo`05Ool200001Goo000007oo00000Woo0P00
00Eoo`00001oo`0007Qoo`00_goo00<007oo00004goo00<007ooOol017oo0P0000Eoo`00Oomoo`00
009oo`800005Ool007ooOol0000<Ool00`00Oomoo`0AOol00`00Oomoo`04Ool200001Goo001oogoo
00000Woo0P0000Eoo`00Oomoo`0007Uoo`00_goo00@007ooOol0019oo`03001oogoo025oo`03001o
ogoo011oo`03001oogoo08eoo`00_Woo00<007ooOol00Woo00<007ooOol03Woo0P0087oo00D007oo
Oomoo`00011oo`8008moo`00_Goo0`000Woo0`0047oo00<007ooOol07Woo1P0047oo00<007ooOol0
SGoo003oOonMOol00001\
\>"],
  ImageRangeCache->{{{0, 411}, {253.438, 0}} -> {-47.0146, 0.0431693, 
  0.194357, 0.000954161}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(ob = t\), ";", \(z = 3\), ";", "\n", 
      RowBox[{"pl", "=", 
        RowBox[{"Plot3D", "[", 
          RowBox[{
          \(radFld[ob, "\<Bz\>", {x, y, z}]\), ",", 
            \({x, \(-thick\)/2, thick/2}\), ",", 
            \({y, \(-width\)/2, width/2}\), "\n", "\t", ",", 
            
            StyleBox[
              \(AxesLabel -> {"\<X [mm]\>", "\<Y [mm]\>", "\<Bz [T]\>"}\),
              "MR"]}], "]"}]}]}]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.04977 -0.0679587 1.04977 [
[.08608 .22315 -25 -14.7884 ]
[.08608 .22315 0 .21156 ]
[.20731 .17545 -24.3204 -15 ]
[.20731 .17545 .67962 0 ]
[.3345 .12542 -9.31117 -15 ]
[.3345 .12542 .68883 0 ]
[.46808 .07289 -14.2307 -15 ]
[.46808 .07289 1.7693 0 ]
[.60856 .01769 -13.5635 -15 ]
[.60856 .01769 2.43648 0 ]
[.29165 .07573 -40.038 -15 ]
[.29165 .07573 2.96197 0 ]
[.70096 -0.00478 0 -10.4368 ]
[.70096 -0.00478 25 4.56323 ]
[.78313 .12104 0 -10.231 ]
[.78313 .12104 25 4.76904 ]
[.8565 .23339 0 -10.0521 ]
[.8565 .23339 10 4.94788 ]
[.9224 .33431 0 -9.89525 ]
[.9224 .33431 16 5.10475 ]
[.98191 .42546 0 -9.75656 ]
[.98191 .42546 16 5.24344 ]
[.91861 .21225 0 -10.0521 ]
[.91861 .21225 43 4.94788 ]
[.02049 .2878 -19 -4.60247 ]
[.02049 .2878 0 10.3975 ]
[.01196 .34127 -25 -4.67793 ]
[.01196 .34127 0 10.3221 ]
[.00313 .39662 -19 -4.75631 ]
[.00313 .39662 0 10.2437 ]
[-0.00602 .45394 -25 -4.83778 ]
[-0.00602 .45394 0 10.1622 ]
[-0.05457 .39542 -36 -4.72232 ]
[-0.05457 .39542 0 10.2777 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
gsave
.08608 .22315 -86 -18.7884 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.21633 .18498 m
.22084 .18975 L
s
gsave
.20731 .17545 -85.3204 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.47614 .08324 m
.48017 .08842 L
s
gsave
.46808 .07289 -75.2307 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.61605 .02846 m
.6198 .03385 L
s
gsave
.60856 .01769 -74.5635 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11921 .22301 m
.12201 .22578 L
s
.14315 .21364 m
.14592 .21643 L
s
.16731 .20417 m
.17006 .20699 L
s
.1917 .19462 m
.19443 .19746 L
s
.24119 .17525 m
.24387 .17813 L
s
.26629 .16542 m
.26894 .16832 L
s
.29163 .15549 m
.29426 .15843 L
s
.31722 .14547 m
.31982 .14843 L
s
.36916 .12514 m
.3717 .12814 L
s
.39551 .11482 m
.39802 .11785 L
s
.42212 .1044 m
.4246 .10745 L
s
.449 .09387 m
.45145 .09696 L
s
.50356 .07251 m
.50595 .07564 L
s
.53126 .06166 m
.53361 .06482 L
s
.55924 .05071 m
.56155 .05389 L
s
.5875 .03964 m
.58978 .04285 L
s
.072 .2415 m
.07484 .24422 L
s
.04872 .25061 m
.05159 .25331 L
s
.6449 .01716 m
.64711 .02042 L
s
.67405 .00575 m
.67622 .00903 L
s
gsave
.29165 .07573 -101.038 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.625000 moveto
(@) show
78.562500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.312500 14.625000 moveto
(D) show
101.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -14.4368 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.7708 .12553 m
.76464 .12778 L
s
gsave
.78313 .12104 -61 -14.231 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.84407 .23761 m
.83786 .23973 L
s
gsave
.8565 .23339 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.9099 .3383 m
.90365 .34029 L
s
gsave
.9224 .33431 -61 -13.8953 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -13.7566 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -14.0521 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.625000 moveto
(@) show
78.562500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.312500 14.625000 moveto
(D) show
101.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03273 .28307 m
.03885 .2807 L
s
gsave
.02049 .2878 -80 -8.60247 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.02424 .33665 m
.03038 .33434 L
s
gsave
.01196 .34127 -86 -8.67793 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.01545 .39211 m
.02162 .38985 L
s
gsave
.00313 .39662 -80 -8.75631 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.00635 .44955 m
.01253 .44736 L
s
gsave
-0.00602 .45394 -86 -8.83778 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.25) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.03106 .29364 m
.03473 .29223 L
s
.02937 .30428 m
.03305 .30287 L
s
.02767 .315 m
.03135 .3136 L
s
.02596 .32578 m
.02965 .32439 L
s
.02251 .34759 m
.0262 .34621 L
s
.02076 .3586 m
.02445 .35723 L
s
.01901 .36969 m
.0227 .36833 L
s
.01724 .38086 m
.02093 .3795 L
s
.01366 .40344 m
.01736 .40209 L
s
.01185 .41484 m
.01555 .4135 L
s
.01003 .42633 m
.01374 .425 L
s
.0082 .4379 m
.0119 .43657 L
s
.0344 .27257 m
.03807 .27114 L
s
.03605 .26214 m
.03972 .26071 L
s
.00449 .46129 m
.0082 .45998 L
s
.00262 .47311 m
.00633 .47181 L
s
.00073 .48501 m
.00445 .48372 L
s
gsave
-0.05457 .39542 -97 -8.72232 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
79.312500 14.625000 moveto
(@) show
83.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 14.625000 moveto
(D) show
94.500000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.28 0 0 r
.38252 .59775 .40506 .60551 .44145 .61052 .41898 .61163 Metetra
.399 0 0 r
.41898 .61163 .44145 .61052 .47876 .61155 .45659 .62209 Metetra
.237 0 0 r
.45659 .62209 .47876 .61155 .51687 .60573 .49533 .61951 Metetra
.035 0 0 r
.49533 .61951 .51687 .60573 .55559 .59468 .53481 .60707 Metetra
.53481 .60707 .55559 .59468 .59484 .58213 .57482 .5931 Metetra
.57482 .5931 .59484 .58213 .63465 .57018 .61541 .58106 Metetra
.01 0 0 r
.61541 .58106 .63465 .57018 .67505 .55849 .65664 .56968 Metetra
.65664 .56968 .67505 .55849 .71603 .54628 .69842 .55676 Metetra
.69842 .55676 .71603 .54628 .75762 .53433 .74087 .54449 Metetra
.048 0 0 r
.74087 .54449 .75762 .53433 .7999 .52299 .78412 .53419 Metetra
.049 0 0 r
.78412 .53419 .7999 .52299 .8427 .51008 .82797 .52232 Metetra
.82797 .52232 .8427 .51008 .88556 .49174 .87146 .50021 Metetra
.568 .898 .65 r
.87146 .50021 .88556 .49174 .92806 .46613 .91378 .4643 Metetra
.825 .998 .842 r
.91378 .4643 .92806 .46613 .97029 .43613 .95565 .42445 Metetra
.548 0 0 r
.35932 .58783 .38252 .59775 .41898 .61163 .39563 .61278 Metetra
.711 .203 .021 r
.39563 .61278 .41898 .61163 .45659 .62209 .43312 .64412 Metetra
.509 .053 .104 r
.43312 .64412 .45659 .62209 .49533 .61951 .47251 .65054 Metetra
.258 0 .033 r
.47251 .65054 .49533 .61951 .53481 .60707 .51299 .63426 Metetra
.224 0 0 r
.51299 .63426 .53481 .60707 .57482 .5931 .55397 .6184 Metetra
.279 0 0 r
.55397 .6184 .57482 .5931 .61541 .58106 .59555 .60673 Metetra
.31 0 .008 r
.59555 .60673 .61541 .58106 .65664 .56968 .63783 .59652 Metetra
.263 0 0 r
.63783 .59652 .65664 .56968 .69842 .55676 .68063 .58213 Metetra
.273 0 0 r
.68063 .58213 .69842 .55676 .74087 .54449 .72412 .56918 Metetra
.331 0 .01 r
.72412 .56918 .74087 .54449 .78412 .53419 .76861 .56051 Metetra
.354 0 .043 r
.76861 .56051 .78412 .53419 .82797 .52232 .81395 .55231 Metetra
.084 0 0 r
.81395 .55231 .82797 .52232 .87146 .50021 .85781 .52055 Metetra
.85781 .52055 .87146 .50021 .91378 .4643 .89889 .46239 Metetra
.897 .986 .786 r
.89889 .46239 .91378 .4643 .95565 .42445 .94021 .41034 Metetra
.625 .073 0 r
.33557 .57383 .35932 .58783 .39563 .61278 .37168 .60626 Metetra
.844 .397 .152 r
.37168 .60626 .39563 .61278 .43312 .64412 .40842 .66637 Metetra
.69 .269 .242 r
.40842 .66637 .43312 .64412 .47251 .65054 .44801 .69799 Metetra
.233 0 .131 r
.44801 .69799 .47251 .65054 .51299 .63426 .48984 .66985 Metetra
.268 0 .066 r
.48984 .66985 .51299 .63426 .55397 .6184 .53194 .6517 Metetra
.348 0 .093 r
.53194 .6517 .55397 .6184 .59555 .60673 .57464 .64062 Metetra
.391 0 .122 r
.57464 .64062 .59555 .60673 .63783 .59652 .61812 .63271 Metetra
.306 0 .099 r
.61812 .63271 .63783 .59652 .68063 .58213 .66205 .61578 Metetra
.327 0 .089 r
.66205 .61578 .68063 .58213 .72412 .56918 .70675 .60199 Metetra
.402 0 .117 r
.70675 .60199 .72412 .56918 .76861 .56051 .75262 .59542 Metetra
.498 .08 .177 r
.75262 .59542 .76861 .56051 .81395 .55231 .80026 .59927 Metetra
0 0 .07 r
.80026 .59927 .81395 .55231 .85781 .52055 .84328 .54105 Metetra
.828 .884 .454 r
.84328 .54105 .85781 .52055 .89889 .46239 .88246 .45231 Metetra
.932 .922 .778 r
.88246 .45231 .89889 .46239 .94021 .41034 .92371 .39176 Metetra
.595 .056 0 r
.31131 .55566 .33557 .57383 .37168 .60626 .34736 .59009 Metetra
.857 .402 .074 r
.34736 .59009 .37168 .60626 .40842 .66637 .38377 .65551 Metetra
.672 .122 0 r
.38377 .65551 .40842 .66637 .44801 .69799 .42343 .69189 Metetra
.815 .924 .908 r
.42343 .69189 .44801 .69799 .48984 .66985 .46603 .65944 Metetra
.696 .887 .968 r
.46603 .65944 .48984 .66985 .53194 .6517 .50874 .64053 Metetra
.58 .853 .995 r
.50874 .64053 .53194 .6517 .57464 .64062 .55202 .62943 Metetra
.507 .828 1 r
.55202 .62943 .57464 .64062 .61812 .63271 .59609 .62181 Metetra
.669 .889 .978 r
.59609 .62181 .61812 .63271 .66205 .61578 .64067 .60396 Metetra
.622 .87 .989 r
.64067 .60396 .66205 .61578 .70675 .60199 .686 .58954 Metetra
.484 .812 1 r
.686 .58954 .70675 .60199 .75262 .59542 .73254 .58312 Metetra
.155 .624 .929 r
.73254 .58312 .75262 .59542 .80026 .59927 .7811 .59079 Metetra
.932 .92 .778 r
.7811 .59079 .80026 .59927 .84328 .54105 .82468 .52698 Metetra
.965 .852 .679 r
.82468 .52698 .84328 .54105 .88246 .45231 .86435 .43198 Metetra
.911 .848 .769 r
.86435 .43198 .88246 .45231 .92371 .39176 .90617 .36863 Metetra
.536 .01 0 r
.28651 .53449 .31131 .55566 .34736 .59009 .32257 .56858 Metetra
.83 .361 0 r
.32257 .56858 .34736 .59009 .38377 .65551 .35892 .63075 Metetra
0 .163 .661 r
.35892 .63075 .38377 .65551 .42343 .69189 .39874 .66246 Metetra
.753 .733 .834 r
.39874 .66246 .42343 .69189 .46603 .65944 .44173 .63352 Metetra
.695 .747 .891 r
.44173 .63352 .46603 .65944 .50874 .64053 .48486 .61544 Metetra
.639 .74 .922 r
.48486 .61544 .50874 .64053 .55202 .62943 .52856 .60381 Metetra
.612 .729 .929 r
.52856 .60381 .55202 .62943 .59609 .62181 .57302 .59459 Metetra
.682 .743 .897 r
.57302 .59459 .59609 .62181 .64067 .60396 .6181 .57755 Metetra
.661 .746 .913 r
.6181 .57755 .64067 .60396 .686 .58954 .66392 .5629 Metetra
.596 .722 .932 r
.66392 .5629 .686 .58954 .73254 .58312 .71085 .55481 Metetra
.464 .649 .939 r
.71085 .55481 .73254 .58312 .7811 .59079 .75951 .55804 Metetra
.853 .767 .766 r
.75951 .55804 .7811 .59079 .82468 .52698 .80419 .49827 Metetra
.925 .79 .693 r
.80419 .49827 .82468 .52698 .86435 .43198 .84512 .40591 Metetra
.893 .815 .764 r
.84512 .40591 .86435 .43198 .90617 .36863 .88777 .34214 Metetra
.505 0 0 r
.26111 .51163 .28651 .53449 .32257 .56858 .29713 .54543 Metetra
.826 .357 0 r
.29713 .54543 .32257 .56858 .35892 .63075 .33323 .60791 Metetra
0 .119 .6 r
.33323 .60791 .35892 .63075 .39874 .66246 .37309 .63993 Metetra
.758 .787 .876 r
.37309 .63993 .39874 .66246 .44173 .63352 .41657 .6127 Metetra
.692 .794 .928 r
.41657 .6127 .44173 .63352 .48486 .61544 .4602 .59503 Metetra
.632 .786 .955 r
.4602 .59503 .48486 .61544 .52856 .60381 .50439 .58283 Metetra
.607 .776 .961 r
.50439 .58283 .52856 .60381 .57302 .59459 .54934 .57256 Metetra
.676 .791 .935 r
.54934 .57256 .57302 .59459 .6181 .57755 .59498 .5558 Metetra
.654 .791 .947 r
.59498 .5558 .6181 .57755 .66392 .5629 .64138 .54094 Metetra
.588 .769 .965 r
.64138 .54094 .66392 .5629 .71085 .55481 .68881 .53166 Metetra
.453 .698 .972 r
.68881 .53166 .71085 .55481 .75951 .55804 .73783 .53233 Metetra
.879 .814 .78 r
.73783 .53233 .75951 .55804 .80419 .49827 .78331 .47142 Metetra
.932 .802 .693 r
.78331 .47142 .80419 .49827 .84512 .40591 .82518 .37793 Metetra
.889 .808 .763 r
.82518 .37793 .84512 .40591 .88777 .34214 .86865 .31367 Metetra
.498 0 0 r
.23502 .48784 .26111 .51163 .29713 .54543 .27098 .52158 Metetra
.827 .359 0 r
.27098 .52158 .29713 .54543 .33323 .60791 .30679 .58451 Metetra
0 .11 .591 r
.30679 .58451 .33323 .60791 .37309 .63993 .34666 .61684 Metetra
.757 .787 .878 r
.34666 .61684 .37309 .63993 .41657 .6127 .39069 .58947 Metetra
.69 .778 .919 r
.39069 .58947 .41657 .6127 .4602 .59503 .43481 .57157 Metetra
.638 .766 .94 r
.43481 .57157 .4602 .59503 .50439 .58283 .47946 .55889 Metetra
.615 .758 .947 r
.47946 .55889 .50439 .58283 .54934 .57256 .52489 .54808 Metetra
.675 .776 .926 r
.52489 .54808 .54934 .57256 .59498 .5558 .57107 .53103 Metetra
.656 .771 .934 r
.57107 .53103 .59498 .5558 .64138 .54094 .61802 .51582 Metetra
.599 .751 .95 r
.61802 .51582 .64138 .54094 .68881 .53166 .66597 .50593 Metetra
.472 .691 .963 r
.66597 .50593 .68881 .53166 .73783 .53233 .71546 .50589 Metetra
.88 .815 .78 r
.71546 .50589 .73783 .53233 .78331 .47142 .76177 .44382 Metetra
.933 .802 .693 r
.76177 .44382 .78331 .47142 .82518 .37793 .80462 .34904 Metetra
.889 .808 .763 r
.80462 .34904 .82518 .37793 .86865 .31367 .84891 .28401 Metetra
.497 0 0 r
.2082 .46329 .23502 .48784 .27098 .52158 .24408 .49703 Metetra
.825 .356 0 r
.24408 .49703 .27098 .52158 .30679 .58451 .27961 .55971 Metetra
0 .129 .614 r
.27961 .55971 .30679 .58451 .34666 .61684 .31951 .59155 Metetra
.753 .776 .872 r
.31951 .59155 .34666 .61684 .39069 .58947 .36408 .56379 Metetra
.688 .764 .91 r
.36408 .56379 .39069 .58947 .43481 .57157 .40868 .54562 Metetra
.64 .752 .93 r
.40868 .54562 .43481 .57157 .47946 .55889 .45379 .53248 Metetra
.619 .744 .936 r
.45379 .53248 .47946 .55889 .52489 .54808 .49967 .52116 Metetra
.675 .762 .917 r
.49967 .52116 .52489 .54808 .57107 .53103 .54638 .50374 Metetra
.657 .757 .924 r
.54638 .50374 .57107 .53103 .61802 .51582 .59386 .48811 Metetra
.605 .738 .939 r
.59386 .48811 .61802 .51582 .66597 .50593 .64232 .47759 Metetra
.485 .682 .953 r
.64232 .47759 .66597 .50593 .71546 .50589 .69228 .47706 Metetra
.875 .806 .778 r
.69228 .47706 .71546 .50589 .76177 .44382 .73949 .4146 Metetra
.931 .799 .693 r
.73949 .4146 .76177 .44382 .80462 .34904 .7834 .31922 Metetra
.889 .808 .762 r
.7834 .31922 .80462 .34904 .84891 .28401 .82854 .25331 Metetra
.49 0 0 r
.18066 .43761 .2082 .46329 .24408 .49703 .21644 .4713 Metetra
.816 .344 0 r
.21644 .4713 .24408 .49703 .27961 .55971 .25173 .53283 Metetra
0 .172 .664 r
.25173 .53283 .27961 .55971 .31951 .59155 .2917 .56331 Metetra
.743 .759 .866 r
.2917 .56331 .31951 .59155 .36408 .56379 .33673 .5362 Metetra
.682 .754 .906 r
.33673 .5362 .36408 .56379 .40868 .54562 .38178 .51814 Metetra
.641 .746 .925 r
.38178 .51814 .40868 .54562 .45379 .53248 .42734 .50449 Metetra
.624 .74 .93 r
.42734 .50449 .45379 .53248 .49967 .52116 .47369 .49241 Metetra
.672 .754 .912 r
.47369 .49241 .49967 .52116 .54638 .50374 .52092 .47481 Metetra
.656 .751 .919 r
.52092 .47481 .54638 .50374 .59386 .48811 .56892 .45876 Metetra
.612 .735 .933 r
.56892 .45876 .59386 .48811 .64232 .47759 .61788 .4472 Metetra
.506 .683 .946 r
.61788 .4472 .64232 .47759 .69228 .47706 .66825 .44502 Metetra
.865 .793 .777 r
.66825 .44502 .69228 .47706 .73949 .4146 .71639 .38304 Metetra
.926 .794 .696 r
.71639 .38304 .73949 .4146 .7834 .31922 .76146 .28795 Metetra
.888 .805 .762 r
.76146 .28795 .7834 .31922 .82854 .25331 .80748 .22119 Metetra
0 .043 .542 r
.15249 .40987 .18066 .43761 .21644 .4713 .18816 .44317 Metetra
.816 .349 0 r
.18816 .44317 .21644 .4713 .25173 .53283 .22293 .50621 Metetra
0 .11 .598 r
.22293 .50621 .25173 .53283 .2917 .56331 .2627 .53892 Metetra
.732 .791 .9 r
.2627 .53892 .2917 .56331 .33673 .5362 .30813 .51435 Metetra
.676 .805 .944 r
.30813 .51435 .33673 .5362 .38178 .51814 .3537 .49659 Metetra
.634 .8 .962 r
.3537 .49659 .38178 .51814 .42734 .50449 .39982 .48234 Metetra
.618 .794 .966 r
.39982 .48234 .42734 .50449 .47369 .49241 .44674 .46924 Metetra
.664 .803 .949 r
.44674 .46924 .47369 .49241 .52092 .47481 .49458 .45174 Metetra
.649 .803 .957 r
.49458 .45174 .52092 .47481 .56892 .45876 .54323 .43537 Metetra
.606 .79 .969 r
.54323 .43537 .56892 .45876 .61788 .4472 .5928 .42257 Metetra
.516 .745 .978 r
.5928 .42257 .61788 .4472 .66825 .44502 .64364 .41682 Metetra
.884 .82 .779 r
.64364 .41682 .66825 .44502 .71639 .38304 .69262 .35156 Metetra
.93 .798 .693 r
.69262 .35156 .71639 .38304 .76146 .28795 .7387 .25395 Metetra
.882 .795 .76 r
.7387 .25395 .76146 .28795 .80748 .22119 .78561 .18664 Metetra
0 .12 .634 r
.12384 .37887 .15249 .40987 .18816 .44317 .15957 .40974 Metetra
.76 .294 0 r
.15957 .40974 .18816 .44317 .22293 .50621 .19426 .46873 Metetra
0 .255 .765 r
.19426 .46873 .22293 .50621 .2627 .53892 .23411 .49813 Metetra
.702 .687 .833 r
.23411 .49813 .2627 .53892 .30813 .51435 .27986 .47385 Metetra
.666 .679 .853 r
.27986 .47385 .30813 .51435 .3537 .49659 .32576 .45548 Metetra
.642 .669 .861 r
.32576 .45548 .3537 .49659 .39982 .48234 .37221 .44036 Metetra
.633 .664 .862 r
.37221 .44036 .39982 .48234 .44674 .46924 .41945 .42622 Metetra
.654 .67 .853 r
.41945 .42622 .44674 .46924 .49458 .45174 .46763 .40865 Metetra
.646 .669 .858 r
.46763 .40865 .49458 .45174 .54323 .43537 .51664 .39202 Metetra
.621 .66 .867 r
.51664 .39202 .54323 .43537 .5928 .42257 .56656 .3787 Metetra
.57 .636 .877 r
.56656 .3787 .5928 .42257 .64364 .41682 .6177 .3715 Metetra
.833 .736 .757 r
.6177 .3715 .64364 .41682 .69262 .35156 .66757 .30858 Metetra
.9 .757 .695 r
.66757 .30858 .69262 .35156 .7387 .25395 .71491 .21419 Metetra
.863 .769 .757 r
.71491 .21419 .7387 .25395 .78561 .18664 .76285 .14841 Metetra
0 .31 .801 r
.09489 .34347 .12384 .37887 .15957 .40974 .13132 .36665 Metetra
0 .221 .743 r
.13132 .36665 .15957 .40974 .19426 .46873 .16852 .39743 Metetra
.492 .468 .759 r
.16852 .39743 .19426 .46873 .23411 .49813 .21017 .40196 Metetra
.612 .495 .696 r
.21017 .40196 .23411 .49813 .27986 .47385 .25509 .3827 Metetra
.613 .504 .706 r
.25509 .3827 .27986 .47385 .32576 .45548 .30062 .36395 Metetra
.603 .498 .708 r
.30062 .36395 .32576 .45548 .37221 .44036 .34672 .34767 Metetra
.599 .495 .707 r
.34672 .34767 .37221 .44036 .41945 .42622 .39358 .33195 Metetra
.604 .497 .705 r
.39358 .33195 .41945 .42622 .46763 .40865 .44135 .31441 Metetra
.602 .497 .707 r
.44135 .31441 .46763 .40865 .51664 .39202 .48994 .29743 Metetra
.591 .491 .709 r
.48994 .29743 .51664 .39202 .56656 .3787 .53942 .28294 Metetra
.588 .488 .709 r
.53942 .28294 .56656 .3787 .6177 .3715 .58992 .26898 Metetra
.664 .527 .687 r
.58992 .26898 .6177 .3715 .66757 .30858 .64056 .23038 Metetra
.771 .624 .697 r
.64056 .23038 .66757 .30858 .71491 .21419 .68993 .16414 Metetra
.818 .719 .756 r
.68993 .16414 .71491 .21419 .76285 .14841 .73912 .1053 Metetra
.293 .496 .884 r
.06578 .30339 .09489 .34347 .13132 .36665 .10354 .3147 Metetra
.413 .494 .833 r
.10354 .3147 .13132 .36665 .16852 .39743 .14305 .32273 Metetra
.559 .5 .746 r
.14305 .32273 .16852 .39743 .21017 .40196 .1854 .31671 Metetra
.607 .508 .717 r
.1854 .31671 .21017 .40196 .25509 .3827 .22974 .30009 Metetra
.615 .52 .723 r
.22974 .30009 .25509 .3827 .30062 .36395 .27495 .28177 Metetra
.61 .519 .726 r
.27495 .28177 .30062 .36395 .34672 .34767 .32081 .26456 Metetra
.607 .517 .726 r
.32081 .26456 .34672 .34767 .39358 .33195 .36744 .24763 Metetra
.609 .517 .724 r
.36744 .24763 .39358 .33195 .44135 .31441 .41493 .22985 Metetra
.607 .517 .726 r
.41493 .22985 .44135 .31441 .48994 .29743 .46324 .21234 Metetra
.601 .513 .727 r
.46324 .21234 .48994 .29743 .53942 .28294 .51244 .19593 Metetra
.607 .514 .724 r
.51244 .19593 .53942 .28294 .58992 .26898 .56257 .17776 Metetra
.644 .531 .71 r
.56257 .17776 .58992 .26898 .64056 .23038 .61332 .14861 Metetra
.706 .583 .716 r
.61332 .14861 .64056 .23038 .68993 .16414 .66397 .10469 Metetra
.761 .668 .759 r
.66397 .10469 .68993 .16414 .73912 .1053 .71447 .05704 Metetra
.47 .574 .878 r
.03634 .26033 .06578 .30339 .10354 .3147 .07538 .26156 Metetra
.531 .555 .825 r
.07538 .26156 .10354 .3147 .14305 .32273 .1161 .2586 Metetra
.586 .546 .776 r
.1161 .2586 .14305 .32273 .1854 .31671 .15876 .24821 Metetra
.615 .551 .759 r
.15876 .24821 .1854 .31671 .22974 .30009 .2029 .23214 Metetra
.625 .559 .761 r
.2029 .23214 .22974 .30009 .27495 .28177 .24798 .21425 Metetra
.624 .562 .764 r
.24798 .21425 .27495 .28177 .32081 .26456 .2938 .19644 Metetra
.622 .561 .765 r
.2938 .19644 .32081 .26456 .36744 .24763 .34041 .17861 Metetra
.623 .561 .764 r
.34041 .17861 .36744 .24763 .41493 .22985 .38785 .16036 Metetra
.622 .561 .765 r
.38785 .16036 .41493 .22985 .46324 .21234 .43614 .14207 Metetra
.619 .559 .765 r
.43614 .14207 .46324 .21234 .51244 .19593 .48531 .12384 Metetra
.626 .56 .761 r
.48531 .12384 .51244 .19593 .56257 .17776 .53539 .10371 Metetra
.65 .57 .752 r
.53539 .10371 .56257 .17776 .61332 .14861 .58626 .07767 Metetra
.687 .6 .753 r
.58626 .07767 .61332 .14861 .66397 .10469 .63755 .04381 Metetra
.724 .65 .775 r
.63755 .04381 .66397 .10469 .71447 .05704 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09549 .2323 m
.1002 .23687 L
s
gsave
.08608 .22315 -86 -18.7884 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.21633 .18498 m
.22084 .18975 L
s
gsave
.20731 .17545 -85.3204 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -70.3112 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.47614 .08324 m
.48017 .08842 L
s
gsave
.46808 .07289 -75.2307 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.61605 .02846 m
.6198 .03385 L
s
gsave
.60856 .01769 -74.5635 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.11921 .22301 m
.12201 .22578 L
s
.14315 .21364 m
.14592 .21643 L
s
.16731 .20417 m
.17006 .20699 L
s
.1917 .19462 m
.19443 .19746 L
s
.24119 .17525 m
.24387 .17813 L
s
.26629 .16542 m
.26894 .16832 L
s
.29163 .15549 m
.29426 .15843 L
s
.31722 .14547 m
.31982 .14843 L
s
.36916 .12514 m
.3717 .12814 L
s
.39551 .11482 m
.39802 .11785 L
s
.42212 .1044 m
.4246 .10745 L
s
.449 .09387 m
.45145 .09696 L
s
.50356 .07251 m
.50595 .07564 L
s
.53126 .06166 m
.53361 .06482 L
s
.55924 .05071 m
.56155 .05389 L
s
.5875 .03964 m
.58978 .04285 L
s
.072 .2415 m
.07484 .24422 L
s
.04872 .25061 m
.05159 .25331 L
s
.6449 .01716 m
.64711 .02042 L
s
.67405 .00575 m
.67622 .00903 L
s
gsave
.29165 .07573 -101.038 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.625000 moveto
(@) show
78.562500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.312500 14.625000 moveto
(D) show
101.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{391, 317},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000670001?A000`40O003h00OogooR7oo003oOon8
Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00
ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOon8
Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00
ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOolPOol50002Ool3001NOol00?moob5oo`06
001oogoo001oo`000goo00<007ooOol0Fgoo003oOolROol01@00Oomoogoo00000goo00<007ooOol0
Fgoo003/Ool50002Ool3000ROol70003Ool01000Oomoo`000goo00<007ooOol0Fgoo003]Ool01P00
Oomoo`00Ool000=oo`03001oogoo02Yoo`03001oo`0000=oo`03001oogoo05]oo`00kWoo00D007oo
Oomoo`0000=oo`03001oogoo02Yoo`03001oo`0000=oo`03001oogoo05]oo`00kgoo00@007ooOol0
00=oo`03001oogoo02Yoo`03001oo`0000=oo`03001oogoo05]oo`00l7oo00<007oo00000goo00<0
07ooOol05goo0P003Goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`1KOol00?1oo`03001oo`00
00=oo`03001oogoo01Eoo`D000eoo`<000=oo`<005ioo`00l7oo00<007oo00000goo00<007ooOol0
4Woo0`000goo0P00M7oo003/Ool01`00Oomoogoo001oo`0000=oo`03001oogoo011oo`80009oo`03
001oogoo00800003Ool007oo079oo`00kGoo0`000goo0`0047oo0`001Goo0P0000ENV000001oo`00
079oo`00ogoo17oo0`001goo00@005jHGYQNV0800003Ool007oo075oo`00ogoo0Woo0P0000=oo`00
Ool01Woo00<005jHGYP00UjH00D005jH001oo`00075oo`00oWoo0`002Goo0P001EjH00<005jH0000
0Woo00<007ooOol0KWoo003lOol2000;Ool00`00GYQNV006GYP01000GYP007oo0P00Kgoo003iOol3
000<Ool00`00GYQNV007GYP00`00GYP00003001_Ool00?Moo`800003Ool007oo00Yoo`8000YNV004
001NV5jH0002Ool00`00Oomoo`1/Ool00?Aoo`<000Aoo`03001oogoo00Moo`03001NV5jH00YNV004
001NV5jH0002Ool00`00Oomoo`1/Ool007Qoo`<001Aoo`<005moo`<0011oo`03001NV5jH00]NV005
001NV5jHGYP00002Ool00`00Oomoo`1[Ool007Qoo`03001oogoo01Ioo`03001oogoo05]oo`<0011o
o`8000iNV005001NV5jHGYP00003Ool00`00Oomoo`1ZOol006aoo`<0009oo`<000Aoo`04001oogoo
Ool3000017oo000007oo1@0000Aoo`00001oo`8000=oo`03001oogoo02]oo`<000=oo`<002Aoo`<0
009oo`03001oogoo00eoo`03001NV5jH00iNV003001NV5jH009NV004001oogoo001/Ool006eoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Aoo`03001oogoo02aoo`05001oogooOol00003Ool00`00Oomoo`0OOol2000COol3
000@GYP00`00GYQNV002GYP01@00Oomoogoo0000Jgoo001^Ool01000Oomoo`001Woo00<007ooOol0
0Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0;7oo00D007oo
Oomoo`0000=oo`03001oogoo01aoo`<001Aoo`05001FN5IhEWP0000?GYP00`00GYQNV003GYP01@00
Oomoogoo0000JWoo001_Ool20007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009o
o`04001oogoo0004Ool00`00Oomoo`0/Ool01@00Oomoogoo00000goo00<007ooOol06Woo0P0000=o
o`00Ool04Woo0P0015Ih00<005jHGYP03EjH00<005jHGYP00ejH00<007ooOol00P00JWoo001`Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool200001Goo000007oo00000Woo0P0000Eoo`00001oo`0000Ao
o`03001oogoo02aoo`05001oogooOol00003Ool00`00Oomoo`0GOol3000FOol00`00EWQFN005EWP0
0`00GYQNV00<GYP00`00GYQNV004GYP01@00Oomoogoo0000JGoo001_Ool20007Ool01000Oomoogoo
0P0000Eoo`00Oomoo`00009oo`800005Ool007ooOol00005Ool00`00Oomoo`0/Ool01@00Oomoogoo
00000goo00<007ooOol057oo0`005goo0P0025Ih00<005jHGYP035jH00<005jHGYP00ejH0P000goo
00<007ooOol0Igoo001^Ool01000Oomoo`001Woo00<007ooOol05Woo00<007ooOol0;7oo00D007oo
Oomoo`0000=oo`03001oogoo019oo`<001Moo`8000]FN003001NV5jH00]NV003001NV5jH009NV004
001R^6:h0003Ool00`00Oomoo`1VOol006eoo`03001oogoo009oo`03001oogoo00=oo`<001Aoo`<0
02eoo`8000=oo`05001oogooOol0000AOol30002Ool00`00Oomoo`0DOol00`00EWQFN00;EWP00`00
GYQNV00;GYP01@00GYQNV5jH00000f:h00<007ooOol00Woo00<007ooOol0IGoo001/Ool30002Ool3
001<Ool00`00Oomoo`02Ool3000@Ool2000JOol2000>EWP00`00GYQNV00;GYP01000GYQNV0001F:h
00D007ooOomoo`0006Moo`00eGoo0`006goo00<005IhEWP03eIh00<005jHGYP02UjH00<005jH0000
1V:h00<007ooOol00Woo00<007ooOol0I7oo003COol20002Ool00`00Oomoo`0GOol2000BEWP00`00
GYQNV00;GYP00`00H[QR^006H[P00`00Oomoo`02Ool00`00Oomoo`1SOol00=1oo`<001eoo`03001F
N5Ih01=FN003001NV5jH00UNV08000QR^004001oogooOol2001UOol00<eoo`<001ioo`<001EFN003
001NV5jH00MNV0800003H[P006:h00QR^003001oogoo009oo`03001oogoo069oo`00bgoo0`007Woo
0P000e9H00<005IhEWP04UIh00<005jHGYP01UjH00D006:hH[QR^00000UR^003001oogoo00=oo`03
001oogoo065oo`00b7oo0`000goo00<007ooOol06Goo0P001E9H00<005IhEWP04eIh00<005jHGYP0
15jH00<006:hH[P00V:h00<006:hH[P026:h00<007ooOol00Woo00<007ooOol0HGoo0036Ool2000P
Ool20008DUP00`00EWQFN00BEWP00`00GYQNV003GYP00`00H[QR^003H[P00`00H[QR^008H[P00`00
Oomoo`03Ool00`00Oomoo`1POol009Yoo`<002Ioo`<0021oo`8000YBF003001FN5Ih01=FN005001N
V5jHGYP00006H[P00`00H[QR^009H[P00`00Oomoo`03Ool00`00Oomoo`1OOol009Uoo`05001oogoo
Ool0000SOol20002Ool00`00Oomoo`0LOol2000<DUP00`00EWQFN00CEWP01000GYQNV0001f:h00<0
06:hH[P02F:h00<007ooOol00goo00<007ooOol0Ggoo002IOol01@00Oomoogoo000087oo0`008Goo
0P003e9H00<005IhEWP04eIh0P0026:h00<006:hH[P02V:h00<007ooOol00goo00<007ooOol0GWoo
002IOol01@00Oomoogoo00007Goo0`008Goo0`004E9H00<005IhEWP04eIh00<006:hH[P01f:h00<0
06:hH[P02V:h00<007ooOol00Woo00<007oo0000Ggoo002IOol01@00Oomoogoo00006goo0P000Woo
00<007ooOol07Goo0P0000=B>000DUP04U9H00<005IhEWP04EIh0P002F:h00<006:hH[P02f:h00<0
07ooOol00goo00<007ooOol04Goo0`000goo0`00@goo002IOol01@00Oomoogoo000067oo0`008Goo
0`00158h00<0059HDUP0459H00<005IhEWP045Ih00@005YFFUH000QR^003001R^6:h00YR^003001Z
n00000Eoo`03001oogoo015oo`05001oogooOol00003Ool00`00Oomoo`10Ool009Uoo`05001oogoo
Ool0000FOol2000QOol30007DSP00`00DUQBF00@DUP00`00EWQFN00?EWP01@00FUIJEUYF000026:h
00<006:hH[P02F:h00@006[hJ_P000Ioo`03001oogoo011oo`05001oogooOol00003Ool00`00Oomo
o`10Ool009Uoo`05001oogooOol0000COol3000QOol2000:DSP00`00DUQBF00ADUP00`00EWQFN00<
EWP20005FUH00`00H[QR^005H[P00`00H[QR^008H[P00`00J_QZn002J_P00`00Oomoo`03Ool00`00
Oomoo`06Ool70003Ool01@00Oomoogoo00000goo00<007ooOol0@7oo002JOol3000BOol20003Ool0
0`00Oomoo`0KOol3000=DSP00`00DUQBF00@DUP00`00EWQFN00;EWP00`00FUIJEP05FUH00`00H[QR
^005H[P00`00H[QR^007H[P00`00J_QZn003J_P00`00Oomoo`04Ool00`00Oomoo`0?Ool01@00Oomo
ogoo00000goo00<007ooOol0@7oo002/Ool3000POol3000@DSP00`00DUQBF00ADUP00`00EWQFN009
EWP00`00FUIJEP07FUH00`00H[QR^004H[P00`00H[QR^007H[P00`00J_QZn004J_P00`00Oomoo`04
Ool00`00Oomoo`0>Ool01@00Oomoogoo00000goo00<007ooOol0@7oo002ZOol2000QOol200000dhh
001B>00ADSP00`00DUQBF00@DUP00`00EWQFN008EWP00`00FUIJEP08FUH00`00H[QR^005H[P00`00
H[QR^005H[P00`00J_QZn006J_P00`00Oomoo`03Ool00`00Oomoo`0>Ool01@00Oomoogoo00000goo
00<007ooOol0@7oo002WOol30002Ool00`00Oomoo`0KOol30004CSP00`00DSQB>00?DSP00`00DUQB
F00ADUP00`00EWQFN006EWP00`00FUIJEP09FUH00`00H[QR^005H[P00`00H[QR^004H[P00`00J_QZ
n007J_P01000Oomoogoo0P0000=oo`00Ool03Goo0P000goo00D007ooOomoo`00049oo`00Y7oo0`00
87oo0`001dhh00<0058hDSP03e8h00<0059HDUP04E9H00<005IhEWP01EIh00<005YFFUH02eYF00<0
06:hH[P016:h00<006:hH[P00f:h00<006[hJ_P02F[h00<007ooOol017oo00<007ooOol037oo00<0
07ooOol00Woo0`00@goo002ROol2000QOol2000;CSP00`00DSQB>00?DSP00`00DUQBF00@DUP00`00
EWQFN004EWP00`00FUIJEP0<FUH00`00H[QR^004H[P00`00H[QR^002H[P00`00J_QZn00;J_P00`00
Oomoo`03Ool00`00Oomoo`1GOol009moo`<00003Ool007oo01eoo`<000e>>003001B>58h00mB>003
001BF59H015BF004001FN5IhEWP2000@FUH00`00H[QR^003H[P01@00H[QR^6:h00003V[h00<007oo
Ool017oo00<007ooOol0EWoo002MOol20005Ool00`00Oomoo`0HOol3000@CSP00`00DSQB>00?DSP0
0`00DUQBF00ADUP01000EWQFN0004UYF00<006:hH[P00f:h00@006:hH[P0011Zn003001oogoo00Ao
o`03001oogoo05Eoo`00JWoo0`000goo0`009goo0`0087oo0P0000=>>000CSP04Dhh00<0058hDSP0
3e8h00<0059HDUP04E9H0P004eYF00<006:hH[P00f:h00<006:h00004F[h00<007ooOol017oo00<0
07ooOol0EGoo001[Ool01@00Oomoogoo00000goo00<007ooOol08Woo0P0000=oo`00Ool07Goo0`00
14hh00<004hhCSP03dhh00<0058hDSP03e8h00<0059HDUP04E9H00<005YFFUH04eYF00<006:hH[P0
0V:h0P004f[h00<007ooOol017oo00<007ooOol0E7oo001[Ool01@00Oomoogoo00000goo00<007oo
Ool07goo0`0087oo0P001dhh00<004hhCSP044hh00<0058hDSP03e8h00<0059HDUP03U9H0`005EYF
00<006:hH[P00V:h0P004V[h00<006lH000017oo00<007oo0000EGoo001ROol70002Ool01@00Oomo
ogoo00000goo00<007ooOol077oo0`0087oo0`002Thh00<004hhCSP03dhh00<0058hDSP03e8h00<0
059HDUP03E9H00D0058FDQIB5P0001EJEP05001R^6:hH[P0000BJ_P01000KaQ_60001Woo00<007oo
Ool0Dgoo001[Ool01@00Oomoogoo00000goo00<007ooOol06Woo0`0087oo0P003Dhh00<004hhCSP0
3dhh00<0058hDSP03e8h00<0059HDUP02e9H0P00158F00<005YFFUH04eYF00<006:hH[P00P004V[h
00D006lHKaQ_600000Ioo`03001oogoo059oo`00Jgoo00D007ooOomoo`0000=oo`03001oogoo01Mo
o`<000=oo`03001oogoo01Yoo`<000m>>003001>>4hh011>>003001B>58h00mB>003001BF59H00QB
F08000IB5P03001JEUYF01AJEP800003J_P006[h011Zn003001_66lH009_6003001oogoo00Eoo`03
001oogoo055oo`00Jgoo00D007ooOomoo`0000=oo`03001oogoo01Eoo`80025oo`800003CSP004hh
011>>003001>>4hh00m>>003001B>58h00mB>003001BF59H00MBF003001B5U8F00MB5P03001JEUYF
01=JEP04001Zn6[h000@J_P00`00KaQ_6004KaP00`00Oomoo`04Ool00`00Oomoo`1AOol006Yoo`80
00=oo`05001oogooOol0000DOol3000POol30004CSP00`00CSQ>>00>CSP00`00CSQ>>00?CSP00`00
DSQB>00?DSP00`00DUQBF005DUP2000:DQH00`00FUIJEP0BFUH20002J_P00`00J_QZn00=J_P00`00
KaQ_6005KaP00`00Oomoo`05Ool00`00Oomoo`1@Ool006]oo`03001oogoo009oo`<001=oo`8000=o
o`03001oogoo01]oo`8000M>>003001>>4hh00m>>003001>>4hh00m>>003001B>58h00mB>003001B
F59H00=BF003001B5U8F00YB5P03001JEUYF019JEP05001RMP00J_P0000?J_P00`00KaQ_6006KaP0
0`00Oomoo`04Ool00`00Oomoo`1@Ool008=oo`<0021oo`<000Y>>003001>>4hh00i>>003001>>4hh
00m>>003001B>58h00mB>004001BF59HDUP2000>DQH00`00FUIJEP0@FUH01000HWIRMP000V[h00<0
06[hJ_P02f[h00<006lHKaP01flH00<007ooOol017oo0P00DGoo0020Ool3000QOol2000=CSP00`00
CSQ>>00>CSP00`00CSQ>>00@CSP00`00DSQB>00?DSP3000@DQH00`00FUIJEP0?FUH00`00HWIRMP02
HWH00`00J_P0000<J_P00`00KaQ_6009KaP00`00Oomoo`05Ool00`00Oomoo`1>Ool007ioo`8000=o
o`03001oogoo01]oo`<000m>>003001>>4hh00m>>003001>>4hh00m>>003001B>58h00iB>080019B
5P03001JEUYF00iJEP03001RMV9f00=RMP03001Zn00000]Zn003001_66lH00Y_6003001oogoo00Eo
o`03001oogoo04ioo`00Ngoo0`008Goo0P0000=>>000CSP044hh00<004hhCSP03Thh00<004hhCSP0
3dhh00<0058hDSP02e8h0`0000=>5`00DQH04U8F00<005YFFUH03EYF00<0069fHWH0169f0P002f[h
00<006lHKaP02flH00<007ooOol01Goo00<007ooOol0CGoo001iOol2000QOol30004CSP00`00CSQ>
>00>CSP00`00CSQ>>00>CSP00`00CSQ>>00@CSP00`00DSQB>007DSP30005CQL00`00DQIB5P0@DQH0
0`00FUIJEP0<FUH00`00HWIRMP05HWH2000:J_P00`00KaQ_600<KaP00`00Oomoo`06Ool00`00Oomo
o`1<Ool007Ioo`<0009oo`03001oogoo01aoo`8000M>>003001>>4hh00m>>003001>>4hh00i>>003
001>>4hh00m>>003001B>58h00=B>0@000Q>5`03001B5U8F011B5P03001JEUYF00]JEP03001RMV9f
00MRMP03001Zn6[h00MZn003001_66lH00i_6003001oogoo00Eoo`03001oogoo04aoo`00M7oo0P00
1Woo00<007ooOol067oo0`002Dhh00<004hhCSP03dhh00<004hhCSP03Thh00<004hhCSP044hh00<0
058h00000P0034hG00<0058FDQH04E8F00<005YFFUH02UYF00<0069fHWH01f9f00<006[hJ_P01V[h
00<006lHKaP03VlH00<007<h00001goo00<007ooOol0;7oo0`005Goo0`0017oo0012Ool50002Ool3
000UOol3000QOol2000=CSP00`00CSQ>>00>CSP00`00CSQ>>00?CSP00`00CSQ>>00>CSP3000?CQL0
0`00DQIB5P0ADQH00`00FUIJEP09FUH00`00HWIRMP08HWH20007J_P00`00KaQ_600>KaP00`00LcP0
0006Ool3000]Ool00`00Oomoo`0GOol00`00Oomoo`02Ool004=oo`06001oogoo001oo`000goo00<0
07ooOol07goo0`000Woo00<007ooOol077oo0`003dhh00<004hhCSP03dhh00<004hhCSP03Thh00<0
04hhCSP034hh0P0000=>5`00CQL044hG00<0058FDQH04E8F00<005YFFUH01eYF00<0069fHWH02F9f
0P001V[h00<006lHKaP03VlH00D007<hLcQc>00000Moo`03001oogoo029oo`<000Ioo`04001oogoo
Ool3000017oo000007oo1@0000Aoo`00001oo`8000Aoo`03001oogoo009oo`00A7oo00D007ooOomo
o`0000=oo`03001oogoo01eoo`80025oo`<00003CSP004hh011>>003001>>4hh00i>>003001>>4hh
00i>>003001>>4hh00U>>0<000A>5`03001>5dhG00i>5`03001B5U8F015B5P03001JEUYF00IJEP03
001RMV9f00YRMP03001RMP0000AZn003001_66lH00i_6003001c>7<h00=c>003001oogoo00Eoo`03
001oogoo029oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol000Eoo`03001oogoo009oo`00>goo1`000goo00@007ooOol000=oo`03001oogoo01Yo
o`<0021oo`<000E>>003001>>4hh00i>>003001>>4hh00m>>003001>>4hh00i>>003001>>4hh00E>
>0<000M>5`03001>5dhG00i>5`03001B5U8F015B5P03001JEUYF00IJEP03001RMV9f00YRMP03001R
MP0000=Zn003001_66lH00i_6003001c>7<h00Ac>003001oogoo00Ioo`03001oogoo025oo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03
001oogoo009oo`00AWoo00<007oo00000goo00<007ooOol067oo0P000Woo00<007ooOol06goo0`00
24hh00<004hhCSP03Thh00<004hhCSP03dhh00<004hhCSP03Thh00<004hhCSP00dhh0P002ThG00<0
04hGCQL03ThG00<0058FDQH04U8F00<005YFFUH015YF00<0069fHWH02f9f00@0069fHWH0009Zn003
001_66lH00i_6003001c>7<h00Ec>003001oogoo00Eoo`03001oogoo025oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo009o
o`00AWoo00<007oo00000goo00<007ooOol05Goo0`007goo0`0034hh00<004hhCSP03Thh00<004hh
CSP03dhh00<004hhCSP03Thh00<004hh00000P0034hG00<004hGCQL03dhG00<0058FDQH04E8F00<0
05YFFUH00eYF00<0069fHWH0369f00H0069fHWH006[h000@KaP00`00LcQc>006LcP00`00Oomoo`06
Ool00`00Oomoo`0OOol00`00Ool00006Ool00`00Oomoo`02Ool200001Goo000007oo00000Woo0P00
00Eoo`00001oo`0000Eoo`03001oogoo009oo`00AWoo00<007oo00000goo00<007ooOol04goo0P00
7goo0`003dhh00<004hhCSP03Thh00<004hhCSP03dhh00<004hhCSP03Dhh0`0044hG00<004hGCQL0
3ThG00<0058FDQH04E8F00<005YFFUH00eYF00<0069fHWH0369f00D0069fHWIRMP00011_6003001c
>7<h00Qc>003001oogoo00Ioo`03001oogoo01ioo`03001oo`0000Ioo`04001oogooOol200001Goo
001oogoo00000Woo0P0000Eoo`00Oomoo`0000Ioo`03001oogoo009oo`00@Woo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`0@Ool30002Ool00`00Oomoo`0JOol200000dhh001>>00?CSP00`00CSQ>
>00>CSP00`00CSQ>>00?CSP00`00CSQ>>00:CSP300000dhG001>5`0@CQL00`00CQM>5`0>CQL00`00
DQIB5P0BDQH01@00FUIJEUYF00003f9f00H0069fHWH007<F000?KaP00`00LcQc>009LcP00`00Oomo
o`04Ool2000POol01000Oomoo`001Goo00<007ooOol05goo00<007ooOol00Woo0013Ool30003Ool3
000@Ool3000POol20004CSP00`00CSQ>>00>CSP00`00CSQ>>00>CSP00`00CSQ>>00?CSP00`00CSQ>
>006CSP30005CQL00`00CQM>5`0>CQL00`00CQM>5`0?CQL00`00DQIB5P0ADQH01000FUIJEP00469f
00H0069fHWH007<F000>KaP00`00LcQc>00:LcP00`00Oomoo`06Ool00`00Oomoo`08Ool3000AOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool3000EOol30004Ool005Yoo`80021oo`<000I>>003001>>4hh
00i>>003001>>4hh00i>>003001>>4hh00m>>003001>>4hh00=>>0<000Q>5`03001>5dhG00m>5`03
001>5dhG00i>5`03001B5U8F015B5P03001JEP00019RMP8000=c5P03001_66lH00Y_6003001c>7<h
00ac>003001oogoo00Ioo`03001oogoo00Ioo`05001oogooOol0000?Ool30002Ool3000ROol005Mo
o`<0009oo`03001oogoo01]oo`8000Y>>003001>>4hh00e>>003001>>4hh00i>>003001>>4hh011>
>003001>>000008000]>5`03001>5dhG00m>5`03001>5dhG00i>5`03001B5U8F019B5P80019RMP80
00=c5P03001_66lH00U_6003001c>7<h00ac>003001c>00000Moo`03001oogoo00Ioo`05001oogoo
Ool0000iOol005Eoo`80025oo`8000a>>003001>>4hh00i>>003001>>4hh00i>>003001>>4hh00i>
>0<000m>5`03001>5dhG00i>5`03001>5dhG00i>5`03001B5U8F019B5P03001RMV9f015RMP03001c
5W<F00=c5P03001_66lH00Q_6003001c>7<h00ac>003001c>00000Qoo`03001oogoo00Eoo`05001o
ogooOol0000iOol0059oo`<0021oo`<000i>>003001>>4hh00i>>003001>>4hh00i>>003001>>4hh
00a>>0800003CQL004hG00m>5`03001>5dhG00i>5`03001>5dhG00m>5`03001B5U8F011B5P8001=R
MP03001c5W<F00Ac5P03001_66lH00I_6003001c>7<h00ac>005001c>7<hLcP00008Ool00`00Oomo
o`04Ool01@00Oomoogoo0000>Goo001@Ool20002Ool00`00Oomoo`0KOol300000dhh001>>00?CSP0
0`00CSQ>>00>CSP00`00CSQ>>00>CSP00`00CSQ>>008CSP30004CQL00`00CQM>5`0=CQL00`00CQM>
5`0?CQL00`00CQM>5`0>CQL00`00DQIB5P0>DQH20002EQD00`00HWIRMP0?HWH20006LaH00`00KaQ_
6005KaP00`00LcQc>00<LcP00`00LcQc>003LcP00`00Oomoo`05Ool00`00Oomoo`04Ool01@00Oomo
ogoo0000>Goo001=Ool30005Ool00`00Oomoo`0HOol20005CSP00`00CSQ>>00=CSP00`00CSQ>>00>
CSP00`00CSQ>>00>CSP00`00CSQ>>005CSP30007CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00
CQM>5`0>CQL00`00DQIB5P0=DQH00`00EQEF5@02EQD00`00HWIRMP0?HWH20007LaH00`00KaQ_6004
KaP00`00LcQc>00;LcP00`00LcQc>004LcP00`00Oomoo`04Ool30005Ool01@00Oomoogoo0000>Goo
001:Ool3000POol30007CSP00`00CSQ>>00>CSP00`00CSQ>>00=CSP00`00CSQ>>00>CSP00`00CSQ>
>003CSP2000:CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`0?CQL00`00DQIB5P0;DQH0
0`00EQEF5@03EQD00`00HWIRMP0>HWH00`00LaH00008LaH00`00KaQ_6002KaP00`00LcQc>00<LcP0
0`00LcQc>005LcP00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo0000>Goo0018Ool20003
Ool00`00Oomoo`0JOol3000:CSP00`00CSQ>>00>CSP00`00CSQ>>00>CSP00`00CSQ>>00>CSP00`00
CSP00002000<CQL00`00CQM>5`0>CQL00`00CQM>5`0?CQL00`00CQM>5`0>CQL00`00DQIB5P09DQH2
0007EQD00`00HWIRMP0=HWH30008LaH01@00KaQ_66lH00003W<h00<007<hLcP01g<h00<007ooOol0
1Goo00<007ooOol00goo0`00>Woo0015Ool3000OOol3000>CSP00`00CSQ>>00=CSP00`00CSQ>>00>
CSP00`00CSQ>>00=CSP3000@CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00
DQIB5P08DQH00`00EQEF5@07EQD00`00HWIRMP0;HWH30002LaH00`00LaIc5P06LaH00`00KaP0000>
LcP00`00LcQc>009LcP00`00Oomoo`05Ool00`00Oomoo`0oOol004=oo`<001eoo`@00003BSP004hh
00i>>003001>>4hh00i>>003001>>4hh00e>>003001>>4hh00Y>>0<00003CQL004hG011>5`03001>
5dhG00i>5`03001>5dhG00i>5`03001>5dhG00i>5`03001B5U8F00MB5P03001F5EHE00QF5@03001R
MV9f00QRMP<00003HWH007<F009c5P03001c5W<F00Ic5P03001_600000ic>003001c>7<h00Uc>003
001oogoo00Ioo`03001oogoo03ioo`00@Goo0P000Woo00<007ooOol067oo0`001TXh00<004hhCSP0
3Dhh00<004hhCSP03Dhh00<004hhCSP03Thh00<004hhCSP01Thh0`001DhG00<004hGCQL03ThG00<0
04hGCQL03ThG00<004hGCQL03ThG00<004hGCQL03dhG00<0058FDQH0158F0P0035HE00<0069fHWH0
169f0`000f9f00<007<FLaH00g<F00<007<FLaH01W<F00<007<hLcP037<h00<007<hLcP02g<h00<0
07ooOol01Goo00<007ooOol0?Woo0011Ool2000IOol40009BSP00`00CSQ>>00=CSP00`00CSQ>>00>
CSP00`00CSQ>>00=CSP00`00CSQ>>003CSP30008CQL00`00CQM>5`0?CQL00`00CQM>5`0>CQL00`00
CQM>5`0>CQL00`00CQM>5`0>CQL00`00DQIB5P03DQH00`00EQEF5@0<EQD00`00HWIRMP02HWH20006
HWH00`00LaIc5P04LaH00`00LaIc5P05LaH2000<LcP00`00LcQc>00;LcP00`00LcP00007Ool00`00
Oomoo`0mOol0045ooa/000e:>003001>>4hh00e>>003001>>4hh00i>>003001>>4hh00i>>003001>
>000008000]>5`03001>5dhG00m>5`03001>5dhG00i>5`03001>5dhG00i>5`03001>5dhG00i>5`03
001B5U8F009B5P03001F5EHE00eF5@03001RMP00008000MRMP03001c5W<F00Ic5P03001c5W<F00=c
5P03001g=P0000]c>003001c>7<h00ac>003001c>00000Ioo`<003ioo`00@7oo0`002ciL00<0048j
@SX02D8j00<004XhBSP03DXh00<004hhCSP03Dhh00<004hhCSP03Thh00<004hhCSP034hh0`003dhG
00<004hGCQL03ThG00<004hGCQL03ThG00<004hGCQL03ThG00<004hGCQL03ThG00<0058FDQH00P00
3eHE0`002V9f00<007<FLaH01W<F00<007<FLaH00g<F00@007LfMcH000Yc>003001c>7<h00]c>005
001c>7<hLcP00007Ool00`00Oomoo`0lOol0041oo`03001oo`0000/nG0030012>T8j00Y2>P03001:
>4Xh00a:>003001>>4hh00e>>003001>>4hh00i>>003001>>4hh00Y>>0800003CQL004hG00m>5`03
001>5dhG00m>5`03001>5dhG00i>5`03001>5dhG00i>5`03001>5dhG00i>5`8000iF5@<0009F5@03
001RMV9f00MRMP03001c5W<F00Qc5P05001c5W<FLaH00004McH00`00LcQc>006LcP00`00LcQc>00;
LcP00`00LcQc>002LcP00`00Oomoo`06Ool00`00Oomoo`0kOol0041oo`04001oogoo000;?U`00`00
@SY2>P09@SX00`00BSQ:>00=BSP00`00CSQ>>00<CSP00`00CSQ>>00>CSP00`00CSQ>>008CSP20004
CQL00`00CQM>5`0=CQL00`00CQM>5`0?CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`0=
CQL2000<EQD30005EQD00`00HWIRMP07HWH00`00LaIc5P09LaH01000LaIc5P0017Lf00<007<hLcP0
1G<h00<007<hLcP02g<h00<007<hLcP017<h00<007ooOol01Goo00<007ooOol0>goo0010Ool20002
Ool00`00?U`nG008?U`00`00@SY2>P0:@SX00`00BSQ:>00<BSP00`00CSQ>>00=CSP00`00CSQ>>00>
CSP00`00CSQ>>004CSP30006CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00
CQM>5`0>CQL00`00CQM>5`09CQL400000dWf001F5@08EQD30008EQD00`00HWIRMP06HWH00`00LaIc
5P0;LaH20006McH00`00LcQc>004LcP00`00LcQc>00;LcP00`00LcQc>005LcP00`00Oomoo`05Ool0
0`00Oomoo`0jOol0041oo`05001oogooOol0000;?U`00`00@SY2>P09@SX00`00BSQ:>00<BSP00`00
CSQ>>00=CSP00`00CSQ>>00>CSP00`00CSQ>>002CSP20009CQL00`00CQM>5`0>CQL00`00CQM>5`0>
CQL00`00CQM>5`0?CQL00`00CQM>5`0=CQL00`00CQM>5`05CQL40006BOH00`00EQEF5@03EQD3000<
EQD00`00HWIRMP05HWH00`00LaIc5P0;LaH20006McH00`00LcQc>003LcP00`00LcQc>00;LcP00`00
LcQc>006LcP00`00Oomoo`06Ool00`00Oomoo`0iOol0041oo`03001oogoo009oo`03000nG3iL00Pn
G0030012>T8j00Y2>P03001:>4Xh00a:>003001>>4hh00a>>003001>>4hh00m>>004001>>000000<
CQL00`00CQM>5`0=CQL00`00CQM>5`0?CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`04
000:BOH00`00EQEF5@03000?EQD00`00HWIRMP04HWH00`00LaIc5P0<LaH20007McH01@00LcQc>7<h
00003G<h00<007<hLcP027<h00<007ooOol017oo0P00>goo000oOol30003Ool00`00?U`nG009?U`0
0`00@SY2>P09@SX00`00BSQ:>00<BSP00`00CSQ>>00=CSP00`00CSQ>>00=CSP3000>CQL00`00CQM>
5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`0=CQL4000>BOH3000BEQD00`00HWIR
MP04HWH00`00LaIc5P0<LaH00`00McH00007McH00`00LcP0000>LcP00`00LcQc>008LcP00`00Oomo
o`06Ool00`00Oomoo`0hOol003moo`03001oogoo00Aoo`03000nG3iL00PnG0030012>T8j00Y2>P03
001:>4Xh00]:>003001>>4hh00e>>003001>>4hh00]>>0800003CQL004hG00i>5`03001>5dhG00i>
5`03001>5dhG00i>5`03001>5dhG00m>5`03001>5dhG00U>5`<00003BOH004Wf00e9mP<001EF5@03
001RMV9f009RMP03001c5W<F00ac5P04001g=WLf0007McH00`00LcP0000=LcP00`00LcQc>00:LcP0
0`00Oomoo`06Ool00`00Oomoo`0gOol003moo`03001oogoo00Eoo`03000nG3iL00PnG0030012>T8j
00U2>P03001:>4Xh00a:>003001>>4hh00e>>003001>>4hh00M>>0<000A>5`03001>5dhG00e>5`03
001>5dhG00e>5`03001>5dhG00m>5`03001>5dhG00i>5`03001>5dhG00I>5`<000E9mP030019mTWf
00Q9mP<000=9mP03001F5EHE019F5@03001RMV9f009RMP03001c5W<F00ac5P05001g=WLfMcH00007
McH00`00LcQc>00;LcP00`00LcQc>00:LcP00`00LcP00007Ool00`00Oomoo`0gOol002aoo`<000=o
o`03001oogoo00<000Moo`8000Ioo`03000nG3iL00PnG0030012>T8j00U2>P03001:>4Xh00a:>003
001>>4hh00e>>003001>>4hh00E>>08000M>5`03001>5dhG00e>5`03001>5dhG00i>5`03001>5dhG
00i>5`03001>5dhG00i>5`03001>5dhG00=>5`<000Q9mP030019mTWf00E9mP<000I9mP03001F5EHE
019F5@05001RMV9fHWH0000>LaH00`00McIg=P03McH00`00McIg=P04McH2000;LcP00`00LcQc>00;
LcP01000LcQc>0001goo00<007ooOol0=Woo000[Ool01@00Oomoogoo00001Woo00<007ooOol01Woo
00<007ooOol01Woo00<003iL?U`023iL00<0048j@SX02D8j00<004XhBSP02dXh00<004hhCSP03Dhh
00<004hhCSP00Thh0`002DhG00<004hGCQL03DhG00<004hGCQL03ThG00<004hGCQL03ThG00<004hG
CQL03dhG00<004hG00000P002dWf00<004WfBOH00TWf0`002DWf00<005HEEQD04eHE00@0069fHWH0
00ic5P03001g=WLf00Ag=P03001g=WLf009g=P03001g=P0000]c>003001c>7<h00Yc>005001c>7<h
LcP00008Ool00`00Oomoo`0eOol002]oo`05001oogooOol00006Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00?U`nG007?U`00`00@SY2>P09@SX00`00BSQ:>00<BSP00`00CSQ>>00=CSP01000CSP0
00003DhG00<004hGCQL03DhG00<004hGCQL03DhG00<004hGCQL03dhG00<004hGCQL03DhG0`003TWf
00<004Wf00000P0034Wf00<005HEEQD04eHE00<0069f00003W<F00<007LfMcH01GLf00<007LfMcH0
0WLf00@007LfMcH000Uc>003001c>7<h00Yc>003001c>7<h00=c>003001oogoo00Eoo`03001oogoo
03Eoo`00:goo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`03001oogoo00Moo`03000nG3iL00Pn
G0030012>T8j00U2>P03001:>4Xh00]:>003001>>4hh00a>>0<000m>5`03001>5dhG00e>5`03001>
5dhG00i>5`03001>5dhG00i>5`03001>5dhG00Y>5`<00003COH004Wf00e9mP<00119mP03001F5EHE
019F5@03001RMP0000ic5P03001g=WLf00Ig=P04001g=WLf0004McH00`00LcQc>005LcP00`00LcQc
>00:LcP00`00LcQc>005LcP00`00Oomoo`03Ool3000fOol002]oo`05001oogooOol00006Ool00`00
Oomoo`05Ool30009Ool20008?U`00`00@SY2>P09@SX00`00BSQ:>00<BSP00`00CSQ>>008CSP30000
0dhF001>5`0?CQL00`00CQM>5`0=CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`07CQL3
0005COH00`00BOI9mP08BOH30002BOH00`00BOI9mP0>BOH00`00EQEF5@0CEQD00`00LaIc5P0<LaH0
0`00McIg=P08McH00`00McH00004McH00`00LcQc>005LcP00`00LcQc>00:LcP00`00LcQc>006LcP0
0`00Oomoo`05Ool00`00Oomoo`0cOol002]oo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool50005?U`00`00@SY2>P09@SX00`00BSQ:>00;BSP00`00CSQ>>006CSP20005CQH00`00
CQM>5`0=CQL00`00CQM>5`0>CQL00`00CQM>5`0=CQL00`00CQM>5`0>CQL00`00CQM>5`03CQL40008
COH00`00BOI9mP05BOH30005BOH00`00BOI9mP0>BOH00`00EQEF5@0CEQD00`00LaIc5P0<LaH00`00
McIg=P09McH00`00McIg=P04McH00`00LcQc>003LcP00`00LcQc>00:LcP00`00LcQc>007LcP00`00
Oomoo`05Ool00`00Oomoo`0cOol002]oo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`009O`Uo0029O`400000ciL0012>P0:@SX00`00BSQ:>00;BSP00`00CSQ>>003CSP30007
CQH00`00CQM>5`0>CQL00`00CQM>5`0=CQL00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQL00002
000<COH00`00BOI9mP02BOH30009BOH00`00BOI9mP0>BOH00`00EQEF5@0AEQD00`00J_P0000<LaH0
0`00McIg=P0:McH00`00McIg=P05McH01@00LcQc>7<h000037<h00<007<hLcP02G<h00<007ooOol0
1Goo00<007ooOol0<Woo000[Ool01@00Oomoogoo00001Goo0P001goo0P0037oo00<002Gl9O`01BGl
1@002D8j00<004XhBSP02dXh00<004hh00000P002ThF00<004hGCQL03ThG00<004hGCQL03DhG00<0
04hGCQL03ThG00<004hGCQL03DhG0`003dgf00<004WfBOH00P0034Wf00<004WfBOH03TWf00<005HE
EQD045HE00@006[hJ_P000ac5P03001g=WLf00Ug=P03001g=P0000Mg=P03001c>00000ec>003001c
>7<h00Yc>003001oogoo00Eoo`03001oogoo035oo`00;7oo0`001goo00<007ooOol01Goo00<007oo
Ool037oo00<002Gl9O`01bGl00<003Gj00000`001D8j00<004XhBSP024Xh1@003ThF00<004hGCQL0
3DhG00<004hGCQL03ThG00<004hGCQL03DhG00<004hGCQL02dhG0P0000==mP00COH03dgf0`003TWf
00<004WfBOH03TWf00<005HEEQD045HE00D006[hJ_QZn00000Yc5P03001g=WLf00Yg=P04001g=WLf
0006McH00`00LcP0000<LcP00`00LcQc>00:LcP00`00LcP00006Ool00`00Oomoo`0aOol003ioo`03
001oogoo00aoo`03000Uo2Gl00LUo003000enSGj00<enP@00092>P04001:>4XhBSP60003AOL00`00
CQI>5P0=CQH00`00CQM>5`0>CQL00`00CQM>5`0=CQL00`00CQM>5`0>CQL00`00CQM>5`07CQL30004
COH00`00COI=mP0:COH300000dgf0019mP0>BOH00`00BOI9mP0>BOH00`00EQEF5@0?EQD00`00J_QZ
n002J_P00`00LaIc5P08LaH00`00McIg=P09McH01@00McIg=WLf00001gLf00<007<hLcP02W<h00<0
07<hLcP02g<h00<007<h00001Goo0`002Woo0`000goo0`007goo000mOol00`00Oomoo`0>Ool00`00
9O`Uo0079O`00`00=OXenP06=OX6000:AOL00`00CQI>5P0<CQH00`00CQM>5`0>CQL00`00CQM>5`0=
CQL00`00CQM>5`0>CQL00`00CQM>5`05CQL20007COH00`00COI=mP07COH30004COH00`00BOI9mP0>
BOH00`00BOI9mP0>BOH00`00EQEF5@0=EQD00`00J_QZn004J_P00`00LaIc5P06LaH00`00McIg=P0:
McH00`00McIg=P02McH00`00McIg=P04McH2000;LcP00`00LcQc>00:LcP01@00LcQc>7<h00001goo
00<007ooOol027oo00D007ooOomoo`0000=oo`03001oogoo01aoo`00?Goo0P0047oo00<002Gl9O`0
1RGl00<003Gj=OX023Gj00<004GgAOL02dGg00<004hFCQH034hF00<004hGCQL03ThG00<004hGCQL0
3ThG00<004hGCQL03DhG00<004hGCQL00ThG0`002Dgf00<004gfCOH014gf0`001dgf00<004WfBOH0
3TWf00<004WfBOH03TWf00<005HEEQD035HE00<006[hJ_P01F[h00<007<FLaH01W<F00<007LfMcH0
2GLf00<007LfMcH017Lf00<007LfMcH00WLf00@007LfMcH000Uc>003001c>7<h00Yc>003001c>7<h
00=c>003001oogoo00Aoo`03001oogoo00Qoo`05001oogooOol00003Ool00`00Oomoo`0LOol003eo
o`03001oogoo011oo`03000Uo2Gl00HUo003000enSGj00PenP030015mdGg00Y5m`03001>5ThF00e>
5P03001>5dhG00i>5`03001>5dhG00e>5`03001>5dhG00i>5`04001>5`00000<COH01000COI=mTgf
0`002dgf00<004WfBOH03DWf00<004WfBOH03TWf00<005HEEQD035HE00<006[hJ_P01V[h00<007<F
LaH017<F00<007LfMcH02WLf00<007LfMcH01GLf00D007LfMcIg=P00009g=P03001c>7<h00Ic>003
001c>7<h00]c>003001c>7<h00=c>003001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00003
Ool00`00Oomoo`0LOol003eoo`03001oogoo011oo`03000Uo2Gl00HUo003000enSGj00PenP030015
mdGg00Y5m`03001>5ThF00e>5P03001>5dhG00i>5`03001>5dhG00e>5`03001>5dhG00e>5`<000m=
mP<000i=mP030019mTWf00i9mP030019mTWf00e9mP03001F5EHE00]F5@03001Zn6[h00QZn003001c
5W<F00=c5P03001g=WLf00Ug=P03001g=WLf00Ig=P04001g=WLf0004McH00`00LcQc>004LcP00`00
LcQc>00;LcP00`00LcQc>005LcP00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo
00<007ooOol077oo000mOol3000AOol00`009O`Uo0069O`00`00=OXenP07=OX00`00AOM5m`0;AOL0
0`00CQI>5P0<CQH00`00CQM>5`0>CQL00`00CQM>5`0>CQL00`00CQM>5`09CQL300000dgf001=mP0<
COH4000@COH00`00BOI9mP0>BOH00`00BOI9mP0>BOH00`00EQEF5@09EQD00`00J_QZn009J_P00`00
LaIc5P02LaH00`00McIg=P0:McH00`00McIg=P07McH00`00McH00005McH00`00LcQc>003LcP00`00
LcQc>00:LcP00`00LcQc>007LcP00`00Oomoo`04Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo
00<007ooOol077oo000mOol00`00Oomoo`0BOol00`009O`Uo0059O`00`00=OXenP08=OX00`00AOM5
m`0:AOL00`00CQI>5P0=CQH00`00CQM>5`0>CQL00`00CQM>5`0=CQL00`00CQM>5`06CQL30005COH0
0`00COI=mP08COH20003COH00`00COI=mP0>COH00`00BOI9mP0>BOH00`00BOI9mP0>BOH00`00EQEF
5@08EQD00`00J_QZn00;J_P01@00LaIc5W<F000037Lf00<007LfMcH027Lf00<007LfMcH01GLf00D0
07<hLcQc>00000ec>003001c>7<h00Mc>003001oogoo00Eoo`03001oogoo00Eoo`05001oogooOol0
0003Ool00`00Oomoo`0LOol003eoo`03001oogoo019oo`03000Uo2Gl00HUo003000enSGj00LenP03
0015mdGg00Y5m`03001>5ThF00e>5P03001>5dhG00i>5`03001>5dhG00e>5`03001>5dhG00=>5`<0
00Q=mP03001=mTgf00E=mP<000E=mP03001=mTgf00m=mP030019mTWf00i9mP030019mTWf00e9mP03
001F5EHE00QF5@03001Zn6[h00]Zn004001c5W<F000<McH00`00McIg=P09McH00`00McIg=P05McH0
1000LcQc>0003G<h00<007<hLcP02G<h00<007ooOol00Woo0P0000=oo`00Ool017oo0P000goo00D0
07ooOomoo`0001ioo`008goo0`000goo00<007ooOol00`000Woo0`0027oo00<007ooOol057oo00<0
02Gl9O`01BGl00<003Gj=OX01cGj00<004GgAOL02dGg00<004hFCQH034hF00<004hGCQL03ThG00<0
04hGCQL03ThG00<004hG00000P002dgf00<004gfCOH00Tgf0`002Dgf00<004gfCOH03Tgf00<004Wf
BOH03TWf00<004WfBOH03TWf00<005HEEQD01UHE00<006[hJ_P03F[h00<007<F000037Lf00<007Lf
McH027Lf00<007Lf00001gLf00<007<h000037<h00<007<hLcP02G<h00<007=H00001Woo00<007oo
Ool017oo00<007ooOol00Woo0`007goo000ROol01@00Oomoogoo00001Woo00<007ooOol017oo00<0
07ooOol01Goo0P005Woo0P001RGl00<003Gj=OX01cGj00<004GgAOL02TGg00<004hFCQH03DhF00<0
04hGCQL03DhG00<004hGCQL03DhG0`003Tgf00<004gf00000P0034gf00<004gfCOH03Tgf00<004Wf
BOH03TWf00<004WfBOH03TWf00<005HEEQD01EHE00<006[hJ_P03V[h0P0037Lf00<007LfMcH02GLf
00@007LfMcH000Mg=P03001c>7<h00]c>003001c>7<h00Uc>003001cF00000Moo`03001oogoo02Yo
o`008Woo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo01Ioo`<0
00@Uo003000enSGj00LenP030015mdGg00Y5m`03001>5ThF00e>5P03001>5dhG00i>5`03001>5dhG
00U>5`<00003COH004gf00e=mP<000m=mP03001=mTgf00m=mP030019mTWf00e9mP030019mTWf00i9
mP03001F5EHE00AF5@03001Zn6[h011Zn003001g=WLf00Yg=P03001g=WLf00Qg=P03001g=WLf009g
=P03001g=WLf00Ag=P8000]c>003001c>7<h00Uc>005001cF7=HLeP00007Ool00`00Oomoo`0YOol0
029oo`05001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00
0CT000049O`00`00=OXenP06=OX00`00AOM5m`0;AOL00`00CQI>5P0<CQH00`00CQM>5`0>CQL00`00
CQM>5`06CQL30005COH00`00COI=mP08COH30002COH00`00COI=mP0=COH00`00COI=mP0?COH00`00
BOI9mP0>BOH00`00BOI9mP0=BOH00`00EQEF5@04EQD00`00J_QZn00?J_P00`00LeP0000:McH00`00
McIg=P09McH00`00McIg=P02McH00`00McIg=P03McH00`00McH0000:LcP00`00LcQc>009LcP00`00
LeQcF003LeP00`00Oomoo`04Ool00`00Oomoo`0YOol0029oo`05001oogooOol00006Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool2000IOol010000CT000000RGl00<003Gj=OX01cGj00<004GgAOL02TGg
00<004hFCQH03DhF00<004hGCQL03DhG00<004hGCQL00dhG0`0024gf00<004gfCOH01Dgf0`001Dgf
00<004gfCOH03Tgf00<004gfCOH03Tgf00<004WfBOH03TWf00<004WfBOH03TWf00<005HEEQD00UHE
00<006[hJ_P046[h00@007=HLeP000Ug=P03001g=WLf00Qg=P03001g=WLf00Ag=P03001g=WLf009g
=P04001g=WLf0009LcP00`00LcQc>009LcP00`00LeQcF003LeP00`00Oomoo`03Ool3000ZOol0029o
o`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`000CT1
>@0200000bGl000enP07=OX00`00AOM5m`0:AOL00`00CQI>5P0=CQH00`00CQM>5`0>CQL00`00CQL0
0002000;COH00`00COI=mP02COH30008COH00`00COI=mP0>COH00`00COI=mP0>COH00`00BOI9mP0>
BOH00`00BOI9mP0>BOH01@00EQEF5EHE00004V[h00D007=HLeQcF00000Qg=P03001g=WLf00Ug=P03
001g=WLf00Eg=P04001g=WLf0004McH00`00LcQc>005LcP00`00LcQc>009LcP00`00LeQcF005LeP0
0`00Oomoo`05Ool00`00Oomoo`0WOol0029oo`05001oogooOol00006Ool00`00Oomoo`02Ool20007
Ool00`00Oomoo`0JOol00`000CT1>@020CT20008=OX00`00AOM5m`0:AOL00`00CQI>5P0=CQH00`00
CQM>5`0=CQL3000>COH00`00COH00002000<COH00`00COI=mP0=COH00`00COI=mP0?COH00`00BOI9
mP0>BOH00`00BOI9mP0=BOH01000EQEF5@004V[h00<007=HLeP00g=H00<007LfMcH01GLf00<007Lf
McH027Lf00<007LfMcH01gLf00<007Lf000017Lf00<007<hLcP017<h00<007<hLcP02G<h00<007=H
LeP01g=H00<007ooOol017oo00<007ooOol09goo000ROol01@00Oomoogoo00001Goo0P0017oo00<0
07ooOol01Woo00<007ooOol06goo00<0004i0CT00`4i00<003Gj=OX01SGj00<004GgAOL02TGg00<0
04hFCQH034hF00<004hGCQL02dhG0P0000=>5P00COH03Tgf0P003dgf00<004gfCOH03Tgf00<004gf
COH03Tgf00<004WfBOH03TWf00<004WfBOH03DWf00@005HEEQD0015Zn003001cF7=H00EcF003001g
=WLf00=g=P03001g=WLf00Ug=P03001g=WLf00Mg=P8000Ig=P03001c>7<h00=c>003001c>7<h00Uc
>003001cF7=H00McF003001oogoo00Eoo`03001oogoo02Ioo`008goo0`001goo00<007ooOol00goo
0`001Goo0P007Goo00<0004i0CT00`4i00<003Gj=OX01CGj00<004GgAOL02TGg00<004hFCQH03DhF
00<004hGCQL01dhG0`0014hF00<004gfCOH02Dgf0`0000==mP00COH03Tgf00<004gfCOH03Tgf00<0
04gfCOH03Tgf00<004WfBOH03TWf00<004WfBOH03TWf0P004V[h00<007=HLeP01W=H00<007LfMcH0
0WLf00<007LfMcH02GLf00<007LfMcH027Lf00<007LfMcH01GLf00D007<hLcQc>00000]c>003001c
F7=H00UcF003001oogoo00Eoo`03001oogoo02Eoo`00>goo00<007ooOol07Goo00<0004i0CT00P4i
0P001SGj00<004GgAOL02TGg00<004hFCQH03DhF00<004hGCQL01DhG0P001dhF00<004gfCOH01Tgf
0`0014gf00<004gfCOH03Dgf00<004gfCOH03Tgf00<004gfCOH03Tgf00<004WfBOH03TWf00<004Wf
BOH02dWf10004V[h00<007=HLeP027=H00@007LfMcH000]g=P03001g=WLf00Qg=P03001g=P0000Mg
=P03001c>00000]c>003001cF7=H00UcF003001gN00000Ioo`03001oogoo02Eoo`00>goo00<007oo
Ool07Woo00<0004i0CT00P4i0`001CGj00<004GgAOL02TGg00<004hFCQH034hF00<004hGCQL00ThG
0`002DhF00<004gfCOH00dgf0`001dgf00<004gfCOH03Tgf00<004gfCOH03Dgf00<004gfCOH03dgf
00<004WfBOH03TWf00<004WfBOH00TWf200014ZL00<006[hJ_P03V[h00<007=HLeP02G=H00@007Lf
McH000]g=P03001g=WLf00Qg=P03001g=P0000Mg=P03001c>00000]c>003001cF7=H00UcF003001g
N00000Eoo`<002Ioo`00>goo0P0087oo00<0004i0CT00P4i00<0003g000013Gj00<004GgAOL02TGg
00<004hFCQH03DhF00@004hG000000a>5P03001=mTgf00<000]=mP03001=mTgf00e=mP03001=mTgf
00i=mP03001=mTgf00i=mP030019mTWf00e9mPH000a:W003001Zn6[h00iZn003001cF7=H00YcF080
00]g=P03001g=WLf00Qg=P05001g=WLfMcH00007McH00`00LcQc>009LcP00`00LeQcF009LeP01@00
MgQgN7Mh00001Woo00<007ooOol097oo000jOol2000ROol01@000CT1>@4i00000P3g00D003Gj=OXe
nP0000a5m`03001>5ThF00a>5P<000i>5P<000i=mP03001=mTgf00e=mP03001=mTgf00i=mP03001=
mTgf00i=mP030019mTWf00U9mP@0009>^`03001:W4ZL00i:W003001Zn6[h00aZn003001cF7=H00ac
F003001g=WLf00Ug=P03001g=WLf00Qg=P03001g=WLf009g=P03001g=WLf00Ag=P8000Uc>003001c
F7=H00UcF003001gN7Mh00=gN003001oogoo00Aoo`03001oogoo02=oo`00>Woo00<007ooOol08Woo
00D0004i0CT1>@000080m`05000enSGj=OX0000<AOL00`00CQI>5P09CQH200000dgf001>5P0;CQH3
00000dhF001=mP0>COH00`00COI=mP0>COH00`00COI=mP0=COH00`00COI=mP0>COH00`00BOI9mP05
BOH40006C[/00`00BYa:W00?BY`00`00J_QZn00:J_P00`00LeQcF00<LeP00`00KcP00009McH00`00
McIg=P09McH00`00McIg=P03McH00`00McIg=P02McH00`00McH00009LcP00`00LeQcF008LeP00`00
MgQgN005MgP00`00Oomoo`04Ool00`00Oomoo`0ROol003Yoo`03001oo`0002=oo`040001>@4i0003
0?L01000=OXenP0034Gg00<004hFCQH01dhF0P0014gf00<004hFCQH01ThF0`0014hF00<004gfCOH0
3Dgf00<004gfCOH03Tgf00<004gfCOH03Dgf00<004gfCOH03dgf00<004WfBOH010002djk00<004ZL
BY`03TZL00<006[hJ_P02F[h00<007=HLeP037=H00@006lhKcP000Ug=P03001g=WLf00Qg=P03001g
=WLf00Ag=P03001g=WLf009g=P04001g=WLf0007LcP00`00LeQcF009LeP00`00MgQgN005MgP00`00
Oomoo`04Ool00`00Oomoo`0ROol0019oo`<000Uoo`<001Uoo`8002Eoo`040001>@4i00030?L3000<
AOL00`00CQI>5P04CQH30006COH00`00CQI>5P03CQH30007CQH00`00COI=mP0>COH00`00COI=mP0=
COH00`00COI=mP0>COH00`00COI=mP0=COH4000?C[/00`00BYa:W00?BY`00`00J_QZn008J_P00`00
LeQcF00<LeP01@00KcQ_>6lh00001gLf00<007LfMcH02GLf00<007LfMcH01GLf00@007LfMcH000Ag
=P03001c>7<h00=c>003001cF7=H00UcF003001gN7Mh00MgN003001oogoo00Aoo`03001oogoo025o
o`004Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol097oo0`0000<1>@000?L00`3g0P00
2dGg00<004hFCQH00ThF0P002Dgf00@004hFCQI>5P8000]>5P03001=mTgf00e=mP03001=mTgf00e=
mP03001=mTgf00i=mP03001=mTgf00Y=mP<0009B^`03001>^djk00m>^`03001:W4ZL00i:W003001Z
n6[h00MZn003001cF7=H00acF003001_>6lh00=_>003001g=WLf00Ag=P03001g=WLf00Qg=P03001g
=WLf00Mg=P03001g=P0000Ag=P03001c>7<h00=c>003001cF7=H00QcF003001gN7Mh00MgN003001g
^00000Aoo`<0029oo`000Woo1P000Woo1@000goo00<007ooOol00goo0`001Goo00<007ooOol00goo
0`000goo00<007oo000010001goo00<007ooOol09Goo00@0001d000000D0m`L000I5m`04001>5P00
000;COH4000=CQH00`00COI=mP0=COH00`00COI=mP0>COH00`00COI=mP0=COH00`00COI=mP07COH3
0005D[/00`00C[]>^`0?C[/00`00BYa:W00?BY`00`00J_QZn005J_P00`00LeQcF00<LeP00`00KcQ_
>004KcP00`00McIg=P03McH00`00McIg=P09McH00`00McIg=P08McH00`00McIg=P04McH01@00LcQc
>7<h00002g=H00<007MhMgP01gMh00@007NhMkP000Eoo`03001oogoo021oo`000goo00<007ooOol0
0Woo00@007ooOol0009oo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo00001Goo00@007ooOol000Ioo`8002Qoo`040000M00000040?L00`00?MPmf004?MP8000;
COH4000?CQH00`00COI=mP0>COH00`00COI=mP0=COH00`00COI=mP0=COH00`00COI=mP03COH40009
D[/00`00C[]>^`0?C[/00`00BYa:W00?BY`00`00J_QZn004J_P00`00LeQcF00;LeP00`00KcQ_>006
KcP00`00McIg=P02McH00`00McIg=P08McH00`00McIg=P09McH00`00McIg=P05McH00`00LcP0000;
LeP00`00MgQgN007MgP01@00MkQg^7Nh00001Woo00<007ooOol07goo0003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00D007ooOomo
o`0000Ioo`03001oogoo00Ioo`03001oogoo02Qoo`040000M00000040?L00`00?MPmf009?MP00`00
COI=mP07COH30003COH00`00CQI>5P0>CQH00`00COI=mP0=COH00`00COI=mP0=COH00`00COI=mP0>
COH00`00COH00002000>D[/00`00C[]>^`0?C[/00`00BYa:W00>BY`00`00J_QZn003J_P00`00LeQc
F00;LeP00`00KcQ_>008KcP01000McIg=P002gLf00<007LfMcH027Lf00<007Lf00001WLf00<007<h
00002W=H00<007MhMgP01gMh00<007NhMkP00gNh00<007ooOol017oo00<007ooOol07Woo0003Ool0
0`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
0Woo00D007ooOomoo`0000Moo`03001oogoo00Eoo`03001oogoo02Uoo`030000M00000@0m`03000m
f3gH00Xmf003001=mTgf00==mP<000I=mP03001>5ThF00i>5P03001=mTgf00e=mP03001=mTgf00e=
mP03001=mTgf00e=mP<0015B^`03001>^djk00m>^`03001:W4ZL00m:W005001Zn6[hJ_P0000>LeP0
0`00KcQ_>009KcP00`00McH0000:McH00`00McIg=P09McH01000McIg=P001WLf00<007=HLeP02G=H
00<007MhMgP01gMh00<007NhMkP017Nh00<007ooOol00goo00<007ooOol07Woo0003Ool50002Ool0
1000Oomoo`0017oo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`00
00Qoo`03001oogoo00Aoo`03001oogoo02Yoo`030000M00000<0m`03000mf3gH00Xmf003001=mTgf
00<000U=mP03001>5ThF00i>5P03001=mTgf00e=mP03001=mTgf00i=mP03001=mTgf00Y=mP80009B
^`03001B^e:k011B^`03001>^djk00m>^`03001:W4ZL00m:W003001Zn00000icF003001_>6lh00Y_
>08000]g=P03001g=WLf00Qg=P05001g=WLfMcH00006McH20009LeP00`00MgQgN007MgP00`00MkQg
^006MkP00`00Oomoo`03Ool00`00Oomoo`07Ool50002Ool3000<Ool000=oo`05001oogooOol00002
Ool50003Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo000027oo
00<007ooOol017oo0P00;7oo00<0001d00000`3g00<003gH?MP02CgH0`003Dgf00<004hFCQH03DhF
00<004gfCOH03Tgf00<004gfCOH03Dgf00<004gfCOH01dgf0`0015:k00<005:kD[/045:k00<004jk
C[/03djk00<004ZLBY`03dZL00<006[h00003G=H00<006lhKcP036lh00<007LfMcH02GLf00<007Lf
McH027Lf00<007LfMcH00WLf00<007LfMcH00WLf00<007Lf000027=H00<007MhMgP01gMh00<007Nh
MkP01WNh00<007?i00000goo00<007oo00002Goo00H007ooOol007oo0003Ool00`00Oomoo`09Ool0
00=oo`05001oogooOol0000:Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00
Oomoogoo000027oo00<007ooOol017oo00<007ooOol0;7oo0P000`3g00<003gH?MP01SgH10003dgf
00<004hFCQH03ThF00<004gfCOH03Dgf00<004gfCOH03Dgf00<004gfCOH01Dgf0P0025:k00<005:k
D[/045:k00<004jkC[/03djk00<004ZLBY`02dZL1@003G=H00<006lhKcP036lh00<006lh00002GLf
00<007LfMcH027Lf00<007LfMcH017Lf00D007LfMcIg=P00009g=P03001cF7=H00AcF003001gN7Mh
00QgN003001g^7Nh00Eg^005001cnG?iLoT00004Ool00`00Oomoo`08Ool01@00Oomoogoo00000goo
00<007ooOol02Goo0003Ool01@00Oomoogoo00002Woo0`0000Eoo`00Oomoo`00009oo`03001oo`00
008000Aoo`05001oogooOol00004Ool01@00Oomoogoo00001Woo00<007ooOol0;Goo0P000P3g00<0
03gH?MP013gH0P0013gH00<004gfCOH034gf00<004hFCQH03ThF00<004gfCOH03Dgf00<004gfCOH0
3Dgf00<004gfCOH00Tgf0`002e:k00<005:kD[/045:k00<004jkC[/03Tjk00<004ZLBY`00dZL2000
1D;o00<007=HLeP02G=H00<006lhKcP036lh00@006lhKcP000Ug=P03001g=WLf00Qg=P03001g=WLf
00Eg=P03001g=P0000Ag=P03001cF7=H00=cF003001gN7Mh00MgN003001g^7Nh00Ig^003001cnG?i
009cn@03001oogoo009oo`03001oogoo00Qoo`04001oogoo0003Ool00`00Oomoo`09Ool0009oo`D0
00moo`L000Uoo`<000Ioo`<000Ioo`03001oogoo02moo`050000m`3g0?L00002?MP30006?MP00`00
COI=mP0=COH00`00CQI>5P0=CQH00`00COI=mP0=COH00`00COI=mP0>COH01000COH000003U:k00<0
05:kD[/045:k00<004jkC[/03Tjk1P003T;o00<007=HLeP027=H00<006lhKcP036lh00D006lhKcQ_
>00000Mg=P03001g=WLf00Qg=P03001g=WLf00Ig=P03001g=P0000Eg=P05001cF7=HLeP00009MgP0
0`00MkQg^006MkP00`00LoUcn@04LoT00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool00003Ool0
0`00Oomoo`09Ool003Qoo`80035oo`030000m`3g00<000Tmf003001=mTgf00e=mP03001>5ThF00i>
5P03001=mTgf00e=mP03001=mTgf00a=mP<0015B^`03001B^e:k011B^`03001>^djk00U>^`@0009?
?`030012od;o00m2o`03001cF7=H00McF003001_>6lh00a_>003001_>6lh00=_>003001g=WLf00Ag
=P03001g=WLf00Qg=P03001g=WLf00Mg=P03001g=WLf00Ag=P04001cF7=H0009MgP00`00MkQg^006
MkP00`00LoUcn@06LoT01@00Oomoogoo00002Woo00<007oo00000goo00<007ooOol02Goo000hOol0
0`00Oomoo`0`Ool4000;?MP00`00COI=mP0=COH00`00CQI>5P0>CQH00`00COI=mP0=COH00`00COI=
mP09COH30002D[/00`00D[]B^`0?D[/00`00D[]B^`0AD[/00`00C[]>^`04C[/40007Ccl00`00@_m2
o`0?@_l00`00LeQcF005LeP00`00KcQ_>00<KcP00`00KcQ_>004KcP00`00McIg=P03McH00`00McIg
=P09McH00`00McIg=P07McH20006McH00`00LeP00009MgP00`00MkQg^005MkP00`00LoUcn@06LoT0
1@00JoX00000Ool00P002Goo00<007oo00000goo00<007ooOol02Goo000hOol00`00Oomoo`0]Ool3
00001Goo0000m`3g00002cgH00<004gfCOH034gf00<004hFCQH03ThF00<004gfCOH03Dgf00<004gf
COH01Tgf0`001E:k00<005:kD[/045:k00<005:kD[/045:k00<004jkC[/0100034lo00<004;o@_l0
3d;o00<007=HLeP00g=H00<006lhKcP036lh00<006lhKcP01Vlh00<007LfMcH00WLf00<007LfMcH0
27Lf00<007LfMcH01gLf00@007LfMcH000Ig=P03001gN7Mh00MgN003001g^7Nh00Ig^003001cnG?i
00Ecn@03001[nV_j009[nP<000Eoo`07001oogooOol007oo00000goo00<007ooOol02Goo000hOol2
000[Ool30005Ool00`000?L0000;?MP00`00COI=mP0=COH00`00CQI>5P0=CQH00`00COI=mP0=COH0
0`00COI=mP03COH30009D[/00`00D[]B^`0@D[/00`00D[]B^`0?D[/3000ACcl00`00@_m2o`0?@_l0
1@00LeQcF7=H00003flh00<006lhKcP01flh00@007LfMcH000]g=P03001g=WLf00Mg=P04001g=WLf
0006McH20007MgP00`00MkQg^006MkP00`00LoUcn@05LoT00`00JoY[nP05JoX00`00Oomoo`04Ool3
0003Ool3000<Ool003Qoo`03001oogoo02Moo`<000Qoo`040000m`3g000:?MP00`00COI=mP0=COH0
0`00CQI>5P0>CQH00`00COI=mP0=COH00`00COH00002000=D[/00`00D[]B^`0?D[/00`00D[]B^`0<
D[/30002Dch00`00Ccm??`0@Ccl00`00@_m2o`0>@_l01@00LeQcF7=H00003Vlh00<006lhKcP02Flh
00<007Lf00002WLf00<007LfMcH027Lf00D007LfMcIg=P0000Ag=P04001kMG]e0006MgP00`00MkQg
^005MkP00`00LoUcn@05LoT00`00JoY[nP05JoX2000KOol003Moo`03001oogoo02Eoo`<000aoo`03
0000m`0000Xmf003001=mTgf00e=mP03001>5ThF00i>5P03001=mTgf00a=mP<0011B^`03001B^e:k
011B^`03001B^e:k00QB^`<000IC?P03001??dlo011??`030012od;o00i2o`03001cF00000i_>003
001_>6lh00Y_>08000]g=P03001g=WLf00Mg=P03001g=WLf00=g=P05001g=WLfMcH00003NgD00`00
MgQgN002MgP00`00MkQg^005MkP00`00LoUcn@05LoT00`00JoY[nP04JoX20002Ool00`00Oomoo`0H
Ool003Moo`03001oogoo029oo`<000moo`030000m`0000/mf003001=mTgf00e=mP03001>5ThF00e>
5P03001=mTgf00Q=mP@0009B^`03001B^e:k00mB^`03001B^e:k011B^`03001B^e:k00=B^`@000YC
?P03001??dlo011??`030012od;o00M2o`P000i_>003001_>6lh00a_>003001g=WLf00Qg=P03001g
=WLf00Qg=P03001g=WLf00=g=P04001g=WLf0005NgD01000MgQgN00027Nh00<007?iLoT00g?i0P00
1V_j00<007ooOol00Woo00<007ooOol067oo000gOol00`00Ool0000POol2000COol00`000?L0000:
?MP00`00COI=mP0=COH00`00CQI>5P0=CQH00`00COI=mP04COH40006D[/00`00D[]B^`0?D[/00`00
D[]B^`0@D[/00`00D[]B^`03000?Dch2000?Ccl;0008@[h00`00KcQ_>00;KcP00`00KcQ_>00;KcP0
0`00LeP00009McH00`00McIg=P07McH00`00McIg=P05McH00`00McH00006NgD00`00MgP00007MkP0
0`00LoUcn@03LoT00`00JoY[nP05JoX00`00Oomoo`03Ool00`00Oomoo`0HOol003Moo`8001ioo`<0
01Ioo`8000Xmf003001=mTgf00e=mP03001>5ThF00i>5P03001=mP0000<000]B^`03001B^e:k00mB
^`03001B^e:k00mB^`<001AC?P03001??dlo00M??`D000=>o@030012_T:n00i2_P03001_>6lh00U_
>003001_>6lh00a_>004001cF7=H0007McH00`00McIg=P08McH00`00McIg=P06McH00`00NgEkM@06
NgD00`00MkQg^005MkP00`00LoUcn@03LoT00`00JoY[nP04JoX20006Ool00`00Oomoo`0HOol001eo
o`<000=oo`03001oo`0000@00004Ool000000009Ool00`00Oomoo`0JOol3000IOol2000:?MP00`00
COI=mP0=COH00`00CQI>5P0=CQH3000@D[/00`00D[]B^`0?D[/00`00D[]B^`0<D[/20002Ech00`00
DciC?P0CDch01000Ccm??dlo1@002Dkm00<004:n@[h03D:n00<006lhKcP026lh00<006lhKcP036lh
00D007=HLeQcF00000Mg=P03001g=WLf00Mg=P03001g=WLf00Mg=P8000MkM@8000Eg^003001cnG?i
00=cn@03001[nV_j00A[nP03001oogoo00Ioo`03001oogoo01Qoo`0077oo00D007ooOomoo`0000Eo
o`04001oogoo0004Ool00`00Oomoo`06Ool00`00Oomoo`0GOol3000MOol2000:?MP00`00COI=mP0=
COH00`00CQI>5P0:CQH20002E[/00`00D[]B^`0>D[/00`00D[]B^`0?D[/00`00D[]B^`09D[/30005
Ech00`00DciC?P0BDch4000?C_d00`00@[i2_P0=@[h00`00KcQ_>006KcP00`00KcQ_>00<KcP00`00
LeQcF003LeP00`00McIg=P03McH00`00McIg=P08McH00`00McIg=P07McH20006NgD00`00Jhi[SP02
0003MkP00`00LoUcn@02LoT00`00JoY[nP04JoX00`00Oomoo`07Ool00`00Oomoo`0HOol001aoo`05
001oogooOol00006Ool00`00Oomoo`05Ool00`00Oomoo`04Ool3000EOol3000POol2000:?MP00`00
COI=mP0=COH00`00CQI>5P07CQH30004E[/00`00D[]B^`0?D[/00`00D[]B^`0?D[/00`00D[]B^`06
D[/20009Ech00`00DciC?P0?Dch20002Dad00`00C_e>o@0?C_d00`00@[i2_P0=@[h00`00KcQ_>005
KcP00`00KcQ_>00;KcP00`00LeQcF005LeP00`00McIg=P02McH00`00McIg=P07McH00`00McIg=P07
McH01000NgEkM@001G]e00<006^>Jhh00V^>00<007Nh000017?i00<006_jJoX00f_j0P002Woo00<0
07ooOol067oo000LOol01@00Oomoogoo00001goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool04Woo0`0097oo00<003gH?MP023gH00<004gfCOH03Dgf00<004hFCQH01DhF0P0025Jk00<005:k
D[/03e:k00<005:kD[/03e:k00<005:kD[/00U:k0`0035Ln00<005<nDch02e<n0`001E<M00<004km
C_d03Tkm00<004:n@[h03T:n00<006lhKcP00flh00<006lhKcP036lh00<007=HLeP01W=H00@007Lf
McH000Yg=P03001g=WLf00Mg=P05001kMG]eNgD00003NgD00`00Jhi[SP04Jhh80003JoX00`00Oomo
o`0;Ool00`00Oomoo`0GOol001aoo`05001oogooOol00008Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool3000WOol20009?MP00`00COI=mP0=COH00`00CQI>5P02CQH3000;E[/00`00
D[]B^`0?D[/00`00D[]B^`0>D[/00`00D[]B^`02000@Ech00`00DciC?P07Dch30008Dad00`00C_e>
o@0?C_d00`00@[i2_P0>@[h01@00KcQ_>6lh00003Vlh00<007=HLeP01g=H00@007LfMcH000Ug=P03
001g=WLf00Mg=P03001kMG]e009kM@05001kMG]eNgD00005Jhh60003Bi@3000>Ool00`00Oomoo`0G
Ool001aoo`05001oogooOol00008Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool3
000[Ool00`00?MPmf008?MP00`00COI=mP0=COH01000CQH000003UJk00<005:kD[/03e:k00<005:k
D[/03U:k0`004eLn00<005<nDch015<n0P0035<M00<004kmC_d03dkm00<004:n@[h03D:n00@006lh
KcP000i_>003001cF7=H00UcF08000Yg=P03001g=WLf00Mg=P03001kMG]e00=kM@03001kM@0000I[
SPD000A;U08000moo`03001oogoo01Moo`0077oo00D007ooOomoo`0000Qoo`03001oogoo008000Qo
o`8000Yoo`<002moo`8000Pmf003001=mTgf00e=mP80015F^`03001B^e:k00mB^`03001B^e:k00UB
^`@0009??P03001G?ULn019G?P03001C?U<n00<000mC7@03001>oDkm00m>o@030012_T:n00e2_P03
001_>00000i_>003001cF7=H00YcF003001g=WLf00Qg=P03001g=WLf00Ig=P03001kMG]e00EkM@80
00E[SPD000=;U080015oo`03001oogoo01Moo`0077oo00D007ooOomoo`0000Aoo`05001oogooOol0
0002Ool00`00Oomoo`07Ool00`00Oomoo`07Ool2000bOol00`000AP00007?MP00`00COI=mP0;COH2
00000eZj001F^`0@E[/00`00D[]B^`0@D[/00`00D[]B^`04D[/40007Cch00`00EciG?P0AEch3000C
Dad00`00C_e>o@0>C_dB000>KcP00`00LeQcF00:LeP00`00LeP00008McH00`00McIg=P07McH00`00
NgEkM@05NgD20004Jhh40003Bi@2000COol00`00Oomoo`0GOol001eoo`<000Ioo`<000Aoo`<000Eo
o`03001oogoo00Eoo`<003Eoo`04000160000005?MP00`00COI=mP09COH20003F[X00`00E[]F^`0@
E[/00`00D[]B^`0?D[/00`00D[]B^`04000<Cch00`00EciG?P0=Ech30002Ead00`00DaeC7@0BDad0
0`00C_e>o@09C_d40002C_h00`00?[hn_P0=?[h00`00KcQ_>00:KcP00`00LeQcF00;LeP01000LeQc
F0001gLf00<007LfMcH01WLf00<007]eNgD01W]e0P000f^>10000d^D00<007ooOol04goo00<007oo
Ool05goo000eOol20003Ool3000iOol010000AP160001CgH00<004gfCOH01Tgf0P001UZj00<005Jk
E[/045Jk00<005:kD[/03U:k0`004Dln0P002ULn0`001ULM00<005<MDad04E<M00<004kmC_d01Dkm
10001dkn00<003jn?[h03Cjn00<006lhKcP02Flh00<007=HLeP02W=H00<007=HLeP00W=H00<007Lf
McH00gLf00<007LfMcH01gLf00<007]eNgD01W]e00<006^>00000V^>0`000T^D0P005Woo00<007oo
Ool05goo000eOol00`00Ool00002000mOol010000AP1600013gH00<004gfCOH01Dgf00<005ZjF[X0
1eZj00<005JkE[/03eJk00<005:kD[/02e:k0`000U<n00<004lnCch04Dln00<005LnEch015Ln0`00
2ULM00<005<MDad04E<M00<004kmC_d010002dkn00<003jn?[h03Cjn00<006lhKcP026lh00<007=H
LeP02W=H00<007=HLeP00g=H00<007LfMcH00gLf00<007LfMcH01gLf00<007]eNgD01G]e00@006^>
Jhi[SP@00003Bi@0000001Qoo`03001oogoo01Moo`00=Goo0P00@7oo00@0004H0AP16080008mf003
001=mTgf00==mP8000YJ^P03001F^eJk011F^`03001B^e:k00MB^`<000IC?P80019??P03001G?ULn
00<000iG7@03001C7E<M011C7@<0011>oP03000n_Sjn00dn_P03001_>6lh00I_>003001cF7=H00Yc
F003001cF7=H00EcF005001g=WLfMcH00009McH00`00NgEkM@06NgD01000Jhi[SV^>1@006goo00<0
07ooOol05Woo000fOol00`00Oomoo`0oOol00`000AP160020AP00`00?MP00003COH2000=F[X00`00
E[]F^`0@E[/00`00D[]B^`03D[/3000;Dch00`00Cci??P0?Cch3000BEad00`00DaeC7@0<Dad30002
Ead00`00C_i>oP0?C_h00`00?[hn_P0=?[h00`00KcQ_>004KcP00`00LeQcF00;LeP00`00LeQcF006
LeP01000McIg=P002GLf00<007]eNgD01G]e00@006^>Jhi[SP@001eoo`03001oogoo01Ioo`00=goo
0P00@7oo00<0004H0AP00P4H1@0045Zj00<005JkE[/03eJk00<005:kD[/00`003e<n00<004lnCch0
2Tln10000Tkm00<005LMEad04ELM00<005<MDad025<M0`001ULM00<004knC_h03dkn00<003jn?[h0
3Cjn00<006lhKcP00flh00<007=HLeP02W=H00<007=HLeP027=H0P002GLf00<007]eNgD01W]e00@0
06^>Jhi[SP@001eoo`03001oogoo01Ioo`00>Goo00<007ooOol0?Woo00<0004H0AP00`4H00<005Zj
F[X04EZj00<005JkE[/03UJk0`004e<n0P001dln0`001dkm00<005LMEad04ELM00<005<MDad015<M
0`002ELM00<004knC_h044kn00<003jn?[h03Cjn00D006lhKcQ_>00000acF003001cF7=H00YcF003
001g=WLf00Mg=P03001kMG]e00EkM@04001[SV^>Jhh20003Ool00`00Oomoo`0JOol00`00Oomoo`0F
Ool003Yoo`03001oogoo03eoo`030001604H00@16003001J^UZj011J^P03001F^eJk00]F^`<0009G
?P8001AC?P03001??Tln00@000]>o@03001G7ELM015G7@03001C7E<M00<000eG7@03001>oTkn00m>
oP03000n_Sjn00dn_P04001_>6lh000<LeP00`00LeQcF00:LeP00`00KaP00007McH00`00NgEkM@06
NgD01000Jhi[SP001Goo00<007ooOol06Woo00<007ooOol05Woo000kOol00`00Oomoo`0mOol00`00
0AP160030AP00`00F[YJ^P0AF[X00`00E[]F^`07E[/30007Ech00`00DciC?P0ADch3000@C_d00`00
EaeG7@0@Ead3000AEad00`00C_i>oP0?C_h00`00?[hn_P0=?[h00`00KcP0000<LeP00`00LeQcF00:
LeP00`00KaP00007McH00`00NgEkM@05NgD01@00Jhi[SV^>00001Woo00<007ooOol06Goo00<007oo
Ool05Woo000lOol2000nOol00`000AP160030AP00`00F[YJ^P0AF[X00`00E[]F^`03E[/3000;Ech2
000=Dch40002D_d00`00C_e>o@0?C_d00`00EaeG7@0<Ead30002Ead00`00EaeG7@0@Ead00`00C_i>
oP0=C_hC000<LeP00`00LeQcF00:LeP01@00KaQ_66lH00001WLf00<007]eNgD01G]e00@006^>Jhh0
00Qoo`03001oogoo01Qoo`03001oogoo01Ioo`00?Woo00<007ooOol0?7oo00<0004H0AP00`4H00<0
05ZjF[X045Zj00<005JkE[/00`0045Ln00<005<nDch01U<n10001e;m00<004kmC_d03dkm00<005LM
Ead025LM0`001ULM00<005LMEad03eLM00<004knC_h024kn1@000dlN00<003kN?]h03CkN00<007=H
LeP027=H00<007=HLeP02W=H00<006lHKaP00flH00<007LfMcH00WLf00<007]eNgD01G]e00@006^>
Jhh000Yoo`03001oogoo01Qoo`03001oogoo01Eoo`00?goo00<007ooOol0?7oo0P000`4H00<005Zj
F[X04EZj0P0055Ln0P000U<n100035;m00<004kmC_d03dkm00<005LMEad015LM0`002ELM00<005LM
Ead045LM00@004knC_i>oPH000U?7P03000ngSkN00dngP03001cF7=H00IcF003001cF7=H00YcF003
001_66lH00A_6003001g=WLf009g=P03001kMG]e00EkM@03001[SP0000]oo`03001oogoo01Qoo`03
001oogoo01Eoo`00@7oo00<007ooOol0?7oo0P000`4H00<005ZjF[X03UZj0P0000=O?000000055Ln
0`004E;m00<004kmC_d03dkm00<005LMEad00`003ELM00<005LMEad03eLM100044lN00<003kN?]h0
3CkN00<007=HLeP01G=H00<007=HLeP02W=H00<006lHKaP01FlH00@007LfMcH000QkM@03001[SP00
00aoo`03001oogoo01Moo`03001oogoo01Eoo`00@Goo00<007ooOol0?7oo0P000`4H00<005ZjF[X0
2eZj0P001Ell00<005LnEch03eLn0P000ULL00<005;mD_d03e;m00<004kmC_d03dkm0`004ELM00<0
05LMEad02eLM0`000U<M00<004lNCah03dlN00<003kN?]h03CkN00<007=HLeP017=H00<007=HLeP0
2W=H00<006lHKaP01flH00<007Lf00001g]e00<006^>00003Woo00<007ooOol05Woo00<007ooOol0
5Goo0012Ool2000nOol200020AP00`00F[YJ^P08F[X20008Gc`00`00EciG?P0<Ech20005Ea`00`00
D_eBo@0?D_d00`00C_e>o@0:C_d40002C_d00`00EaeG7@0@Ead00`00EaeG7@07Ead30006Dad00`00
Cai?7P0?Cah00`00?]hngP0=?]h00`00LeQcF002LeP00`00LeQcF00:LeP00`00KaQ_6008KaP20008
NgD2000@Ool00`00Oomoo`0EOol00`00Oomoo`0EOol004Aoo`03001oogoo03aoo`8000030AP005Zj
00QJ^P03001O?5ll00UO?08000UG?P<000QG7003001BoE;m00mBo@03001>oDkm00E>o@@000M>o@03
001G7ELM00mG7@03001G7ELM00AG7@<000YC7@03001?7TlN00m?7P03000ngSkN00dngP04001cF7=H
000<LeP00`00KaQ_600:KaP00`00NgEkM@05NgD00`00Jhh0000@Ool00`00Oomoo`0EOol00`00Oomo
o`0EOol004Eoo`03001oogoo03aoo`8000030AP005Zj00EJ^P8000iO?003001G?ULn00AG?P8000aG
7003001BoE;m00mBo@03001>oDkm00@000a>o@03001G7ELM00mG7@03001G7ELM00<000iC7@03001?
7TlN00m?7P03000ngSkN00dngP03001cF00000acF003001_66lH00U_6003001g^00000IkM@80019o
o`03001oogoo01Aoo`03001oogoo01Eoo`00AWoo00<007ooOol0?7oo10000eZj0P004Ell0P000ULn
0P003eLL00<005;mD_d03U;m0`004Dkm00<005LMEad03ULM0`004U<M00<004lNCah03DlN4`0037=H
00<006lHKaP02VlH00@007NhMkP000AkM@8001Aoo`03001oogoo01Aoo`03001oogoo01Aoo`00Agoo
0P00?Goo00@0001c001J^P8001EO?080019G7003001BoE;m00UBo@@0009C7@03001>oDkm00m>o@03
001G7ELM00]G7@<0009G7@03001C7E<M015C7@03001?7TlN00M?7PD000=;7P03000jgc[O00djg`03
001cF7=H00QcF003001_66lH00Y_6003001g^7Nh009g^080009kM@03001oogoo01=oo`03001oogoo
01Aoo`03001oogoo01Aoo`00BGoo00<007ooOol0>goo0`005Ell0P0000=O6`00Ea`04ULL00<005;m
D_d01E;m0`001e<M00<004kmC_d03dkm00<005LMEad025LM0P001ULM00<005<MDad04E<M00@004lN
Cai?7PD000U;7P03000jgc[O00djg`03001cF7=H00IcF003001_66lH00]_6003001g^7Nh00Ag^0<0
01Ioo`03001oogoo01=oo`03001oogoo01Aoo`00BWoo00<007ooOol0>goo0`004Ull0P0015lK00<0
05LLEa`04ELL00<005;mD_d010002e<M00<004kmC_d03dkm00<005LMEad015LM0`002ELM00<005<M
Dad045<M10003d/N00<003[O>]l03C[O00<007=HLeP01G=H00<006lHKaP02VlH00<007NhMkP01WNh
00<007ooOol05Woo00<007ooOol04Woo00<007ooOol057oo001;Ool00`00Oomoo`0kOol3000@Gc`0
0`00Ga]O6`05Ga/00`00EaaG700@Ea`3000@Dad00`00C_e>o@0?C_d00`00EaeG7@03000=Ead2000<
Dad40002Dch00`00Bai;7P0?Bah00`00>]ljg`0<>]l00`00LeQcF004LeP00`00KaQ_600:KaP00`00
MkQg^006MkP00`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`0DOol004aoo`8003aoo`<000eO
?08000UO6`03001G75LL00eG7080009K7@03001C7E<M00mC7@03001>oDkm00e>o@@0019G7@03001C
7E<M00EC7@@000MC?P03001;7T/N00m;7P03000jgc[O00`jg`03001cF7=H009cF003001_66lH00]_
6003001g^7Nh00Ig^003001oogoo01Qoo`03001oogoo015oo`03001oogoo01Aoo`00CWoo00<007oo
Ool0>Woo00@0002e000000UO?08000]O6`03001G75LL00YG70<000EK7@03001C7E<M00mC7@03001>
oDkm00M>o@D000=?7P03001G7ELM015G7@03001C7E<M00@000aC?P03001;7T/N00m;7P03000jgc[O
00`jg`04001cF7=H000=KaP00`00MkQg^006MkP00`00Oomoo`0JOol00`00Oomoo`0@Ool00`00Oomo
o`0DOol004moo`03001oogoo03Yoo`040000]@000007Gc`00`00Ga]O6`0<Ga/00`00EaaG7007Ea`2
0009Fad00`00DaeC7@0?Dad01000C_e>oDkm1@002DlN00<005LMEad045LM0`004E<n00<004/NBah0
3D/N2P001c[O00<007=H000036lH00<007NhMkP01WNh00<007ooOol077oo00<007ooOol047oo00<0
07ooOol04goo001@Ool00`00Oomoo`0jOol010000;D0000015ll0P0045lK00<005LLEa`00eLL0`00
35/M00<005<MDad03U<M10003dlN00<005LMEad03ELM0P000ULm00<005<nDch045<n00<004/NBah0
1d/N1@000dkm00<003ZN>Yh013ZN2@003FlH00<007NhMkP01GNh00<007ooOol07Woo00<007ooOol0
3goo00<007ooOol04goo001AOol00`00Oomoo`0jOol01@000;D0]@00Gc`00P004elK00<005LLEa`0
0P003e/M00<005<MDad02e<M0`000U<N00<004lNCah03TlN00<005LMEad02ULM0`001ELm00<005<n
Dch045<n00@004/NBai;7PD000U>o@03000jWSZN00`jWP03001_66lH00U_6003001g^7Nh00Ig^003
001oogoo01ioo`03001oogoo00moo`03001oogoo01=oo`00DWoo0P00>goo00@0002e0;D001IO6`80
019K7@03001C7E<M00QC7@8000IC7P03001?7TlN00i?7P03001G7ELM00MG7@8000UG?@03001C?U<n
00mC?P@000i>o@03000jWSZN00`jWP03001_66lH00U_6003001g^7Nh00Eg^003001oogoo021oo`03
001oogoo00ioo`03001oogoo01=oo`00E7oo00<007ooOol0>Goo0P0000<0]@00Ga/04UlK0P0000=S
6`00Fad04U/M00<005<MDad015<M0`002E<N00<004lNCah03TlN00<005LMEad00eLM0`0035Lm00<0
05<nDch02U<n10000UKm00<004kmC_d03Tkm00<003ZN>Yh033ZN00<006lHKaP01flH00<007NhMkP0
1GNh00<007ooOol08Woo00<007ooOol03Goo00<007ooOol04goo001EOol00`00Oomoo`0iOol20000
0`2e001O6`0@Ga/00`00Ha]S6`02Ha/00`00FaeK7@0AFad00`00DaeC7@03000=Dah00`00Cai?7P0>
Cah00`00EaeG7@02000@Ecd00`00DciC?P05Dch40007E_d00`00C_e>o@0>C_d00`00>YhjWP0<>Yh0
0`00KaQ_6005KaP00`00MkQg^005MkP00`00Oomoo`0SOol00`00Oomoo`0=Ool00`00Oomoo`0COol0
05Ioo`03001oogoo03Uoo`8000030;D005lK00eO6`8000IS6`03001K7E/M011K7@<0015C7P03001?
7TlN00a?7P@001=G?@03001C?U<n00@000aFo@03001>oDkm00i>o@03000jWSZN00/jWP03001_66lH
00E_6003001g^7Nh00Eg^003001oogoo02Aoo`03001oogoo00aoo`03001oogoo01=oo`00Egoo0P00
>goo0`0035lK00<006<KHa/01f<K0P003E/M0`000U/M00<005<NDah045<N00<004lNCah01dlN1000
0dlN00<005LmEcd04ELm0`0045Km00<004kmC_d03Tkm00<003ZN>Yh033ZN00<006lHKaP00flH00<0
07NhMkP01GNh00<007ooOol09Woo00<007ooOol037oo00<007ooOol04Woo001IOol00`00Oomoo`0i
Ool30009Ga/2000<Ha/00`00FaeK7@08Fad20006Fad00`00DaiC7P0@Dah01000Cai?7TlN1@0024lN
00<005LmEcd03ULm0P000UKl00<005KmE_d03eKm00<004kmC_d03Tkm00<003ZN>Yh02cZN00<006lH
KaP00VlH00<007NhMkP01GNh00<007ooOol0:7oo00<007ooOol02goo00<007ooOol04Woo001JOol0
0`00Oomoo`0iOol30006Ga/2000?Ha/00`00FaeK7@04Fad30009Fad00`00DaiC7P0?Dah4000>Cah0
0`00EceG?@0;Ecd20005E_`00`00E_eFo@0?E_d00`00C_e>o@0;C_d6000;>Yh01@00KaQ_66lH0000
1gNh00<007ooOol0:7oo00<007ooOol02goo00<007ooOol04Woo001KOol00`00Oomoo`0iOol30004
Ga/00`00Ha]S6`0@Ha/00`00FaeK7@03000=Fad2000;Dah40002Dch00`00Cai?7P0>Cah20008Ecd3
0008E_`00`00E_eFo@0?E_d00`00C_e>o@02C_d80004?cl70007>Yh00`00KaP00007MkP00`00Oomo
o`0ZOol00`00Oomoo`0:Ool00`00Oomoo`0BOol005aoo`8003Yoo`040000T`00Ga/2000DHa/2000B
Fad00`00DaiC7P05Dah30007Dch00`00Cai?7P0?Cah00`00EceG?@03Ecd2000<E_`00`00E_eFo@0>
E_d5000>?cl00`004WdBO@024Wd6000013ZN001_60001WNh00<007ooOol0;7oo00<007ooOol02Goo
00<007ooOol04Woo001NOol00`00Oomoo`0hOol3000DHa/200000f<l001K7@0BFad00`00DaiC7P04
000;Dch00`00Cai?7P0?Cah00`00EceG?@02000>E_`00`00E_eFo@0;E_d30002Cgl2000@?cl20008
4Wd40005MkP00`00Oomoo`0]Ool00`00Oomoo`09Ool00`00Oomoo`0BOol005moo`03001oogoo03Qo
o`<0019S6`03001S?6<l009S?003001K7E/M011K7@<0011C?P8000i?7P@0015Fo003001FoEKm00QF
o@8000M?O`8000do?`/000@BO@<0009g^003001oogoo02ioo`03001oogoo00Qoo`03001oogoo019o
o`00H7oo00<007ooOol0>7oo0`003f<K0P001V<l00<005/MFad03E/M0P000U/m00<005<nDch045<n
00<004lNCah01dlN10000dkm00<005KlE_`045Kl00<005KmE_d015Km0`002dmo0P0013lo1`002goo
2@00<Woo00<007ooOol01goo00<007ooOol04Woo001QOol2000jOol2000=Ha/00`00HcaS?007Hc`0
0`00FaeK7@0:Fad20005Fcd00`00DciC?P0@Dch01000Cai?7TlN1@0024km00<005KlE_`045Kl00<0
05KmE_d00`003dmo1@00CWoo00<007ooOol01goo00<007ooOol04Goo001SOol00`00Oomoo`0hOol3
0009Ha/2000;Hc`00`00FaeK7@06Fad30008Fcd00`00DciC?P0?Dch4000=C_d00`00E_aFo00@E_`3
000?Cgl3001COol00`00Oomoo`07Ool00`00Oomoo`0AOol006Aoo`03001oogoo03Qoo`<000IS6`80
00iS?003001K7E/M00=K7@8000aK?@8000]C?P@0009Bo@03001>oDkm00e>o@03001Fo5Kl00eFo080
009GW`8000a?O`8005Moo`03001oogoo00Ioo`03001oogoo015oo`00IGoo00<007ooOol0>7oo0`00
16<K00<006<lHc`03f<l00<005/MFad00P0045/m00<005<nDch01E<n0`001e;m00<004kmC_d03Dkm
00<005KlE_`02EKl0`001UNO0P001dmo0`00FWoo00<007ooOol01Goo00<007ooOol04Goo001VOol0
0`00Oomoo`0hOol300000f<K0000000CHc`2000CFcd00`00DciC?P04000;D_d00`00C_e>o@0=C_d0
0`00E_aFo006E_`2000;Eil20002Cgl3001NOol00`00Oomoo`04Ool00`00Oomoo`0AOol006Moo`80
03Yoo`8001=S?0800003Hc`005/m019K?@<000mBo@03001>oDkm00e>o@03001Fo5Kl00=Fo0<000iG
W`<0065oo`03001oogoo00Aoo`03001oogoo015oo`00JGoo00<007ooOol0>7oo0P0046<l0P0016<l
0P003U/m0`000U[l00<005;mD_d03U;m00<004kmC_d03Dkm00<005KlE_`00P003UNO0`00IGoo00<0
07ooOol00goo00<007ooOol04Goo001ZOol00`00Oomoo`0hOol2000=Hc`20008Hc`00`00FceK?@09
Fcd20006F_`00`00D_eBo@0>D_d00`00C_e>o@0:C_d5000=Eil3001YOol00`00Oomoo`03Ool00`00
Oomoo`0@Ool006]oo`03001oogoo03Uoo`03001S?6<l00US?003001S?6<l00US?003001K?E/m00EK
?@<000UJo003001BoE;m00iBo@03001>oDkm009>o@L000E3G`8000QGW`<006aoo`03001oogoo00=o
o`03001oogoo011oo`00K7oo0P00>Woo0P001f<l0P003F<l0P000U/m0`003E[l00<005;mD_d03E;m
1@003T=O0P000eNO0`00L7oo00<007ooOol00Woo00<007ooOol047oo001^Ool00`00Oomoo`0hOol2
0004Hc`2000AHc`2000AF_`00`00D_eBo@09D_d30002Bgl2000@@el4001dOol01@00Oomoogoo0000
4Woo001_Ool00`00Oomoo`0hOol200000f<l0000000AHc`200000f;j001Jo00AF_`00`00D_eBo@04
D_d40007Bgl2000:@el4001iOol01000Oomoo`004Woo001`Ool00`00Oomoo`0hOol2000BHc`00`00
H_YRnP02H_X00`00F_aJo00@F_`00`00D_eBo@03000=Bgl20004@el4001mOol01000Oomoo`004Woo
001aOol2000iOol2000@Hc`00`00H_YRnP04H_X00`00F_aJo00?F_`3000ABgl50022Ool00`00Ool0
000BOol007=oo`03001oogoo03Moo`8000eS?08000QRnP03001Jo5[l00aJo08000=KWP8000];O`@0
08Qoo`03001oo`00015oo`00M7oo00<007ooOol0=goo0P002f<l00<006;jH_X026;j00<005[lF_`0
2U[l0P001e^N0P0014]o1@00SGoo0P004Goo001eOol00`00Oomoo`0gOol20008Hc`2000<H_X00`00
F_aJo006F_`3000;Fih4002BOol2000AOol007Ioo`03001oogoo03Moo`8000IS?003001RnV;j00eR
nP03001Jo5[l00=Jo08000aKWP8009Ioo`80015oo`00Mgoo0P00>7oo0P0016<l00<006;jH_X03f;j
00<005[lF_`00P0035^N0P00U7oo10004goo001iOol00`00Oomoo`0fOol200000f<l0000000CH_X2
000;Fih3002BOol4000GOol007Yoo`03001oogoo03Ioo`8001=RnP80009[_@8000MKWP80095oo`@0
01]oo`00Ngoo00<007ooOol0=Woo0P004F;j00<006^mJkd016^m0P000e^N0P00Sgoo10007goo001l
Ool2000gOol2000?H_X00`00Jke[_@07Jkd3002=Ool4000SOol007ioo`03001oogoo03Aoo`<000aR
nP8000U[_@8008]oo`@002Moo`00Ogoo00<007ooOol0<goo00@007oo000000YRnP03001[_F^m00Q[
_@03001oogoo08Qoo`<002]oo`00P7oo00<007ooOol0<Woo00@007ooOol000QRnP8000U[_@8008Mo
o`@002ioo`00PGoo0P00<Woo00D007ooOomoo`0000IRnP03001[_F^m00Q[_@03001oogoo08=oo`@0
039oo`00Pgoo00<007ooOol0;goo00<007ooOol00Woo00<006;jH_X00V;j00<006^mJkd026^m00<0
07ooOol0P7oo1000=Woo0024Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool01000H_X000002F^m0P00
Ogoo1000>Woo0025Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool20009Jkd00`00Oomoo`1kOol4000n
Ool008Ioo`03001oogoo02aoo`03001oogoo00Ioo`@000=[_@8007Yoo`@0049oo`00Qgoo0P00;7oo
00<007ooOol02Woo0`00NGoo0`00AWoo0029Ool00`00Oomoo`0YOol00`00Oomoo`22Ool40019Ool0
08Yoo`03001oogoo02Qoo`03001oogoo07ioo`@004eoo`00Rgoo00<007ooOol09goo00<007ooOol0
NWoo1000DGoo002<Ool2000WOol00`00Oomoo`1fOol4001EOol008ioo`03001oogoo02Aoo`03001o
ogoo079oo`@005Uoo`00Sgoo00<007ooOol08goo00<007ooOol0KWoo1000GGoo002@Ool00`00Oomo
o`0ROol00`00Oomoo`1[Ool3001QOol0095oo`80029oo`03001oogoo06Moo`@006Aoo`00Tgoo00<0
07ooOol07goo00<007ooOol0Hgoo1000J7oo002DOol00`00Oomoo`0NOol00`00Oomoo`1OOol4001/
Ool009Eoo`03001oogoo01eoo`03001oogoo05]oo`@0071oo`00UWoo0P007Goo00<007ooOol0Egoo
1000M7oo002HOol00`00Oomoo`0JOol00`00Oomoo`1COol4001hOol009Uoo`03001oogoo01Uoo`03
001oogoo04moo`@007aoo`00VWoo00<007ooOol067oo00<007ooOol0C7oo0`00P7oo002KOol00`00
Oomoo`0GOol00`00Oomoo`18Ool40023Ool009aoo`8001Moo`03001oogoo04Aoo`@008Moo`00WWoo
00<007ooOol057oo00<007ooOol0@7oo1000Rgoo002OOol00`00Oomoo`0BOol00`00Oomoo`0mOol4
002?Ool00:1oo`03001oogoo015oo`03001oogoo03Uoo`@009=oo`00XGoo0P004Goo00<007ooOol0
=Goo1000Ugoo002SOol00`00Oomoo`0>Ool00`00Oomoo`0bOol3002KOol00:Aoo`03001oogoo00eo
o`03001oogoo02ioo`@009ioo`00YGoo00<007ooOol037oo00<007ooOol0:Woo1000XWoo002VOol2
000<Ool00`00Oomoo`0VOol4002VOol00:Qoo`03001oogoo00Uoo`03001oogoo029oo`@00:Yoo`00
ZGoo00<007ooOol027oo00<007ooOol07Woo1000[Woo002ZOol00`00Oomoo`07Ool00`00Oomoo`0J
Ool4002bOol00:]oo`03001oogoo00Ioo`03001oogoo01Moo`<00;Ioo`00[7oo0P001Woo00<007oo
Ool04goo1000^Goo002^Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool4002mOol00:moo`03001oogoo
009oo`03001oogoo00]oo`@00<5oo`00/7oo00D007ooOomoo`0000Uoo`@00<Eoo`00/Goo0P0000=o
o`00Ool017oo1000bGoo002cOol200000goo00000002003=Ool00;Aoo`800=5oo`00ogooR7oo003o
Oon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQo
o`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo003o
Oon8Ool00?moohQoo`00ogooR7oo003oOon8Ool00?moohQoo`00ogooR7oo0000\
\>"],
  ImageRangeCache->{{{0, 390}, {316, 0}} -> {-0.159299, -0.0377309, 
  0.00298087, 0.00298087}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ob = t; \n
    Plot[radFldInt[ob, "\<inf\>", "\<ibz\>", {\(-1\), y, z}, {1, y, z}], {y, 
        \(-20\), 20}, \n
      FrameLabel -> {"\<Y [mm]\>", "\<Iz [T mm]\>", "\<Z = 0\>", "\<\>"}]; 
    \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.0238095 -0.755897 0.082292 [
[.02381 -0.0125 -12.5 -15 ]
[.02381 -0.0125 12.5 0 ]
[.2619 -0.0125 -12.5 -15 ]
[.2619 -0.0125 12.5 0 ]
[.5 -0.0125 -5 -15 ]
[.5 -0.0125 5 0 ]
[.7381 -0.0125 -8 -15 ]
[.7381 -0.0125 8 0 ]
[.97619 -0.0125 -8 -15 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.5 -30 ]
[.5 -0.0125 21.5 -15 ]
[-0.0125 .06702 -16 -7.5 ]
[-0.0125 .06702 0 7.5 ]
[-0.0125 .14932 -16 -7.5 ]
[-0.0125 .14932 0 7.5 ]
[-0.0125 .23161 -16 -7.5 ]
[-0.0125 .23161 0 7.5 ]
[-0.0125 .3139 -16 -7.5 ]
[-0.0125 .3139 0 7.5 ]
[-0.0125 .39619 -16 -7.5 ]
[-0.0125 .39619 0 7.5 ]
[-0.0125 .47848 -16 -7.5 ]
[-0.0125 .47848 0 7.5 ]
[-0.0125 .56078 -16 -7.5 ]
[-0.0125 .56078 0 7.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -69 -7.5 ]
[-0.01875 .30902 -16 7.5 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -15.5 0 ]
[.5 .63053 15.5 15 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .06702 m
1 .06702 L
s
0 .14932 m
1 .14932 L
s
0 .23161 m
1 .23161 L
s
0 .3139 m
1 .3139 L
s
0 .39619 m
1 .39619 L
s
0 .47848 m
1 .47848 L
s
0 .56078 m
1 .56078 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -73.5 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(20) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.5 -34 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.625000 moveto
(@) show
78.562500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.312500 14.625000 moveto
(D) show
101.250000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
0 .06702 m
.00625 .06702 L
s
gsave
-0.0125 .06702 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .14932 m
.00625 .14932 L
s
gsave
-0.0125 .14932 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(11) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .23161 m
.00625 .23161 L
s
gsave
-0.0125 .23161 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .3139 m
.00625 .3139 L
s
gsave
-0.0125 .3139 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(13) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .39619 m
.00625 .39619 L
s
gsave
-0.0125 .39619 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(14) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .47848 m
.00625 .47848 L
s
gsave
-0.0125 .47848 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(15) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
0 .56078 m
.00625 .56078 L
s
gsave
-0.0125 .56078 -77 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(16) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .08348 m
.00375 .08348 L
s
0 .09994 m
.00375 .09994 L
s
0 .1164 m
.00375 .1164 L
s
0 .13286 m
.00375 .13286 L
s
0 .16577 m
.00375 .16577 L
s
0 .18223 m
.00375 .18223 L
s
0 .19869 m
.00375 .19869 L
s
0 .21515 m
.00375 .21515 L
s
0 .24807 m
.00375 .24807 L
s
0 .26452 m
.00375 .26452 L
s
0 .28098 m
.00375 .28098 L
s
0 .29744 m
.00375 .29744 L
s
0 .33036 m
.00375 .33036 L
s
0 .34682 m
.00375 .34682 L
s
0 .36327 m
.00375 .36327 L
s
0 .37973 m
.00375 .37973 L
s
0 .41265 m
.00375 .41265 L
s
0 .42911 m
.00375 .42911 L
s
0 .44557 m
.00375 .44557 L
s
0 .46203 m
.00375 .46203 L
s
0 .49494 m
.00375 .49494 L
s
0 .5114 m
.00375 .5114 L
s
0 .52786 m
.00375 .52786 L
s
0 .54432 m
.00375 .54432 L
s
0 .05057 m
.00375 .05057 L
s
0 .03411 m
.00375 .03411 L
s
0 .01765 m
.00375 .01765 L
s
0 .00119 m
.00375 .00119 L
s
0 .57723 m
.00375 .57723 L
s
0 .59369 m
.00375 .59369 L
s
0 .61015 m
.00375 .61015 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -130 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Iz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
75.062500 14.625000 moveto
(@) show
79.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
89.312500 14.625000 moveto
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
108.062500 14.625000 moveto
(D) show
112.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math2
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math2
%%DocumentFonts: + font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -76.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
84.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
90.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.99375 .06702 m
1 .06702 L
s
.99375 .14932 m
1 .14932 L
s
.99375 .23161 m
1 .23161 L
s
.99375 .3139 m
1 .3139 L
s
.99375 .39619 m
1 .39619 L
s
.99375 .47848 m
1 .47848 L
s
.99375 .56078 m
1 .56078 L
s
.125 Mabswid
.99625 .08348 m
1 .08348 L
s
.99625 .09994 m
1 .09994 L
s
.99625 .1164 m
1 .1164 L
s
.99625 .13286 m
1 .13286 L
s
.99625 .16577 m
1 .16577 L
s
.99625 .18223 m
1 .18223 L
s
.99625 .19869 m
1 .19869 L
s
.99625 .21515 m
1 .21515 L
s
.99625 .24807 m
1 .24807 L
s
.99625 .26452 m
1 .26452 L
s
.99625 .28098 m
1 .28098 L
s
.99625 .29744 m
1 .29744 L
s
.99625 .33036 m
1 .33036 L
s
.99625 .34682 m
1 .34682 L
s
.99625 .36327 m
1 .36327 L
s
.99625 .37973 m
1 .37973 L
s
.99625 .41265 m
1 .41265 L
s
.99625 .42911 m
1 .42911 L
s
.99625 .44557 m
1 .44557 L
s
.99625 .46203 m
1 .46203 L
s
.99625 .49494 m
1 .49494 L
s
.99625 .5114 m
1 .5114 L
s
.99625 .52786 m
1 .52786 L
s
.99625 .54432 m
1 .54432 L
s
.99625 .05057 m
1 .05057 L
s
.99625 .03411 m
1 .03411 L
s
.99625 .01765 m
1 .01765 L
s
.99625 .00119 m
1 .00119 L
s
.99625 .57723 m
1 .57723 L
s
.99625 .59369 m
1 .59369 L
s
.99625 .61015 m
1 .61015 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .06702 m
1 .06702 L
s
.5 0 m
.5 .61803 L
s
.002 w
.02381 .01472 m
.06244 .09243 L
.10458 .19039 L
.14415 .29678 L
.18221 .41309 L
.20342 .47885 L
.22272 .52805 L
.23233 .54605 L
.24276 .56074 L
.25261 .57081 L
.26171 .57759 L
.26637 .58032 L
.27138 .58277 L
.28044 .58614 L
.28596 .5876 L
.28868 .58817 L
.29121 .58862 L
.29592 .58926 L
.29841 .5895 L
.29967 .5896 L
.30106 .58969 L
.30241 .58976 L
.30367 .5898 L
.30436 .58983 L
.30499 .58984 L
.30572 .58985 L
.30642 .58986 L
.30764 .58986 L
.30878 .58986 L
.31002 .58984 L
.31065 .58982 L
.31135 .5898 L
.31411 .5897 L
.31566 .58961 L
.31708 .58953 L
.32247 .58912 L
.33292 .58818 L
.33801 .58778 L
.34042 .58764 L
.34264 .58753 L
.34372 .58749 L
.3449 .58745 L
.34609 .58742 L
.34735 .5874 L
.34846 .58739 L
.34964 .5874 L
.35077 .58741 L
.35179 .58743 L
.35304 .58746 L
.35419 .5875 L
Mistroke
.35681 .58762 L
.35911 .58778 L
.36157 .58797 L
.36716 .58856 L
.37243 .58925 L
.38227 .59076 L
.42087 .59688 L
.44085 .59926 L
.45103 .60022 L
.46193 .6011 L
.47222 .60177 L
.4816 .60228 L
.4905 .60266 L
.49995 .60297 L
.50468 .60309 L
.50989 .60319 L
.51217 .60323 L
.51463 .60326 L
.51695 .60328 L
.51907 .6033 L
.52029 .60331 L
.52158 .60331 L
.5228 .60332 L
.52391 .60332 L
.52522 .60332 L
.52596 .60332 L
.52663 .60332 L
.52788 .60331 L
.5292 .60331 L
.53046 .6033 L
.53182 .60329 L
.53427 .60326 L
.53719 .60322 L
.53985 .60318 L
.54464 .60307 L
.54974 .60292 L
.55891 .60256 L
.56877 .60202 L
.57966 .60125 L
.59898 .59943 L
.60894 .59833 L
.61983 .59714 L
.62484 .59666 L
.6302 .59622 L
.63279 .59605 L
.63525 .59592 L
.63746 .59583 L
.6387 .59579 L
.63985 .59577 L
.64106 .59575 L
Mistroke
.64236 .59575 L
.6436 .59575 L
.64472 .59577 L
.64604 .5958 L
.64678 .59582 L
.64747 .59585 L
.65009 .59597 L
.65151 .59607 L
.65284 .59617 L
.65534 .59639 L
.66094 .59706 L
.67933 .60011 L
.68437 .6009 L
.68977 .6016 L
.69239 .60186 L
.69486 .60206 L
.69709 .6022 L
.69835 .60225 L
.69951 .60229 L
.70065 .60231 L
.70188 .60232 L
.70305 .60232 L
.70411 .6023 L
.70529 .60227 L
.70658 .60221 L
.70793 .60213 L
.70919 .60204 L
.71179 .60179 L
.71416 .60148 L
.71692 .60103 L
.71946 .60052 L
.72467 .59917 L
.7303 .59721 L
.73527 .59499 L
.74053 .59207 L
.74998 .58507 L
.75528 .57995 L
.76012 .57438 L
.76952 .56073 L
.77844 .54386 L
.7983 .49312 L
.8167 .43681 L
.85591 .31887 L
.89756 .20961 L
.9377 .11918 L
.97619 .0444 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{399, 246.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006?0000mQ000`40O003h00OogooT7oo003oOon@
Ool00?mooi1oo`00i7oo0`0057oo0`00TGoo003TOol00`00Oomoo`0FOol00`00Oomoo`2?Ool00=Yo
o`<000Moo`04001oogooOol3000017oo000007oo1@0000Aoo`00001oo`8000=oo`03001oogoo08mo
o`00fgoo00<007ooOol01Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000
Oomoo`0017oo00<007ooOol0Sgoo003KOol00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`2?Ool00=]oo`03001oogoo00Ioo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo08mo
o`00fWoo00<007oo00001goo00<007ooOol00Woo0P0000Eoo`00001oo`00009oo`800005Ool00000
Ool00004Ool00`00Oomoo`2?Ool00=Yoo`03001oo`0000Moo`04001oogooOol200001Goo001oogoo
00000Woo0P0000Eoo`00Oomoo`0000Eoo`03001oogoo08moo`00fWoo00@007ooOol000Ioo`03001o
ogoo01Ioo`03001oogoo08moo`00fGoo00<007ooOol00Woo00<007ooOol00goo0`0057oo0`00TGoo
003HOol30002Ool3002_Ool00?mooi1oo`00ogooT7oo003oOon@Ool00?mooi1oo`00ogooT7oo003o
Oon@Ool005Eoo`D0009oo`<0045oo`<000=oo`<0045oo`<004Aoo`<000=oo`<0041oo`D0009oo`<0
00]oo`00EWoo00H007ooOol007oo0003Ool00`00Oomoo`0oOol01@00Oomoogoo00000goo00<007oo
Ool0?Goo00D007ooOomoo`0004Aoo`05001oogooOol00003Ool00`00Oomoo`0nOol01P00Oomoo`00
Ool000=oo`03001oogoo00Qoo`00Egoo00D007ooOomoo`0000=oo`03001oogoo03moo`05001oogoo
Ool00003Ool00`00Oomoo`0mOol01@00Oomoogoo0000A7oo00D007ooOomoo`0000=oo`03001oogoo
03moo`05001oogooOol00003Ool00`00Oomoo`08Ool004ioo`L000=oo`04001oogoo0003Ool00`00
Oomoo`0fOol70002Ool01@00Oomoogoo00000goo00<007ooOol0?Goo00D007ooOomoo`0004Aoo`05
001oogooOol00003Ool00`00Oomoo`10Ool01000Oomoo`000goo00<007ooOol027oo001IOol00`00
Ool00003Ool00`00Oomoo`0oOol01@00Oomoogoo00000goo00<007ooOol0?Goo00D007ooOomoo`00
04Aoo`05001oogooOol00003Ool00`00Oomoo`11Ool00`00Ool00003Ool00`00Oomoo`08Ool005Uo
o`03001oo`0000=oo`03001oogoo03moo`05001oogooOol00003Ool00`00Oomoo`0mOol01@00Oomo
ogoo0000A7oo00D007ooOomoo`0000=oo`03001oogoo045oo`03001oo`0000=oo`03001oogoo00Qo
o`00FGoo00<007oo00000goo00<007ooOol0?goo00D007ooOomoo`0000=oo`03001oogoo03eoo`05
001oogooOol00014Ool01@00Oomoogoo00000goo00<007ooOol0@Goo00<007oo00000goo00<007oo
Ool027oo001EOol01`00Oomoogoo001oo`0000=oo`03001oogoo03ioo`8000=oo`05001oogooOol0
000oOol01@00Oomoogoo0000@goo0P000goo00D007ooOomoo`0003moo`07001oogooOol007oo0000
0goo00<007ooOol027oo001FOol30003Ool30012Ool00`00Oomoo`02Ool30011Ool30015Ool00`00
Oomoo`02Ool30011Ool30003Ool3000;Ool00?mooi1oo`00ogooT7oo003oOon@Ool00?mooi1oo`00
ogooT7oo001@Oooo000i0007Ool0051oo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00ao
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00ao
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00ao
o`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo00Eo
o`00D7oo00<007ooOol017oo00<007ooOol0Agoo00<007ooOol0B7oo00<007ooOol0Agoo00<007oo
Ool0Agoo00<007ooOol017oo00<007ooOol01Goo001@Ool00`00Oomoo`1>Ool00`0?Oomoo`18Ool0
0`00Oomoo`17Ool00`0?Oomoo`1>Ool00`00Oomoo`05Ool0051oo`03001oogoo04ioo`0300moogoo
04Qoo`03001oogoo04Moo`0300moogoo04ioo`03001oogoo00Eoo`00D7oo0P001Goo00<007ooOol0
Agoo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0CGoo0P001goo001@Ool00`00Oomoo`04
Ool00`00Oomoo`17Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`1>Ool00`00Oomoo`05
Ool0051oo`03001oogoo00Eoo`03001oogoo04Ioo`0300moogoo04Qoo`03001oogoo04Moo`0300mo
ogoo04ioo`03001oogoo00Eoo`00D7oo00<007ooOol01Goo00<007ooOol0AWoo00<03gooOol0B7oo
00<007ooOol0Agoo00<03gooOol0CWoo00<007ooOol01Goo001@Ool00`00Oomoo`06Ool00`00Oomo
o`15Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`1>Ool00`00Oomoo`05Ool0051oo`03
001oogoo00Ioo`03001oogoo04Eoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo04ioo`03
001oogoo00Eoo`00D7oo0P0027oo00<007ooOol0A7oo00<03gooOol0B7oo00<007ooOol0Agoo00<0
3gooOol0CGoo0P001goo001@Ool00`00Oomoo`07Ool00`00Oomoo`14Ool00`0?Oomoo`18Ool00`00
Oomoo`17Ool00`0?Oomoo`1>Ool00`00Oomoo`05Ool0051oo`03001oogoo00Qoo`03001oogoo04=o
o`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo04ioo`03001oogoo00Eoo`00D7oo00<007oo
Ool027oo00<007ooOol0@goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0Agoo00<007oo
Ool017oo00<007ooOol01Goo001@Ool00`00Oomoo`09Ool00`00Oomoo`12Ool00`0?Oomoo`18Ool0
0`00Oomoo`17Ool00`0?Oomoo`16Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0051oo`8000Yoo`03
001oogoo049oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo04Ioo`03001oogoo00Aoo`80
00Moo`00D7oo00<007ooOol02Woo00<007ooOol0@Goo00<03gooOol0B7oo00<007ooOol0Agoo00<0
3gooOol0AGoo00<007ooOol01Woo00<007ooOol01Goo001@Ool00`00Oomoo`0:Ool00`00Oomoo`11
Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`15Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool003moo`<000=oo`<000Qoo`03001oogoo00]oo`03001oogoo041oo`0300moogoo04Qoo`03001o
ogoo04Moo`0300moogoo04Aoo`03001oogoo00Moo`03001oogoo00Eoo`00@7oo00D007ooOomoo`00
00=oo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo041oo`0300moogoo04Qoo`03001oogoo
04Moo`0300moogoo04Aoo`03001oogoo00Moo`03001oogoo00Eoo`00@7oo00D007ooOomoo`0000=o
o`03001oogoo00Eoool003T000Moo`00@7oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001o
ogoo00aoo`03001oogoo03moo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo04=oo`03001o
ogoo00Qoo`03001oogoo00Eoo`00@7oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo
00eoo`03001oogoo03ioo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo049oo`03001oogoo
00Uoo`03001oogoo00Eoo`00@7oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00eo
o`03001oogoo03ioo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo049oo`03001oogoo00Uo
o`03001oogoo00Eoo`00@7oo00D007ooOomoo`0000=oo`03001oogoo00Eoo`03001oogoo00ioo`03
001oogoo03eoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo045oo`03001oogoo00Yoo`03
001oogoo00Eoo`00?goo0P000goo00D007ooOomoo`0000Moo`8000moo`03001oogoo03eoo`0300mo
ogoo04Qoo`03001oogoo04Moo`0300moogoo045oo`03001oogoo00Uoo`8000Moo`00@7oo00<007oo
Ool00Woo0`0027oo00<007ooOol03goo00<007ooOol0?7oo00<03gooOol0B7oo00<007ooOol0Agoo
00<03gooOol0@7oo00<007ooOol02goo00<007ooOol01Goo001@Ool00`00Oomoo`0?Ool00`00Oomo
o`0lOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`10Ool00`00Oomoo`0;Ool00`00Oomo
o`05Ool0051oo`03001oogoo011oo`03001oogoo03]oo`0300moogoo04Qoo`03001oogoo04Moo`03
00moogoo03moo`03001oogoo00aoo`03001oogoo00Eoo`00D7oo00<007ooOol047oo00<007ooOol0
>goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0?goo00<007ooOol037oo00<007ooOol0
1Goo001@Ool2000BOol00`00Oomoo`0jOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0n
Ool00`00Oomoo`0<Ool20007Ool0051oo`03001oogoo015oo`03001oogoo03Yoo`0300moogoo04Qo
o`03001oogoo04Moo`0300moogoo03ioo`03001oogoo00eoo`03001oogoo00Eoo`00D7oo00<007oo
Ool04Woo00<007ooOol0>Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0?Goo00<007oo
Ool03Woo00<007ooOol01Goo001@Ool00`00Oomoo`0BOol00`00Oomoo`0iOol00`0?Oomoo`18Ool0
0`00Oomoo`17Ool00`0?Oomoo`0mOol00`00Oomoo`0>Ool00`00Oomoo`05Ool0051oo`03001oogoo
01=oo`03001oogoo03Qoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo03aoo`03001oogoo
00moo`03001oogoo00Eoo`00D7oo0P0057oo00<007ooOol0>7oo00<03gooOol0B7oo00<007ooOol0
Agoo00<03gooOol0?7oo00<007ooOol03Woo0P001goo001@Ool00`00Oomoo`0COol00`00Oomoo`0h
Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0kOol00`00Oomoo`0@Ool00`00Oomoo`05
Ool0051oo`03001oogoo01Aoo`03001oogoo03Moo`0300moogoo04Qoo`03001oogoo04Moo`0300mo
ogoo03]oo`03001oogoo011oo`03001oogoo00Eoo`00D7oo00<007ooOol057oo00<007ooOol0=goo
00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0>Woo00<007ooOol04Goo00<007ooOol01Goo
001@Ool00`00Oomoo`0EOol00`00Oomoo`0fOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomo
o`0jOol00`00Oomoo`0AOol00`00Oomoo`05Ool0051oo`8001Ioo`03001oogoo03Ioo`0300moogoo
04Qoo`03001oogoo04Moo`0300moogoo03Uoo`03001oogoo015oo`8000Moo`00D7oo00<007ooOol0
5Woo00<007ooOol0=Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0>Goo00<007ooOol0
4Woo00<007ooOol01Goo001@Ool00`00Oomoo`0FOol00`00Oomoo`0eOol00`0?Oomoo`18Ool00`00
Oomoo`17Ool00`0?Oomoo`0hOol00`00Oomoo`0COol00`00Oomoo`05Ool003moo`<000=oo`<000Qo
o`03001oogoo01Ioo`03001oogoo03Eoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo03Qo
o`03001oogoo01=oo`03001oogoo00Eoo`00@7oo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool05goo00<007ooOol0=7oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0>7oo00<007oo
Ool04goo00<007ooOol01Goo0010Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0GOol0
0`00Oomoo`0dOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0gOol00`00Oomoo`0DOol0
0`00Oomoo`05Ool0041oo`03001oogoo00=oo`03001oogoo00Moo`<001P03`0300003`0?07h03`03
00003`0?08403`0300003`0?01<03`8000Moo`00@7oo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol067oo00<007ooOol0<goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0=Woo00<0
07ooOol05Goo00<007ooOol01Goo0010Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0I
Ool00`00Oomoo`0bOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0fOol00`00Oomoo`0E
Ool00`00Oomoo`05Ool0041oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Uoo`03001o
ogoo039oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo03Eoo`03001oogoo01Ioo`03001o
ogoo00Eoo`00?goo0P0017oo0P002Goo00<007ooOol06Woo00<007ooOol0<Goo00<03gooOol0B7oo
00<007ooOol0Agoo00<03gooOol0=Goo00<007ooOol05Woo00<007ooOol01Goo0010Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool2000KOol00`00Oomoo`0aOol00`0?Oomoo`18Ool00`00Oomoo`17Ool0
0`0?Oomoo`0eOol00`00Oomoo`0EOol20007Ool0051oo`03001oogoo01Yoo`03001oogoo035oo`03
00moogoo04Qoo`03001oogoo04Moo`0300moogoo03Aoo`03001oogoo01Moo`03001oogoo00Eoo`00
D7oo00<007ooOol06goo00<007ooOol0<7oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0
=7oo00<007ooOol05goo00<007ooOol01Goo001@Ool00`00Oomoo`0KOol00`00Oomoo`0`Ool00`0?
Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0cOol00`00Oomoo`0HOol00`00Oomoo`05Ool0051o
o`03001oogoo01aoo`03001oogoo02moo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo03=o
o`03001oogoo01Qoo`03001oogoo00Eoo`00D7oo0P007Goo00<007ooOol0;goo00<03gooOol0B7oo
00<007ooOol0Agoo00<03gooOol0<Woo00<007ooOol067oo0P001goo001@Ool00`00Oomoo`0MOol0
0`00Oomoo`0^Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0bOol00`00Oomoo`0IOol0
0`00Oomoo`05Ool0051oo`03001oogoo01eoo`03001oogoo02ioo`0300moogoo04Qoo`03001oogoo
04Moo`0300moogoo039oo`03001oogoo01Uoo`03001oogoo00Eoo`00D7oo00<007ooOol07Goo00<0
07ooOol0;Woo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0<Goo00<007ooOol06Woo00<0
07ooOol01Goo001@Ool00`00Oomoo`0NOol00`00Oomoo`0]Ool00`0?Oomoo`18Ool00`00Oomoo`17
Ool00`0?Oomoo`0aOol00`00Oomoo`0JOol00`00Oomoo`05Ool0051oo`8001moo`03001oogoo02eo
o`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo031oo`03001oogoo01Yoo`8000Moo`00D7oo
00<007ooOol07goo00<007ooOol0;7oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0<7oo
00<007ooOol06goo00<007ooOol01Goo001@Ool00`00Oomoo`0OOol00`00Oomoo`0/Ool00`0?Oomo
o`18Ool00`00Oomoo`17Ool00`0?Oomoo`0_Ool00`00Oomoo`0LOol00`00Oomoo`05Ool0051oo`03
001oogoo01moo`03001oogoo02aoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo02moo`03
001oogoo01aoo`03001oogoo00Eoo`00D7oo00<007ooOol087oo00<007ooOol0:goo00<03gooOol0
B7oo00<007ooOol0Agoo00<03gooOol0;goo00<007ooOol077oo00<007ooOol01Goo001@Ool2000Q
Ool00`00Oomoo`0[Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0^Ool00`00Oomoo`0L
Ool20007Ool0051oo`03001oogoo025oo`03001oogoo02Yoo`0300moogoo04Qoo`03001oogoo04Mo
o`0300moogoo02ioo`03001oogoo01eoo`03001oogoo00Eoo`00D7oo00<007ooOol08Goo00<007oo
Ool0:Woo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0;Goo00<007ooOol07Woo00<007oo
Ool01Goo000oOol30002Ool50007Ool00`00Oomoo`0QOol00`00Oomoo`0ZOol00`0?Oomoo`18Ool0
0`00Oomoo`17Ool00`0?Oomoo`0]Ool00`00Oomoo`0NOol00`00Oomoo`05Ool0041oo`03001oogoo
009oo`04001oogoo0007Ool00`00Oomoo`0ROol00`00Oomoo`0YOol00`0?Oomoo`18Ool00`00Oomo
o`17Ool00`0?Oomoo`0]Ool00`00Oomoo`0NOol00`00Oomoo`05Ool0041oo`03001oogoo00=oo`03
001oogoo00Moo`<002803`0300003`0?07@03`0300003`0?07H03`0300003`0?01h03`8000Moo`00
@7oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol08goo00<007ooOol0:7oo00<03gooOol0
B7oo00<007ooOol0Agoo00<03gooOol0;7oo00<007ooOol07goo00<007ooOol01Goo0010Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0SOol00`00Oomoo`0XOol00`0?Oomoo`18Ool00`00
Oomoo`17Ool00`0?Oomoo`0/Ool00`00Oomoo`0OOol00`00Oomoo`05Ool0041oo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo02=oo`03001oogoo02Qoo`0300moogoo04Qoo`03001oogoo04Mo
o`0300moogoo02]oo`03001oogoo021oo`03001oogoo00Eoo`00@7oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol097oo00<007ooOol09goo00<03gooOol0B7oo00<007ooOol0Agoo00<03goo
Ool0:goo00<007ooOol087oo00<007ooOol01Goo000oOol20003Ool01@00Oomoogoo00001goo0P00
9Goo00<007ooOol09goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0:Woo00<007ooOol0
87oo0P001goo0010Ool00`00Oomoo`02Ool30008Ool00`00Oomoo`0TOol00`00Oomoo`0WOol00`0?
Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0ZOol00`00Oomoo`0QOol00`00Oomoo`05Ool0051o
o`03001oogoo02Eoo`03001oogoo02Ioo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo02Yo
o`03001oogoo025oo`03001oogoo00Eoo`00D7oo00<007ooOol09Goo00<007ooOol09Woo00<03goo
Ool0B7oo00<007ooOol0Agoo00<03gooOol0:Goo00<007ooOol08Woo00<007ooOol01Goo001@Ool0
0`00Oomoo`0VOol00`00Oomoo`0UOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0YOol0
0`00Oomoo`0ROol00`00Oomoo`05Ool0051oo`8002Moo`03001oogoo02Eoo`0300moogoo04Qoo`03
001oogoo04Moo`0300moogoo02Qoo`03001oogoo029oo`8000Moo`00D7oo00<007ooOol09Woo00<0
07ooOol09Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0:7oo00<007ooOol08goo00<0
07ooOol01Goo001@Ool00`00Oomoo`0WOol00`00Oomoo`0TOol00`0?Oomoo`18Ool00`00Oomoo`17
Ool00`0?Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`05Ool0051oo`03001oogoo02Moo`03001o
ogoo02Aoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo02Moo`03001oogoo02Aoo`03001o
ogoo00Eoo`00D7oo00<007ooOol0:7oo00<007ooOol08goo00<03gooOol0B7oo00<007ooOol0Agoo
00<03gooOol09goo00<007ooOol097oo00<007ooOol01Goo001@Ool00`00Oomoo`0XOol00`00Oomo
o`0SOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0WOol00`00Oomoo`0TOol00`00Oomo
o`05Ool0051oo`8002Uoo`03001oogoo02=oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo
02Ioo`03001oogoo02Aoo`8000Moo`00D7oo00<007ooOol0:Goo00<007ooOol08Woo00<03gooOol0
B7oo00<007ooOol0Agoo00<03gooOol09Woo00<007ooOol09Goo00<007ooOol01Goo001@Ool00`00
Oomoo`0YOol00`00Oomoo`0ROol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0UOol00`00
Oomoo`0VOol00`00Oomoo`05Ool0051oo`03001oogoo02Yoo`03001oogoo025oo`0300moogoo04Qo
o`03001oogoo04Moo`0300moogoo02Eoo`03001oogoo02Ioo`03001oogoo00Eoo`004goo0`007goo
0`0067oo00<007ooOol0:Woo00<007ooOol08Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03goo
Ool09Goo00<007ooOol09Woo00<007ooOol01Goo000COol00`00Oomoo`0QOol00`00Oomoo`0FOol2
000[Ool00`00Oomoo`0QOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0TOol00`00Oomo
o`0VOol20007Ool000Moo`<00003Ool0000000<000=oo`03001oogoo00=oo`<000Eoo`<00004Ool0
0000Ool5000017oo000007oo0P0017oo00<007ooOol05Woo00<007ooOol0:goo00<007ooOol087oo
00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol097oo00<007ooOol09goo00<007ooOol01Goo
0008Ool01@00Oomoogoo00000Woo00D007ooOomoo`0000Ioo`03001oogoo00Eoo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol000Eoo`03001oogoo01Ioo`03001oogoo02]oo`03001oogoo
021oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo02Aoo`03001oogoo02Moo`03001oogoo
00Eoo`0027oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`001Goo00<007ooOol01Goo0`000Woo100027oo
00<007ooOol0:goo00<007ooOol087oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol08goo
00<007ooOol0:7oo00<007ooOol01Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0005Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0/Ool00`00Oomoo`0OOol00`0?
Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0SOol00`00Oomoo`0XOol00`00Oomoo`05Ool000Qo
o`04001oogoo0002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool200001Goo0000
07oo00000Woo0P0000Eoo`00001oo`0000Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo
00Eoo`<002`03`0300003`0?06X03`0300003`0?06`03`0300003`0?02P03`8000Moo`0027oo00<0
07ooOol01@000goo00<007ooOol017oo00<007ooOol017oo0P0000Eoo`00Oomoo`00009oo`800005
Ool007ooOol00006Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0/
Ool00`00Oomoo`0OOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0ROol00`00Oomoo`0Y
Ool00`00Oomoo`05Ool000Qoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo01Yoo`03001o
ogoo00Ioo`03001oogoo00=oo`8000Qoo`03001oogoo02eoo`03001oogoo01ioo`0300moogoo04Qo
o`03001oogoo04Moo`0300moogoo029oo`03001oogoo02Uoo`03001oogoo00Eoo`0027oo00<007oo
Ool027oo0`0000Eoo`00Oomoo`00009oo`03001oogoo01Eoo`<000Qoo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo02eoo`03001oogoo01ioo`0300moogoo04Qoo`03001oogoo04Moo`0300mo
ogoo025oo`03001oogoo02Yoo`03001oogoo00Eoo`001goo0`003Goo1`008Woo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol0;Goo00<007ooOol07Woo00<03gooOol0B7oo00<007ooOol0Agoo
00<03gooOol08Goo00<007ooOol0:Woo00<007ooOol01Goo000oOol20003Ool01@00Oomoogoo0000
1goo0P00;goo00<007ooOol07Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol08Goo00<0
07ooOol0:Goo0P001goo0010Ool00`00Oomoo`02Ool30008Ool00`00Oomoo`0^Ool00`00Oomoo`0M
Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0POol00`00Oomoo`0[Ool00`00Oomoo`05
Ool0051oo`03001oogoo02ioo`03001oogoo01eoo`0300moogoo04Qoo`03001oogoo04Moo`0300mo
ogoo021oo`03001oogoo02]oo`03001oogoo00Eoo`00D7oo00<007ooOol0;goo00<007ooOol077oo
00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol087oo00<007ooOol0:goo00<007ooOol01Goo
001@Ool00`00Oomoo`0_Ool00`00Oomoo`0LOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomo
o`0OOol00`00Oomoo`0/Ool00`00Oomoo`05Ool0051oo`80031oo`03001oogoo01aoo`0300moogoo
04Qoo`03001oogoo04Moo`0300moogoo01moo`03001oogoo02]oo`8000Moo`00D7oo00<007ooOol0
<7oo00<007ooOol06goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol07Woo00<007ooOol0
;Goo00<007ooOol01Goo001@Ool00`00Oomoo`0`Ool00`00Oomoo`0KOol00`0?Oomoo`18Ool00`00
Oomoo`17Ool00`0?Oomoo`0NOol00`00Oomoo`0]Ool00`00Oomoo`05Ool0051oo`03001oogoo031o
o`03001oogoo01]oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo01ioo`03001oogoo02eo
o`03001oogoo00Eoo`00D7oo00<007ooOol0<7oo00<007ooOol06goo00<03gooOol0B7oo00<007oo
Ool0Agoo00<03gooOol07Goo00<007ooOol0;Woo00<007ooOol01Goo001@Ool2000bOol00`00Oomo
o`0JOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0MOol00`00Oomoo`0]Ool20007Ool0
051oo`03001oogoo035oo`03001oogoo01Yoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo
01eoo`03001oogoo02ioo`03001oogoo00Eoo`00D7oo00<007ooOol0<Goo00<007ooOol06Woo00<0
3gooOol0B7oo00<007ooOol0Agoo00<03gooOol077oo00<007ooOol0;goo00<007ooOol01Goo001@
Ool00`00Oomoo`0bOol00`00Oomoo`0IOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0L
Ool00`00Oomoo`0_Ool00`00Oomoo`05Ool0051oo`03001oogoo039oo`03001oogoo01Uoo`0300mo
ogoo04Qoo`03001oogoo04Moo`0300moogoo01aoo`03001oogoo02moo`03001oogoo00Eoo`00D7oo
0P00<goo00<007ooOol06Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol06goo00<007oo
Ool0;goo0P001goo001@Ool00`00Oomoo`0cOol00`00Oomoo`0HOol00`0?Oomoo`18Ool00`00Oomo
o`17Ool00`0?Oomoo`0KOol00`00Oomoo`0`Ool00`00Oomoo`05Ool0051oo`03001oogoo03=oo`03
001oogoo01Qoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo01]oo`03001oogoo031oo`03
001oogoo00Eoo`00?goo0`001Woo00<007ooOol01Goo00<007ooOol0<goo00<007ooOol067oo00<0
3gooOol0B7oo00<007ooOol0Agoo00<03gooOol06Woo00<007ooOol0<Goo00<007ooOol01Goo0010
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0dOol00`00Oomoo`0GOol00`0?Oomoo`18
Ool00`00Oomoo`17Ool00`0?Oomoo`0JOol00`00Oomoo`0aOol00`00Oomoo`05Ool0041oo`04001o
ogooOol60006Ool3000d00l00`0000l03`1R00l00`0000l03`1T00l00`0000l03`0`00l20007Ool0
041oo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`0dOol00`00Oomoo`0GOol00`0?
Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0IOol00`00Oomoo`0bOol00`00Oomoo`05Ool0041o
o`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`0eOol00`00Oomoo`0FOol00`0?Oomoo`18
Ool00`00Oomoo`17Ool00`0?Oomoo`0IOol00`00Oomoo`0bOol00`00Oomoo`05Ool0041oo`03001o
ogoo00=oo`03001oo`0000Moo`03001oogoo03Eoo`03001oogoo01Ioo`0300moogoo04Qoo`03001o
ogoo04Moo`0300moogoo01Uoo`03001oogoo039oo`03001oogoo00Eoo`00@7oo00<007ooOol00goo
00<007oo00001goo00<007ooOol0=Goo00<007ooOol05Woo00<03gooOol0B7oo00<007ooOol0Agoo
00<03gooOol067oo00<007ooOol0<goo00<007ooOol01Goo000oOol20006Ool20007Ool00`00Oomo
o`0fOol00`00Oomoo`0EOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0HOol00`00Oomo
o`0cOol00`00Oomoo`05Ool0041oo`03001oogoo00Eoo`03001oogoo00Eoo`8003Moo`03001oogoo
01Eoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo01Moo`03001oogoo03=oo`8000Moo`00
D7oo00<007ooOol0=Woo00<007ooOol05Goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0
5goo00<007ooOol0=7oo00<007ooOol01Goo001@Ool00`00Oomoo`0gOol00`00Oomoo`0DOol00`0?
Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0GOol00`00Oomoo`0dOol00`00Oomoo`05Ool0051o
o`03001oogoo03Moo`03001oogoo01Aoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo01Io
o`03001oogoo03Eoo`03001oogoo00Eoo`00D7oo00<007ooOol0=goo00<007ooOol057oo00<03goo
Ool0B7oo00<007ooOol0Agoo00<03gooOol05Woo00<007ooOol0=Goo00<007ooOol01Goo001@Ool2
000hOol00`00Oomoo`0DOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0FOol00`00Oomo
o`0dOol20007Ool0051oo`03001oogoo03Qoo`03001oogoo01=oo`0300moogoo04Qoo`03001oogoo
04Moo`0300moogoo01Eoo`03001oogoo03Ioo`03001oogoo00Eoo`00D7oo00<007ooOol0>7oo00<0
07ooOol04goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol05Goo00<007ooOol0=Woo00<0
07ooOol01Goo001@Ool00`00Oomoo`0hOol00`00Oomoo`0COol00`0?Oomoo`18Ool00`00Oomoo`17
Ool00`0?Oomoo`0EOol00`00Oomoo`0fOol00`00Oomoo`05Ool0051oo`03001oogoo03Uoo`03001o
ogoo019oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo01Aoo`03001oogoo03Moo`03001o
ogoo00Eoo`00D7oo0P00>Woo00<007ooOol04Woo00<03gooOol0B7oo00<007ooOol0Agoo00<03goo
Ool057oo00<007ooOol0=Woo0P001goo001@Ool00`00Oomoo`0iOol00`00Oomoo`0BOol00`0?Oomo
o`18Ool00`00Oomoo`17Ool00`0?Oomoo`0DOol00`00Oomoo`0gOol00`00Oomoo`05Ool0051oo`03
001oogoo03Yoo`03001oogoo015oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo01Aoo`03
001oogoo03Moo`03001oogoo00Eoo`00D7oo00<007ooOol0>Woo00<007ooOol04Goo00<03gooOol0
B7oo00<007ooOol0Agoo00<03gooOol04goo00<007ooOol0>7oo00<007ooOol01Goo001@Ool00`00
Oomoo`0jOol00`00Oomoo`0AOol00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0COol00`00
Oomoo`0hOol00`00Oomoo`05Ool0051oo`8003]oo`03001oogoo015oo`0300moogoo04Qoo`03001o
ogoo04Moo`0300moogoo01=oo`03001oogoo03Moo`8000Moo`00D7oo00<007ooOol0>goo00<007oo
Ool047oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol04Woo00<007ooOol0>Goo00<007oo
Ool01Goo001@Ool00`00Oomoo`0kOol00`00Oomoo`0@Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool0
0`0?Oomoo`0BOol00`00Oomoo`0iOol00`00Oomoo`05Ool003moo`<0009oo`<000Uoo`03001oogoo
03]oo`03001oogoo011oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo019oo`03001oogoo
03Uoo`03001oogoo00Eoo`00@7oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol0?7oo00<0
07ooOol03goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol04Woo00<007ooOol0>Goo00<0
07ooOol01Goo0010Ool00`00Oomoo`05Ool00`00Oomoo`05Ool3000l00l00`0000l03`1J00l00`00
00l03`1K00l00`0000l03`0i00l20007Ool0041oo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo03aoo`03001oogoo00moo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo015oo`03001o
ogoo03Yoo`03001oogoo00Eoo`00@7oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0?Goo
00<007ooOol03Woo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol04Goo00<007ooOol0>Woo
00<007ooOol01Goo0010Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomo
o`0>Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0AOol00`00Oomoo`0jOol00`00Oomo
o`05Ool0041oo`03001oogoo009oo`8000Uoo`03001oogoo03eoo`03001oogoo00ioo`0300moogoo
04Qoo`03001oogoo04Moo`0300moogoo011oo`03001oogoo03]oo`03001oogoo00Eoo`00?goo0P00
17oo00<007ooOol027oo0P00?goo00<007ooOol03Goo00<03gooOol0B7oo00<007ooOol0Agoo00<0
3gooOol047oo00<007ooOol0>Woo0P001goo0010Ool00`00Oomoo`03Ool30007Ool00`00Oomoo`0n
Ool00`00Oomoo`0=Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0@Ool00`00Oomoo`0k
Ool00`00Oomoo`05Ool0051oo`03001oogoo03moo`03001oogoo00aoo`0300moogoo04Qoo`03001o
ogoo04Moo`0300moogoo00moo`03001oogoo03aoo`03001oogoo00Eoo`00D7oo00<007ooOol0?goo
00<007ooOol037oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol03goo00<007ooOol0?7oo
00<007ooOol01Goo001@Ool00`00Oomoo`0oOol00`00Oomoo`0<Ool00`0?Oomoo`18Ool00`00Oomo
o`17Ool00`0?Oomoo`0>Ool00`00Oomoo`0mOol00`00Oomoo`05Ool0051oo`80045oo`03001oogoo
00]oo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo00ioo`03001oogoo03aoo`8000Moo`00
D7oo00<007ooOol0@7oo00<007ooOol02goo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol0
3Goo00<007ooOol0?Woo00<007ooOol01Goo001@Ool00`00Oomoo`10Ool00`00Oomoo`0;Ool00`0?
Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0=Ool00`00Oomoo`0nOol00`00Oomoo`05Ool0051o
o`03001oogoo045oo`03001oogoo00Yoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo00ao
o`03001oogoo03moo`03001oogoo00Eoo`00D7oo00<007ooOol0@Goo00<007ooOol02Woo00<03goo
Ool0B7oo00<007ooOol0Agoo00<03gooOol037oo00<007ooOol0?goo00<007ooOol01Goo001@Ool2
0013Ool00`00Oomoo`09Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`0;Ool00`00Oomo
o`0oOol20007Ool0051oo`03001oogoo049oo`03001oogoo00Uoo`0300moogoo04Qoo`03001oogoo
04Moo`0300moogoo00]oo`03001oogoo041oo`03001oogoo00Eoo`00D7oo00<007ooOol0@goo00<0
07ooOol027oo00<03gooOol0B7oo00<007ooOol0Agoo00<03gooOol02Woo00<007ooOol0@Goo00<0
07ooOol01Goo001@Ool00`00Oomoo`13Ool00`00Oomoo`08Ool00`0?Oomoo`18Ool00`00Oomoo`17
Ool00`0?Oomoo`0:Ool00`00Oomoo`11Ool00`00Oomoo`05Ool0051oo`03001oogoo04Aoo`03001o
ogoo00Moo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo00Uoo`03001oogoo049oo`03001o
ogoo00Eoo`00D7oo00<007ooOol0A7oo00<007ooOol01goo00<03gooOol0B7oo00<007ooOol0Agoo
00<03gooOol02Goo00<007ooOol0@Woo00<007ooOol01Goo001@Ool20016Ool00`00Oomoo`06Ool0
0`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomoo`09Ool00`00Oomoo`11Ool20007Ool0051oo`03
001oogoo04Ioo`03001oogoo00Eoo`0300moogoo04Qoo`03001oogoo04Moo`0300moogoo00Qoo`03
001oogoo04=oo`03001oogoo00Eoo`00D7oo00<007ooOol0AWoo00<007ooOol01Goo00<03gooOol0
B7oo00<007ooOol0Agoo00<03gooOol027oo00<007ooOol0@goo00<007ooOol01Goo000oOol30003
Ool30008Ool00`00Oomoo`17Ool00`00Oomoo`04Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?
Oomoo`08Ool00`00Oomoo`13Ool00`00Oomoo`05Ool0041oo`05001oogooOol00003Ool00`00Oomo
o`05Ool00`00Oomoo`17Ool00`00Oomoo`04Ool00`0?Oomoo`18Ool00`00Oomoo`17Ool00`0?Oomo
o`07Ool00`00Oomoo`14Ool00`00Oomoo`05Ool0041oo`05001oogooOol00003Ool00`00Oomoo`05
Ool3001800l00`0000l03`1>00l00`0000l03`1A00l00`0000l03`1300l20007Ool0041oo`05001o
ogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomoo`02Ool00`0?Oomoo`18Ool0
0`00Oomoo`17Ool00`0?Oomoo`06Ool00`00Oomoo`15Ool00`00Oomoo`05Ool0041oo`04001oogoo
Ool20002Ool00`00Oomoo`05Ool00`00Oomoo`1:Ool20002Ool00`0?Oomoo`18Ool00`00Oomoo`17
Ool00`0?Oomoo`05Ool00`00Oomoo`16Ool00`00Oomoo`05Ool0041oo`06001oogooOol007oo0P00
27oo00<007ooOol0C7oo00<007oo00l0BWoo00<007ooOol0Agoo00<03gooOol01Goo00<007ooOol0
AWoo00<007ooOol01Goo0010Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`1=Ool00`00
00moo`19Ool00`00Oomoo`17Ool00`0?Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`05Ool003mo
o`8000Eoo`03001oogoo00Moo`8004moo`03001oogoo04Qoo`03001oogoo04Moo`0300moogoo00=o
o`03001oogoo04Moo`8000Moo`00@7oo00<007ooOol017oo0P001goo00<007ooOol0CWoo00<03`00
0000B7oo00<007ooOol0Agoo00<03gooOol00Woo00<007ooOol0BGoo00<007ooOol01Goo001@Ool0
0`00Oomoo`1>Ool00`0?Oomoo`020016Ool00`00Oomoo`17Ool01@0?Oomoogoo0000C7oo00<007oo
Ool01Goo001@Ool00`00Oomoo`1>Ool00`0?Oomoo`02Ool6000;Ool<000YOol00`00Oomoo`17Ool0
100?Oomoo`00CGoo00<007ooOol01Goo001@Ool00`00Oomoo`1>Ool00`0?Oomoo`08Ool;000<Ool7
000ROol00`00Oomoo`17Ool00`0?Ool0001>Ool00`00Oomoo`05Ool0051oo`8004moo`0300moogoo
02Ioo`H001aoo`03001oogoo04Ioo`<004ioo`8000Moo`00D7oo00<007ooOol0CWoo00<03gooOol0
;7oo1P005Woo00<007ooOol07Woo50004Woo0P0000=oo`0?Ool0Cgoo00<007ooOol01Goo001@Ool0
0`00Oomoo`1>Ool00`0?Oomoo`0bOol<000:Ool00`00Oomoo`0DOol:000DOol70006Ool50003Ool0
0`0?Oomoo`1>Ool00`00Oomoo`05Ool0051oo`03001oogoo04ioo`0300moogoo03ioob4002Eoo`L0
00Moo`0300moogoo04ioo`03001oogoo00Eoo`00D7oo00<007ooOol0CWoo00<03gooOol0B7oo00<0
07ooOol0Agoo00<03gooOol0CWoo00<007ooOol01Goo001@Ool2001?Ool00`0?Oomoo`18Ool00`00
Oomoo`17Ool00`0?Oomoo`1=Ool20007Ool0051oo`03001oogoo00Aoo`03001oogoo00aoo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001o
ogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00Aoo`03001o
ogoo00Eoo`00D7oo00<007ooOol017oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol037oo
00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol02goo
00<007ooOol037oo00<007ooOol037oo00<007ooOol017oo00<007ooOol01Goo001@Oooo000i0007
Ool00?mooi1oo`00ogooT7oo003oOon@Ool00?mooi1oo`00ogooT7oo003oOon@Ool00?mooi1oo`00
ogooT7oo003NOol7000?Ool3002HOol00=moo`03001oogoo009oo`03001oogoo009oo`L000=oo`05
001oogooOol0002GOol00=moo`03001oogoo009oo`03001oogoo00aoo`05001oogooOol0002GOol0
0>1oo`03001oogoo011oo`05001oogooOol0002GOol00>5oo`03001oogoo00Eoo`L000=oo`05001o
ogooOol0002GOol00>5oo`03001oogoo00moo`05001oogooOol0002GOol00>9oo`03001oogoo00io
o`05001oogooOol0002GOol00=moo`05001oogooOol0000?Ool01@00Oomoogoo0000Ugoo003OOol6
000?Ool3002HOol00?mooi1oo`00\
\>"],
  ImageRangeCache->{{{0, 398}, {245.438, 0}} -> {-31.8173, 7.86406, 0.134743, 
  0.0389851}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Magnetic Force ", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"One computes the force over the element g1 induced by the whole structure. \
One should be cautious that the cpu time to compute the force can be very \
long and one must set the segmentation parameter k to the lowest values \
consistent with   sufficient precision . Taking into account the symmetry \
with respect to the x axis {1,0,0}  would remove the Fx component and double \
the Fy and Fz components. ",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(k = {1, 1, 2}; \nt1 = AbsoluteTime[]; \n
    fr = radFldEnrFrc[g1, t, "\<\>", k]; \nt2 = AbsoluteTime[]; \n
    Print["\<{Fx, Fy, Fz} = \>", N[fr, 3], "\< Newton\>"]; \n
    Print\ ["\<cpu time : \>", N[t2 - t1, 3], "\< seconds\>"]; \)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\("{Fx, Fy, Fz} = "\), "\[InvisibleSpace]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["1.96679994766135735`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            StyleBox["1.25948822621735345`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3], ",", 
            StyleBox["13.7964991046479745`",
              StyleBoxAutoDelete->True,
              PrintPrecision->3]}], "}"}], "\[InvisibleSpace]", 
        \(" Newton"\)}],
      SequenceForm[ 
      "{Fx, Fy, Fz} = ", {1.9667999476613574, 1.2594882262173535, 
        13.796499104647975}, " Newton"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\("cpu time : "\), "\[InvisibleSpace]", 
        StyleBox["6.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", \(" seconds"\)}],
      SequenceForm[ "cpu time : ", 6.0, " seconds"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Creating the Model and Solving with Rectangular Segmentation in the Corner\
\>", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The same model is created but the segmentation in the corner is \
made with parallelepipedic sub-elements. The precision of the field in the \
gap is much poorer. It can be improved by using larger values of n3 and n5 \
such as {nx,4,4} or {nx,6,6},  but the CPU time and memory requirements grow  \
quickly.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
(* Geometry Parameters *)

gap=10;  \t\t\t\t\t(* in mm  *)
thick=50;\t\t\t\t\t(* in mm  *)
width=40;\t\t\t\t\t(* in mm  *)
chamfer=8;\t\t\t\t\t(* in mm  *)
current=-2000;\t\t\t\t(* in Ampere  *)

(* Segmentation Parameters *)

nx=2;\t\t\t\t\t\t
nbp=2;nbr=2; \t\t\t\t(* for the corners *)
n1={nx,3,2};\t\t\t\t(* pole faces *)
n2={nx,2,2};\t\t\t\t(* Small Vert. Arm *)
n3={nx,2,2};\t\t\t\t
n4={nx,2,2};\t\t\t\t(* Horiz.  Arm  *)
n5={nx,2,2};\t\t\t\t
n6={nx,2,2};\t\t\t\t(* Inside the Coil *)

(* Build the geometry *)

t0=AbsoluteTime[];
radUtiDelAll[];
ironmat=radMatSatIso[{20000,2},{0.1,2},{0.1,2}];
geom[0];

(* Solve the geometry *)

t1=AbsoluteTime[];
res=RadSolve[t,0.0001,1500];
t2=AbsoluteTime[];

(* Print The results *)

b0=radFld[t,\"Bz\",{0,0,0}];
bampere=(-4*Pi*current/gap)/10000;
r=b0/bampere;

Print[\"Mag_Max  H_Max  N_Iter = \",N[res[[2]],3],\" T \",N[res[[3]],3],\" T \
\",res[[4]]];
Print[\"Built & Solved in \",Round[t1-t0],\" & \",Round[t2-t1], \" seconds\"]
Print[\"Bz = \", N[b0,4],\" T,   Bz Computed / Bz Ampere Law  = \",N[r,4]]

draw=radObjDrw[t];
RadPlot3DOptions[];
Show[Graphics3D[draw]
,ViewPoint->{5,-1.5,1}
,PlotRange->All
 ,AmbientLight -> GrayLevel[0.1]];
 
 Print[\" Segmenting iron corners into parallellepiped should be avoided. \
Instead, one should use a circular or ellipsoidal segmentation\"]\
\>", 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\("Mag_Max  H_Max  N_Iter = "\), "\[InvisibleSpace]", 
        StyleBox["0.439719630532325744`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", \(" T "\), 
        "\[InvisibleSpace]", 
        StyleBox["0.0000223506450436030856`",
          StyleBoxAutoDelete->True,
          PrintPrecision->3], "\[InvisibleSpace]", \(" T "\), 
        "\[InvisibleSpace]", "86"}],
      SequenceForm[ 
      "Mag_Max  H_Max  N_Iter = ", .43971963053232571, " T ",
         .000022350645043603083, " T ", 86],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Built & Solved in "\[InvisibleSpace]1
        \[InvisibleSpace]" & "\[InvisibleSpace]1\[InvisibleSpace]" seconds"\),
      
      SequenceForm[ "Built & Solved in ", 1, " & ", 1, " seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{\("Bz = "\), "\[InvisibleSpace]", 
        StyleBox["0.109143162197598053`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", 
        \(" T,   Bz Computed / Bz Ampere Law  = "\), "\[InvisibleSpace]", 
        StyleBox["0.434266844210705471`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4]}],
      SequenceForm[ 
      "Bz = ", .10914316219759805, " T,   Bz Computed / Bz Ampere Law  = ",
         .43426684421070549],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.76419 .84714 -12.3237 0 ]
[.76419 .84714 12.6763 15 ]
[.81448 .83438 -4.91601 0 ]
[.81448 .83438 5.08399 15 ]
[.8687 .82063 -7.84233 0 ]
[.8687 .82063 8.15767 15 ]
[.81553 .89687 -7.86561 0 ]
[.81553 .89687 8.13439 15 ]
[.2965 .11046 -4.94346 -15 ]
[.2965 .11046 5.05654 0 ]
[.44098 .12297 -7.97378 -15 ]
[.44098 .12297 8.02622 0 ]
[.58205 .13518 -11.0501 -15 ]
[.58205 .13518 10.9499 0 ]
[.71986 .14711 -11.1341 -15 ]
[.71986 .14711 10.8659 0 ]
[.85449 .15877 -11.2161 -15 ]
[.85449 .15877 10.7839 0 ]
[.55741 .07057 -8.02557 -15 ]
[.55741 .07057 7.97443 0 ]
[.88922 .2025 0 -6.8695 ]
[.88922 .2025 31 8.1305 ]
[.89214 .34183 0 -6.95972 ]
[.89214 .34183 25 8.04028 ]
[.8951 .48333 0 -7.05139 ]
[.8951 .48333 10 7.94861 ]
[.8981 .62705 0 -7.14455 ]
[.8981 .62705 16 7.85545 ]
[.90115 .77303 0 -7.23923 ]
[.90115 .77303 22 7.76077 ]
[.95749 .48707 0 -7.05139 ]
[.95749 .48707 15 7.94861 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
.74656 .83907 m
.88929 .80284 L
s
.25 Mabswid
.76401 .83464 m
.76393 .82839 L
s
gsave
.76419 .84714 -73.3237 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.81427 .82189 m
.81417 .81564 L
s
gsave
.81448 .83438 -65.916 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.86845 .80813 m
.86833 .80189 L
s
gsave
.8687 .82063 -68.8423 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.77377 .83217 m
.77372 .82842 L
s
.78367 .82965 m
.78362 .8259 L
s
.79372 .8271 m
.79366 .82335 L
s
.80392 .82451 m
.80386 .82076 L
s
.82478 .81922 m
.82472 .81547 L
s
.83545 .81651 m
.83538 .81276 L
s
.84628 .81376 m
.84621 .81001 L
s
.85728 .81097 m
.85721 .80722 L
s
.75439 .83708 m
.75434 .83333 L
s
.8798 .80525 m
.87972 .80151 L
s
gsave
.81553 .89687 -68.8656 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.2211 .11645 m
.87617 .17312 L
s
.25 Mabswid
.29636 .12296 m
.29629 .12921 L
s
gsave
.2965 .11046 -65.9435 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.44094 .13547 m
.44092 .14172 L
s
gsave
.44098 .12297 -68.9738 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.58211 .14768 m
.58214 .15393 L
s
gsave
.58205 .13518 -72.0501 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.72001 .15961 m
.72008 .16586 L
s
gsave
.71986 .14711 -72.1341 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(150) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.85474 .17127 m
.85486 .17752 L
s
gsave
.85449 .15877 -72.2161 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(200) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.32555 .12549 m
.32552 .12924 L
s
.35461 .128 m
.35458 .13175 L
s
.38352 .1305 m
.3835 .13425 L
s
.4123 .13299 m
.41228 .13674 L
s
.46944 .13794 m
.46943 .14169 L
s
.49781 .14039 m
.49781 .14414 L
s
.52604 .14283 m
.52605 .14658 L
s
.55414 .14526 m
.55415 .14901 L
s
.60995 .15009 m
.60997 .15384 L
s
.63766 .15249 m
.63769 .15624 L
s
.66524 .15487 m
.66527 .15862 L
s
.69269 .15725 m
.69273 .161 L
s
.7472 .16197 m
.74726 .16572 L
s
.77427 .16431 m
.77433 .16806 L
s
.80122 .16664 m
.80128 .17039 L
s
.82804 .16896 m
.82811 .17271 L
s
.26703 .12043 m
.26698 .12418 L
s
.23755 .11788 m
.2375 .12163 L
s
gsave
.55741 .07057 -69.0256 -19 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.003 w
.87617 .17312 m
.88929 .80284 L
s
.25 Mabswid
.87676 .20145 m
.87054 .20093 L
s
gsave
.88922 .2025 -61 -10.8695 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87967 .34094 m
.87344 .34049 L
s
gsave
.89214 .34183 -61 -10.9597 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.88262 .48259 m
.87638 .48221 L
s
gsave
.8951 .48333 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88562 .62646 m
.87937 .62616 L
s
gsave
.8981 .62705 -61 -11.1446 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88866 .7726 m
.88241 .77238 L
s
gsave
.90115 .77303 -61 -11.2392 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87734 .22918 m
.8736 .22887 L
s
.87792 .25699 m
.87418 .25669 L
s
.8785 .28489 m
.87476 .2846 L
s
.87908 .31287 m
.87535 .31259 L
s
.88026 .36909 m
.87652 .36883 L
s
.88084 .39733 m
.8771 .39708 L
s
.88143 .42566 m
.87769 .42542 L
s
.88203 .45408 m
.87828 .45385 L
s
.88322 .51118 m
.87947 .51097 L
s
.88381 .53987 m
.88007 .53966 L
s
.88441 .56864 m
.88067 .56844 L
s
.88501 .5975 m
.88127 .59732 L
s
.88622 .6555 m
.88248 .65533 L
s
.88683 .68464 m
.88308 .68448 L
s
.88744 .71387 m
.88369 .71372 L
s
.88805 .74319 m
.8843 .74305 L
s
.87619 .17381 m
.87245 .17349 L
s
.88928 .80211 m
.88553 .80198 L
s
gsave
.95749 .48707 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.14199 .22149 m
.13013 .8214 L
s
.13013 .8214 m
.74656 .83907 L
s
.74656 .83907 m
.73904 .26772 L
s
.73904 .26772 m
.14199 .22149 L
s
.2211 .11645 m
.87617 .17312 L
s
.87617 .17312 m
.88929 .80284 L
s
.88929 .80284 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.14199 .22149 m
.13013 .8214 L
s
.13013 .8214 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.2211 .11645 m
.14199 .22149 L
s
.73904 .26772 m
.87617 .17312 L
s
.87617 .17312 m
.88929 .80284 L
s
.88929 .80284 m
.74656 .83907 L
s
.74656 .83907 m
.73904 .26772 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.68559 .40522 m .63296 .68006 L .68838 .68029 L .81 0 0 r
F
.68559 .40522 m .63099 .40488 L .63296 .68006 L F
.66855 .38542 m .63099 .40488 L .68559 .40522 L .652 0 0 r
F
.73545 .39962 m .68559 .40522 L .68838 .68029 L .738 0 0 r
F
.67489 .38469 m .68559 .40522 L .73545 .39962 L .652 0 0 r
F
.67489 .38469 m .66855 .38542 L .68559 .40522 L F
.66855 .38542 m .66155 .38538 L .63099 .40488 L F
.66855 .38542 m .67115 .66737 L .66405 .66734 L .811 0 0 r
F
.67489 .38469 m .67115 .66737 L .66855 .38542 L .735 0 0 r
F
.67489 .38469 m .67759 .66689 L .67115 .66737 L F
.67888 .38337 m .67489 .38469 L .73545 .39962 L .652 0 0 r
F
.67888 .38337 m .67759 .66689 L .67489 .38469 L .593 0 0 r
F
.73545 .39962 m .68838 .68029 L .73902 .67663 L .738 0 0 r
F
.7679 .38936 m .73545 .39962 L .73902 .67663 L .603 0 0 r
F
.7679 .38936 m .73902 .67663 L .77201 .66993 L F
[ ] 0 setdash
.67888 .38337 m .68164 .66603 L .77201 .66993 L p .845 0 0 r
F P
0 g
s
.67888 .38337 m .77201 .66993 L .68164 .66603 L .845 0 0 r
F
.72974 .64657 m .68164 .66603 L .67888 .38337 L p .398 0 0 r
F P
0 g
s
.67888 .38337 m .68164 .66603 L .67759 .66689 L .593 0 0 r
F
.66855 .38542 m .66405 .66734 L .66155 .38538 L .811 0 0 r
F
.66599 .37588 m .66732 .5229 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
.66732 .5229 m .69049 .51075 L .69049 .51075 L p 0 .458 1 r
F P
0 g
s
.66155 .38538 m .63099 .40488 L p .64718 .53346 L .393 0 0 r
F P
0 g
s
.66279 .52528 m .66155 .38538 L p .64718 .53346 L .393 0 0 r
F P
0 g
s
.63296 .68006 m .66405 .66734 L p .64718 .53346 L .393 0 0 r
F P
0 g
s
.63099 .40488 m .63196 .54144 L p .64718 .53346 L .393 0 0 r
F P
0 g
s
.63196 .54144 m .63296 .68006 L p .64718 .53346 L .393 0 0 r
F P
0 g
s
.63296 .68006 m .63099 .40488 L .47243 .39455 L p .844 0 0 r
F P
0 g
s
.66155 .38538 m .63296 .68006 L .63099 .40488 L .393 0 0 r
F
.47243 .39455 m .47201 .67332 L .63296 .68006 L p .844 0 0 r
F P
0 g
s
.64718 .53346 m .66405 .66734 L .63296 .68006 L .393 0 0 r
F
.66155 .38538 m .66279 .52528 L .64718 .53346 L F
.66279 .52528 m .66405 .66734 L .64718 .53346 L F
.66405 .66734 m .66279 .52528 L p .64718 .53346 L F P
0 g
s
.47243 .39455 m .63099 .40488 L .66155 .38538 L p .652 0 0 r
F P
0 g
s
.66155 .38538 m .49934 .37452 L .47243 .39455 L p .652 0 0 r
F P
0 g
s
.49934 .37452 m .66155 .38538 L .66405 .66734 L p .845 0 0 r
F P
0 g
s
.66405 .66734 m .49933 .66025 L .49934 .37452 L p .845 0 0 r
F P
0 g
s
.50333 .51383 m .66732 .5229 L .66599 .37588 L p 0 .344 .781 r
F P
0 g
s
.52373 .50134 m .50333 .51383 L .66732 .5229 L p 0 .458 1 r
F P
0 g
s
.66732 .5229 m .50333 .51383 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.69049 .51075 m .52373 .50134 L p .66732 .5229 L 0 .458 1 r
F P
0 g
s
.66732 .5229 m .66732 .5229 L .69049 .51075 L 0 .458 1 r
F
.67888 .38337 m .73545 .39962 L .7679 .38936 L .652 0 0 r
F
0 g
.68596 .40518 m
.73545 .39962 L
s
.49933 .66025 m .47201 .67332 L .47243 .39455 L p .326 0 0 r
F P
0 g
s
.47243 .39455 m .49934 .37452 L .49933 .66025 L p .326 0 0 r
F P
0 g
s
.47243 .39455 m .42348 .66915 L .47201 .67332 L .881 0 0 r
F
.47243 .39455 m .42464 .38816 L .42348 .66915 L F
.49934 .37452 m .42464 .38816 L .47243 .39455 L .652 0 0 r
F
.49934 .37452 m .47243 .39455 L .47201 .67332 L .326 0 0 r
F
.69049 .51075 m .66732 .5229 L .66862 .66547 L p 0 .162 .706 r
F P
0 g
s
.67115 .66737 m .68838 .68029 L .63296 .68006 L .538 0 0 r
F
.67115 .66737 m .63296 .68006 L .66405 .66734 L F
.67759 .66689 m .68838 .68029 L .67115 .66737 L F
.67759 .66689 m .73902 .67663 L .68838 .68029 L F
.68164 .66603 m .73902 .67663 L .67759 .66689 L F
.68164 .66603 m .77201 .66993 L .73902 .67663 L F
.7679 .38936 m .77201 .66993 L .82315 .65078 L p .428 0 0 r
F P
0 g
s
.77201 .66993 m .7679 .38936 L .67888 .38337 L p .845 0 0 r
F P
0 g
s
.67888 .38337 m .7679 .38936 L .77201 .66993 L .845 0 0 r
F
.82315 .65078 m .77201 .66993 L .68164 .66603 L p .538 0 0 r
F P
0 g
s
.72974 .64657 m .82315 .65078 L p .75135 .65852 L .538 0 0 r
F P
0 g
s
.68164 .66603 m .70524 .65648 L p .75135 .65852 L .538 0 0 r
F P
0 g
s
.70524 .65648 m .72974 .64657 L p .75135 .65852 L .538 0 0 r
F P
0 g
s
.69049 .51075 m .66862 .66547 L .66966 .66504 L 0 .162 .706 r
F
.66405 .66734 m .63296 .68006 L .47201 .67332 L p .538 0 0 r
F P
0 g
s
.47201 .67332 m .49933 .66025 L .49933 .66025 L p .538 0 0 r
F P
0 g
s
.49933 .66025 m .66405 .66734 L p .47201 .67332 L .538 0 0 r
F P
0 g
s
.47201 .67332 m .49933 .66025 L .47201 .67332 L .538 0 0 r
F
.66868 .67231 m .66732 .5229 L .50333 .51383 L p 0 .344 .781 r
F P
0 g
s
.66993 .81026 m .66868 .67231 L .50335 .66526 L p 0 .344 .781 r
F P
0 g
s
.50338 .8051 m .50335 .66526 L .50335 .66526 L p 0 .134 .679 r
F P
0 g
s
.50335 .66526 m .66868 .67231 L p .66868 .67231 L 0 .344 .781 r
F P
0 g
s
.50333 .51383 m .50335 .66526 L p .50335 .66526 L 0 .344 .781 r
F P
0 g
s
.50333 .51383 m .50335 .66526 L .66868 .67231 L 0 .344 .781 r
F
.50333 .51383 m .50335 .66526 L .50333 .51383 L F
.50335 .66526 m .50338 .8051 L p .50338 .8051 L 0 .134 .679 r
F P
0 g
s
.50335 .66526 m .50335 .66526 L p .66868 .67231 L 0 .344 .781 r
F P
0 g
s
.50335 .66526 m .66868 .67231 L p .66868 .67231 L 0 .455 1 r
F P
0 g
s
.52392 .65555 m .50335 .66526 L p .66868 .67231 L 0 .455 1 r
F P
0 g
s
.50335 .66526 m .50335 .66526 L p .66868 .67231 L 0 .455 1 r
F P
0 g
s
.50335 .66526 m .52392 .65555 L p .52392 .65555 L 0 .134 .679 r
F P
0 g
s
.66868 .67231 m .50335 .66526 L p .52392 .65555 L 0 .455 1 r
F P
0 g
s
.50335 .66526 m .50338 .8051 L .66993 .81026 L p 0 .344 .781 r
F P
0 g
s
.52392 .65555 m .50338 .8051 L .50335 .66526 L 0 .134 .679 r
F
.52392 .65555 m .50335 .66526 L .50335 .66526 L F
.50335 .66526 m .52392 .65555 L p .52392 .65555 L 0 .455 1 r
F P
0 g
s
.52392 .65555 m .50335 .66526 L p .50335 .66526 L 0 .134 .679 r
F P
0 g
s
.50338 .8051 m .50338 .8051 L .50335 .66526 L 0 .134 .679 r
F
.52392 .65555 m .50335 .66526 L .50338 .8051 L F
.52392 .65555 m .50335 .66526 L .52392 .65555 L F
.50335 .66526 m .50335 .66526 L p .52392 .65555 L 0 .455 1 r
F P
0 g
s
.50333 .51383 m .52373 .50134 L p .50427 .65789 L 0 .134 .679 r
F P
0 g
s
.50335 .65832 m .50333 .51383 L p .50427 .65789 L 0 .134 .679 r
F P
0 g
s
.42464 .38816 m .3951 .66201 L .42348 .66915 L .992 0 0 r
F
.42464 .38816 m .39671 .37721 L .3951 .66201 L F
.49934 .37452 m .47201 .67332 L .49933 .66025 L .326 0 0 r
F
.39671 .37721 m .39513 .65365 L .3951 .66201 L .809 0 0 r
F
.49933 .66025 m .47201 .67332 L .42348 .66915 L .538 0 0 r
F
.49318 .6597 m .42348 .66915 L .3951 .66201 L F
.49933 .66025 m .42348 .66915 L .49318 .6597 L F
.48974 .65879 m .3951 .66201 L .39513 .65365 L F
.49318 .6597 m .3951 .66201 L .48974 .65879 L F
.50338 .8051 m .50335 .66526 L .39509 .66065 L p 0 .344 .781 r
F P
0 g
s
.39509 .66065 m .28484 .65595 L p .39469 .73092 L 0 .344 .781 r
F P
0 g
s
.39469 .73092 m .50338 .8051 L .39509 .66065 L 0 .344 .781 r
F
.39671 .37721 m .39676 .36441 L .39513 .65365 L .809 0 0 r
F
.49934 .37452 m .49329 .37368 L .42464 .38816 L .652 0 0 r
F
.49934 .37452 m .49318 .6597 L .49329 .37368 L .883 0 0 r
F
.49934 .37452 m .49933 .66025 L .49318 .6597 L F
.49329 .37368 m .39671 .37721 L .42464 .38816 L .652 0 0 r
F
.49329 .37368 m .4899 .37228 L .39671 .37721 L F
.49329 .37368 m .48974 .65879 L .4899 .37228 L .999 0 0 r
F
.49329 .37368 m .49318 .6597 L .48974 .65879 L F
.4899 .37228 m .48993 .65774 L .49009 .37068 L .1 0 0 r
F
.4899 .37228 m .48974 .65879 L .48993 .65774 L F
.52392 .65555 m .50335 .66526 L p .50335 .66526 L 0 .134 .679 r
F P
0 g
s
.52373 .50134 m .52392 .65555 L p .50335 .66526 L 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52392 .65555 L p .50335 .66526 L 0 .134 .679 r
F P
0 g
s
.50335 .66526 m .52392 .65555 L .52392 .65555 L p 0 .455 1 r
F P
0 g
s
.49009 .37068 m .48993 .65774 L .51026 .64788 L p .32 0 0 r
F P
0 g
s
.50335 .66526 m .50335 .65832 L p .50427 .65789 L 0 .134 .679 r
F P
0 g
s
.4899 .37228 m .39676 .36441 L .39671 .37721 L .652 0 0 r
F
.4899 .37228 m .49009 .37068 L .39676 .36441 L F
.48993 .65774 m .49009 .37068 L .39676 .36441 L p .845 0 0 r
F P
0 g
s
.49009 .37068 m .39513 .65365 L .39676 .36441 L .845 0 0 r
F
.49009 .37068 m .48993 .65774 L .39513 .65365 L F
.39676 .36441 m .39513 .65365 L .48993 .65774 L p F P
0 g
s
.39513 .65365 m .39676 .36441 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.4332 .63322 m .4138 .64363 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.4138 .64363 m .39513 .65365 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.48974 .65879 m .39513 .65365 L .48993 .65774 L .538 0 0 r
F
.66599 .37588 m .5033 .36485 L .50333 .51383 L p 0 .344 .781 r
F P
0 g
s
.52373 .50134 m .50333 .51383 L .5033 .36485 L p 0 .134 .679 r
F P
0 g
s
.48993 .65774 m .39513 .65365 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.66868 .67231 m .69207 .66287 L .69207 .66287 L p 0 .455 1 r
F P
0 g
s
.66868 .67231 m .66868 .67231 L .69207 .66287 L 0 .455 1 r
F
.66868 .67231 m .69207 .66287 L .69207 .66287 L p 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .69049 .51075 L p .66868 .67231 L 0 .162 .706 r
F P
0 g
s
.66868 .67231 m .66868 .67231 L .69207 .66287 L 0 .162 .706 r
F
.69207 .66287 m .71635 .65307 L p .71635 .65307 L 0 .455 1 r
F P
0 g
s
.68231 .6535 m .68446 .65557 L .64782 .65395 L 0 .344 .78 r
F
.68231 .6535 m .64782 .65395 L .52392 .64849 L F
.52392 .64849 m .52373 .50134 L p .68231 .6535 L F P
0 g
s
.69207 .66287 m .52392 .65555 L .52392 .64849 L p 0 .344 .78 r
F P
0 g
s
.68446 .65557 m .69207 .66287 L .52392 .64849 L 0 .344 .78 r
F
.52373 .50134 m .69049 .51075 L .66732 .5229 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .69049 .51075 L .692 .6559 L p 0 .344 .78 r
F P
0 g
s
.692 .6559 m .69207 .66287 L p .68446 .65557 L 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .692 .6559 L .68446 .65557 L 0 .344 .78 r
F
.69207 .66287 m .69207 .66287 L p .71635 .65307 L 0 .455 1 r
F P
0 g
s
.69207 .66287 m .71635 .65307 L p .71635 .65307 L 0 .162 .706 r
F P
0 g
s
.69049 .51075 m .69207 .66287 L p .71635 .65307 L 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .69207 .66287 L p .71635 .65307 L 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .69049 .51075 L .52373 .50134 L p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .69207 .66287 L p .69207 .66287 L 0 .455 1 r
F P
0 g
s
.52392 .65555 m .69207 .66287 L .52392 .65555 L 0 .455 1 r
F
.66862 .66547 m .66868 .67231 L p .66966 .66504 L 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .52392 .65555 L p .66868 .67231 L 0 .455 1 r
F P
0 g
s
.52392 .65555 m .69207 .66287 L .66868 .67231 L p 0 .455 1 r
F P
0 g
s
.52373 .50134 m .52392 .64849 L p .52392 .64849 L 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .52392 .65555 L .69207 .66287 L 0 .344 .78 r
F
.52373 .50134 m .52392 .65555 L .52373 .50134 L F
.52392 .64849 m .52392 .65555 L .52392 .65555 L F
.52392 .64849 m .52392 .65555 L p .52392 .64849 L F P
0 g
s
.54529 .64546 m .52392 .65555 L .52392 .65555 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52373 .50134 L p .54529 .64546 L 0 .134 .679 r
F P
0 g
s
.54529 .64546 m .54529 .64546 L .52392 .65555 L 0 .134 .679 r
F
.52392 .65555 m .54529 .64546 L p .54529 .64546 L 0 .455 1 r
F P
0 g
s
.51026 .64012 m .51026 .64788 L .53138 .63764 L .32 0 0 r
F
.49009 .37068 m .51026 .64788 L .51018 .50057 L F
.4332 .63322 m .53138 .63764 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.39513 .65365 m .4138 .64363 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.4138 .64363 m .4332 .63322 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.53138 .63764 m .51026 .64788 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.51026 .64788 m .48993 .65774 L p .46222 .64576 L .538 0 0 r
F P
0 g
s
.30155 .64587 m .52392 .65555 L p .54529 .64546 L 0 .455 1 r
F P
0 g
s
.52392 .65555 m .52392 .65555 L p .54529 .64546 L 0 .455 1 r
F P
0 g
s
.51026 .63669 m .53138 .63764 L p .51018 .50057 L .32 0 0 r
F P
0 g
s
.52392 .65555 m .54529 .64546 L .54529 .64546 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52392 .65555 L .54532 .65648 L 0 .344 .78 r
F
.52392 .65555 m .54532 .65648 L .69207 .66287 L F
.69207 .66287 m .52392 .65555 L p .52392 .65555 L F P
0 g
s
.52392 .65555 m .69207 .66287 L p .69207 .66287 L 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .52392 .65555 L p .69207 .66287 L 0 .344 .78 r
F P
0 g
s
.71635 .65307 m .54529 .64546 L .52392 .65555 L p 0 .455 1 r
F P
0 g
s
.52392 .65555 m .69207 .66287 L .71635 .65307 L 0 .455 1 r
F
.52392 .65555 m .52392 .65555 L .69207 .66287 L 0 .344 .78 r
F
.69207 .66287 m .66868 .67231 L .66993 .81026 L p 0 .162 .706 r
F P
0 g
s
.66993 .81026 m .69352 .80336 L .69207 .66287 L p 0 .162 .706 r
F P
0 g
s
.69352 .80336 m .69207 .66287 L p .52392 .65555 L 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .69207 .66287 L .69352 .80336 L p 0 .344 .78 r
F P
0 g
s
.71635 .65307 m .69207 .66287 L .52392 .65555 L p 0 .455 1 r
F P
0 g
s
.54529 .64546 m .52392 .65555 L p .52392 .65555 L 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52411 .79801 L .69352 .80336 L p 0 .344 .78 r
F P
0 g
s
.69352 .80336 m .52411 .79801 L .52392 .65555 L p 0 .344 .78 r
F P
0 g
s
.52392 .65555 m .54529 .64546 L .71635 .65307 L p 0 .455 1 r
F P
0 g
s
.54529 .64546 m .54565 .79063 L p .52392 .65555 L 0 .134 .679 r
F P
0 g
s
.54565 .79063 m .54529 .64546 L p .52392 .65555 L 0 .134 .679 r
F P
0 g
s
.54529 .64546 m .54529 .64546 L p .52392 .65555 L 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .54529 .64546 L .52392 .65555 L 0 .134 .679 r
F
.54529 .64546 m .31893 .6354 L .30155 .64587 L p 0 .455 1 r
F P
0 g
s
.31893 .6354 m .54529 .64546 L .5453 .64893 L p 0 .344 .779 r
F P
0 g
s
.54565 .79063 m .52411 .79801 L .52392 .65555 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52411 .79801 L .54565 .79063 L p 0 .134 .679 r
F P
0 g
s
.5453 .64893 m .54565 .79063 L p .54565 .79063 L 0 .344 .779 r
F P
0 g
s
.33644 .64739 m .30155 .64587 L p .33956 .64952 L 0 .455 1 r
F P
0 g
s
.33956 .64952 m .50335 .66526 L .33644 .64739 L 0 .455 1 r
F
.52392 .65555 m .33644 .64739 L p .50335 .66526 L F P
0 g
s
.41376 .6511 m .51027 .65496 L .51027 .65559 L 0 .344 .78 r
F
.30155 .64587 m .41377 .65076 L p .41376 .6511 L F P
0 g
s
.41377 .65076 m .51027 .65496 L p .41376 .6511 L 0 .344 .78 r
F P
0 g
s
.50335 .66526 m .50335 .66526 L .52392 .65555 L 0 .455 1 r
F
.52392 .65555 m .52411 .79801 L .50338 .8051 L p 0 .134 .679 r
F P
0 g
s
.50338 .8051 m .52411 .79801 L .52392 .65555 L p 0 .134 .679 r
F P
0 g
s
.52392 .65555 m .52393 .65623 L p .51027 .65559 L 0 .344 .78 r
F P
0 g
s
.51027 .65496 m .52392 .65555 L p .51027 .65559 L 0 .344 .78 r
F P
0 g
s
.52393 .65623 m .52411 .79801 L p .52411 .79801 L 0 .344 .78 r
F P
0 g
s
.50335 .66526 m .50335 .66526 L p .50338 .8051 L 0 .134 .679 r
F P
0 g
s
.30155 .64587 m .28484 .65595 L .50335 .66526 L p 0 .455 1 r
F P
0 g
s
.30155 .64587 m .52393 .65623 L .52411 .79801 L 0 .344 .78 r
F
.52411 .79801 m .52392 .65555 L .30155 .64587 L p F P
0 g
s
.31893 .6354 m .5453 .64893 L .54565 .79063 L 0 .344 .779 r
F
0 g
.69225 .68001 m
.73902 .67663 L
s
.82315 .65078 m .81808 .36003 L .7679 .38936 L p .428 0 0 r
F P
0 g
s
.67888 .38337 m .7679 .38936 L .79253 .37496 L p .652 0 0 r
F P
0 g
s
.67888 .38337 m .79253 .37496 L .74747 .37187 L .652 0 0 r
F
.81808 .36003 m .7261 .35359 L .70205 .36875 L p F P
0 g
s
.70205 .36875 m .67888 .38337 L p .74747 .37187 L .652 0 0 r
F P
0 g
s
.74747 .37187 m .81808 .36003 L .70205 .36875 L .652 0 0 r
F
.7261 .35359 m .72974 .64657 L p .70363 .51149 L .398 0 0 r
F P
0 g
s
.67888 .38337 m .70205 .36875 L p .70363 .51149 L .398 0 0 r
F P
0 g
s
.70205 .36875 m .7261 .35359 L p .70363 .51149 L .398 0 0 r
F P
0 g
s
.69049 .51075 m .68894 .36111 L .66599 .37588 L p 0 .162 .706 r
F P
0 g
s
.69049 .51075 m .52373 .50134 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.68901 .36786 m .69049 .51075 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .69049 .51075 L .68901 .36786 L p 0 .344 .78 r
F P
0 g
s
.68894 .36111 m .68901 .36786 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.68901 .36786 m .68894 .36111 L p .68159 .36735 L 0 .344 .78 r
F P
0 g
s
.52373 .50134 m .68901 .36786 L .68159 .36735 L 0 .344 .78 r
F
.79253 .37496 m .81808 .36003 L p .74747 .37187 L .652 0 0 r
F P
0 g
s
.72651 .38657 m
.7679 .38936 L
s
.7679 .38936 m
.7717 .64846 L
s
.66479 .24424 m .50328 .2315 L .5033 .36485 L p 0 .344 .781 r
F P
0 g
s
.5033 .36485 m .66599 .37588 L .66479 .24424 L p 0 .344 .781 r
F P
0 g
s
.66479 .24424 m .66599 .37588 L .68894 .36111 L p 0 .162 .706 r
F P
0 g
s
.68894 .36111 m .68756 .22717 L .66479 .24424 L p 0 .162 .706 r
F P
0 g
s
.66479 .24424 m .68756 .22717 L .52335 .21395 L p 0 .451 1 r
F P
0 g
s
.52335 .21395 m .50328 .2315 L .66479 .24424 L p 0 .451 1 r
F P
0 g
s
.50328 .2315 m .52335 .21395 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .5033 .36485 L .50328 .2315 L p 0 .134 .679 r
F P
0 g
s
.28996 .21466 m .28839 .35029 L p .28839 .35029 L 0 .344 .781 r
F P
0 g
s
.50328 .2315 m .28996 .21466 L p .28839 .35029 L 0 .344 .781 r
F P
0 g
s
.28996 .21466 m .28996 .21466 L p .28839 .35029 L 0 .344 .781 r
F P
0 g
s
.17801 .34281 m .28839 .35029 L .28996 .21466 L p 0 .344 .781 r
F P
0 g
s
.28839 .35029 m .17801 .34281 L .19253 .32678 L p 0 .456 1 r
F P
0 g
s
.28839 .35029 m .17801 .34281 L .17654 .42588 L p 0 .344 .781 r
F P
0 g
s
.19253 .32678 m .17801 .34281 L .28839 .35029 L p 0 .456 1 r
F P
0 g
s
.17801 .34281 m .19253 .32678 L .19111 .41139 L p 0 .052 .589 r
F P
0 g
s
.28996 .21466 m .28839 .35029 L .30489 .33455 L p 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .28839 .35029 L .28839 .35029 L p 0 .084 .626 r
F P
0 g
s
.28839 .35029 m .28996 .21466 L p .30489 .33455 L 0 .084 .626 r
F P
0 g
s
.19253 .32678 m .30489 .33455 L .28839 .35029 L p 0 .456 1 r
F P
0 g
s
.28839 .35029 m .28839 .35029 L p .30489 .33455 L 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .28839 .35029 L .30489 .33455 L 0 .084 .626 r
F
.30489 .33455 m .28839 .35029 L .30489 .33455 L F
.28839 .35029 m .30192 .33738 L .19253 .32678 L p 0 .456 1 r
F P
0 g
s
.28839 .35029 m .5033 .36485 L .50328 .2315 L p 0 .344 .781 r
F P
0 g
s
.5033 .36485 m .28839 .35029 L .30489 .33455 L p 0 .456 1 r
F P
0 g
s
.30489 .33455 m .28839 .35029 L p .28839 .35029 L 0 .084 .626 r
F P
0 g
s
.30399 .41842 m .30489 .33455 L p .28839 .35029 L 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .30489 .33455 L p .28839 .35029 L 0 .084 .626 r
F P
0 g
s
.50328 .2315 m .5033 .36485 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .52335 .21395 L .50328 .2315 L p 0 .134 .679 r
F P
0 g
s
.50328 .2315 m .52335 .21395 L .30637 .19647 L p 0 .451 1 r
F P
0 g
s
.30637 .19647 m .28996 .21466 L .50328 .2315 L p 0 .451 1 r
F P
0 g
s
.30489 .33455 m .30637 .19647 L p .28996 .21466 L 0 .084 .626 r
F P
0 g
s
.28996 .21466 m .30637 .19647 L .30489 .33455 L p 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .30541 .28536 L p .19253 .32678 L 0 .344 .78 r
F P
0 g
s
.30541 .28536 m .30489 .33455 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .19253 .32678 L p .30541 .28536 L 0 .344 .78 r
F P
0 g
s
.30637 .19647 m .28996 .21466 L p .28996 .21466 L 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .30637 .19647 L p .28996 .21466 L 0 .084 .626 r
F P
0 g
s
.52335 .21395 m .52353 .34967 L .5101 .34874 L p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .5033 .36485 L .66599 .37588 L p 0 .456 1 r
F P
0 g
s
.66599 .37588 m .5033 .36485 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.66599 .37588 m .68894 .36111 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.52353 .34967 m .68894 .36111 L p .68894 .36111 L 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .68894 .36111 L .66599 .37588 L p 0 .456 1 r
F P
0 g
s
.52373 .50134 m .52353 .34967 L p .68894 .36111 L 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .52353 .34967 L p .68894 .36111 L 0 .344 .78 r
F P
0 g
s
.68756 .22717 m .52335 .21395 L .52353 .34967 L p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .68894 .36111 L .68756 .22717 L p 0 .344 .78 r
F P
0 g
s
.68756 .22717 m .68894 .36111 L .52353 .34967 L p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .52335 .21395 L .68756 .22717 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .52353 .34967 L .5033 .36485 L p 0 .456 1 r
F P
0 g
s
.30489 .33455 m .30637 .19647 L .52335 .21395 L p 0 .344 .78 r
F P
0 g
s
.30637 .19647 m .30489 .33455 L p .30489 .33455 L 0 .344 .78 r
F P
0 g
s
.52335 .21395 m .30637 .19647 L p .30489 .33455 L 0 .344 .78 r
F P
0 g
s
.30637 .19647 m .30637 .19647 L p .30489 .33455 L 0 .344 .78 r
F P
0 g
s
.3234 .17758 m .30637 .19647 L .30637 .19647 L p 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .52335 .21395 L .5442 .19573 L p 0 .451 1 r
F P
0 g
s
.5442 .19573 m .3234 .17758 L .30637 .19647 L p 0 .451 1 r
F P
0 g
s
.30489 .33455 m .32203 .3182 L .3234 .17758 L p 0 .084 .626 r
F P
0 g
s
.30637 .19647 m .30489 .33455 L p .3234 .17758 L 0 .084 .626 r
F P
0 g
s
.3234 .17758 m .3234 .17758 L .30637 .19647 L 0 .084 .626 r
F
.19253 .32678 m .30489 .33455 L .30637 .19647 L p 0 .344 .78 r
F P
0 g
s
.30488 .33455 m .19253 .32678 L p .19253 .32678 L 0 .456 1 r
F P
0 g
s
.30489 .33455 m .30637 .19647 L .3234 .17758 L p 0 .084 .626 r
F P
0 g
s
.32203 .3182 m .30489 .33455 L p .30489 .33455 L 0 .084 .626 r
F P
0 g
s
.3234 .17758 m .32203 .3182 L p .30489 .33455 L 0 .084 .626 r
F P
0 g
s
.32203 .3182 m .32203 .3182 L p .30489 .33455 L 0 .084 .626 r
F P
0 g
s
.32203 .3182 m .30489 .33455 L .30488 .33455 L p 0 .456 1 r
F P
0 g
s
.19253 .32678 m .32203 .3182 L .30488 .33455 L 0 .456 1 r
F
.19253 .32678 m .30456 .33453 L .32203 .3182 L p F P
0 g
s
.19111 .41139 m .19253 .32678 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.30489 .33455 m .19253 .32678 L .19111 .41139 L p 0 .344 .78 r
F P
0 g
s
.19253 .32678 m .20763 .31012 L .32203 .3182 L p 0 .456 1 r
F P
0 g
s
.32203 .3182 m .20763 .31012 L .19253 .32678 L p 0 .456 1 r
F P
0 g
s
.19111 .41139 m .19253 .32678 L .20763 .31012 L p 0 .052 .589 r
F P
0 g
s
.32203 .3182 m .30489 .33455 L .30489 .33455 L p 0 .084 .626 r
F P
0 g
s
.5101 .34874 m .4152 .34218 L p .51003 .22131 L 0 .344 .78 r
F P
0 g
s
.4152 .34218 m .30489 .33455 L p .41552 .27348 L 0 .344 .78 r
F P
0 g
s
.41552 .27348 m .51003 .22131 L .4152 .34218 L 0 .344 .78 r
F
.51003 .22131 m .52335 .21395 L .5101 .34874 L F
.52335 .21395 m .68756 .22717 L .71118 .20946 L p 0 .451 1 r
F P
0 g
s
.71118 .20946 m .5442 .19573 L .52335 .21395 L p 0 .451 1 r
F P
0 g
s
.52353 .34967 m .52335 .21395 L .5442 .19573 L p 0 .134 .679 r
F P
0 g
s
.5442 .19573 m .52335 .21395 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .52335 .21395 L p .51003 .22131 L 0 .344 .78 r
F P
0 g
s
.51009 .34019 m .52353 .34967 L .51003 .22131 L 0 .344 .78 r
F
.4152 .34218 m .52353 .34967 L p .41552 .27348 L F P
0 g
s
.5033 .36485 m .52353 .34967 L .52373 .50134 L p 0 .134 .679 r
F P
0 g
s
.71118 .20946 m .68756 .22717 L .68894 .36111 L p 0 .162 .706 r
F P
0 g
s
.68894 .36111 m .71277 .34579 L .71118 .20946 L p 0 .162 .706 r
F P
0 g
s
.52353 .34967 m .68894 .36111 L .71277 .34579 L p 0 .456 1 r
F P
0 g
s
.71277 .34579 m .68894 .36111 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.71277 .34579 m .54453 .33391 L .52353 .34967 L p 0 .456 1 r
F P
0 g
s
.54453 .33391 m .71277 .34579 L p .71277 .34579 L 0 .344 .779 r
F P
0 g
s
.71277 .34579 m .68894 .36111 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
.68894 .36111 m .52353 .34967 L .52373 .50134 L p 0 .344 .78 r
F P
0 g
s
.52353 .34967 m .54453 .33391 L .71277 .34579 L p 0 .456 1 r
F P
0 g
s
.54491 .48837 m .54453 .33391 L p .71277 .34579 L 0 .344 .779 r
F P
0 g
s
.54453 .33391 m .54453 .33391 L p .71277 .34579 L 0 .344 .779 r
F P
0 g
s
.69049 .51075 m .71454 .49814 L .71277 .34579 L p 0 .162 .706 r
F P
0 g
s
.52373 .50134 m .69049 .51075 L .71454 .49814 L p 0 .458 1 r
F P
0 g
s
.71454 .49814 m .69049 .51075 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.5442 .19573 m .54453 .33391 L .52353 .34967 L p 0 .134 .679 r
F P
0 g
s
.52353 .34967 m .54453 .33391 L .5442 .19573 L p 0 .134 .679 r
F P
0 g
s
.41552 .27348 m .51009 .34019 L .51003 .22131 L 0 .344 .78 r
F
.30489 .33455 m .4152 .34218 L p .41552 .27348 L F P
0 g
s
.54453 .33391 m .52353 .34967 L .30489 .33455 L p 0 .456 1 r
F P
0 g
s
.30489 .33455 m .32203 .3182 L .54453 .33391 L p 0 .456 1 r
F P
0 g
s
.30399 .41842 m .32119 .40363 L .32203 .3182 L p 0 .084 .626 r
F P
0 g
s
.30489 .33455 m .30399 .41842 L p .32203 .3182 L 0 .084 .626 r
F P
0 g
s
.17654 .42588 m .28743 .43265 L .28839 .35029 L p 0 .344 .781 r
F P
0 g
s
.28839 .35029 m .28743 .43265 L .30399 .41842 L p 0 .084 .626 r
F P
0 g
s
.19111 .41139 m .30399 .41842 L .28743 .43265 L p 0 .458 1 r
F P
0 g
s
.30381 .43528 m .30399 .41842 L .29563 .4256 L p 0 .084 .626 r
F P
0 g
s
.29563 .4256 m .30399 .41842 L .26659 .41609 L p 0 .458 1 r
F P
0 g
s
.30489 .33455 m .30399 .41842 L .19111 .41139 L p 0 .344 .78 r
F P
0 g
s
.19111 .41139 m .30399 .41842 L .30489 .33455 L p 0 .344 .78 r
F P
0 g
s
.32119 .40363 m .30399 .41842 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.28743 .43265 m .17654 .42588 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.28743 .43265 m .25069 .43041 L .25047 .44701 L p 0 .344 .781 r
F P
0 g
s
.25047 .44701 m .28724 .44921 L .28743 .43265 L p 0 .344 .781 r
F P
0 g
s
.28743 .43265 m .28724 .44921 L .29545 .44231 L p 0 .084 .626 r
F P
0 g
s
.29545 .44231 m .29563 .4256 L .28743 .43265 L p 0 .084 .626 r
F P
0 g
s
.28743 .43265 m .29563 .4256 L .25857 .42331 L p 0 .458 1 r
F P
0 g
s
.25857 .42331 m .25069 .43041 L .28743 .43265 L p 0 .458 1 r
F P
0 g
s
.29563 .4256 m .29545 .44231 L .30381 .43528 L p 0 .084 .626 r
F P
0 g
s
.26659 .41609 m .25857 .42331 L .29563 .4256 L p 0 .458 1 r
F P
0 g
s
.30399 .41842 m .30381 .43528 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.26638 .433 m .26659 .41609 L .30399 .41842 L p 0 .344 .78 r
F P
0 g
s
.31251 .41109 m .30399 .41842 L .30381 .43528 L p 0 .084 .626 r
F P
0 g
s
.26659 .41609 m .30399 .41842 L .31251 .41109 L p 0 .458 1 r
F P
0 g
s
.30399 .41842 m .26659 .41609 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.26638 .433 m .30381 .43528 L .30399 .41842 L p 0 .344 .78 r
F P
0 g
s
.30381 .43528 m .31233 .42812 L .31251 .41109 L p 0 .084 .626 r
F P
0 g
s
.31251 .41109 m .27478 .40872 L .26659 .41609 L p 0 .458 1 r
F P
0 g
s
.32119 .40363 m .31251 .41109 L .31233 .42812 L p 0 .084 .626 r
F P
0 g
s
.27478 .40872 m .31251 .41109 L .32119 .40363 L p 0 .458 1 r
F P
0 g
s
.31233 .42812 m .32103 .42081 L .32119 .40363 L p 0 .084 .626 r
F P
0 g
s
.32119 .40363 m .32103 .42081 L .28291 .41844 L p 0 .344 .779 r
F P
0 g
s
.52373 .50134 m .52353 .34967 L .54453 .33391 L p 0 .134 .679 r
F P
0 g
s
.71454 .49814 m .54491 .48837 L .52373 .50134 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .54491 .48837 L .71454 .49814 L p 0 .458 1 r
F P
0 g
s
.52373 .50134 m .54491 .48837 L .54529 .64546 L p 0 .134 .679 r
F P
0 g
s
.54453 .33391 m .54491 .48837 L .52373 .50134 L p 0 .134 .679 r
F P
0 g
s
.53138 .63764 m .53088 .33992 L .5101 .35559 L p .32 0 0 r
F P
0 g
s
.39676 .36441 m .43019 .36666 L p .43124 .35812 L .652 0 0 r
F P
0 g
s
.43019 .36666 m .49009 .37068 L p .43124 .35812 L .652 0 0 r
F P
0 g
s
.49009 .37068 m .53088 .33992 L p .43124 .35812 L .652 0 0 r
F P
0 g
s
.53088 .33992 m .43429 .33315 L .39676 .36441 L p .652 0 0 r
F P
0 g
s
.43429 .33315 m .4332 .63322 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.5442 .19573 m .54453 .33391 L .43431 .32613 L p 0 .344 .779 r
F P
0 g
s
.5101 .35559 m .49009 .37068 L p .51018 .50057 L .32 0 0 r
F P
0 g
s
.51018 .50057 m .53138 .63764 L .5101 .35559 L .32 0 0 r
F
.43429 .33315 m .53088 .33992 L .53138 .63764 L p .847 0 0 r
F P
0 g
s
.53088 .33992 m .46522 .32104 L .43429 .33315 L .652 0 0 r
F
.53088 .33992 m .4332 .63322 L .53138 .63764 L .847 0 0 r
F
.53088 .33992 m .43429 .33315 L .4332 .63322 L F
.53138 .63764 m .4332 .63322 L .43429 .33315 L p F P
0 g
s
.43429 .33315 m .46522 .32104 L .46464 .62529 L .55 0 0 r
F
.43431 .32613 m .32203 .3182 L p .43456 .25617 L 0 .344 .779 r
F P
0 g
s
.43456 .25617 m .5442 .19573 L .43431 .32613 L 0 .344 .779 r
F
.39676 .36441 m .41517 .34908 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.41517 .34908 m .43429 .33315 L p .41449 .49517 L .273 0 0 r
F P
0 g
s
.32203 .3182 m .32203 .3182 L .30489 .33455 L 0 .084 .626 r
F
0 g
.73902 .67663 m
.77201 .66993 L
s
.69211 .66648 m
.77201 .66993 L
s
0 0 0 r
.54441 .28313 m
.68825 .29389 L
s
.6077 .50608 m
.6077 .50608 L
s
.3968 .35764 m
.3968 .35764 L
s
.3968 .35764 m
.3968 .35764 L
s
.60646 .29462 m
.60671 .3383 L
s
.60602 .2206 m
.60646 .29462 L
s
.6127 .43079 m
.68972 .43563 L
s
.4152 .34218 m
.4152 .34218 L
s
.3968 .35764 m
.4152 .34218 L
s
.3968 .35764 m
.3968 .35764 L
s
.32177 .34422 m
.40592 .34998 L
s
.40592 .34998 m
.41347 .3505 L
s
0 g
.39521 .63879 m
.39676 .36441 L
s
0 0 0 r
.60859 .65924 m
.60859 .65924 L
s
.66993 .81026 m .50338 .8051 L .52411 .79801 L p 0 .443 1 r
F P
0 g
s
.52411 .79801 m .69352 .80336 L .66993 .81026 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.58724 .8077 m
.58724 .8077 L
s
.58724 .8077 m
.58724 .8077 L
s
.28996 .21466 m .18043 .20602 L .17801 .34281 L p 0 .344 .781 r
F P
0 g
s
.28996 .21466 m .30637 .19647 L .19489 .1875 L p 0 .451 1 r
F P
0 g
s
.19489 .1875 m .18043 .20602 L .28996 .21466 L p 0 .451 1 r
F P
0 g
s
0 0 0 r
.6077 .50608 m
.6077 .50608 L
s
.60728 .43539 m
.60761 .49198 L
s
.68162 .80684 m
.68162 .80684 L
s
.68162 .80684 m
.68162 .80684 L
s
.71635 .65307 m .71454 .49814 L .69049 .51075 L p 0 .162 .706 r
F P
0 g
s
0 0 0 r
.69128 .5865 m
.69128 .5865 L
s
.53393 .34186 m
.53393 .34186 L
s
.7261 .35359 m .81808 .36003 L .82315 .65078 L p .847 0 0 r
F P
0 g
s
.7261 .35359 m .82315 .65078 L .81808 .36003 L .847 0 0 r
F
.82504 .34666 m .81808 .36003 L .82315 .65078 L .1 0 0 r
F
.72678 .35191 m .81808 .36003 L .82504 .34666 L .652 0 0 r
F
.72678 .35191 m .7261 .35359 L .81808 .36003 L F
.71118 .20946 m .71277 .34579 L .54453 .33391 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.71197 .27737 m
.71197 .27737 L
s
.71197 .27737 m
.71197 .27737 L
s
.54453 .33391 m .5442 .19573 L .71118 .20946 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.54436 .26456 m
.54436 .26456 L
s
.54436 .26456 m
.54436 .26456 L
s
.54436 .26456 m
.54436 .26456 L
s
.62827 .20264 m
.62827 .20264 L
s
.62827 .20264 m
.62827 .20264 L
s
.58724 .8077 m
.58724 .8077 L
s
.69128 .5865 m
.69128 .5865 L
s
.68162 .80684 m
.68162 .80684 L
s
.18043 .20602 m .19489 .1875 L .19253 .32678 L p 0 .052 .589 r
F P
0 g
s
.19253 .32678 m .17801 .34281 L .18043 .20602 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.17922 .27416 m
.17922 .27416 L
s
.17922 .27416 m
.17922 .27416 L
s
.54436 .26456 m
.54436 .26456 L
s
.54436 .26456 m
.54436 .26456 L
s
.54436 .26456 m
.71197 .27737 L
s
.71197 .27737 m
.71197 .27737 L
s
.18759 .19684 m
.18759 .19684 L
s
.18759 .19684 m
.18759 .19684 L
s
.29808 .20595 m
.29809 .20565 L
s
.29809 .20565 m
.29809 .20565 L
s
.60859 .65924 m
.60859 .65924 L
s
.4152 .34218 m
.4152 .34218 L
s
.41584 .20529 m
.41584 .20529 L
s
.4152 .34218 m
.4152 .34218 L
s
.41555 .26664 m
.41584 .20529 L
s
.53393 .34186 m
.53393 .34186 L
s
.53393 .34186 m
.53393 .34186 L
s
.71802 .79619 m .71635 .65307 L .69207 .66287 L p 0 .162 .706 r
F P
0 g
s
.69207 .66287 m .69352 .80336 L .71802 .79619 L p 0 .162 .706 r
F P
0 g
s
0 0 0 r
.53422 .49491 m
.53422 .49491 L
s
.53422 .49491 m
.53422 .49491 L
s
.24897 .33068 m
.24897 .33068 L
s
.24897 .33068 m
.24897 .33068 L
s
.82315 .65078 m .72974 .64657 L .7261 .35359 L p .847 0 0 r
F P
0 g
s
.7261 .35359 m .72974 .64657 L .82315 .65078 L .847 0 0 r
F
.72678 .35191 m .72974 .64657 L .7261 .35359 L .1 0 0 r
F
0 g
.7268 .35363 m
.81808 .36003 L
s
0 0 0 r
.62827 .20264 m
.62827 .20264 L
s
.17922 .27416 m
.17922 .27415 L
s
.28724 .44921 m .25047 .44701 L .25024 .46365 L p 0 .344 .781 r
F P
0 g
s
.25024 .46365 m .28705 .4658 L .28724 .44921 L p 0 .344 .781 r
F P
0 g
s
.28724 .44921 m .28705 .4658 L .29526 .45905 L p 0 .084 .626 r
F P
0 g
s
.29526 .45905 m .29545 .44231 L .28724 .44921 L p 0 .084 .626 r
F P
0 g
s
.71277 .34579 m .71454 .49814 L .54491 .48837 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.71365 .42165 m
.71365 .42165 L
s
.28484 .65595 m .28319 .79829 L .50338 .8051 L p 0 .344 .781 r
F P
0 g
s
.50338 .8051 m .28319 .79829 L .3 .79093 L p 0 .443 1 r
F P
0 g
s
.3 .79093 m .52411 .79801 L .50338 .8051 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.51365 .80159 m
.51365 .80159 L
s
.51365 .80159 m
.51365 .80159 L
s
.28705 .4658 m .25024 .46365 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .29526 .45905 L .28705 .4658 L p 0 .458 1 r
F P
0 g
s
.25024 .46365 m .28705 .4658 L .29526 .45905 L p 0 .458 1 r
F P
0 g
s
.28401 .46959 m .29526 .45905 L .28705 .4658 L p 0 .05 .1 r
F P
0 g
s
.28705 .4658 m .27848 .47413 L .28401 .46959 L p 0 .05 .1 r
F P
0 g
s
.27848 .47413 m .28705 .4658 L .25024 .46365 L p 0 .267 .584 r
F P
0 g
s
.72678 .35191 m .73043 .64548 L .72974 .64657 L .1 0 0 r
F
.72372 .35043 m .73043 .64548 L .72678 .35191 L 1 0 0 r
F
.72372 .35043 m .72678 .35191 L .82504 .34666 L .652 0 0 r
F
0 0 0 r
.54549 .72731 m
.69279 .73285 L
s
.39429 .80173 m
.39429 .80173 L
s
.39429 .80173 m
.39429 .80173 L
s
.25069 .43041 m .21373 .42815 L .21347 .44481 L p 0 .344 .781 r
F P
0 g
s
.21347 .44481 m .25047 .44701 L .25069 .43041 L p 0 .344 .781 r
F P
0 g
s
.25069 .43041 m .25857 .42331 L .22128 .42102 L p 0 .458 1 r
F P
0 g
s
.22128 .42102 m .21373 .42815 L .25069 .43041 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.51365 .80159 m
.51365 .80159 L
s
.51365 .80159 m
.51365 .80159 L
s
.51365 .80159 m
.51365 .80159 L
s
.51364 .79085 m
.51364 .79767 L
s
.25047 .44701 m .21347 .44481 L .21321 .4615 L p 0 .344 .781 r
F P
0 g
s
.21321 .4615 m .25024 .46365 L .25047 .44701 L p 0 .344 .781 r
F P
0 g
s
.72372 .35043 m .72733 .64451 L .73043 .64548 L 1 0 0 r
F
.72372 .35043 m .82504 .34666 L .8015 .33452 L .652 0 0 r
F
.71772 .34955 m .72733 .64451 L .72372 .35043 L .888 0 0 r
F
.71772 .34955 m .72372 .35043 L .8015 .33452 L .652 0 0 r
F
0 g
.72372 .35043 m
.72678 .35191 L
s
.19111 .41139 m .17654 .42588 L .17801 .34281 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.17728 .38425 m
.17728 .38425 L
s
.17728 .38425 m
.17728 .38425 L
s
.25024 .46365 m .21321 .4615 L .22076 .45467 L p 0 .458 1 r
F P
0 g
s
.22076 .45467 m .25813 .45687 L .25024 .46365 L p 0 .458 1 r
F P
0 g
s
.29526 .45905 m .25813 .45687 L .25024 .46365 L p 0 .458 1 r
F P
0 g
s
.25024 .46365 m .2526 .47264 L .27848 .47413 L p 0 .267 .584 r
F P
0 g
s
.21321 .4615 m .25024 .46365 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.2526 .47264 m .25024 .46365 L .21321 .4615 L p 0 .267 .584 r
F P
0 g
s
0 0 0 r
.1852 .33487 m
.1852 .33487 L
s
.1852 .33487 m
.1852 .33487 L
s
.1852 .33487 m
.1852 .33487 L
s
.71772 .34955 m .72124 .64393 L .72733 .64451 L .888 0 0 r
F
.71772 .34955 m .8015 .33452 L .7529 .3271 L .652 0 0 r
F
.71772 .34955 m .7571 .62926 L .72124 .64393 L .393 0 0 r
F
.71772 .34955 m .7529 .3271 L .7571 .62926 L F
.7571 .62926 m .7529 .3271 L .71772 .34955 L p F P
0 g
s
.71772 .34955 m .72124 .64393 L .7571 .62926 L p .393 0 0 r
F P
0 g
s
.54491 .48837 m .71454 .49814 L .71635 .65307 L p 0 .344 .779 r
F P
0 g
s
.72124 .64393 m .71772 .34955 L .54885 .33767 L p .847 0 0 r
F P
0 g
s
0 0 0 r
.63034 .49329 m
.63034 .49329 L
s
.63034 .49329 m
.63034 .49329 L
s
.54493 .49553 m
.55283 .49598 L
s
.60795 .54892 m
.60853 .64827 L
s
.54513 .57919 m
.64463 .58416 L
s
.54885 .33767 m .71772 .34955 L .7529 .3271 L p .652 0 0 r
F P
0 g
s
0 0 0 r
.62827 .20264 m
.6292 .33351 L
s
.43431 .32613 m
.43431 .32613 L
s
.43431 .32613 m
.43431 .32613 L
s
.43431 .32613 m
.43431 .32613 L
s
.4152 .34218 m
.43431 .32613 L
s
.4152 .34218 m
.4152 .34218 L
s
.4152 .34218 m
.4152 .34218 L
s
.31338 .32645 m
.31338 .32645 L
s
.31338 .32645 m
.31338 .32645 L
s
.31338 .32645 m
.31338 .32645 L
s
.32194 .32705 m
.42466 .33423 L
s
.42466 .33423 m
.43235 .33477 L
s
.53088 .34165 m
.53393 .34186 L
s
.53422 .49491 m
.53422 .49491 L
s
.53422 .49491 m
.53422 .49491 L
s
.53393 .34186 m
.53422 .49491 L
s
.53393 .34186 m
.53393 .34186 L
s
.28602 .55479 m .28621 .53804 L .24925 .53611 L p 0 .344 .781 r
F P
0 g
s
.29445 .53196 m .28621 .53804 L .28602 .55479 L p 0 .084 .626 r
F P
0 g
s
.27787 .52433 m .28621 .53804 L .29445 .53196 L p 0 .292 .96 r
F P
0 g
s
.28621 .53804 m .27787 .52433 L .25192 .52294 L p 0 .387 .893 r
F P
0 g
s
.25192 .52294 m .24925 .53611 L .28621 .53804 L p 0 .387 .893 r
F P
0 g
s
.28621 .53804 m .29445 .53196 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.25716 .52999 m .24925 .53611 L .28621 .53804 L p 0 .458 1 r
F P
0 g
s
.28621 .53804 m .24925 .53611 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.25716 .52999 m .29445 .53196 L .28621 .53804 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.60859 .65924 m
.60903 .73406 L
s
.21373 .42815 m .17654 .42588 L .17625 .44259 L p 0 .344 .781 r
F P
0 g
s
.17625 .44259 m .21347 .44481 L .21373 .42815 L p 0 .344 .781 r
F P
0 g
s
.21373 .42815 m .22128 .42102 L .18375 .41871 L p 0 .458 1 r
F P
0 g
s
.18375 .41871 m .17654 .42588 L .21373 .42815 L p 0 .458 1 r
F P
0 g
s
.71802 .79619 m .69352 .80336 L .52411 .79801 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.60903 .73406 m
.6094 .79721 L
s
.60942 .8007 m
.60942 .8007 L
s
.60942 .8007 m
.60942 .8007 L
s
.51365 .80159 m
.68162 .80684 L
s
.58724 .8077 m
.60942 .8007 L
s
.60942 .8007 m
.60942 .8007 L
s
.60942 .8007 m
.60942 .8007 L
s
.27273 .48015 m .28401 .46959 L .27848 .47413 L p 0 .05 .1 r
F P
0 g
s
.27848 .47413 m .26982 .48253 L .27273 .48015 L p 0 .05 .1 r
F P
0 g
s
.27848 .47413 m .2526 .47264 L .25497 .48169 L p 0 .267 .584 r
F P
0 g
s
.25497 .48169 m .26982 .48253 L .27848 .47413 L p 0 .267 .584 r
F P
0 g
s
0 0 0 r
.1852 .33487 m
.1852 .33487 L
s
.1852 .33487 m
.1852 .33487 L
s
.1852 .33487 m
.18759 .19684 L
s
.18759 .19684 m
.18759 .19684 L
s
.28582 .57157 m .28602 .55479 L .24903 .55291 L p 0 .344 .781 r
F P
0 g
s
.29426 .54886 m .28602 .55479 L .28582 .57157 L p 0 .084 .626 r
F P
0 g
s
.24925 .53611 m .24903 .55291 L .28602 .55479 L p 0 .344 .781 r
F P
0 g
s
.28602 .55479 m .29426 .54886 L .29445 .53196 L p 0 .084 .626 r
F P
0 g
s
0 0 0 r
.19182 .36899 m
.19182 .36899 L
s
.19182 .36899 m
.19182 .36899 L
s
.17728 .38425 m
.19182 .36899 L
s
.17728 .38425 m
.17728 .38425 L
s
.19253 .32678 m .19489 .1875 L .30637 .19647 L p 0 .344 .78 r
F P
0 g
s
.19489 .1875 m .30637 .19647 L .3234 .17758 L p 0 .451 1 r
F P
0 g
s
.30637 .19647 m .19489 .1875 L .19253 .32678 L p 0 .344 .78 r
F P
0 g
s
0 0 0 r
.30563 .26525 m
.30563 .26525 L
s
.30563 .26525 m
.30563 .26525 L
s
.21347 .44481 m .17625 .44259 L .17595 .45932 L p 0 .344 .781 r
F P
0 g
s
.17595 .45932 m .21321 .4615 L .21347 .44481 L p 0 .344 .781 r
F P
0 g
s
.28484 .65595 m .28582 .57157 L .17407 .56603 L p 0 .344 .781 r
F P
0 g
s
.30247 .55992 m .28582 .57157 L .28484 .65595 L p 0 .084 .626 r
F P
0 g
s
.24903 .55291 m .2488 .56974 L .28582 .57157 L p 0 .344 .781 r
F P
0 g
s
.28582 .57157 m .29407 .5658 L .29426 .54886 L p 0 .084 .626 r
F P
0 g
s
.28582 .57157 m .2488 .56974 L .25671 .56393 L p 0 .458 1 r
F P
0 g
s
.25671 .56393 m .29407 .5658 L .28582 .57157 L p 0 .458 1 r
F P
0 g
s
.2488 .56974 m .24903 .55291 L .21181 .55101 L p 0 .344 .781 r
F P
0 g
s
.21181 .55101 m .21155 .56789 L .2488 .56974 L p 0 .344 .781 r
F P
0 g
s
.21913 .56205 m .25671 .56393 L .2488 .56974 L p 0 .458 1 r
F P
0 g
s
.21155 .56789 m .21181 .55101 L .17437 .5491 L p 0 .344 .781 r
F P
0 g
s
.30266 .54282 m .29426 .54886 L .29407 .5658 L p 0 .084 .626 r
F P
0 g
s
.29407 .5658 m .30247 .55992 L .30266 .54282 L p 0 .084 .626 r
F P
0 g
s
.29407 .5658 m .25671 .56393 L .26478 .55801 L p 0 .458 1 r
F P
0 g
s
.26478 .55801 m .30247 .55992 L .29407 .5658 L p 0 .458 1 r
F P
0 g
s
.25671 .56393 m .21913 .56205 L .22686 .55609 L p 0 .458 1 r
F P
0 g
s
.22686 .55609 m .26478 .55801 L .25671 .56393 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .22686 .55609 L .21913 .56205 L p 0 .458 1 r
F P
0 g
s
.28582 .57157 m .30247 .55992 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.2488 .56974 m .21155 .56789 L .21913 .56205 L p 0 .458 1 r
F P
0 g
s
.17437 .5491 m .17407 .56603 L .21155 .56789 L p 0 .344 .781 r
F P
0 g
s
.21155 .56789 m .17407 .56603 L .18131 .56016 L p 0 .458 1 r
F P
0 g
s
.18131 .56016 m .21913 .56205 L .21155 .56789 L p 0 .458 1 r
F P
0 g
s
.21913 .56205 m .18131 .56016 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .17407 .56603 L .28582 .57157 L p 0 .458 1 r
F P
0 g
s
.17407 .56603 m .17256 .65116 L .28484 .65595 L p 0 .344 .781 r
F P
0 g
s
.17256 .65116 m .17407 .56603 L .1887 .55416 L p 0 .052 .589 r
F P
0 g
s
.32203 .3182 m .3234 .17758 L .5442 .19573 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.43481 .18674 m
.43481 .18674 L
s
.43481 .18674 m
.43481 .18674 L
s
.21321 .4615 m .17595 .45932 L .18317 .45245 L p 0 .458 1 r
F P
0 g
s
.18317 .45245 m .22076 .45467 L .21321 .4615 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .22076 .45467 L .21321 .4615 L p 0 .458 1 r
F P
0 g
s
.21321 .4615 m .21544 .4705 L .2526 .47264 L p 0 .267 .584 r
F P
0 g
s
.21321 .4615 m .22076 .45467 L .18317 .45245 L p 0 .458 1 r
F P
0 g
s
.18317 .45245 m .17595 .45932 L .21321 .4615 L p 0 .458 1 r
F P
0 g
s
.21544 .4705 m .21321 .4615 L .17595 .45932 L p 0 .267 .584 r
F P
0 g
s
0 0 0 r
.63034 .49329 m
.63034 .49329 L
s
.63034 .49329 m
.63034 .49329 L
s
.63026 .4823 m
.63034 .49329 L
s
.82504 .34666 m .82315 .65078 L .83031 .64205 L .1 0 0 r
F
.73043 .64548 m .82315 .65078 L .72974 .64657 L .538 0 0 r
F
0 g
.72972 .64526 m
.72974 .64657 L
s
.73043 .64548 m .83031 .64205 L .82315 .65078 L .538 0 0 r
F
0 g
.72974 .64657 m
.82315 .65078 L
s
.81808 .36003 m
.823 .6423 L
s
0 0 0 r
.70566 .79981 m
.70566 .79981 L
s
.70566 .79981 m
.70566 .79981 L
s
.61804 .65423 m
.7041 .65801 L
s
.7041 .65801 m
.7041 .65801 L
s
.2526 .47264 m .21544 .4705 L .21768 .47957 L p 0 .267 .584 r
F P
0 g
s
.21768 .47957 m .25497 .48169 L .2526 .47264 L p 0 .267 .584 r
F P
0 g
s
.8015 .33452 m .82504 .34666 L .83031 .64205 L 1 0 0 r
F
.24903 .55291 m .24925 .53611 L .21207 .53416 L p 0 .344 .781 r
F P
0 g
s
.24925 .53611 m .25192 .52294 L .21466 .52095 L p 0 .387 .893 r
F P
0 g
s
.21466 .52095 m .21207 .53416 L .24925 .53611 L p 0 .387 .893 r
F P
0 g
s
.24925 .53611 m .25716 .52999 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.21965 .528 m .21207 .53416 L .24925 .53611 L p 0 .458 1 r
F P
0 g
s
.24925 .53611 m .21207 .53416 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.21965 .528 m .25716 .52999 L .24925 .53611 L p 0 .458 1 r
F P
0 g
s
.17654 .42588 m .18375 .41871 L .18346 .43556 L p 0 .052 .589 r
F P
0 g
s
.18346 .43556 m .17625 .44259 L .17654 .42588 L p 0 .052 .589 r
F P
0 g
s
.29445 .53196 m .28342 .5201 L .27787 .52433 L p 0 .292 .96 r
F P
0 g
s
.26947 .51053 m .27787 .52433 L .28342 .5201 L p 0 .292 .96 r
F P
0 g
s
.25192 .52294 m .27787 .52433 L .26947 .51053 L p 0 .387 .893 r
F P
0 g
s
0 0 0 r
.18375 .41871 m
.18375 .41871 L
s
.21207 .53416 m .21181 .55101 L .24903 .55291 L p 0 .344 .781 r
F P
0 g
s
0 0 0 r
.17332 .6085 m
.17332 .6085 L
s
.17332 .6085 m
.17332 .6085 L
s
.17625 .44259 m .18346 .43556 L .18317 .45245 L p 0 .052 .589 r
F P
0 g
s
.18317 .45245 m .17595 .45932 L .17625 .44259 L p 0 .052 .589 r
F P
0 g
s
.29545 .44231 m .29526 .45905 L .30363 .45218 L p 0 .084 .626 r
F P
0 g
s
.30363 .45218 m .30381 .43528 L .29545 .44231 L p 0 .084 .626 r
F P
0 g
s
0 0 0 r
.39429 .80173 m
.39429 .80173 L
s
.29901 .26475 m
.30563 .26525 L
s
.17595 .45932 m .18929 .46899 L .21544 .4705 L p 0 .267 .584 r
F P
0 g
s
.18929 .46899 m .17595 .45932 L .18317 .45245 L p 0 .29 .961 r
F P
0 g
s
.27273 .48015 m .26982 .48253 L .25497 .48169 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.51365 .80159 m
.51365 .80159 L
s
.51365 .80159 m
.51365 .80159 L
s
.26947 .51053 m .2546 .50972 L .25192 .52294 L p 0 .387 .893 r
F P
0 g
s
.21466 .52095 m .25192 .52294 L .2546 .50972 L p 0 .387 .893 r
F P
0 g
s
.29526 .45905 m .25813 .45687 L .26616 .44995 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .30363 .45218 L .29526 .45905 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .29526 .45905 L .30363 .45218 L p 0 .458 1 r
F P
0 g
s
.29526 .45905 m .28401 .46959 L .29229 .4628 L p 0 .05 .1 r
F P
0 g
s
.29229 .4628 m .30363 .45218 L .29526 .45905 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.25088 .192 m
.25088 .192 L
s
.24897 .33068 m
.24897 .33068 L
s
.24921 .31306 m
.25088 .192 L
s
.54436 .26456 m
.54436 .26456 L
s
.54436 .26456 m
.54436 .26456 L
s
.21768 .47957 m .21544 .4705 L .18929 .46899 L p 0 .267 .584 r
F P
0 g
s
.21181 .55101 m .21207 .53416 L .17466 .5322 L p 0 .344 .781 r
F P
0 g
s
.18843 .51955 m .17466 .5322 L .21207 .53416 L p 0 .387 .893 r
F P
0 g
s
.21207 .53416 m .21466 .52095 L .18843 .51955 L p 0 .387 .893 r
F P
0 g
s
.21207 .53416 m .21965 .528 L .1819 .52601 L p 0 .458 1 r
F P
0 g
s
.1819 .52601 m .17466 .5322 L .21207 .53416 L p 0 .458 1 r
F P
0 g
s
.21965 .528 m .21207 .53416 L .17466 .5322 L p 0 .458 1 r
F P
0 g
s
.28319 .79829 m .3 .79093 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .3 .79093 L p .3 .79093 L 0 .344 .78 r
F P
0 g
s
.28484 .65595 m .30155 .64587 L .30247 .55992 L p 0 .084 .626 r
F P
0 g
s
.28484 .65595 m .17256 .65116 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.18723 .6409 m .30155 .64587 L .28484 .65595 L p 0 .455 1 r
F P
0 g
s
.30155 .64587 m .28484 .65595 L .28319 .79829 L p 0 .084 .626 r
F P
0 g
s
.28319 .79829 m .28484 .65595 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.28319 .79829 m .28484 .65595 L .17256 .65116 L p 0 .344 .781 r
F P
0 g
s
.28484 .65595 m .30155 .64587 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.18723 .6409 m .17256 .65116 L .28484 .65595 L p 0 .455 1 r
F P
0 g
s
.30155 .64587 m .3 .79093 L .28319 .79829 L p 0 .084 .626 r
F P
0 g
s
.3 .79093 m .30155 .64587 L .3 .79093 L 0 .344 .78 r
F
.18723 .6409 m .30155 .64587 L p .3 .79093 L F P
0 g
s
.30155 .64587 m .30155 .64587 L p .3 .79093 L 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .30155 .64587 L p .3 .79093 L 0 .344 .78 r
F P
0 g
s
.25497 .48169 m .25783 .4793 L .27273 .48015 L p 0 .458 1 r
F P
0 g
s
.22042 .47717 m .25783 .4793 L .25497 .48169 L p 0 .458 1 r
F P
0 g
s
.25497 .48169 m .21768 .47957 L .22042 .47717 L p 0 .458 1 r
F P
0 g
s
.28342 .5201 m .27238 .50824 L .26947 .51053 L p 0 .292 .96 r
F P
0 g
s
.26947 .51053 m .27238 .50824 L .25746 .50743 L p 0 .458 1 r
F P
0 g
s
.25746 .50743 m .2546 .50972 L .26947 .51053 L p 0 .458 1 r
F P
0 g
s
.25857 .42331 m .26659 .41609 L .22897 .41375 L p 0 .458 1 r
F P
0 g
s
.22897 .41375 m .22128 .42102 L .25857 .42331 L p 0 .458 1 r
F P
0 g
s
.17466 .5322 m .17437 .5491 L .21181 .55101 L p 0 .344 .781 r
F P
0 g
s
.29229 .4628 m .28401 .46959 L .27273 .48015 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.60942 .8007 m
.60942 .8007 L
s
.18317 .45245 m .19429 .46439 L .18929 .46899 L p 0 .29 .961 r
F P
0 g
s
.18929 .46899 m .2027 .47872 L .21768 .47957 L p 0 .267 .584 r
F P
0 g
s
.18929 .46899 m .19429 .46439 L .20539 .47631 L p 0 .29 .961 r
F P
0 g
s
.20539 .47631 m .2027 .47872 L .18929 .46899 L p 0 .29 .961 r
F P
0 g
s
.2546 .50972 m .21725 .50768 L .21466 .52095 L p 0 .387 .893 r
F P
0 g
s
.21725 .50768 m .2546 .50972 L .25746 .50743 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.18375 .41871 m
.18375 .41871 L
s
.18375 .41871 m
.18375 .41871 L
s
.1852 .33487 m
.1852 .33487 L
s
.1852 .33487 m
.1852 .33487 L
s
.53422 .49491 m
.53422 .49491 L
s
.20225 .50686 m .18843 .51955 L .21466 .52095 L p 0 .387 .893 r
F P
0 g
s
.21466 .52095 m .21725 .50768 L .20225 .50686 L p 0 .387 .893 r
F P
0 g
s
.27273 .48015 m .28091 .47346 L .29229 .4628 L p 0 .05 .1 r
F P
0 g
s
.28091 .47346 m .27273 .48015 L .25783 .4793 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .22076 .45467 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .26616 .44995 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.30363 .45218 m .26616 .44995 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.25813 .45687 m .26616 .44995 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .22076 .45467 L .25813 .45687 L p 0 .458 1 r
F P
0 g
s
.17466 .5322 m .1819 .52601 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.17437 .5491 m .17466 .5322 L .1819 .52601 L p 0 .052 .589 r
F P
0 g
s
.17466 .5322 m .18843 .51955 L .19344 .51526 L p 0 .05 .1 r
F P
0 g
s
.19344 .51526 m .1819 .52601 L .17466 .5322 L p 0 .05 .1 r
F P
0 g
s
.20539 .47631 m .22042 .47717 L .21768 .47957 L p 0 .458 1 r
F P
0 g
s
.21768 .47957 m .2027 .47872 L .20539 .47631 L p 0 .458 1 r
F P
0 g
s
.30284 .52576 m .29445 .53196 L .29426 .54886 L p 0 .084 .626 r
F P
0 g
s
.28342 .5201 m .29445 .53196 L .30284 .52576 L p 0 .292 .96 r
F P
0 g
s
.29445 .53196 m .30284 .52576 L .26522 .52375 L p 0 .458 1 r
F P
0 g
s
.26522 .52375 m .25716 .52999 L .29445 .53196 L p 0 .458 1 r
F P
0 g
s
.29445 .53196 m .25716 .52999 L .26522 .52375 L p 0 .458 1 r
F P
0 g
s
.26522 .52375 m .30284 .52576 L .29445 .53196 L p 0 .458 1 r
F P
0 g
s
.22128 .42102 m .22897 .41375 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.19111 .41139 m .18375 .41871 L .22128 .42102 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.18375 .41871 m
.2665 .4238 L
s
.18375 .41871 m
.1852 .33487 L
s
.25783 .4793 m .26587 .47259 L .28091 .47346 L p 0 .458 1 r
F P
0 g
s
.25783 .4793 m .22042 .47717 L .22813 .47042 L p 0 .458 1 r
F P
0 g
s
.22813 .47042 m .26587 .47259 L .25783 .4793 L p 0 .458 1 r
F P
0 g
s
.30284 .52576 m .29171 .51379 L .28342 .5201 L p 0 .292 .96 r
F P
0 g
s
.28057 .50181 m .27238 .50824 L .28342 .5201 L p 0 .292 .96 r
F P
0 g
s
.28342 .5201 m .29171 .51379 L .28057 .50181 L p 0 .292 .96 r
F P
0 g
s
0 0 0 r
.70566 .79981 m
.70566 .79981 L
s
.17407 .56603 m .17437 .5491 L .18161 .54307 L p 0 .052 .589 r
F P
0 g
s
.1819 .52601 m .18161 .54307 L .17437 .5491 L p 0 .052 .589 r
F P
0 g
s
.27238 .50824 m .28057 .50181 L .26551 .50098 L p 0 .458 1 r
F P
0 g
s
.26551 .50098 m .25746 .50743 L .27238 .50824 L p 0 .458 1 r
F P
0 g
s
.3234 .17758 m .20991 .16825 L .19489 .1875 L p 0 .451 1 r
F P
0 g
s
.19253 .32678 m .19489 .1875 L .20991 .16825 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.20014 .25735 m
.29901 .26475 L
s
.19371 .25687 m
.19371 .25687 L
s
.19371 .25687 m
.19371 .25687 L
s
.17922 .27415 m
.19371 .25687 L
s
.19371 .25687 m
.19371 .25687 L
s
.19371 .25687 m
.19371 .25687 L
s
.29426 .54886 m .30266 .54282 L .30284 .52576 L p 0 .084 .626 r
F P
0 g
s
0 0 0 r
.31373 .29187 m
.3148 .18712 L
s
.31338 .32645 m
.31338 .32645 L
s
.31338 .32645 m
.31338 .32645 L
s
.31338 .32645 m
.31338 .32645 L
s
.31347 .3176 m
.31373 .29187 L
s
.3148 .18712 m
.3148 .18712 L
s
.19344 .51526 m .18843 .51955 L .20225 .50686 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.63034 .49329 m
.63034 .49329 L
s
.19182 .36899 m
.19182 .36899 L
s
.19182 .36899 m
.19182 .36899 L
s
.19796 .36939 m
.30444 .37639 L
s
.18161 .54307 m .18131 .56016 L .17407 .56603 L p 0 .052 .589 r
F P
0 g
s
.25746 .50743 m .21999 .50538 L .21725 .50768 L p 0 .458 1 r
F P
0 g
s
.20225 .50686 m .21725 .50768 L .21999 .50538 L p 0 .458 1 r
F P
0 g
s
.53088 .33992 m .53541 .63668 L .53484 .33844 L .564 0 0 r
F
0 0 0 r
.53101 .42016 m
.53209 .41942 L
s
.53088 .33992 m .53138 .63764 L .53541 .63668 L .564 0 0 r
F
0 0 0 r
.53448 .6369 m
.5345 .64498 L
s
.53088 .33992 m .53484 .33844 L .46522 .32104 L .652 0 0 r
F
0 g
.53088 .33992 m
.53113 .48757 L
s
0 0 0 r
.43431 .32613 m
.43431 .32613 L
s
.43431 .32613 m
.43481 .18674 L
s
.43481 .18674 m
.43481 .18674 L
s
.25746 .50743 m .26551 .50098 L .22771 .49889 L p 0 .458 1 r
F P
0 g
s
.22771 .49889 m .21999 .50538 L .25746 .50743 L p 0 .458 1 r
F P
0 g
s
.22076 .45467 m .18317 .45245 L .19053 .44545 L p 0 .458 1 r
F P
0 g
s
.19053 .44545 m .22846 .44771 L .22076 .45467 L p 0 .458 1 r
F P
0 g
s
.22076 .45467 m .22846 .44771 L .19053 .44545 L p 0 .458 1 r
F P
0 g
s
.19053 .44545 m .18317 .45245 L .22076 .45467 L p 0 .458 1 r
F P
0 g
s
.54529 .64546 m .71635 .65307 L .71802 .79619 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.71718 .72435 m
.71718 .72435 L
s
.71718 .72435 m
.71718 .72435 L
s
.71635 .65307 m .54529 .64546 L .54491 .48837 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.63144 .64929 m
.63144 .64929 L
s
.63144 .64929 m
.63144 .64929 L
s
.63144 .64929 m
.63144 .64929 L
s
.54531 .65103 m
.55201 .65133 L
s
.63144 .64929 m
.63144 .64929 L
s
.63144 .64929 m
.63144 .64929 L
s
.21999 .50538 m .20494 .50455 L .20225 .50686 L p 0 .458 1 r
F P
0 g
s
.20225 .50686 m .20494 .50455 L .19344 .51526 L p 0 .05 .1 r
F P
0 g
s
.72733 .64451 m .83031 .64205 L .73043 .64548 L .538 0 0 r
F
0 g
.72974 .64657 m
.73043 .64548 L
s
.25716 .52999 m .26522 .52375 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .21965 .528 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.25716 .52999 m .21965 .528 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .26522 .52375 L .25716 .52999 L p 0 .458 1 r
F P
0 g
s
.53484 .33844 m .5421 .63614 L .54142 .33762 L .729 0 0 r
F
0 0 0 r
.53499 .41745 m
.53673 .41626 L
s
.53484 .33844 m .53541 .63668 L .5421 .63614 L .729 0 0 r
F
.53484 .33844 m .51879 .31414 L .46522 .32104 L .652 0 0 r
F
.53484 .33844 m .54142 .33762 L .51879 .31414 L F
0 g
.53088 .33992 m
.53484 .33844 L
s
.18375 .41871 m .19111 .41139 L .19082 .4284 L p 0 .052 .589 r
F P
0 g
s
.19082 .4284 m .18346 .43556 L .18375 .41871 L p 0 .052 .589 r
F P
0 g
s
.21296 .46955 m .22813 .47042 L .22042 .47717 L p 0 .458 1 r
F P
0 g
s
.22042 .47717 m .20539 .47631 L .21296 .46955 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.17332 .6085 m
.17332 .6085 L
s
.2479 .408 m
.24897 .33068 L
s
.54885 .33767 m .54965 .63617 L .72124 .64393 L p .847 0 0 r
F P
0 g
s
.58124 .62106 m .54965 .63617 L .54885 .33767 L p .326 0 0 r
F P
0 g
s
.7529 .3271 m .57989 .31457 L .54885 .33767 L p .652 0 0 r
F P
0 g
s
.54885 .33767 m .57989 .31457 L .58124 .62106 L p .326 0 0 r
F P
0 g
s
.54885 .33767 m .58124 .62106 L .57989 .31457 L .326 0 0 r
F
.54885 .33767 m .54965 .63617 L .58124 .62106 L F
.54142 .33762 m .54965 .63617 L .54885 .33767 L .811 0 0 r
F
0 0 0 r
.54159 .41295 m
.54346 .41167 L
s
.54142 .33762 m .54885 .33767 L .57989 .31457 L .652 0 0 r
F
.54142 .33762 m .5421 .63614 L .54965 .63617 L .811 0 0 r
F
0 g
.54885 .33767 m
.54925 .48571 L
s
.54142 .33762 m .57989 .31457 L .51879 .31414 L .652 0 0 r
F
0 g
.53484 .33844 m
.54142 .33762 L
s
.54142 .33762 m
.54885 .33767 L
s
.46519 .33532 m
.53088 .33992 L
s
.18346 .43556 m .19082 .4284 L .19053 .44545 L p 0 .052 .589 r
F P
0 g
s
.19053 .44545 m .18317 .45245 L .18346 .43556 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.19371 .25687 m
.19371 .25687 L
s
.17256 .65116 m .17003 .79479 L .28319 .79829 L p 0 .344 .781 r
F P
0 g
s
.28319 .79829 m .17003 .79479 L .18476 .78729 L p 0 .443 1 r
F P
0 g
s
.18476 .78729 m .3 .79093 L .28319 .79829 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.22687 .79655 m
.22687 .79655 L
s
.22687 .79655 m
.22687 .79655 L
s
.29151 .79465 m
.29151 .79465 L
s
.29151 .79465 m
.29151 .79465 L
s
.20539 .47631 m .19429 .46439 L .20175 .4575 L p 0 .29 .961 r
F P
0 g
s
.20175 .4575 m .21296 .46955 L .20539 .47631 L p 0 .29 .961 r
F P
0 g
s
.30381 .43528 m .30363 .45218 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .26638 .433 L .30381 .43528 L p 0 .344 .78 r
F P
0 g
s
.31233 .42812 m .30381 .43528 L .30363 .45218 L p 0 .084 .626 r
F P
0 g
s
.30381 .43528 m .26638 .433 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .30363 .45218 L .30381 .43528 L p 0 .344 .78 r
F P
0 g
s
.72733 .64451 m .80646 .63411 L .83031 .64205 L .538 0 0 r
F
.72124 .64393 m .80646 .63411 L .72733 .64451 L F
0 g
.72733 .64451 m
.73043 .64548 L
s
.19429 .46439 m .18317 .45245 L .19053 .44545 L p 0 .29 .961 r
F P
0 g
s
.19053 .44545 m .20175 .4575 L .19429 .46439 L p 0 .29 .961 r
F P
0 g
s
.20494 .50455 m .21999 .50538 L .22771 .49889 L p 0 .458 1 r
F P
0 g
s
.52411 .79801 m .54565 .79063 L .71802 .79619 L p 0 .443 1 r
F P
0 g
s
.52411 .79801 m .3 .79093 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .3 .79093 L .52411 .79801 L p 0 .344 .78 r
F P
0 g
s
.54565 .79063 m .52411 .79801 L .3 .79093 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.4131 .7945 m
.4131 .7945 L
s
.4131 .7945 m
.4131 .7945 L
s
.39429 .80173 m
.4131 .7945 L
s
.29151 .79465 m
.51365 .80159 L
s
.53477 .79435 m
.53477 .79435 L
s
.53477 .79435 m
.53477 .79435 L
s
.26602 .46126 m .26616 .44995 L .30363 .45218 L p 0 .344 .78 r
F P
0 g
s
.30363 .45218 m .29229 .4628 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.30363 .45218 m .31216 .44517 L .31233 .42812 L p 0 .084 .626 r
F P
0 g
s
.31216 .44517 m .30363 .45218 L .26616 .44995 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .30363 .45218 L .31216 .44517 L p 0 .458 1 r
F P
0 g
s
.29229 .4628 m .30363 .45218 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.30363 .45218 m .29229 .4628 L .30072 .45589 L p 0 .05 .1 r
F P
0 g
s
.30072 .45589 m .31216 .44517 L .30363 .45218 L p 0 .05 .1 r
F P
0 g
s
.72124 .64393 m .7571 .62926 L .80646 .63411 L .538 0 0 r
F
.7571 .62926 m .72124 .64393 L .54965 .63617 L p F P
0 g
s
.72124 .64393 m
.72733 .64451 L
s
.71772 .34955 m
.72107 .63046 L
s
0 0 0 r
.63139 .64214 m
.63144 .64929 L
s
.63138 .63987 m
.63139 .64214 L
s
.1887 .55416 m .18723 .6409 L .17256 .65116 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.18131 .56016 m
.18131 .56016 L
s
.17003 .79479 m .17256 .65116 L .18723 .6409 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.1713 .7227 m
.1713 .7227 L
s
.1713 .7227 m
.1713 .7227 L
s
.21965 .528 m .22737 .52173 L .18928 .51969 L p 0 .458 1 r
F P
0 g
s
.18928 .51969 m .1819 .52601 L .21965 .528 L p 0 .458 1 r
F P
0 g
s
.22771 .49889 m .21252 .49805 L .20494 .50455 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .21965 .528 L .1819 .52601 L p 0 .458 1 r
F P
0 g
s
.19344 .51526 m .20494 .50455 L .21252 .49805 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.71718 .72435 m
.71718 .72435 L
s
.29151 .79465 m
.29151 .79465 L
s
.29151 .79465 m
.29151 .79465 L
s
.29151 .79465 m
.29151 .79465 L
s
.29156 .79066 m
.29168 .77986 L
s
.4131 .7945 m
.4131 .7945 L
s
.26659 .41609 m .26638 .433 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
.22872 .43071 m .22897 .41375 L .26659 .41609 L p 0 .344 .78 r
F P
0 g
s
.22897 .41375 m .26659 .41609 L .27478 .40872 L p 0 .458 1 r
F P
0 g
s
.26659 .41609 m .22897 .41375 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
0 0 0 r
.24781 .41492 m
.24781 .41492 L
s
.24781 .41492 m
.24781 .41492 L
s
.24781 .41492 m
.24781 .41492 L
s
.22872 .43071 m .26638 .433 L .26659 .41609 L p 0 .344 .78 r
F P
0 g
s
0 0 0 r
.4131 .7945 m
.4131 .7945 L
s
.41311 .79079 m
.41354 .70018 L
s
.26587 .47259 m .26602 .46126 L .29229 .4628 L p 0 .344 .78 r
F P
0 g
s
.29229 .4628 m .28091 .47346 L .26587 .47259 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .26602 .46126 L .29229 .4628 L p 0 .344 .78 r
F P
0 g
s
.28091 .47346 m .29229 .4628 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.30072 .45589 m .29229 .4628 L .28091 .47346 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.53477 .79435 m
.53477 .79435 L
s
.53477 .79435 m
.53477 .79435 L
s
.53477 .79435 m
.53477 .79435 L
s
.53475 .78317 m
.53477 .79064 L
s
.1819 .52601 m .19344 .51526 L .20092 .50885 L p 0 .05 .1 r
F P
0 g
s
.21252 .49805 m .20092 .50885 L .19344 .51526 L p 0 .05 .1 r
F P
0 g
s
.26638 .433 m .26616 .44995 L .22846 .44771 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .22872 .43071 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.26638 .433 m .22872 .43071 L .22846 .44771 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .26616 .44995 L .26638 .433 L p 0 .344 .78 r
F P
0 g
s
.8015 .33452 m .83031 .64205 L .80646 .63411 L 1 0 0 r
F
0 g
.82315 .65078 m
.83031 .64205 L
s
.7529 .3271 m .8015 .33452 L .80646 .63411 L .891 0 0 r
F
0 g
.8015 .33452 m
.82504 .34666 L
s
.20991 .16825 m .20763 .31012 L .19253 .32678 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.20232 .17797 m
.20232 .17797 L
s
.20232 .17797 m
.20232 .17797 L
s
.26616 .44995 m .26602 .46126 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.2283 .45906 m .22846 .44771 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
.26616 .44995 m .27435 .4429 L .31216 .44517 L p 0 .458 1 r
F P
0 g
s
.27435 .4429 m .26616 .44995 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.31216 .44517 m .27435 .4429 L .26616 .44995 L p 0 .458 1 r
F P
0 g
s
.26602 .46126 m .26587 .47259 L .28091 .47346 L p 0 .344 .78 r
F P
0 g
s
.28091 .47346 m .28924 .46664 L .30072 .45589 L p 0 .05 .1 r
F P
0 g
s
.28924 .46664 m .28091 .47346 L .26587 .47259 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .26616 .44995 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.26616 .44995 m .22846 .44771 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.2283 .45906 m .26602 .46126 L .26616 .44995 L p 0 .344 .78 r
F P
0 g
s
0 0 0 r
.31337 .32645 m
.31337 .32645 L
s
.31338 .32645 m
.31338 .32645 L
s
.31338 .32645 m
.31338 .32645 L
s
.22687 .79655 m
.22687 .79655 L
s
.1819 .52601 m .18928 .51969 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.18161 .54307 m .1819 .52601 L .18928 .51969 L p 0 .052 .589 r
F P
0 g
s
.20092 .50885 m .18928 .51969 L .1819 .52601 L p 0 .05 .1 r
F P
0 g
s
.26602 .46126 m .26587 .47259 L .22813 .47042 L p 0 .344 .78 r
F P
0 g
s
.22813 .47042 m .2283 .45906 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.26602 .46126 m .2283 .45906 L .22813 .47042 L p 0 .344 .78 r
F P
0 g
s
.22813 .47042 m .26587 .47259 L .26602 .46126 L p 0 .344 .78 r
F P
0 g
s
.43429 .33315 m .46464 .62529 L .4332 .63322 L .55 0 0 r
F
0 g
.43429 .33315 m
.43429 .33315 L
s
.43429 .33315 m
.43429 .33315 L
s
.26522 .52375 m .30284 .52576 L .30266 .54282 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .30284 .52576 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.31122 .53666 m .3114 .51944 L .30284 .52576 L p 0 .084 .626 r
F P
0 g
s
.30284 .52576 m .30266 .54282 L .31122 .53666 L p 0 .084 .626 r
F P
0 g
s
.30266 .54282 m .30284 .52576 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.26537 .51236 m .26522 .52375 L .30284 .52576 L p 0 .344 .78 r
F P
0 g
s
.30284 .52576 m .29171 .51379 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .30284 .52576 L .3114 .51944 L p 0 .292 .96 r
F P
0 g
s
.26522 .52375 m .30284 .52576 L .3114 .51944 L p 0 .458 1 r
F P
0 g
s
.26522 .52375 m .26537 .51236 L .29171 .51379 L p 0 .344 .78 r
F P
0 g
s
.30284 .52576 m .26522 .52375 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.27344 .51739 m .3114 .51944 L .30284 .52576 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.63144 .64929 m
.63144 .64929 L
s
.63144 .64929 m
.63144 .64929 L
s
.1713 .7227 m
.1713 .7227 L
s
.22897 .41375 m .22872 .43071 L .19082 .4284 L p 0 .344 .78 r
F P
0 g
s
.19082 .4284 m .19111 .41139 L .22897 .41375 L p 0 .344 .78 r
F P
0 g
s
.19111 .41139 m .20624 .39632 L .32119 .40363 L p 0 .458 1 r
F P
0 g
s
.27478 .40872 m .23681 .40633 L .22897 .41375 L p 0 .458 1 r
F P
0 g
s
.19111 .41139 m .22897 .41375 L .23681 .40633 L p 0 .458 1 r
F P
0 g
s
.22897 .41375 m .19111 .41139 L .19082 .4284 L p 0 .344 .78 r
F P
0 g
s
.19082 .4284 m .22872 .43071 L .22897 .41375 L p 0 .344 .78 r
F P
0 g
s
.26587 .47259 m .27407 .46575 L .28924 .46664 L p 0 .458 1 r
F P
0 g
s
.27407 .46575 m .26587 .47259 L .22813 .47042 L p 0 .458 1 r
F P
0 g
s
.28057 .50181 m .29171 .51379 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.3114 .51944 m .30016 .50735 L .29171 .51379 L p 0 .292 .96 r
F P
0 g
s
.26551 .50098 m .26537 .51236 L .29171 .51379 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .28057 .50181 L .26551 .50098 L p 0 .344 .78 r
F P
0 g
s
.29171 .51379 m .30016 .50735 L .28891 .49525 L p 0 .292 .96 r
F P
0 g
s
.28891 .49525 m .28057 .50181 L .29171 .51379 L p 0 .292 .96 r
F P
0 g
s
.71802 .79619 m .54565 .79063 L .54529 .64546 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.63144 .64929 m
.63246 .79343 L
s
.63246 .79343 m
.63246 .79343 L
s
.54547 .71776 m
.71718 .72435 L
s
.54547 .71776 m
.54547 .71776 L
s
.54547 .71776 m
.54547 .71776 L
s
.53477 .79435 m
.70566 .79981 L
s
.63246 .79343 m
.63246 .79343 L
s
.60942 .8007 m
.63246 .79343 L
s
.54547 .71776 m
.54547 .71776 L
s
.54547 .71776 m
.54547 .71776 L
s
.54547 .71776 m
.54547 .71776 L
s
.18131 .56016 m .18161 .54307 L .18899 .53691 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.18131 .56016 m
.18131 .56016 L
s
.18928 .51969 m .18899 .53691 L .18161 .54307 L p 0 .052 .589 r
F P
0 g
s
.26537 .51236 m .26551 .50098 L .28057 .50181 L p 0 .344 .78 r
F P
0 g
s
.27372 .4944 m .26551 .50098 L .28057 .50181 L p 0 .458 1 r
F P
0 g
s
.28057 .50181 m .28891 .49525 L .27372 .4944 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.20232 .17797 m
.20232 .17797 L
s
.265 .54086 m .30266 .54282 L .30247 .55992 L p 0 .344 .78 r
F P
0 g
s
.30266 .54282 m .265 .54086 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.31105 .55392 m .31122 .53666 L .30266 .54282 L p 0 .084 .626 r
F P
0 g
s
.30266 .54282 m .30247 .55992 L .31105 .55392 L p 0 .084 .626 r
F P
0 g
s
.30247 .55992 m .30266 .54282 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.26522 .52375 m .265 .54086 L .30266 .54282 L p 0 .344 .78 r
F P
0 g
s
0 0 0 r
.19182 .36899 m
.19182 .36899 L
s
.3234 .17758 m .32203 .3182 L .20763 .31012 L p 0 .344 .779 r
F P
0 g
s
.20763 .31012 m .20991 .16825 L .3234 .17758 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.32272 .24762 m
.32272 .24762 L
s
.32272 .24762 m
.32272 .24762 L
s
.32272 .24762 m
.32272 .24762 L
s
.32272 .24762 m
.32272 .24762 L
s
.32272 .24762 m
.54436 .26456 L
s
.19371 .25687 m
.20877 .23891 L
s
.20877 .23891 m
.20877 .23891 L
s
.26692 .17294 m
.26692 .17294 L
s
.26692 .17294 m
.26692 .17294 L
s
.22872 .43071 m .22846 .44771 L .19053 .44545 L p 0 .344 .78 r
F P
0 g
s
.19053 .44545 m .19082 .4284 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
.22872 .43071 m .19082 .4284 L .19053 .44545 L p 0 .344 .78 r
F P
0 g
s
.19053 .44545 m .22846 .44771 L .22872 .43071 L p 0 .344 .78 r
F P
0 g
s
0 0 0 r
.18131 .56016 m
.18131 .56016 L
s
.18131 .56016 m
.18131 .56016 L
s
.18899 .53691 m .1887 .55416 L .18131 .56016 L p 0 .052 .589 r
F P
0 g
s
.30247 .55992 m .26478 .55801 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .26551 .50098 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.265 .54086 m .26478 .55801 L .30247 .55992 L p 0 .344 .78 r
F P
0 g
s
.31105 .55392 m .30247 .55992 L .26478 .55801 L p 0 .458 1 r
F P
0 g
s
.26537 .51236 m .26551 .50098 L .22771 .49889 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .26551 .50098 L .27372 .4944 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .30247 .55992 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.31893 .6354 m .31978 .5478 L .30247 .55992 L p 0 .084 .626 r
F P
0 g
s
.31748 .78327 m .31893 .6354 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.31893 .6354 m .31748 .78327 L p .31748 .78327 L 0 .344 .779 r
F P
0 g
s
.30247 .55992 m .30155 .64587 L .31893 .6354 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .30247 .55992 L .1887 .55416 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .18723 .6409 L .1887 .55416 L p 0 .344 .78 r
F P
0 g
s
.30155 .64587 m .3 .79093 L .31748 .78327 L p 0 .084 .626 r
F P
0 g
s
.31748 .78327 m .3 .79093 L .30155 .64587 L p 0 .084 .626 r
F P
0 g
s
.30155 .64587 m .31893 .6354 L .31748 .78327 L p 0 .084 .626 r
F P
0 g
s
.1887 .55416 m .18723 .6409 L .30155 .64587 L p 0 .344 .78 r
F P
0 g
s
.31893 .6354 m .30155 .64587 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.3 .79093 m .30155 .64587 L .18723 .6409 L p 0 .344 .78 r
F P
0 g
s
.18723 .6409 m .30155 .64587 L .31893 .6354 L p 0 .455 1 r
F P
0 g
s
.18723 .6409 m .20249 .63023 L .31893 .6354 L p 0 .455 1 r
F P
0 g
s
.31893 .6354 m .20249 .63023 L .18723 .6409 L p 0 .455 1 r
F P
0 g
s
.20249 .63023 m .31893 .6354 L p .31748 .78327 L 0 .344 .779 r
F P
0 g
s
.31893 .6354 m .31893 .6354 L p .31748 .78327 L 0 .344 .779 r
F P
0 g
s
.22711 .53889 m .265 .54086 L .26478 .55801 L p 0 .344 .78 r
F P
0 g
s
.26478 .55801 m .265 .54086 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.26478 .55801 m .22686 .55609 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.26478 .55801 m .27301 .55197 L .31105 .55392 L p 0 .458 1 r
F P
0 g
s
.22711 .53889 m .22686 .55609 L .26478 .55801 L p 0 .344 .78 r
F P
0 g
s
.27301 .55197 m .26478 .55801 L .22686 .55609 L p 0 .458 1 r
F P
0 g
s
.18899 .53691 m .22711 .53889 L .22686 .55609 L p 0 .344 .78 r
F P
0 g
s
.22686 .55609 m .22711 .53889 L .18899 .53691 L p 0 .344 .78 r
F P
0 g
s
.22686 .55609 m .1887 .55416 L .18899 .53691 L p 0 .344 .78 r
F P
0 g
s
.22686 .55609 m .23474 .55002 L .27301 .55197 L p 0 .458 1 r
F P
0 g
s
.18899 .53691 m .1887 .55416 L .22686 .55609 L p 0 .344 .78 r
F P
0 g
s
.23474 .55002 m .22686 .55609 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.31122 .53666 m .31105 .55392 L .31978 .5478 L p 0 .084 .626 r
F P
0 g
s
.31978 .5478 m .31105 .55392 L .27301 .55197 L p 0 .458 1 r
F P
0 g
s
.27301 .55197 m .2814 .54582 L .31978 .5478 L p 0 .458 1 r
F P
0 g
s
.2814 .54582 m .27301 .55197 L .23474 .55002 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .30247 .55992 L .31978 .5478 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .2283 .45906 L .20175 .4575 L p 0 .344 .78 r
F P
0 g
s
.20175 .4575 m .19053 .44545 L .22846 .44771 L p 0 .344 .78 r
F P
0 g
s
.22846 .44771 m .23631 .44061 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .22846 .44771 L .19053 .44545 L p 0 .458 1 r
F P
0 g
s
.27435 .4429 m .23631 .44061 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.19803 .43831 m .19053 .44545 L .22846 .44771 L p 0 .458 1 r
F P
0 g
s
.22846 .44771 m .23631 .44061 L .19803 .43831 L p 0 .458 1 r
F P
0 g
s
.2283 .45906 m .22846 .44771 L .19053 .44545 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .26537 .51236 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.26537 .51236 m .22754 .5103 L .22771 .49889 L p 0 .344 .78 r
F P
0 g
s
.26522 .52375 m .26537 .51236 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .22754 .5103 L .26537 .51236 L p 0 .344 .78 r
F P
0 g
s
.20175 .4575 m .2283 .45906 L .22813 .47042 L p 0 .344 .78 r
F P
0 g
s
.19053 .44545 m .20175 .4575 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.21296 .46955 m .22813 .47042 L .2283 .45906 L p 0 .344 .78 r
F P
0 g
s
.2283 .45906 m .20175 .4575 L .21296 .46955 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .26522 .52375 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.26522 .52375 m .22737 .52173 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.3114 .51944 m .27344 .51739 L .26522 .52375 L p 0 .458 1 r
F P
0 g
s
.265 .54086 m .26522 .52375 L .22737 .52173 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .22737 .52173 L .26522 .52375 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .26522 .52375 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.27344 .51739 m .26522 .52375 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.20763 .31012 m .20624 .39632 L .19111 .41139 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.20001 .31853 m
.20232 .17797 L
s
.20001 .31853 m
.20001 .31853 L
s
.20001 .31853 m
.20001 .31853 L
s
.20749 .31906 m
.31338 .32645 L
s
.20001 .31853 m
.20001 .31853 L
s
.20001 .31853 m
.20001 .31853 L
s
.20001 .31853 m
.20001 .31853 L
s
.22813 .47042 m .21296 .46955 L .20175 .4575 L p 0 .344 .78 r
F P
0 g
s
.23681 .40633 m .1986 .40393 L .19111 .41139 L p 0 .458 1 r
F P
0 g
s
.19082 .4284 m .19111 .41139 L .1986 .40393 L p 0 .052 .589 r
F P
0 g
s
.22813 .47042 m .23598 .46354 L .27407 .46575 L p 0 .458 1 r
F P
0 g
s
.22068 .46265 m .23598 .46354 L .22813 .47042 L p 0 .458 1 r
F P
0 g
s
.22813 .47042 m .21296 .46955 L .22068 .46265 L p 0 .458 1 r
F P
0 g
s
.265 .54086 m .22711 .53889 L .22737 .52173 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .22711 .53889 L .265 .54086 L p 0 .344 .78 r
F P
0 g
s
.18723 .6409 m .18476 .78729 L .17003 .79479 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.17983 .64608 m
.18131 .56016 L
s
.17983 .64608 m
.17983 .64608 L
s
.17983 .64608 m
.17983 .64608 L
s
.18714 .64639 m
.1915 .64658 L
s
.17983 .64608 m
.17983 .64608 L
s
.17983 .64608 m
.17983 .64608 L
s
.17983 .64608 m
.17983 .64608 L
s
.1986 .40393 m .19832 .4211 L .19082 .4284 L p 0 .052 .589 r
F P
0 g
s
.19053 .44545 m .19082 .4284 L .19832 .4211 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.17732 .79108 m
.17732 .79108 L
s
.17732 .79108 m
.29151 .79465 L
s
.29151 .79465 m
.29151 .79465 L
s
.29151 .79465 m
.29151 .79465 L
s
.21296 .46955 m .20175 .4575 L .20936 .45048 L p 0 .29 .961 r
F P
0 g
s
.20936 .45048 m .22068 .46265 L .21296 .46955 L p 0 .29 .961 r
F P
0 g
s
.32103 .42081 m .31233 .42812 L .31216 .44517 L p 0 .084 .626 r
F P
0 g
s
0 0 0 r
.4131 .7945 m
.4131 .7945 L
s
.19053 .44545 m .19803 .43831 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.20175 .4575 m .19053 .44545 L .19803 .43831 L p 0 .29 .961 r
F P
0 g
s
.19803 .43831 m .20936 .45048 L .20175 .4575 L p 0 .29 .961 r
F P
0 g
s
.21252 .49805 m .22771 .49889 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.27372 .4944 m .23557 .49227 L .22771 .49889 L p 0 .458 1 r
F P
0 g
s
.20092 .50885 m .22754 .5103 L .22771 .49889 L p 0 .344 .78 r
F P
0 g
s
.22771 .49889 m .21252 .49805 L .20092 .50885 L p 0 .344 .78 r
F P
0 g
s
.21252 .49805 m .22771 .49889 L .23557 .49227 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.20877 .23891 m
.20877 .23891 L
s
.20877 .23891 m
.32272 .24762 L
s
.32272 .24762 m
.32272 .24762 L
s
.32272 .24762 m
.32272 .24762 L
s
.19832 .4211 m .19803 .43831 L .19053 .44545 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.53477 .79435 m
.53477 .79435 L
s
.53477 .79435 m
.53477 .79435 L
s
.18928 .51969 m .20092 .50885 L .22754 .5103 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .22737 .52173 L .18928 .51969 L p 0 .344 .78 r
F P
0 g
s
.22754 .5103 m .20092 .50885 L .21252 .49805 L p 0 .344 .78 r
F P
0 g
s
.22737 .52173 m .22754 .5103 L .20092 .50885 L p 0 .344 .78 r
F P
0 g
s
.31216 .44517 m .32086 .43802 L .32103 .42081 L p 0 .084 .626 r
F P
0 g
s
.32086 .43802 m .31216 .44517 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.27435 .4429 m .31216 .44517 L .32086 .43802 L p 0 .458 1 r
F P
0 g
s
.30655 .45111 m .32086 .43802 L .31216 .44517 L p 0 .05 .1 r
F P
0 g
s
.31216 .44517 m .30072 .45589 L .30655 .45111 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.26692 .17294 m
.26692 .17294 L
s
.17732 .79108 m
.17732 .79108 L
s
.17732 .79108 m
.17983 .64608 L
s
.17983 .64608 m
.17983 .64608 L
s
.17983 .64608 m
.17983 .64608 L
s
.18928 .51969 m .22737 .52173 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.27344 .51739 m .23524 .51533 L .22737 .52173 L p 0 .458 1 r
F P
0 g
s
.22711 .53889 m .22737 .52173 L .18928 .51969 L p 0 .344 .78 r
F P
0 g
s
.20092 .50885 m .18928 .51969 L .22737 .52173 L p 0 .344 .78 r
F P
0 g
s
.18928 .51969 m .22737 .52173 L .23524 .51533 L p 0 .458 1 r
F P
0 g
s
.22737 .52173 m .23524 .51533 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.23524 .51533 m .22737 .52173 L .18928 .51969 L p 0 .458 1 r
F P
0 g
s
.23557 .49227 m .22024 .49142 L .21252 .49805 L p 0 .458 1 r
F P
0 g
s
.20092 .50885 m .21252 .49805 L .22024 .49142 L p 0 .05 .1 r
F P
0 g
s
0 0 0 r
.31811 .71877 m
.44781 .72364 L
s
.24482 .63211 m
.24585 .55705 L
s
.32119 .40363 m .28312 .40121 L .27478 .40872 L p 0 .458 1 r
F P
0 g
s
.23681 .40633 m .27478 .40872 L .28312 .40121 L p 0 .458 1 r
F P
0 g
s
.57989 .31457 m .7529 .3271 L .7571 .62926 L p .848 0 0 r
F P
0 g
s
.7529 .3271 m .80646 .63411 L .7571 .62926 L .891 0 0 r
F
0 g
.7529 .3271 m
.8015 .33452 L
s
.80646 .63411 m
.83031 .64205 L
s
.22711 .53889 m .18899 .53691 L .18928 .51969 L p 0 .344 .78 r
F P
0 g
s
.18928 .51969 m .18899 .53691 L .22711 .53889 L p 0 .344 .78 r
F P
0 g
s
.29228 .46415 m .30655 .45111 L .30072 .45589 L p 0 .05 .1 r
F P
0 g
s
.30072 .45589 m .28924 .46664 L .29228 .46415 L p 0 .05 .1 r
F P
0 g
s
.18928 .51969 m .20092 .50885 L .20854 .50232 L p 0 .05 .1 r
F P
0 g
s
.22024 .49142 m .20854 .50232 L .20092 .50885 L p 0 .05 .1 r
F P
0 g
s
.53138 .63764 m .46464 .62529 L .53541 .63668 L .538 0 0 r
F
0 g
.53113 .48757 m
.53138 .63603 L
s
.53138 .63764 m .4332 .63322 L .46464 .62529 L .538 0 0 r
F
0 g
.53138 .63764 m
.53138 .63764 L
s
.4332 .63322 m
.43429 .33315 L
s
0 0 0 r
.20001 .31853 m
.20001 .31853 L
s
.20001 .31853 m
.20001 .31853 L
s
.27435 .4429 m .28271 .43571 L .32086 .43802 L p 0 .458 1 r
F P
0 g
s
.28271 .43571 m .27435 .4429 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.32086 .43802 m .28271 .43571 L .27435 .4429 L p 0 .458 1 r
F P
0 g
s
.29228 .46415 m .28924 .46664 L .27407 .46575 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .27435 .4429 L .28271 .43571 L p 0 .458 1 r
F P
0 g
s
.32203 .3182 m .32119 .40363 L .20624 .39632 L p 0 .344 .779 r
F P
0 g
s
.20624 .39632 m .20763 .31012 L .32203 .3182 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.32161 .36081 m
.32161 .36081 L
s
.32161 .36081 m
.32161 .36081 L
s
.19182 .36899 m
.20694 .35312 L
s
.20694 .35312 m
.20694 .35312 L
s
.2651 .31418 m
.26692 .17294 L
s
.2651 .31418 m
.2651 .31418 L
s
.2651 .31418 m
.2651 .31418 L
s
.2651 .31418 m
.2651 .31418 L
s
.2651 .31418 m
.2651 .31418 L
s
.2651 .31418 m
.2651 .31418 L
s
.19651 .53063 m .18899 .53691 L .18928 .51969 L p 0 .052 .589 r
F P
0 g
s
.23524 .51533 m .1968 .51325 L .18928 .51969 L p 0 .458 1 r
F P
0 g
s
.18928 .51969 m .1968 .51325 L .23524 .51533 L p 0 .458 1 r
F P
0 g
s
.18928 .51969 m .1968 .51325 L .19651 .53063 L p 0 .052 .589 r
F P
0 g
s
.20854 .50232 m .1968 .51325 L .18928 .51969 L p 0 .05 .1 r
F P
0 g
s
.31995 .53038 m .32012 .51299 L .3114 .51944 L p 0 .084 .626 r
F P
0 g
s
.3114 .51944 m .31122 .53666 L .31995 .53038 L p 0 .084 .626 r
F P
0 g
s
.30016 .50735 m .3114 .51944 L .32012 .51299 L p 0 .292 .96 r
F P
0 g
s
.27344 .51739 m .3114 .51944 L .32012 .51299 L p 0 .458 1 r
F P
0 g
s
.3114 .51944 m .27344 .51739 L .28182 .5109 L p 0 .458 1 r
F P
0 g
s
.28182 .5109 m .32012 .51299 L .3114 .51944 L p 0 .458 1 r
F P
0 g
s
.53541 .63668 m .51911 .62077 L .5421 .63614 L .538 0 0 r
F
.53541 .63668 m .46464 .62529 L .51911 .62077 L F
0 g
.53138 .63764 m
.53541 .63668 L
s
.28312 .40121 m .2448 .39877 L .23681 .40633 L p 0 .458 1 r
F P
0 g
s
.1986 .40393 m .23681 .40633 L .2448 .39877 L p 0 .458 1 r
F P
0 g
s
.27407 .46575 m .27706 .46326 L .29228 .46415 L p 0 .458 1 r
F P
0 g
s
.23885 .46103 m .27706 .46326 L .27407 .46575 L p 0 .458 1 r
F P
0 g
s
.27407 .46575 m .23598 .46354 L .23885 .46103 L p 0 .458 1 r
F P
0 g
s
.32012 .51299 m .306 .5029 L .30016 .50735 L p 0 .292 .96 r
F P
0 g
s
.28891 .49525 m .30016 .50735 L .306 .5029 L p 0 .292 .96 r
F P
0 g
s
.19623 .54805 m .1887 .55416 L .18899 .53691 L p 0 .052 .589 r
F P
0 g
s
.18899 .53691 m .19651 .53063 L .19623 .54805 L p 0 .052 .589 r
F P
0 g
s
.306 .5029 m .29196 .49286 L .28891 .49525 L p 0 .292 .96 r
F P
0 g
s
.27672 .49201 m .27372 .4944 L .28891 .49525 L p 0 .458 1 r
F P
0 g
s
.28891 .49525 m .29196 .49286 L .27672 .49201 L p 0 .458 1 r
F P
0 g
s
.31978 .5478 m .31995 .53038 L .31122 .53666 L p 0 .084 .626 r
F P
0 g
s
.54965 .63617 m .58124 .62106 L .7571 .62926 L p .538 0 0 r
F P
0 g
s
.5421 .63614 m .58124 .62106 L .54965 .63617 L .538 0 0 r
F
0 g
.54925 .48571 m
.54964 .63323 L
s
.5421 .63614 m .51911 .62077 L .58124 .62106 L .538 0 0 r
F
0 g
.53541 .63668 m
.5421 .63614 L
s
.5421 .63614 m
.54965 .63617 L
s
.1887 .55416 m .19623 .54805 L .23474 .55002 L p 0 .458 1 r
F P
0 g
s
.20249 .63023 m .18723 .6409 L .1887 .55416 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.17332 .6085 m
.18797 .59743 L
s
.18797 .59743 m
.18797 .59743 L
s
.18797 .59743 m
.18797 .59743 L
s
.18797 .59743 m
.18797 .59743 L
s
.18797 .59743 m
.18797 .59743 L
s
.23474 .55002 m .24278 .54382 L .2814 .54582 L p 0 .458 1 r
F P
0 g
s
.24278 .54382 m .23474 .55002 L .19623 .54805 L p 0 .458 1 r
F P
0 g
s
.19623 .54805 m .20391 .54181 L .24278 .54382 L p 0 .458 1 r
F P
0 g
s
.31978 .5478 m .20391 .54181 L .1887 .55416 L p 0 .458 1 r
F P
0 g
s
.1887 .55416 m .20391 .54181 L .20249 .63023 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.203 .59814 m
.30202 .6028 L
s
.20694 .35312 m
.20694 .35312 L
s
.20694 .35312 m
.32161 .36081 L
s
.32161 .36081 m
.32161 .36081 L
s
.54547 .71776 m
.54547 .71776 L
s
.54547 .71776 m
.54547 .71776 L
s
.23557 .49227 m .27372 .4944 L .27672 .49201 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .24432 .43338 L .28271 .43571 L p 0 .458 1 r
F P
0 g
s
.24432 .43338 m .23631 .44061 L .19803 .43831 L p 0 .458 1 r
F P
0 g
s
.28271 .43571 m .24432 .43338 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.20569 .43103 m .19803 .43831 L .23631 .44061 L p 0 .458 1 r
F P
0 g
s
.23631 .44061 m .24432 .43338 L .20569 .43103 L p 0 .458 1 r
F P
0 g
s
.29228 .46415 m .27706 .46326 L .27988 .44952 L p 0 .388 .894 r
F P
0 g
s
.27988 .44952 m .30655 .45111 L .29228 .46415 L p 0 .388 .894 r
F P
0 g
s
.32012 .51299 m .28182 .5109 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.23524 .51533 m .27344 .51739 L .28182 .5109 L p 0 .458 1 r
F P
0 g
s
.27344 .51739 m .23524 .51533 L .24327 .5088 L p 0 .458 1 r
F P
0 g
s
.24327 .5088 m .28182 .5109 L .27344 .51739 L p 0 .458 1 r
F P
0 g
s
.2448 .39877 m .20624 .39632 L .1986 .40393 L p 0 .458 1 r
F P
0 g
s
.19832 .4211 m .1986 .40393 L .20624 .39632 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.1986 .40393 m
.20001 .31853 L
s
.1986 .40393 m
.1986 .40393 L
s
.20371 .40425 m
.30338 .41052 L
s
.1986 .40393 m
.1986 .40393 L
s
.2235 .46013 m .23885 .46103 L .23598 .46354 L p 0 .458 1 r
F P
0 g
s
.23598 .46354 m .22068 .46265 L .2235 .46013 L p 0 .458 1 r
F P
0 g
s
0 0 0 r
.18797 .59743 m
.18797 .59743 L
s
.27706 .46326 m .23885 .46103 L .24158 .44724 L p 0 .388 .894 r
F P
0 g
s
.24158 .44724 m .27988 .44952 L .27706 .46326 L p 0 .388 .894 r
F P
0 g
s
.28291 .41844 m .28312 .40121 L .32119 .40363 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.2651 .31418 m
.2651 .31418 L
s
.2651 .31418 m
.2651 .31418 L
s
.27672 .49201 m .29196 .49286 L .306 .5029 L p 0 .265 .577 r
F P
0 g
s
.32086 .43802 m .30655 .45111 L .27988 .44952 L p 0 .388 .894 r
F P
0 g
s
.20624 .39632 m .20597 .41366 L .19832 .4211 L p 0 .052 .589 r
F P
0 g
s
.19803 .43831 m .19832 .4211 L .20597 .41366 L p 0 .052 .589 r
F P
0 g
s
.46522 .32104 m .51911 .62077 L .46464 .62529 L .726 0 0 r
F
.46522 .32104 m .51879 .31414 L .51911 .62077 L F
0 g
.43429 .33315 m
.46522 .32104 L
s
.3 .79093 m .18476 .78729 L .18723 .6409 L p 0 .344 .78 r
F P
0 g
s
.3 .79093 m .31748 .78327 L .54565 .79063 L p 0 .443 1 r
F P
0 g
s
.18723 .6409 m .18476 .78729 L .3 .79093 L p 0 .344 .78 r
F P
0 g
s
.31748 .78327 m .3 .79093 L .18476 .78729 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.22687 .79655 m
.24265 .78912 L
s
.24265 .78912 m
.24265 .78912 L
s
.24265 .78912 m
.24265 .78912 L
s
.24265 .78912 m
.24265 .78912 L
s
.24265 .78912 m
.24265 .78912 L
s
.2427 .78553 m
.24408 .68558 L
s
.2235 .46013 m .22068 .46265 L .20936 .45048 L p 0 .29 .961 r
F P
0 g
s
.32103 .42081 m .32086 .43802 L .28271 .43571 L p 0 .344 .779 r
F P
0 g
s
.28271 .43571 m .28291 .41844 L .32103 .42081 L p 0 .344 .779 r
F P
0 g
s
.19803 .43831 m .20569 .43103 L .24432 .43338 L p 0 .458 1 r
F P
0 g
s
.20569 .43103 m .21462 .44563 L .20936 .45048 L p 0 .29 .961 r
F P
0 g
s
.20936 .45048 m .19803 .43831 L .20569 .43103 L p 0 .29 .961 r
F P
0 g
s
.20936 .45048 m .21462 .44563 L .2235 .46013 L p 0 .29 .961 r
F P
0 g
s
.27672 .49201 m .23844 .48986 L .23557 .49227 L p 0 .458 1 r
F P
0 g
s
.22024 .49142 m .23557 .49227 L .23844 .48986 L p 0 .458 1 r
F P
0 g
s
.20597 .41366 m .20569 .43103 L .19803 .43831 L p 0 .052 .589 r
F P
0 g
s
.54565 .79063 m .31748 .78327 L .31893 .6354 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.43265 .78698 m
.43265 .78698 L
s
.4131 .7945 m
.43265 .78698 L
s
.36835 .71097 m
.54547 .71776 L
s
.31821 .70904 m
.36835 .71097 L
s
.31821 .70904 m
.31821 .70904 L
s
.31821 .70904 m
.31821 .70904 L
s
0 g
.4332 .63322 m
.53138 .63764 L
s
0 0 0 r
.31821 .70904 m
.31821 .70904 L
s
.31821 .70904 m
.31821 .70904 L
s
.43318 .64048 m
.43318 .64048 L
s
.43318 .64048 m
.43318 .64048 L
s
.306 .5029 m .27926 .50142 L .27672 .49201 L p 0 .265 .577 r
F P
0 g
s
.23844 .48986 m .27672 .49201 L .27926 .50142 L p 0 .265 .577 r
F P
0 g
s
.27988 .44952 m .28271 .43571 L .32086 .43802 L p 0 .388 .894 r
F P
0 g
s
.20009 .77948 m .18476 .78729 L .18723 .6409 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.186 .71381 m
.186 .71381 L
s
.186 .71381 m
.186 .71381 L
s
.186 .71381 m
.186 .71381 L
s
.186 .71381 m
.186 .71381 L
s
.1713 .7227 m
.186 .71381 L
s
.18723 .6409 m .20249 .63023 L .20009 .77948 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.20113 .71437 m
.26759 .71687 L
s
.28182 .5109 m .24327 .5088 L .23524 .51533 L p 0 .458 1 r
F P
0 g
s
.1968 .51325 m .23524 .51533 L .24327 .5088 L p 0 .458 1 r
F P
0 g
s
.24327 .5088 m .23524 .51533 L .1968 .51325 L p 0 .458 1 r
F P
0 g
s
.21381 .4978 m .20854 .50232 L .22024 .49142 L p 0 .05 .1 r
F P
0 g
s
.23844 .48986 m .22306 .489 L .22024 .49142 L p 0 .458 1 r
F P
0 g
s
.22024 .49142 m .22306 .489 L .21381 .4978 L p 0 .05 .1 r
F P
0 g
s
.28271 .43571 m .27988 .44952 L .24158 .44724 L p 0 .388 .894 r
F P
0 g
s
.4332 .63322 m
.46464 .62529 L
s
0 0 0 r
.19478 .63562 m
.19478 .63562 L
s
.19478 .63562 m
.19478 .63562 L
s
.19478 .63562 m
.19478 .63562 L
s
.20239 .63595 m
.20694 .63615 L
s
.24158 .44724 m .23885 .46103 L .2235 .46013 L p 0 .388 .894 r
F P
0 g
s
.28182 .5109 m .27926 .50142 L .306 .5029 L p 0 .265 .577 r
F P
0 g
s
.306 .5029 m .32012 .51299 L .28182 .5109 L p 0 .265 .577 r
F P
0 g
s
.28312 .40121 m .28291 .41844 L .24456 .41606 L p 0 .344 .779 r
F P
0 g
s
.24456 .41606 m .2448 .39877 L .28312 .40121 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.26399 .39999 m
.26399 .39999 L
s
.26399 .39999 m
.2651 .31418 L
s
.26399 .39999 m
.26399 .39999 L
s
.26399 .39999 m
.26399 .39999 L
s
.26399 .39999 m
.26399 .39999 L
s
.43265 .78698 m
.43265 .78698 L
s
.43265 .78698 m
.43318 .64048 L
s
.43318 .64048 m
.43318 .64048 L
s
.1968 .51325 m .20854 .50232 L .21381 .4978 L p 0 .05 .1 r
F P
0 g
s
.28291 .41844 m .28271 .43571 L .24432 .43338 L p 0 .344 .779 r
F P
0 g
s
.24432 .43338 m .24456 .41606 L .28291 .41844 L p 0 .344 .779 r
F P
0 g
s
.2235 .46013 m .21462 .44563 L .24158 .44724 L p 0 .388 .894 r
F P
0 g
s
.27926 .50142 m .24084 .49929 L .23844 .48986 L p 0 .265 .577 r
F P
0 g
s
.23844 .48986 m .24084 .49929 L .21381 .4978 L p 0 .265 .577 r
F P
0 g
s
.21381 .4978 m .22306 .489 L .23844 .48986 L p 0 .265 .577 r
F P
0 g
s
.24158 .44724 m .24432 .43338 L .28271 .43571 L p 0 .388 .894 r
F P
0 g
s
.24327 .5088 m .24084 .49929 L .27926 .50142 L p 0 .265 .577 r
F P
0 g
s
.27926 .50142 m .28182 .5109 L .24327 .5088 L p 0 .265 .577 r
F P
0 g
s
0 0 0 r
.24265 .78912 m
.24265 .78912 L
s
.20419 .52423 m .19651 .53063 L .1968 .51325 L p 0 .052 .589 r
F P
0 g
s
.24327 .5088 m .20447 .50669 L .1968 .51325 L p 0 .458 1 r
F P
0 g
s
.1968 .51325 m .20447 .50669 L .24327 .5088 L p 0 .458 1 r
F P
0 g
s
.1968 .51325 m .20447 .50669 L .20419 .52423 L p 0 .052 .589 r
F P
0 g
s
.21381 .4978 m .20447 .50669 L .1968 .51325 L p 0 .05 .1 r
F P
0 g
s
.24432 .43338 m .24158 .44724 L .21462 .44563 L p 0 .388 .894 r
F P
0 g
s
.28182 .5109 m .32012 .51299 L .31995 .53038 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.186 .71381 m
.186 .71381 L
s
.2448 .39877 m .24456 .41606 L .20597 .41366 L p 0 .344 .779 r
F P
0 g
s
.20597 .41366 m .20624 .39632 L .2448 .39877 L p 0 .344 .779 r
F P
0 g
s
.20391 .54181 m .19623 .54805 L .19651 .53063 L p 0 .052 .589 r
F P
0 g
s
0 0 0 r
.19623 .54805 m
.19623 .54805 L
s
.19651 .53063 m .20419 .52423 L .20391 .54181 L p 0 .052 .589 r
F P
0 g
s
.28161 .52834 m .31995 .53038 L .31978 .5478 L p 0 .344 .779 r
F P
0 g
s
.31995 .53038 m .28161 .52834 L .28182 .5109 L p 0 .344 .779 r
F P
0 g
s
.24456 .41606 m .24432 .43338 L .20569 .43103 L p 0 .344 .779 r
F P
0 g
s
.20569 .43103 m .20597 .41366 L .24456 .41606 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.19478 .63562 m
.19478 .63562 L
s
.19478 .63562 m
.19478 .63562 L
s
.19478 .63562 m
.19623 .54805 L
s
.19623 .54805 m
.19623 .54805 L
s
.21462 .44563 m .20569 .43103 L .24432 .43338 L p 0 .388 .894 r
F P
0 g
s
.31978 .5478 m .2814 .54582 L .28161 .52834 L p 0 .344 .779 r
F P
0 g
s
.20391 .54181 m .31978 .5478 L .31893 .6354 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.31936 .5915 m
.31936 .5915 L
s
.31936 .5915 m
.31936 .5915 L
s
.7571 .62926 m .58124 .62106 L .57989 .31457 L p .848 0 0 r
F P
0 g
s
.7571 .62926 m
.80646 .63411 L
s
.7529 .3271 m
.7571 .62926 L
s
.72124 .64393 m
.7571 .62926 L
s
.51879 .31414 m .57989 .31457 L .58124 .62106 L .811 0 0 r
F
.24084 .49929 m .24327 .5088 L .20447 .50669 L p 0 .265 .577 r
F P
0 g
s
.20447 .50669 m .21381 .4978 L .24084 .49929 L p 0 .265 .577 r
F P
0 g
s
.51879 .31414 m .58124 .62106 L .51911 .62077 L .811 0 0 r
F
0 g
.46522 .32104 m
.51879 .31414 L
s
.54965 .63617 m
.58124 .62106 L
s
.57989 .31457 m
.58124 .62106 L
s
.51879 .31414 m
.57989 .31457 L
s
.24327 .5088 m .28182 .5109 L .28161 .52834 L p 0 .344 .779 r
F P
0 g
s
.24302 .5263 m .28161 .52834 L .2814 .54582 L p 0 .344 .779 r
F P
0 g
s
.28161 .52834 m .24302 .5263 L .24327 .5088 L p 0 .344 .779 r
F P
0 g
s
.18476 .78729 m .20009 .77948 L .31748 .78327 L p 0 .443 1 r
F P
0 g
s
0 0 0 r
.3087 .78299 m
.30881 .77173 L
s
.30866 .78714 m
.30866 .78714 L
s
.30866 .78714 m
.30866 .78714 L
s
.30866 .78714 m
.30866 .78714 L
s
.30866 .78714 m
.53477 .79435 L
s
.30866 .78714 m
.30866 .78714 L
s
.30866 .78714 m
.30866 .78714 L
s
.31936 .5915 m
.31936 .5915 L
s
.19235 .78342 m
.19235 .78342 L
s
.19235 .78342 m
.30866 .78714 L
s
.30866 .78714 m
.30866 .78714 L
s
.30866 .78714 m
.30866 .78714 L
s
.2814 .54582 m .24278 .54382 L .24302 .5263 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.26212 .54482 m
.26212 .54482 L
s
.19235 .78342 m
.19235 .78342 L
s
.19235 .78342 m
.19478 .63562 L
s
.19478 .63562 m
.19478 .63562 L
s
.19478 .63562 m
.19478 .63562 L
s
.20447 .50669 m .24327 .5088 L .24302 .5263 L p 0 .344 .779 r
F P
0 g
s
.31893 .6354 m .20249 .63023 L .20391 .54181 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.26212 .54482 m
.26212 .54482 L
s
.2032 .58592 m
.31936 .5915 L
s
.2032 .58592 m
.2032 .58592 L
s
.26099 .63283 m
.26099 .63283 L
s
.26099 .63283 m
.26099 .63283 L
s
.26099 .63283 m
.26099 .63283 L
s
.2032 .58592 m
.2032 .58592 L
s
.18797 .59743 m
.2032 .58592 L
s
.26099 .63283 m
.26099 .63283 L
s
.26099 .63283 m
.26099 .63283 L
s
.26099 .63283 m
.26212 .54482 L
s
.26212 .54482 m
.26212 .54482 L
s
.26212 .54482 m
.26212 .54482 L
s
.20419 .52423 m .24302 .5263 L .24278 .54382 L p 0 .344 .779 r
F P
0 g
s
.24302 .5263 m .20419 .52423 L .20447 .50669 L p 0 .344 .779 r
F P
0 g
s
.24278 .54382 m .20391 .54181 L .20419 .52423 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.31821 .70904 m
.31821 .70904 L
s
.31821 .70904 m
.31821 .70904 L
s
0 g
.46464 .62529 m
.51911 .62077 L
s
0 0 0 r
.26099 .63283 m
.26099 .63283 L
s
.26099 .63283 m
.26099 .63283 L
s
.31748 .78327 m .20009 .77948 L .20249 .63023 L p 0 .344 .779 r
F P
0 g
s
0 0 0 r
.25907 .78138 m
.26099 .63283 L
s
.25907 .78138 m
.25907 .78138 L
s
.20129 .70456 m
.31821 .70904 L
s
.20129 .70456 m
.20129 .70456 L
s
.25907 .78138 m
.25907 .78138 L
s
.24265 .78912 m
.25907 .78138 L
s
.20129 .70456 m
.20129 .70456 L
s
.186 .71381 m
.20129 .70456 L
s
0 g
.51911 .62077 m
.58124 .62106 L
s
[ .01 .01 ] 0 setdash
.2211 .11645 m
.87617 .17312 L
s
.87617 .17312 m
.88929 .80284 L
s
.88929 .80284 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.14199 .22149 m
.13013 .8214 L
s
.13013 .8214 m
.2108 .78103 L
s
.2108 .78103 m
.2211 .11645 L
s
.2211 .11645 m
.14199 .22149 L
s
.003 w
[ ] 0 setdash
.87617 .17312 m
.88929 .80284 L
s
.25 Mabswid
.87676 .20145 m
.87054 .20093 L
s
gsave
.88922 .2025 -61 -10.8695 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.87967 .34094 m
.87344 .34049 L
s
gsave
.89214 .34183 -61 -10.9597 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.312500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Math1
%%DocumentNeededResources: + font Times-Roman
%%DocumentNeededFonts: Math1
%%DocumentNeededFont: + Times-Roman
%%DocumentFonts: font Math1
%%DocumentFonts: + font Times-Roman
grestore
.88262 .48259 m
.87638 .48221 L
s
gsave
.8951 .48333 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88562 .62646 m
.87937 .62616 L
s
gsave
.8981 .62705 -61 -11.1446 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.88866 .7726 m
.88241 .77238 L
s
gsave
.90115 .77303 -61 -11.2392 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.87734 .22918 m
.8736 .22887 L
s
.87792 .25699 m
.87418 .25669 L
s
.8785 .28489 m
.87476 .2846 L
s
.87908 .31287 m
.87535 .31259 L
s
.88026 .36909 m
.87652 .36883 L
s
.88084 .39733 m
.8771 .39708 L
s
.88143 .42566 m
.87769 .42542 L
s
.88203 .45408 m
.87828 .45385 L
s
.88322 .51118 m
.87947 .51097 L
s
.88381 .53987 m
.88007 .53966 L
s
.88441 .56864 m
.88067 .56844 L
s
.88501 .5975 m
.88127 .59732 L
s
.88622 .6555 m
.88248 .65533 L
s
.88683 .68464 m
.88308 .68448 L
s
.88744 .71387 m
.88369 .71372 L
s
.88805 .74319 m
.8843 .74305 L
s
.87619 .17381 m
.87245 .17349 L
s
.88928 .80211 m
.88553 .80198 L
s
gsave
.95749 .48707 -61 -11.0514 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.187500 14.625000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Roman
%%DocumentNeededFonts: Times-Roman
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{416, 416},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006P0001X1000`40O003h00OogooXGoo003oOonQ
Ool00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00
ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQ
Ool00?mooj5oo`00ogooXGoo003oOonQOol00>=oo`<00;Yoo`00i7oo00<007ooOol0^Goo003TOol0
0`00Oomoo`2iOol00>Aoo`03001oogoo0;Uoo`00hgoo00<007oo0000^Woo003SOol00`00Ool0002j
Ool00>=oo`04001oogoo002iOol00>9oo`03001oogoo009oo`03001oogoo0;Ioo`00hGoo0`000Woo
0`00]goo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQ
Ool00?mooj5oo`00NGoo0`00ogoo9Goo001hOol01@00Oomoogoo0000ogoo97oo001hOol01@00Oomo
ogoo0000ogoo97oo001hOol01@00Oomoogoo0000ogoo97oo001hOol01@00Oomoogoo0000ogoo97oo
001hOol01@00Oomoogoo0000=7oo0`0017oo0`00iGoo001hOol01@00Oomoogoo0000=goo00@007oo
Ool000=oo`03001oogoo0>9oo`00N7oo00D007ooOomoo`0003Qoo`03001oo`0000=oo`03001oogoo
0>9oo`00NGoo0`00>Goo00<007oo00000goo00<007ooOol0hWoo002eOol00`00Ool00003Ool00`00
Oomoo`3ROol00;Aoo`04001oogoo0003Ool00`00Oomoo`0[Ool30003Ool30003Ool3002XOol00;9o
o`8000=oo`05001oogooOol0000^Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol0
YGoo001KOol600000goo001oo`1>Ool00`00Oomoo`02Ool01@00Oomoogoo0000;Woo00D007ooOomo
o`0000=oo`03001oo`0000=oo`03001oogoo0:Eoo`00FWoo0P001Goo3P00A7oo0`000Woo0`00;goo
00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo0:Eoo`00FWoo0P001Woo00<007ooOol0
27oo3000LGoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo0:Eoo`00FGoo00<007oo
Ool04Woo00<007ooOol027oo3P00Hgoo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo
02Moo`<0009oo`<000Aoo`<006moo`00NWoo00<007ooOol027oo3000FGoo00D007ooOomoo`0000=o
o`03001oo`0000=oo`03001oogoo02Qoo`03001oogoo00Aoo`04001oogoo0003Ool00`00Oomoo`1/
Ool007Yoo`03001oogoo00Yoo`03001oogoo00Eoo`h004aoo`8000=oo`07001oogooOol007oo0000
0goo00<007ooOol0:7oo00<007ooOol01Goo00<007oo00000goo00<007ooOol0K7oo001FOol00`00
Oomoo`02Ool00`00Oomoo`0eOol00`00Oomoo`07Ool;0012Ool00`00Oomoo`02Ool30003Ool3000[
Ool00`00Oomoo`05Ool00`00Ool00003Ool00`00Oomoo`1/Ool005Eoo`03001oogoo00=oo`03001o
ogoo045oo`03001oogoo00Ioo``006moo`03001oogoo00Eoo`03001oo`0000=oo`03001oogoo06ao
o`00EGoo00<007ooOol00goo00<007ooOol0CGoo00<007ooOol01Woo3@00HWoo00<007ooOol017oo
00@007ooOol000=oo`03001oogoo02Eoo`D0009oo`<000=oo`<003Moo`00E7oo00<007ooOol017oo
00<007ooOol0F7oo00<007ooOol01goo3000Egoo00<007ooOol00Woo0P000goo00D007ooOomoo`00
02Qoo`06001oogoo001oo`000goo00<007oo00000goo00<007ooOol0=7oo001DOol00`00Oomoo`04
Ool00`00Oomoo`1HOol00`00Oomoo`09Ool00`00Oomoo`04Ool?001:Ool20004Ool00`00Oomoo`02
Ool01@00Oomoogoo0000:Goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo03Aoo`00
cWoo00<007ooOol01Woo3000@7oo00<007ooOol00goo0`000Woo0`00:goo00@007ooOol000=oo`03
001oo`0000=oo`03001oogoo03Aoo`00fWoo00<007ooOol01Goo3@00KWoo00<007oo00000goo00<0
07oo00000goo00<007ooOol0=7oo001AOol00`00Oomoo`2AOol00`00Oomoo`07Ool<001ROol00`00
Ool00003Ool00`00Ool00003Ool00`00Oomoo`0dOol0051oo`03001oogoo00Qoo`03001oogoo09=o
o`03001oogoo00Ioo`d005Ioo`03001oo`0000=oo`03001oo`0000=oo`03001oogoo03Aoo`00D7oo
00<007ooOol027oo00<007ooOol0Tgoo00<007ooOol02Goo00<007ooOol00goo0`0000=oo`000000
2P00AWoo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`0dOol004moo`03001o
ogoo00Uoo`03001oogoo0:Yoo`03001oogoo00Ioo`h003]oo`<000=oo`<000=oo`<003Moo`00Fgoo
00<007ooOol0]Woo00<007ooOol01Goo3P00MWoo001KOol00`00Oomoo`31Ool00`00Oomoo`08Ool<
001ZOol00?moob]oo`03001oogoo00Moo`h005ioo`00C7oo00<007ooOol0fgoo00<007ooOol02Goo
00<007ooOol017oo0`0000=oo`0000002`00DWoo001;Ool00`00Oomoo`09Ool6003TOol00`00Oomo
o`07Ool?0016Ool004]oo`03001oogoo00Qoo`8000D1N0`00>=oo`03001oogoo00Ioo`<0009oo``0
03Yoo`00BWoo00<007ooOol027oo00<0000b00000`5h00<0005h0GP02`5h3000hWoo00<007ooOol0
27oo00<007oo00001`00=7oo001DOol010000380<P000`5h00<0005h0GP0405h00<0005h0GP0105h
3000hGoo00<007ooOol01Goo0P00=7oo001COol2000203801@000GP1N05h00004P5h00<0005h0GP0
405h2`00eWoo00<007ooOol017oo00<007oo0000=7oo0017Ool00`00Oomoo`09Ool01@000380<P0b
00000`5h00<0005h0GP0405h00<0005h0GP05@5h00<0005h0GP00`5h3000dgoo00<007ooOol0<Woo
0016Ool00`00Oomoo`09Ool2000303801@000GP1N05h00004P5h00<0005h0GP05@5h00<0005h0GP0
3`5h2`00`Woo00<007ooOol00goo00<007ooOol0<Woo0016Ool00`00Oomoo`08Ool00`0003800003
03800`000GP1N00D0GP00`000GP1N00E0GP00`000GP1N00J0GP;002fOol00`00Oomoo`04Ool00`00
Oomoo`0bOol004Eoo`03001oogoo00Qoo`040000<P0b000303800`000GP1N00D0GP00`000GP1N00E
0GP00`000GP1N00U0GP<002YOol00`00Oomoo`05Ool00`00Oomoo`0bOol004Eoo`03001oogoo00Mo
o`800080<P050000<P0b0380000F0GP00`000GP1N00E0GP00`000GP1N00[0GP00`000GP1N0030GP;
002MOol00`00Oomoo`06Ool00`00Oomoo`0bOol004ioo`030000<P000080<P050000<P0b03800003
0GP00`000GP1N00@0GP00`000GP1N00E0GP00`000GP1N00[0GP00`000GP1N00>0GP;002KOol00`00
Oomoo`0bOol004ioo`030000<P000080<P050000<P0b038000030GP00`000GP1N00@0GP00`000GP1
N00E0GP00`000GP1N00[0GP00`000GP1N00I0GP<0023Ool00`00Oomoo`09Ool00`00Oomoo`0bOol0
049oo`03001oogoo00Qoo`8000050380000b0380000303801@000GP1N05h00004P5h00<0005h0GP0
5@5h00<0005h0GP0:`5h00<0005h0GP09@5h3000MGoo0P0037oo00<007ooOol0<Woo0011Ool00`00
Oomoo`08Ool20002038010000380<P000`0b00D0005h0GP1N0000181N0030001N05h01D1N0030001
N05h02/1N0030001N05h02X1N0030001N05h00@1N0h006Eoo`8000ioo`03001oogoo00ioo`<000=o
o`<000=oo`<001Eoo`00@Goo00<007ooOol01goo00<0000b00000P0b00@0000b038000<0<P050001
N05h0GP0000B0GP00`000GP1N00E0GP00`000GP1N00[0GP00`000GP1N00Z0GP00`000GP1N00B0GP>
00000goo001oo`1ROol3000AOol01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol04Woo
0010Ool00`00Oomoo`08Ool00`0003800002038010000380<P000`0b00<0005h0GP0505h00<0005h
0GP05@5h00<0005h0GP0:`5h00<0005h0GP0:P5h00<0005h0GP0805h3P00FGoo00<007ooOol03goo
00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo019oo`00BWoo00@0000b03800080<P04
0000<P0b000303800`000GP1N00D0GP00`000GP1N00E0GP00`000GP1N00[0GP00`000GP1N00Z0GP0
0`000GP1N00P0GP00`000GP1N00;0GP>000hOol00`00Oomoo`0@Ool00`00Oomoo`06Ool70002Ool0
1@00Oomoogoo00000goo00<007oo00000goo00<007ooOol04Woo001:Ool010000380<P000P0b00@0
000b038000<0<P030001N05h01@1N0030001N05h01D1N0030001N05h02/1N0030001N05h02X1N003
0001N05h0201N0030001N05h01T1N0P002ioo`8001=oo`03001oogoo00moo`05001oogooOol00003
Ool00`00Ool00003Ool00`00Oomoo`0BOol004Yoo`040000<P0b0002038010000380<P000`0b00D0
005h0GP1N0000181N0030001N05h01D1N0030001N05h02/1N0030001N05h02X1N0030001N05h0201
N0030001N05h0201N003001oogoo02Yoo`8001Eoo`03001oogoo00moo`05001oogooOol00003Ool0
0`00Ool00003Ool00`00Oomoo`0BOol003eoo`03001oogoo00Yoo`040000<P0b0002038010000380
<P000`0b00D0005h0GP1N0000181N0030001N05h01D1N0030001N05h02/1N0030001N05h02X1N003
0001N05h0201N0030001N05h0201N003001oogoo045oo`03001oogoo00moo`05001oogooOol00003
Ool00`00Ool00003Ool00`00Oomoo`0BOol003aoo`03001oogoo00]oo`040000<P0b000203801000
0380<P000`0b00D0005h0GP1N0000181N0030001N05h01D1N0030001N05h02/1N0030001N05h02X1
N0030001N05h0201N0030001N05h0201N003001oogoo02Moo`03001oogoo01Moo`03001oogoo00io
o`8000=oo`07001oogooOol007oo00000goo00<007ooOol04Woo000lOol00`00Oomoo`0;Ool01000
0380<P000P0b00@0000b038000<0<P050001N05h0GP0000B0GP00`000GP1N00E0GP00`000GP1N00[
0GP00`000GP1N00Z0GP00`000GP1N00P0GP00`000GP1N00P0GP00`00Oomoo`0VOol00`00Oomoo`0H
Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool30003Ool3000EOol003Yoo`8000ioo`040000<P0b0002
038010000380<P000`0b00D0005h0GP1N0000181N0030001N05h01D1N0030001N05h02/1N0030001
N05h02X1N0030001N05h0201N0030001N05h0201N003001oogoo02Eoo`03001oogoo01Uoo`03001o
ogoo039oo`00>Woo00@007ooOomoo`D000=oo`80009oo`040000<P0b0002038010000380<P000`0b
00<0005h0GP0505h00<0005h0GP05@5h00<0005h0GP0:`5h00<0005h0GP0:P5h00<0005h0GP0805h
00<0005h0GP0805h00<007ooOol097oo00<007ooOol06Woo00<007ooOol0<Woo000jOol00`00Oomo
o`0;Ool30002038010000380<P000P0b00D0000b0380<P0001H1N0030001N05h01D1N0030001N05h
02/1N0030001N05h02X1N0030001N05h0201N0030001N05h0201N003001oogoo049oo`03001oogoo
035oo`00>Woo00<007ooOol03Goo00@0000b03800080<P040000<P0b000303800`000GP1N00D0GP0
0`000GP1N00E0GP00`000GP1N00[0GP00`000GP1N00Z0GP00`000GP1N00P0GP00`000GP1N00P0GP0
0`00Oomoo`0POol00`00Oomoo`0MOol00`00Ool0000cOol003Yoo`03001oogoo00eoo`040000<P0b
0002038010000380<P000`0b00D0005h0GP1N0000181N0030001N05h01D1N0030001N05h02/1N003
0001N05h02X1N0030001N05h0201N0030001N05h0201N003001oogoo01ioo`80025oo`8003=oo`00
>Woo00<007ooOol03Goo00@0000b03800080<P040000<P0b000303801@000GP1N05h00004P5h00<0
005h0GP05@5h00<0005h0GP0:`5h00<0005h0GP0:P5h00<0005h0GP0805h00<0005h0GP0805h00<0
07ooOol07Goo00<007ooOol08Woo00<007ooOol0<Goo001:Ool010000380<P000P0b00@0000b0380
00<0<P050001N05h0GP0000B0GP00`000GP1N00E0GP00`000GP1N00[0GP00`000GP1N00Z0GP00`00
0GP1N00P0GP00`000GP1N00P0GP00`00Oomoo`12Ool00`00Oomoo`0aOol004Yoo`040000<P0b0002
038010000380<P000P0b0P000P5h00<0005h0GP04@5h00<0005h0GP05@5h00<0005h0GP0:`5h00<0
005h0GP0:P5h00<0005h0GP0805h00<0005h0GP0805h00<007ooOol0@Woo00<007ooOol0<Goo001:
Ool010000380<P000P0b00@0000b03800080<PP00101N0030001N05h01D1N0030001N05h02/1N003
0001N05h02X1N0030001N05h0201N0030001N05h0201N003001oogoo01Uoo`03001oogoo02Ioo`03
001oogoo035oo`00>Woo00<007ooOol03Goo00@0000b03800080<P050000<P0b0000<P0200030GP0
10000GP1N05h4@005`5h00<0005h0GP0:`5h00<0005h0GP0:P5h00<0005h0GP0805h00<0005h0GP0
805h00<007ooOol05goo0P00:Goo00<007ooOol0<Goo000jOol00`00Oomoo`0=Ool010000380<P00
0P0b00<0000b03800P0000<0<P000GP05P5h4000205h00<0005h0GP0:`5h00<0005h0GP0:P5h00<0
005h0GP0805h00<0005h0GP0805h00<007ooOol05Woo00<007ooOol0:Goo00<007ooOol0<Goo000j
Ool00`00Oomoo`0=Ool010000380<P000P0b00@0000b03800080<P030001N05h01D1N0030001N05h
00d1N0h002P1N0030001N05h02X1N0030001N05h0201N0030001N05h0201N003001oogoo049oo`03
001oogoo035oo`00>Woo00<007ooOol03Goo00@0000b03800080<P040000<P0b000203800`000GP1
N00E0GP00`000GP1N00D0GP00`000GP1N0040GP=000K0GP00`000GP1N00Z0GP00`000GP1N00P0GP0
0`000GP1N00P0GP00`00Oomoo`12Ool00`00Oomoo`0aOol003Yoo`03001oogoo00eoo`040000<P0b
000203801000038000000P0b00D0005h0GP1N00001<1N0030001N05h01@1N0030001N05h0141N0d0
00h1N0030001N05h02X1N0030001N05h0201N0030001N05h0201N003001oogoo019oo`03001oogoo
02eoo`03001oogoo035oo`00BWoo00@0000b03800080<P8000050380000b038000030GP00`000GP1
N00A0GP00`000GP1N00D0GP00`000GP1N00N0GP=00000`5h0001N00[0GP00`000GP1N00P0GP00`00
0GP1N00P0GP00`00Oomoo`0@Ool2000`Ool00`00Oomoo`0aOol004Yoo`050000<P0b0000<P020002
038010000380<P000`5h00<0005h0GP04@5h00<0005h0GP0505h00<0005h0GP0:`5h3P00805h00<0
005h0GP0805h00<0005h0GP0805h00<007ooOol03goo00<007ooOol0;Woo0`00<goo001:Ool01P00
0380<P00038000<0<P040000<P0b00030GP00`000GP1N00A0GP00`000GP1N00D0GP00`000GP1N00/
0GP00`000GP1N00:0GP=000C0GP00`000GP1N00P0GP00`000GP1N00P0GP00`00Oomoo`12Ool00`00
Oomoo`0aOol003Yoo`03001oogoo00eoo`030000<P0b00<000<0<P040000<P0b00030GP00`000GP1
N00A0GP00`000GP1N00D0GP00`000GP1N00/0GP00`000GP1N00G0GP=00060GP00`000GP1N00P0GP0
0`000GP1N00P0GP00`00Oomoo`0<Ool00`00Oomoo`0cOol00`00Oomoo`0aOol003Yoo`03001oogoo
00eoo`060000<P0b0000<P000`0b00@0000b038001L1N0030001N05h01@1N0030001N05h02`1N003
0001N05h02@1N0`001d1N0030001N05h0201N003001oogoo00]oo`03001oogoo03Aoo`03001oogoo
035oo`00>Woo00<007ooOol03Goo00H0000b0000000b0003038010000380<P005`5h00<0005h0GP0
505h00<0005h0GP0;05h00<0005h0GP0:P5h00<0005h0GP00`5h30004@5h00<0005h0GP0805h1000
0goo0P000goo0P00=goo00<007ooOol0<Goo000jOol00`00Oomoo`0=Ool00`000380000203801@00
0380<P0b00000P0b00<0005h0GP05@5h00<0005h0GP0505h00<0005h0GP0;05h00<0005h0GP0:P5h
00<0005h0GP03`5h30001@5h00<0005h0GP0805h00<007ooOol01Woo0`00>Goo00<007ooOol0<Goo
000jOol00`00Oomoo`0=Ool3000203801@000380<P0b00000P0b00D0005h0GP1N00001<1N0030001
N05h01@1N0030001N05h02`1N0030001N05h02X1N0030001N05h01/1N0/001d1N003001oogoo00Qo
o`03001oogoo03Moo`03001oogoo035oo`00BWoo00<0000b00000P0b00D0000b0380<P000080<P05
0001N05h0GP0000C0GP00`000GP1N00D0GP00`000GP1N00/0GP00`000GP1N00Z0GP00`000GP1N00Q
0GP00`000GP1N0020GP<000A0GP00`00Oomoo`08Ool00`00Oomoo`0gOol00`00Oomoo`0aOol004Uo
o`040000<P0b000203801@000380<P0b00000P0b00D0005h0GP1N00001<1N0030001N05h01@1N003
0001N05h02`1N0030001N05h02X1N0030001N05h0241N0030001N05h00h1N0`000D1N003001oogoo
00Qoo`03001oogoo03Moo`03001oogoo035oo`00BGoo00@0000b03800080<P050000<P0b03800002
03801@000GP1N05h00004`5h00<0005h0GP0505h00<0005h0GP0;05h00<0005h0GP0:P5h00<0005h
0GP08@5h00<0005h0GP06P5h1P002Woo00<007ooOol0=goo00<007ooOol0<Goo000jOol00`00Oomo
o`0<Ool010000380<P000P0b00D0000b0380<P000080<P050001N05h0GP0000C0GP00`000GP1N00D
0GP00`000GP1N00/0GP00`000GP1N00Z0GP00`000GP1N00Q0GP00`000GP1N00O0GP00`00Oomoo`12
Ool00`00Oomoo`0aOol003Yoo`03001oogoo00aoo`040000<P0b000203801@000380<P0b00000P0b
00<0005h0GP05@5h00<0005h0GP0505h00<0005h0GP0;05h00<0005h0GP0:P5h00<0005h0GP08@5h
00<0005h0GP07`5h00<007ooOol0@Woo00<007ooOol0<Goo000jOol00`00Oomoo`0<Ool010000380
<P000P0b00D0000b0380<P000080<P030001N05h01D1N0030001N05h01@1N0030001N05h02`1N003
0001N05h02X1N0030001N05h0241N0030001N05h01l1N003001oogoo045oo`8003=oo`00>Woo00<0
07ooOol037oo00@0000b03800080<P050000<P0b0380000203800`000GP1N00E0GP00`000GP1N00D
0GP00`000GP1N00/0GP00`000GP1N00Z0GP00`000GP1N00Q0GP00`000GP1N00O0GP00`00Oomoo`12
Ool00`00Oomoo`0aOol003Yoo`03001oogoo00aoo`040000<P0b000203801@000380<P0b00000P0b
00D0005h0GP1N00001<1N0030001N05h01@1N0030001N05h02`1N0030001N05h02X1N0030001N05h
0241N0030001N05h01l1N003001oogoo00Qoo`03001oogoo03Moo`03001oogoo035oo`00BGoo00@0
000b03800080<P050000<P0b0380000203801@000GP1N05h00004`5h00<0005h0GP0505h00<0005h
0GP0;05h00<0005h0GP0:P5h00<0005h0GP08@5h00<0005h0GP07`5h00<007ooOol027oo00<007oo
Ool0=goo00<007ooOol0<Goo0019Ool010000380<P000P0b00D0000b0380<P000080<P050001N05h
0GP0000C0GP00`000GP1N00D0GP00`000GP1N00/0GP00`000GP1N00Z0GP00`000GP1N00Q0GP00`00
0GP1N00O0GP00`00Oomoo`08Ool00`00Oomoo`0gOol00`00Oomoo`0aOol004Uoo`040000<P0b0002
03801@000380<P0b00000P0b00D0005h0GP1N00001<1N0030001N05h01@1N0030001N05h02`1N003
0001N05h02X1N0030001N05h0241N0030001N05h01l1N003001oogoo00Qoo`03001oogoo03Moo`03
001oogoo035oo`00BGoo00@0000b03800080<P050000<P0b0380000203801@000GP1N05h00004`5h
00<0005h0GP0505h00<0005h0GP0;05h00<0005h0GP0:P5h00<0005h0GP08@5h00<0005h0GP07`5h
00<007ooOol027oo00<007ooOol0=goo00<007ooOol0<Goo000jOol00`00Oomoo`0<Ool010000380
<P000P0b00D0000b0380<P000080<P030001N05h01D1N0030001N05h01@1N0030001N05h02`1N003
0001N05h02X1N0030001N05h0241N0030001N05h01l1N003001oogoo049oo`03001oogoo035oo`00
>Woo00<007ooOol037oo00@0000b03800080<P050000<P0b0380000203800`000GP1N00E0GP00`00
0GP1N00D0GP00`000GP1N00/0GP00`000GP1N00Z0GP00`000GP1N00Q0GP00`000GP1N00O0GP00`00
Oomoo`12Ool00`00Oomoo`0aOol003Yoo`03001oogoo00aoo`040000<P0b000203801@000380<P0b
00000P0b00<0005h0GP05@5h00<0005h0GP0505h00<0005h0GP0;05h00<0005h0GP0:P5h00<0005h
0GP08@5h00<0005h0GP07`5h00<007ooOol0@Woo00<007ooOol0<Goo000jOol00`00Oomoo`0<Ool0
10000380<P000P0b00D0000b0380<P000080<PH00181N0030001N05h01@1N0030001N05h02`1N003
0001N05h02X1N0030001N05h0241N0030001N05h01l1N003001oogoo00Qoo`03001oogoo03Moo`03
001oogoo035oo`00>Woo00<007ooOol037oo00@0000b03800080<P060000<P0b0380000b0P000`5h
00<0005h00002`001P5h00<0005h0GP0505h00<0005h0GP0;05h00<0005h0GP0:P5h00<0005h0GP0
8@5h00<0005h0GP07`5h00<007ooOol027oo00<007ooOol0=Woo0P00<goo0019Ool010000380<P00
0P0b00@0000b0380<P8000030380005h0081N0030001N05h00/1N0`00141N0030001N05h02`1N003
0001N05h01d1N2@000d1N0030001N05h01l1N003001oogoo00Qoo`03001oogoo03Moo`03001oogoo
035oo`00BGoo00@0000b03800080<P050000<P0b0380000203801@000GP1N05h00004`5h00<0005h
0GP00`5h30001@5h00<0005h0GP0;05h00<0005h0GP05P5h1`000e`06F@000<006`0K0001F`03P00
8@5h00<007ooOol027oo00<007ooOol0=goo00<007ooOol0<Goo0019Ool010000380<P000P0b00<0
000b03800P000P0b00D0005h0GP1N00001<1N0030001N05h00l1N0d002L1N0030001N05h00h1N0P0
00YL01UT0003001/06`001=/00h001<1N003001oogoo00Qoo`03001oogoo03Moo`03001oogoo035o
o`00>Woo00<007ooOol037oo00@0000b03800080<P050000<P000380000203801@000GP1N05h0000
4`5h00<0005h0GP0505h00<0007O0Ml01@7O40005`5h00<0005h0GP02@5h1@004U`06F@000<006`0
K0008F`03`00105h00<007ooOol0@Woo00<007ooOol0<Goo000jOol00`00Oomoo`0<Ool010000380
<P000P0b0P000P0b00@0000b038001L1N0030001N05h01@1N0030001g`7O01@1ga4000L1N0030001
N05h00L1N0800003A01L05`001AL01UT0003001/06`0031/00h003]oo`03001oogoo035oo`00>Goo
00<007ooOol03Goo00@0000b03800080<P050000<P0b0380000203800`000GP1N00E0GP00`000GP1
N00D0GP8000O0MlB0003A00FG00II0000`00K01/000nK00;000`Ool00`00Oomoo`0aOol003Uoo`03
001oogoo00eoo`050000<P0b0000<P020003038010000380<P005`5h00<0005h0GP0505h00<0007O
0Ml01@7O3P00607O00<0007O0Ml00P7O0`001T@05U`06F@000<006`0K000AF`000@00700L01`00H0
02Yoo`03001oogoo035oo`00>Goo00<007ooOol03Goo00<0000b03800P0000<0<P0003800P0b00@0
000b038000<1N0030001N05h0141N0030001N05h01@1N0030001g`7O01<1g`h000T1g`040001g`00
0Ml20009A00FG00II0000`00K01/0015K0000`00L01`0007L007000TOol00`00Oomoo`0`Ool004Uo
o`030000<P0b008000030380000b0080<P040000<P0b00030GP00`000GP1N00A0GP00`000GP1N00D
0GP00`000Ml1g`0Q0Ml=000;A00FG00II0000`00K01/0015K0000`00L01`000>L004000OOol2000b
Ool004Uoo`040000<P0b000203801@000380<P0b00000P0b00D0005h0GP1N00001<1N0030001N05h
01@1N0d001d1g`800081g`8000a401IL01UT0003001/06`004E/0003001`0700019`008001eoo`80
039oo`00BGoo00@0000b00000080<P050000<P0b0380000203801@000GP1N05h00004`5h00<0005h
0GP0505h00<0007O0Ml0207O3`003`7O00<0007O0Ml00P0000<P0000A0002d@05U`06F@000<006`0
K000AF`000<00700L0004W000W`00P006goo0P003Woo0`0017oo0`006Woo000iOol00`00Oomoo`0=
Ool200001@0b0000<P0b00000`0b00@0000b038000<1N0030001N05h0141N0030001N05h01@1N003
0001g`7O01<1ga<00081g`05000P02008000000<A00FG00II0000`00K01/0015K0000`00L01`000B
L004O002000GOol4000AOol01000Oomoo`000goo00<007ooOol05goo000iOol00`00Oomoo`0=Ool0
10000380<P000P0b00D0000b0380<P000080<P030001N05h01D1N0030001N05h01@1N0H001`1g`T0
00@P0003001404@000Y401IL01UT0003001/06`004E/0003001`0700019`00Il008001Qoo`03001o
ogoo011oo`03001oo`0000=oo`03001oogoo01Moo`00>Goo00<007ooOol03Goo00@0000b03800080
<P050000<P0b0380000203800`000GP1N00E0GP00`000GP1N00D0GP00`000Ml1g`030Ml<000D0Ml0
10000Ml000001B0000<004@0A0002T@05U`06F@000<006`0K000AF`000<00700L0004W0027`00P00
5Woo00<007ooOol01Goo1`0017oo00<007oo00000goo00<007ooOol05goo000iOol00`00Oomoo`0=
Ool010000380<P000P0b00D0000b0380<P000080<P030001N05h01D1N0030001N05h01@1N0030001
g`7O00l1g``000H1g`8000030Ml0020000HP0003001404@000Y401IL01UT0003001/06`004E/0003
001`0700019`00Yl01Ioo`03001oogoo011oo`03001oo`0000=oo`03001oogoo01Moo`00>Goo00<0
07ooOol03Goo00@0000b03800080<P050000<P0b0380000203801@000GP1N05h00004`5h00<0005h
0GP0505h00<0007O0Ml06`7O2@00220000<004@0A0002T@05U`06F@000<006`0K000AF`000<00700
L0004W002W`05Woo00<007ooOol03goo00@007ooOol000=oo`03001oogoo01Moo`00BGoo00@0000b
03800080<P060000<P0b0380000b20004@5h00<0005h0GP0505h2@006@7O00@0007O0Ml000TP0003
001404@000Y401IL01UT0003001/06`004E/0003001`0700019`00Yl01Ioo`03001oogoo00eoo`80
00=oo`05001oogooOol0000IOol004Uoo`040000<P0b0002038010000380<P0b0`00105h00<0005h
0GP0400000<1N0000GP05@5h00<007ooOol01Woo3`00207O0P000P7O00<002008000220000<004@0
A0002T@05U`06F@000<006`0K000AF`000<00700L0004W002W`05Woo00<007ooOol03Goo00<007oo
Ool00Woo00D007ooOomoo`0001Uoo`00BGoo00@0000b03800080<P070000<P0b0380000b0000105h
00<0005h0GP0405h4000205h00<007ooOol05Goo30002b0000<004@0A0002T@05U`06F@000<006`0
K000AF`000<00700L0004W002W`05Woo00<007ooOol03Woo0`000Woo0`006Woo0019Ool010000380
<P000P0b00<0000b03800P0000<0<P000GP00`5h00<0005h0GP0405h00<0005h0GP03@5h2@0087oo
00<0020080002b0000<004@0A0002T@05U`06F@000<006`0K000AF`000<00700L0004W002W`05Woo
00<007ooOol0<7oo000iOol00`00Oomoo`0=Ool010000380<P000P0b00@0000b03800080<P030001
N05h01D1N0030001N05h01D1N003001oogoo01eoo`03000P020000`P0003001404@000Y401IL01UT
0003001/06`004E/0003001`0700019`00Yl01Ioo`03001oogoo031oo`00>Goo00<007ooOol03Goo
00@0000b03800080<P040000<P00000203800`000GP1N00E0GP00`000GP1N00E0GP00`00Oomoo`0L
Ool00`00800P000=80000`00A014000:A00FG00II0000`00K01/0015K0000`00L01`000BL00:O00F
Ool00`00Oomoo`0`Ool003Uoo`03001oogoo00eoo`040000<P0b0002038200001@0b0000<P0b0000
5`5h00<0005h0GP05@5h00<007ooOol077oo00<0020080003B0000<004@0A0002T@05U`06F@000<0
06`0K000AF`000<00700L0004W002W`05Woo00<007ooOol0<7oo000iOol00`00Oomoo`0=Ool01000
0380<P000P0b00@0000b03800080<P030001N05h0081N0030001N05h0101N0030001N05h01D1N003
001oogoo01aoo`03000P020000dP0003001404@000Y401IL01UT0003001/06`004E/0003001`0700
019`00Yl01Aoo`<0039oo`00>Goo00<007ooOol03Goo00D0000b0380000b00800080<P040000<P0b
00040GP00`000GP1N00@0GP00`000GP1N00E0GP00`00Oomoo`0LOol00`00800P000=80000`00A014
000:A00FG00II0000`00K01/0015K0000`00L01`000BL00:O00FOol00`00Oomoo`0`Ool004Uoo`03
0000<P0b008000050380000b0380000203800`000GP1N0020GP00`000GP1N00@0GP00`000GP1N00E
0GP00`00Oomoo`0LOol00`00800P000=80000`00A014000:A00FG00II0000`00K01/0015K0000`00
L01`000BL00:O00FOol00`00Oomoo`0`Ool004Uoo`040000<P0b0002038010000380<P000P0b00<0
005h0GP00P5h00<0005h0GP0405h00<0005h0GP05@5h00<007ooOol077oo00<0020080003B0000<0
04@0A0002T@05U`06F@000<006`0K000AF`000<00700L0004W002W`05Woo00<007ooOol0<7oo0019
Ool01000038000000P0b00@0000b03800080<P030001N05h0081N0030001N05h0101N0030001N05h
01D1N003001oogoo01aoo`03000P020000dP0003001404@000Y401IL01UT0003001/06`004E/0003
001`0700019`00Yl01Ioo`03001oogoo031oo`00>Goo00<007ooOol03Goo0P0000D0<P000380<P00
0080<P040000<P0b00040GP00`000GP1N00@0GP00`000GP1N00E0GP00`00Oomoo`0LOol00`00800P
000=80000`00A014000:A00FG00II0000`00K01/0015K0000`00L01`000BL00:O00FOol00`00Oomo
o`0`Ool003Uoo`03001oogoo00eoo`040000<P0b0002038010000380<P000P0b00<0005h0GP05@5h
00<0005h0GP05@5h00<007ooOol077oo00<0020080003B0000<004@0A0002T@05U`06F@000<006`0
K000AF`000<00700L0004W002W`05Woo00<007ooOol0<7oo000iOol00`00Oomoo`0=Ool010000380
<P000P0b00@0000b03800080<P030001N05h01D1N0030001N05h01D1N003001oogoo01aoo`03000P
020000dP0003001404@000Y401IL01UT0003001/06`004E/0003001`0700019`00Yl01Ioo`03001o
ogoo031oo`00>Goo00<007ooOol03Goo00@0000b03800080<P040000<P0b000203800`000GP1N00E
0GP00`000GP1N00E0GP00`00Oomoo`0LOol00`00800P000=80000`00A014000:A00FG00II0000`00
K01/0015K0000`00L01`000BL00:O00FOol00`00Oomoo`0`Ool003Uoo`03001oogoo00eoo`040000
<P0b0002038010000380<P000P0b00D0005h0GP1N00001<1N0030001N05h01D1N003001oogoo01ao
o`03000P020000dP0003001404@000Y401IL01UT0003001/06`004E/0003001`0700019`00Yl01Io
o`03001oogoo031oo`00BGoo00@0000b03800080<P040000<P0b000203801@000GP1N05h00004`5h
00<0005h0GP05@5h00<007ooOol077oo00<0020080003B0000<004@0A0002T@05U`06F@000<006`0
K000AF`000<00700L0004W002W`05Woo00<007ooOol0<7oo0019Ool010000380<P000P0b00@0000b
03800080<PP00101N0030001N05h01D1N003001oogoo01aoo`03000P020000dP0003001404@000Y4
01IL01UT0003001/06`004E/0003001`0700019`00Yl01Aoo`<0039oo`00BGoo00@0000b03800080
<P050000<P0b0000<P0200030GP010000GP1N05h4@005`5h00<007ooOol077oo00<0020080003B00
00<004@0A0002T@05U`06F@000<006`0K000AF`000<00700L0004W002W`05Woo00<007ooOol0<7oo
000iOol00`00Oomoo`0=Ool010000380<P000P0b00<0000b03800P0000<0<P000GP00P5h00<0005h
0GP02@5h00<0005h0GP01@5h4000205h00<007ooOol077oo00<0020080003B0000<004@0A0002T@0
5U`06F@000<006`0K000AF`000<00700L0004W002W`05Woo00<007ooOol0<7oo000iOol00`00Oomo
o`0=Ool010000380<P000P0b00D0000b0380000b008000l1N0030001N05h00d1N0030001N05h00D1
N0T001ioo`03000P020000dP0003001404@000Y401IL01UT0003001/06`004I/0003001`0700015`
00Yl01Ioo`03001oogoo031oo`00>Goo00<007ooOol03Goo00@0000b03800080<P040000<P000002
03800`000GP1N00=0GP00`000GP1N00=0GP00`000GP1N00=0GP00`00Oomoo`0LOol00`00800P000=
80000`00A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00FOol00`00Oomoo`0`
Ool003Uoo`03001oogoo00eoo`040000<P0b0002038200001@0b0000<P0b00003`5h00<0005h0GP0
3@5h00<0005h0GP03@5h00<007ooOol077oo00<0020080003B0000<004@0A0002T@05U`06F@000<0
06`0K000AV`000<00700L0004G002W`05Woo00<007ooOol0<7oo000iOol00`00Oomoo`0=Ool01000
0380<P000P0b00@0000b03800080<P050001N05h0GP0000;0GP00`000GP1N00=0GP00`000GP1N005
0GP00`000GP1N0050GP00`00Oomoo`0LOol00`00800P000=80000`00A014000:A00FG00II0000`00
K01/0016K0000`00L01`000AL00:O00FOol00`00Oomoo`0`Ool004Uoo`050000<P0b0000<P020002
03800`000380<P0800080GP00`000GP1N00=0GP00`000GP1N00=0GP00`00Oomoo`0LOol00`00800P
000=80000`00A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00FOol00`00Oomo
o`0`Ool004Uoo`030000<P0b008000060380000b0380000b0P000`5h00@0005h0GP1N10000P1N003
0001N05h00d1N003001oogoo01aoo`03000P020000dP0003001404@000Y401IL01UT0003001/06`0
04I/0003001`0700015`00Yl01Ioo`03001oogoo031oo`00BGoo00@0000b03800080<P030000<P0b
008000030380005h0081N0030001N05h00T1N0030001N05h00D1N10000P1N003001oogoo01aoo`03
000P020000dP0003001404@000Y401IL01UT0003001/06`004I/0003001`0700015`00Yl01Ioo`03
001oogoo031oo`00>Goo00<007ooOol03Goo00@0000b00000080<P040000<P0b000203801@000GP1
N05h00002`5h00<0005h0GP03@5h00<0005h0GP01@5h2@007Woo00<0020080003B0000<004@0A000
2T@05U`06F@000<006`0K000AV`000<00700L0004G002W`05Woo00<007ooOol0<7oo000iOol00`00
Oomoo`0=Ool200001P0b0000<P0b0000<P800080<P030001N05h00d1N0030001N05h00d1N0030001
N05h00d1N003001oogoo01aoo`03000P020000dP0003001404@000Y401IL01UT0003001/06`004I/
0003001`0700015`00Yl01Ioo`03001oogoo031oo`00>Goo00<007ooOol03Goo00@0000b03800080
<P8000050380000b0380000?0GP00`000GP1N00=0GP00`000GP1N00=0GP00`00Oomoo`0LOol00`00
800P000=80000`00A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00EOol2000b
Ool003Uoo`03001oogoo00eoo`040000<P0b0002038010000380<P000P0b00<0005h0GP03@5h00<0
005h0GP03@5h00<0005h0GP03@5h00<007ooOol077oo00<0020080003B0000<004@0A0002T@05U`0
6F@000<006`0K000AV`000<00700L0004G002W`05Woo00<007ooOol0<7oo000iOol00`00Oomoo`0=
Ool01@000380<P0003800P000P0b00<0000b03802000205h00<0005h0GP03@5h00<0005h0GP03@5h
00<007ooOol077oo00<0020080003B0000<004@0A0002T@05U`06F@000<006`0K000AV`000<00700
L0004G002W`05Woo00<007ooOol0<7oo000iOol00`00Oomoo`0=Ool00`000380<P0200002@0b0000
<P0b0000<P000Ch000020I`010000I`1W06L4000205h00<0005h0GP03@5h00<007ooOol077oo00<0
020080003B0000<004@0A0002T@05U`06F@000<006`0K000AV`000<00700L0004G002W`05Woo00<0
07ooOol0<7oo0019Ool010000380<P000P0b00<0000b03800P000P4n00@0006L0I`000/1W0030001
W06L00D1W10000P1N003001oogoo01aoo`03000P020000dP0003001404@000Y401IL01UT0003001/
06`004I/0003001`0700015`00Yl01Ioo`03001oogoo031oo`00BGoo00@0000b00000080<P040000
<P0b00040Ch00`000I`0000;0I`00`000I`1W00=0I`00`000I`1W0050I`9000NOol00`00800P000=
80000`00A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00FOol2000aOol004Uo
o`8000090380000b0380000b0001?P0000@1?P8000X1W0030001W06L00h1W0030001W06L00`1W003
001oogoo01eoo`03000P020000dP0003001404@000Y401IL01UT0003001/06`004I/0003001`0700
015`00Yl01Ioo`80035oo`00>Goo00<007ooOol03Goo00@0000b03800080<P8000<1?P040001?P4n
0Ch2000:0I`00`000I`1W00=0I`00`000I`1W00<0I`00`00Oomoo`0NOol00`00800P000=80000`00
A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00FOol2000aOol003Uoo`03001o
ogoo00eoo`040000<P0b000203800`000Ch1?P020Ch00`000Ch1?P020Ch600050I`00`000I`1W00=
0I`00`000I`1W00;0I`00`00Oomoo`0OOol00`00800P000=80000`00A014000:A00FG00II0000`00
K01/0016K0000`00L01`000AL00:O00GOol00`00Oomoo`0_Ool003Uoo`03001oogoo00eoo`080000
<P0b0000<P000Ch000@1?P030001?P00008000D1W0d000P1W0030001W06L00X1W003001oogoo021o
o`03000P020000dP0003001404@000Y401IL01UT0003001/06`004I/0003001`0700015`00Yl01Mo
o`03001oogoo02moo`00>Goo00<007ooOol03Goo00<0000b03800P000`4n00<0004n0Ch00P4n00D0
004n0Ch1?P0000T1W0030001W06L00D1W0h000H1W003001oogoo025oo`03000P020000dP00030014
04@000Y401IL01UT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo02moo`00>Goo
00<007ooOol03Goo00@0000b038000@1?P080001?P4n0Ch0004n0001?P8000T1W0030001W06L00d1
W0030001W06L00<1W0H002Aoo`03000P020000dP0003001404@000Y401IL01UT0003001/06`004I/
0003001`0700015`00Yl01Moo`03001oogoo02moo`00BGoo00D0000b0001?P0000@1?P030001?P00
00<1?P8000030Ch0006L00H1W0030001W06L00d1W0030001W06L00P1W003001oogoo02=oo`03000P
020000dP0003001404@000Y401IL01UT0003001/06`004I/0003001`0700015`00Yl01Eoo`<0035o
o`00BGoo0P000`4n00<0004n0Ch00P4n00<0004n0Ch00`4n00<0004n00001`6L00<0006L0I`03@6L
00<0006L0I`01`6L00<007ooOol097oo00<0020080003B0000<004@0A0002T@05U`06F@000<006`0
K000AV`000<00700L0004G002W`05Woo0P00<Goo0019Ool00`000Ch1?P020Ch01`000Ch1?P4n0001
?P0000@1?P8000030Ch00000008000<1W0030001W06L00d1W0030001W06L00D1W08002Moo`03000P
020000dP0003001404@000Y401IL01UT0003001/06`004I/0003001`0700015`00Yl01Ioo`80035o
o`00>7oo00<007ooOol03goo00<0004n0Ch00P4n00<0004n00000`4n00H0004n0Ch1?P000Ch30002
0Ml;00070I`00`000I`1W0050I`00`00Oomoo`0WOol00`00800P000=80000`00A014000:A00FG00I
I0000`00K01/0016K0000`00L01`000AL00:O00GOol00`00Oomoo`0_Ool003Qoo`03001oogoo011o
o`8000<1?P030001?P4n00<1?P050001?P4n0Ch000030Ml;00020Ml?000ZOol00`00800P000=8000
0`00A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00GOol00`00Oomoo`0_Ool0
03Qoo`03001oogoo019oo`050001?P000Ch000050Ch00`000Ch000060Ml00`000Ml1g`060Ml@000[
Ool00`00800P000=80000`00A014000:A00FG00II0000`00K01/0016K0000`00L01`000AL00:O00G
Ool00`00Oomoo`0_Ool003Qoo`03001oogoo01=oo`050001?P4n0Ch000050Ch300040Ml00`000Ml1
g`0>0Ml00`000Ml1g`040Ml00`00Oomoo`0ZOol00`00800P000=80000`00A014000:A00FG00JI000
0`00K01/0015K0000`00L01`000AL00:O00GOol00`00Oomoo`0_Ool003Qoo`03001oogoo01Aoo`80
0081?P080001?P4n0Ch0007O0001g`/000T1g`030001g`7O00<1g`8002eoo`03000P020000dP0003
001404@000Y401IL01YT0003001/06`004E/0003001`0700015`00Yl01Moo`03001oogoo02moo`00
DGoo00H0004n0Ch0004n00020Ml01@000Ml1g`7O0000207O3`00;goo00<0020080003B0000<004@0
A0002T@05U`06V@000<006`0K000AF`000<00700L0004G002W`05goo00<007ooOol0;goo001BOol2
00001P4n000000000Ml00081g`030001g`7O00d1g`8000D1g`03001oogoo02ioo`03000P020000dP
0003001404@000Y401IL01YT0003001/06`004E/0003001`0700015`00Yl01Moo`03001oogoo02mo
o`00E7oo0`0000<1g`0000005000107O00<007ooOol0;goo00<0020080003B0000<004@0A0002T@0
5U`06V@000<006`0K000AF`000<00700L0004G002W`05goo00<007ooOol01Goo0`009goo000hOol0
0`00Oomoo`0LOolD00030Ml4000bOol00`00800P000=80000`00A014000:A00FG00JI0000`00K01/
0015K0000`00L01`000AL00:O00GOol00`00Oomoo`04Ool01@00Oomoogoo00009Woo000hOol00`00
Oomoo`0aOol5000cOol00`00800P000<80000`00A014000;A00FG00JI0000`00K01/0015K0000`00
L01`000AL00:O00DOol40006Ool01@00Oomoogoo00005Goo1`002Woo000hOol00`00Oomoo`1YOol0
0`00800P000<80000`00A014000;A00FG00JI0000`00K01/0015K0000`00L01`000BL009O00GOol0
0`00Oomoo`04Ool01@00Oomoogoo00005Woo00<007ooOol00Woo00<007ooOol027oo000hOol00`00
Oomoo`0QOol30015Ool00`00800P000<80000`00A014000;A00FG00JI0000`00K01/0015K0000`00
L01`000BL009O00GOol00`00Oomoo`04Ool01@00Oomoogoo00005Woo00<007ooOol00Woo00<007oo
Ool027oo000hOol00`00Oomoo`0NOol00`00Ool000030A8;000jOol00`00800P000<80000`00A014
000;A00FG00JI0000`00K01/0015K0000`00L01`000BL009O00GOol00`00Oomoo`04Ool01@00Oomo
ogoo00005goo00<007ooOol037oo001IOol200070A800`000A814P050A8@000ZOol00`00800P000<
80000`00A014000;A00FG00JI0000`00K01/0015K0000`00L01`000BL009O00GOol00`00Oomoo`04
Ool01@00Oomoogoo000067oo00<007ooOol02goo001IOol00`000A814P060A800`000A814P0=0A80
0`000A814P050A800`00Oomoo`0WOol00`00800P000<80000`00A014000;A00FG00JI0000`00K01/
0015K0000`00L01`000BL00:O00FOol00`00Oomoo`04Ool01@00Oomoogoo000067oo00<007ooOol0
2goo001HOol600050A800`000A814P0<0A800`000A814P060A82000WOol00`00800P000<80000`00
A014000;A00FG00JI0000`00K01/0015K0000`00L01`000BL00:O00FOol00`00Oomoo`05Ool3000J
Ool00`00Oomoo`0:Ool005Moo`0300014P0000@14Pd000P14P0300014P4B00L14P03001oogoo02Ao
o`03000P020000`P0003001404@000]401IL01YT0003001/06`004E/0003001`0700019`00Yl01Io
o`03001oogoo01moo`05001oogooOol0000;Ool003Qoo`03001oogoo01]oo`0300014P4B00X14P03
00014P4B00D14Q@002Eoo`03000P020000`P0003001404@000]401IL01YT0003001/06`004E/0003
001`0700019`00Yl01Ioo`03001oogoo01moo`H000Yoo`00>7oo00<007ooOol06Woo00<0004B0A80
2`4B00<0004B0A803@4B00<0004B0A802@4B0P008goo00<002008000320000<004@0A0002d@05U`0
6V@000<006`0K000AF`000<00700L0004W002W`05Woo00<007ooOol0;goo000hOol00`00Oomoo`0H
Ool900080A800`000A814P0<0A800`000A814P0;0A800`00Oomoo`0POol00`00800P000<80000`00
A014000;A00FG00JI0000`00K01/0015K0000`00L01`000BL00:O00FOol00`00Oomoo`0_Ool003Qo
o`03001oogoo01Moo`<000L1N10000P14P0300014P4B00/14P8001moo`8000hP0003001404@000]4
01IL01YT0003001/06`004E/0003001`0700019`00Yl01Ioo`03001oogoo02moo`00>7oo00<007oo
Ool05Woo00@0000b038000@1N0030001N05h00P1N0030001N05h00D1N1T001ioo`8000hP00030014
04@000]401IL01YT0003001/06`004E/0003001`0700019`00Yl01Aoo`<0035oo`00D7oo0P000P0b
00<0005h0GP00P5h00<0005h0GP0205h00<0005h0GP03@5h00<0005h0GP03@5h00<007ooOol077oo
0P003R0000<004@0A0002d@05U`06V@000<006`0K000AF`000<00700L0004W002W`05Woo00<007oo
Ool0;goo001?Ool00`000380000203800`000GP1N0020GP00`000GP1N0080GP00`000GP1N00=0GP0
0`000GP1N00=0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0015K000
0`00L01`000BL00:O00FOol00`00Oomoo`0_Ool004ioo`040000<P0b000203800`000GP1N0020GP0
0`000GP1N0080GP00`000GP1N00=0GP00`000GP1N00=0GP00`00Oomoo`0LOol2000>80000`00A014
000;A00FG00JI0000`00K01/0015K0000`00L01`000BL00:O00FOol00`00Oomoo`0_Ool003Qoo`03
001oogoo019oo`800080<P040000<P0b00040GP00`000GP1N0080GP00`000GP1N00=0GP00`000GP1
N00=0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0015K0000`00L01`
000BL00:O00FOol00`00Oomoo`0_Ool003Qoo`03001oogoo015oo`030000<P000080<P030000<P0b
00P000P1N0030001N05h00d1N0030001N05h00d1N003001oogoo01aoo`8000hP0003001404@000]4
01IL01YT0003001/06`004E/0003001`0700019`00Yl01Ioo`03001oogoo02moo`00>7oo00<007oo
Ool03goo0P000P0b00D0000b0380000b008000L1N10000P1N0030001N05h00d1N003001oogoo01ao
o`8000hP0003001404@000]401IL01YT0003001/06`004E/0003001`0700019`00Yl01Ioo`03001o
ogoo02moo`00>7oo00<007ooOol03Woo0`000P0b00<0000b03800P0000<0<P000GP03P5h00<0005h
0GP01@5h4000205h00<007ooOol077oo0P003R0000<004@0A0002d@05U`06V@000<006`0K000AF`0
00<00700L0004W002W`05Woo00<007ooOol0;goo000hOol00`00Oomoo`0=Ool010000380<P000P0b
00@0000b03800080<P030001N05h0081N0030001N05h00P1N0030001N05h00d1N0030001N05h00D1
N0T001ioo`8000hP0003001404@000]401IL01YT0003001/06`004E/0003001`0700019`00Yl01Io
o`03001oogoo02moo`00B7oo00@0000b03800080<P@00080<P030001N05h0081N0030001N05h00P1
N0030001N05h00d1N0030001N05h00d1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT
0003001/06`004E/0003001`0700019`00Yl01Ioo`03001oogoo02moo`00B7oo00@0000b03800080
<P040000<P0b000203801@000GP1N05h00002`5h00<0005h0GP03@5h00<0005h0GP03@5h00<007oo
Ool077oo0P003R0000<004@0A0002d@05U`06V@000<006`0K000AF`000<00700L0004W002W`05Woo
00<007ooOol0;goo0018Ool01@000380<P0003800P000P0b00@0000b038000<1N0030001N05h00T1
N0030001N05h00d1N0030001N05h00d1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT
0003001/06`004E/0003001`0700019`00Yl01Eoo`80035oo`00>7oo00<007ooOol03Goo00<0000b
03800P0000D0<P000380<P000080<PP000P1N0030001N05h00d1N0030001N05h00d1N003001oogoo
01aoo`8000hP0003001404@000]401IL01YT0003001/06`004E/0003001`0700019`00Yl01Ioo`80
031oo`00>7oo00<007ooOol03Goo00@0000b03800080<P050000<P0b0000<P0200070GP@00000`5h
0001N0050GP00`000GP1N00=0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00
K01/0015K0000`00L01`000BL00:O00FOol2000`Ool003Qoo`03001oogoo00eoo`@00080<P030000
<P0b008000030380005h01H1N10000P1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT
0003001/06`004E/0003001`0700019`00Yl01Moo`03001oogoo02ioo`00>7oo00<007ooOol03Goo
00@0000b03800080<P040000<P00000203800`000GP1N00E0GP00`000GP1N00=0GP9000NOol2000>
80000`00A014000;A00FG00JI0000`00K01/0015K0000`00L01`000BL00:O00GOol00`00Oomoo`0^
Ool003Qoo`03001oogoo00eoo`040000<P0b0002038200001@0b0000<P0b00000`5h00<0005h0GP0
4@5h00<0005h0GP05@5h00<007ooOol077oo0P003R0000<004@0A0002d@05U`06V@000<006`0K000
AF`000<00700L0004W002W`05goo00<007ooOol0;Woo0018Ool010000380<P000P0b00@0000b0380
0080<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`00Oomoo`0LOol2000>80000`00A014000;
A00FG00JI0000`00K01/0015K0000`00L01`000BL00:O00FOol2000`Ool004Qoo`050000<P0b0000
<P020002038010000380<P000`5h00<0005h0GP04@5h00<0005h0GP05@5h00<007ooOol077oo0P00
3R0000<004@0A0002d@05U`06V@000<006`0K000AV`000<00700L0004G002W`05Woo0P00<7oo0018
Ool00`000380<P0200001@0b0000<P0b00000P0b00D0005h0GP1N00001<1N0030001N05h01D1N003
001oogoo01aoo`8000hP0003001404@000]401IL01YT0003001/06`004I/0003001`0700015`00Yl
01Ioo`80031oo`00B7oo00@0000b03800080<P040000<P0b000203801@000GP1N05h00004`5h00<0
005h0GP05@5h00<007ooOol077oo0P003R0000<004@0A0002d@05U`06V@000<006`0K000AV`000<0
0700L0004G002W`05Woo0P00<7oo000hOol00`00Oomoo`0=Ool40002038010000380<P000P0b00<0
005h0GP05@5h00<0005h0GP05@5h00<007ooOol077oo0P003R0000<004@0A0002d@05U`06V@000<0
06`0K000AV`000<00700L0004G002W`05Woo0P00<7oo000hOol00`00Oomoo`0=Ool010000380<P00
0P0b00@0000b03800080<P030001N05h01D1N0030001N05h01D1N003001oogoo01aoo`8000hP0003
001404@000]401IL01YT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo02ioo`00
>7oo00<007ooOol03Goo00@0000b03800080<P040000<P0b000203800`000GP1N00E0GP00`000GP1
N00E0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0016K0000`00L01`
000AL00:O00EOol3000`Ool003Qoo`03001oogoo00eoo`040000<P0b0002038010000380<P000P0b
00D0005h0GP1N00001<1N0030001N05h01D1N003001oogoo01aoo`8000hP0003001404@000]401IL
01YT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo02ioo`00>7oo00<007ooOol0
3Goo00@0000b03800080<P040000<P0b000203801@000GP1N05h00004`5h00<0005h0GP05@5h00<0
07ooOol077oo0P003R0000<004@0A0002d@05U`06V@000<006`0K000AV`000<00700L0004G002W`0
5goo00<007ooOol0;Woo0018Ool010000380<P000P0b00@0000b03800080<P050001N05h0GP0000C
0GP00`000GP1N00E0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0016
K0000`00L01`000AL00:O00GOol00`00Oomoo`0^Ool004Qoo`040000<P0b0002038010000380<P00
0P0b00D0005h0GP1N00001<1N0030001N05h01D1N003001oogoo01aoo`8000hP0003001404@000]4
01IL01YT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo02ioo`00B7oo00@0000b
03800080<P040000<P0b000203801@000GP1N05h00004`5h00<0005h0GP05@5h00<007ooOol077oo
0P003R0000<004@0A0002d@05U`06V@000<006`0K000AV`000<00700L0004G002W`05goo00<007oo
Ool0;Woo000gOol00`00Oomoo`0>Ool010000380<P000P0b00@0000b03800080<P050001N05h0GP0
000C0GP00`000GP1N00E0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/
0016K0000`00L01`000AL00:O00GOol00`00Oomoo`0^Ool003Moo`03001oogoo00ioo`040000<P0b
0002038010000380<P000P0b00<0005h0GP05@5h00<0005h0GP05@5h00<007ooOol077oo0P003R00
00<004@0A0002d@05U`06V@000<006`0K000AV`000<00700L0004G002W`05goo00<007ooOol0;Woo
000gOol00`00Oomoo`0>Ool010000380<P000P0b00@0000b03800080<P`000`1N0030001N05h01D1
N003001oogoo01aoo`8000hP0003001404@000]401IL01YT0003001/06`004I/0003001`0700015`
00Yl01Moo`03001oogoo02ioo`00=goo00<007ooOol03Woo00@0000b03800080<P030000<P0b00@0
00/1N1P000`1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT0003001/06`004I/0003
001`0700015`00Yl01Moo`03001oogoo02ioo`00=goo00<007ooOol03Woo00@0000b03800080<P04
0000<P00000203801@000GP1N05h00004`5h00<0005h0GP02@5h3@007Woo0P003R0000<004@0A000
2d@05U`06V@000<006`0K000AV`000<00700L0004G002W`05goo00<007ooOol0;Woo0018Ool01000
0380<P000P0b0`000`0b00D0005h0GP1N00001<1N0030001N05h01D1N003001oogoo01aoo`8000hP
0003001404@000]401IL01YT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo02io
o`00B7oo00D0000b0380000b008000030380000b0080<P050001N05h0GP0000C0GP00`000GP1N00E
0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0016K0000`00L01`000A
L00:O00EOol3000`Ool004Qoo`030000<P0b00<00080<P050000<P0b038000030GP00`000GP1N00A
0GP00`000GP1N00E0GP00`00Oomoo`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0016
K0000`00L01`000AL00:O00GOol00`00Oomoo`0^Ool003Moo`03001oogoo00ioo`060000<P0b0000
<P000P0b00D0000b0380<P0000<1N0030001N05h0141N0030001N05h01D1N003001oogoo01aoo`80
00hP0003001404@000]401IL01YT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo
02ioo`00=goo00<007ooOol03Woo00<0000b00000P0b00@0000b038000<0<P030001N05h01D1N003
0001N05h01D1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT0003001/06`004I/0003
001`0700015`00Yl01Moo`03001oogoo02ioo`00=goo00<007ooOol03Woo0`000P0b00@0000b0380
00<0<P030001N05h01D1N0030001N05h01D1N003001oogoo01aoo`8000hP0003001404@000]401IL
01YT0003001/06`004I/0003001`0700015`00Yl01Moo`03001oogoo02ioo`00=goo00<007ooOol0
3Goo0P0000D0<P000380<P000080<P050000<P0b0380000G0GP00`000GP1N00E0GP00`00Oomoo`0L
Ool2000>80000`00A014000;A00FG00JI0000`00K01/0016K0000`00L01`000AL00:O00GOol00`00
Oomoo`0^Ool003Moo`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00D0005h0GP1
N00001<1N0030001N05h01D1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT0003001/
06`004I/0003001`0700015`00Yl01Moo`03001oogoo02ioo`00Agoo00@0000b03800080<P040000
<P0b000303801@000GP1N05h00004`5h00<0005h0GP05@5h00<007ooOol077oo0P003R0000<004@0
A0002d@05U`06V@000<006`0K000AV`000<00700L0004G002W`05goo00<007ooOol0;Woo0017Ool0
10000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`00Oomo
o`0LOol2000>80000`00A014000;A00FG00JI0000`00K01/0016K0000`00L01`000AL00:O00GOol0
0`00Oomoo`0^Ool004Moo`040000<P0b0002038010000380<P000`0b00D0005h0GP1N00001<1N003
0001N05h01D1N003001oogoo01aoo`8000hP0003001404@000]401IL01YT0003001/06`004I/0003
001`0700015`00Yl01Moo`03001oogoo02ioo`00=goo00<007ooOol03Goo00@0000b03800080<P04
0000<P0b000303801@000GP1N05h00004`5h00<0005h0GP05@5h00<007ooOol077oo0P003R0000<0
04@0A0002d@04E`0:@00?f`000<00700L0004G002W`05goo00<007ooOol0;Woo000gOol00`00Oomo
o`0=Ool010000380<P000P0b00@0000b038000<0<P030001N05h01D1N0030001N05h01D1N003001o
ogoo01aoo`8000hP0003001404@000]400EL00`001e4008000Y4018002e/0003001`0700015`00Yl
01Moo`03001oogoo00Aoo`<000Aoo`<0021oo`00=goo00<007ooOol03Goo00@0000b03800080<P04
0000<P0b000303800`000GP1N00E0GP00`000GP1N00E0GP00`00Oomoo`0LOol2000>80000`00A014
0008A008000WA002000NA00B000KK0000`00L01`000AL00:O00DOol40009Ool01000Oomoo`000goo
00<007ooOol07Goo000gOol00`00Oomoo`0=Ool010000380<P000P0b00@0000b038000<0<P030001
N05h01D1N0030001N05h01D1N003001oogoo01aoo`8000hP0003001404@000A400@002e400800394
018000U/0003001`0700015`00Yl01Moo`03001oogoo00Qoo`03001oo`0000=oo`03001oogoo01eo
o`00=goo00<007ooOol03Goo00@0000b03800080<P040000<P0b0003038<000<0GP00`000GP1N00E
0GP00`00Oomoo`0LOol2000>80000`00A0140004000_A0020016A00>000?L00:O00GOol00`00Oomo
o`08Ool00`00Ool00003Ool00`00Oomoo`0MOol003Moo`03001oogoo00eoo`040000<P0b00020380
1@000380<P0003800`000`5h00<0005h0GP01@5h6000305h00<007ooOol077oo0P003R002`009T@0
00<004@0A0000P00CT@00P001T@02P001G002W`05goo00<007ooOol027oo00<007oo00000goo00<0
07ooOol07Goo0017Ool010000380<P000P0b00<0000b03800P0000<0<P0000000`5h00<0005h0GP0
4@5h00<0005h0GP02@5h60004goo0P0032000P002d@050003T@00P000d@00P00CD@00`004T@01`00
27`05goo00<007ooOol01goo00@007ooOol000=oo`03001oogoo01eoo`00Agoo00@0000b03800080
<P@000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1N00=0GPD000880000`00A014
000OA00>000209D>0012A002000LA0030005O00GOol00`00Oomoo`05Ool20003Ool01@00Oomoogoo
00007goo0017Ool010000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1
N00E0GP00`000GP1N00M0GP010000GP1N05h5`006T@00P000P2E00<0002E09D00P2E00<0005h0GP0
2`5h60009d@00`008D@0100000=l07ooOol05Goo00<007ooOol01Goo00<007ooOol00Woo00D007oo
Oomoo`0001moo`00=goo00<007ooOol03Goo00D0000b0380000b00800080<P050000<P0b03800003
0GP00`000GP1N00A0GP00`000GP1N00E0GP00`000GP1N00/0GP00`000GP1N0090GPK000309D00`00
09D0U@0209D00`000GP1N00Q0GP00`000GP0000G000=A002000XA002000FOol00`00Oomoo`06Ool3
0002Ool3000POol003Moo`03001oogoo00eoo`030000<P0b008000050380000b0380000303800`00
0GP1N00E0GP00`000GP1N00E0GP00`000GP1N00/0GP00`000GP1N00Q0GPD000K0GP00`000GP1N00G
0GP@000WA0000`00Oomoo`0EOol00`00Oomoo`0^Ool003Moo`03001oogoo00eoo`040000<P000002
038010000380<P000`0b00<0005h0GP05@5h00<0005h0GP05@5h00<0005h0GP0;05h00<0005h0GP0
;05h00<0005h0GP01P5h4P002@5h00<0005h0GP0805h00@00300<00`00/001i40003001oogoo01Mo
o`03001oogoo02eoo`00=goo00<007ooOol03Goo0P0000D0<P000380<P000080<P050000<P0b0380
000G0GP00`000GP1N00E0GP00`000GP1N00/0GP00`000GP1N00/0GP00`000GP1N00H0GPB000J0GP0
1000<00000002d@050002T@000<007ooOol05goo00<007ooOol0;Goo000gOol00`00Oomoo`0=Ool0
10000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1
N00/0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N0060GPB00080GP2000QA00:000JOol0
0`00Oomoo`0]Ool004Moo`040000<P0b0002038010000380<P000`0b00D0005h0GP1N00001<1N003
0001N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001N05h0241N0030001N05h01P1N0T0
02540003=01404@000A4008001Yoo`<002moo`00Agoo00@0000b03800080<P040000<P0b00030380
1@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h0GP0;05h00<0005h0GP0;05h00<0005h0GP0
8@5h00<0005h0GP0805h00<004@0A0005D@000<d04@0A0002d@00`007Goo0P00;goo0017Ool01000
0380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1N00/
0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00A014000;A0000f`0A014000B
A003000POol2000_Ool003Moo`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00D0
005h0GP1N00001<1N0030001N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001N05h0241
N0030001N05h0201N003001404@001i4008002=oo`8002moo`00=goo00<007ooOol03Goo00@0000b
03800080<P040000<P0b000303800`000GP1N00E0GP00`000GP1N00E0GP00`000GP1N00/0GP00`00
0GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00A014000KA003000UOol2000_Ool003Mo
o`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00<0005h0GP05@5h00<0005h0GP0
5@5h00<0005h0GP0;05h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<004@0A000
64@00`00:Goo00<007ooOol0;Goo000gOol00`00Oomoo`0=Ool010000380<P000P0b00@0000b0380
00<0<P030001N05h01D1N0030001N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001N05h
0241N0030001N05h0201N0l000Y4008002aoo`03001oogoo02eoo`00=goo00<007ooOol03Goo00@0
000b03800080<P040000<P0b000303801@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h0GP0
;05h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<004@0A0002d@02`00;Woo00<0
07ooOol0;Goo0017Ool010000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`00
0GP1N00E0GP00`000GP1N00/0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00
A014000:A007000bOol2000_Ool004Moo`040000<P0b0002038010000380<P000`0b00D0005h0GP1
N00001<1N0030001N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001N05h0241N0030001
N05h0201N003001404@0009400P003Uoo`8002moo`00Agoo00@0000b03800080<P040000<P0b0003
03801@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h0GP0;05h00<0005h0GP0;05h00<0005h
0GP08@5h00<0005h0GP0805h1@001Woo00<007ooOol0>7oo0P00;goo000gOol00`00Oomoo`0=Ool0
10000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1
N00/0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`13Ool2000_Ool0
03Moo`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00<0005h0GP05@5h00<0005h
0GP05@5h00<0005h0GP0;05h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<007oo
Ool0@goo0P00;goo000gOol00`00Oomoo`0=Ool010000380<P000P0b00@0000b038000<0<P030001
N05h00h1N0030001N05h00@1N0030001N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001
N05h0241N0030001N05h0201N003001oogoo049oo`<002moo`00=goo00<007ooOol03Goo00@0000b
03800080<P040000<P0b000303800`000GP1N00E0GP00`000GP1N00E0GP00`000GP1N00/0GP00`00
0GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`14Ool00`00Oomoo`0]Ool003Mo
o`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00D0005h0GP1N00001<1N0030001
N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003001o
ogoo00Qoo`03001oogoo03Uoo`03001oogoo02eoo`00Agoo00@0000b03800080<P040000<P0b0003
03801@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h0GP0;05h00<0005h0GP0;05h00<0005h
0GP08@5h00<0005h0GP0805h00<007ooOol027oo00<007ooOol0>Goo00<007ooOol0;Goo0017Ool0
10000380<P000P0b00@0000b038000<0<P040001N05h000D0GP00`000GP1N00E0GP00`000GP1N00/
0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`08Ool00`00Oomoo`0i
Ool00`00Oomoo`0]Ool004Moo`040000<P0b0002038010000380<P000`0b00@0005h0GP001@1N003
0001N05h01D1N0030001N05h02`1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003
001oogoo00Uoo`03001oogoo03Qoo`03001oogoo02eoo`00Agoo00@0000b03800080<P040000<P0b
0003038010000GP1N000505h00<0005h0GP05@5h00<0005h0GP0;05h00<0005h0GP0;05h00<0005h
0GP08@5h00<0005h0GP0805h00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol0;Goo000fOol0
0`00Oomoo`0>Ool010000380<P000P0b00@0000b038000<0<P030001N05h01D1N0030001N05h01D1
N0030001N05h02`1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003001oogoo04Ao
o`03001oogoo02eoo`00=Woo00<007ooOol03Woo00@0000b03800080<P040000<P0b0002038=000<
0GP00`000GP1N00E0GP00`000GP1N00/0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P
0GP00`00Oomoo`14Ool00`00Oomoo`0]Ool003Ioo`03001oogoo00ioo`040000<P0b000203800`00
0380<P04000<0GPH000<0GP00`000GP1N00/0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1
N00P0GP00`00Oomoo`14Ool00`00Oomoo`0]Ool003Ioo`03001oogoo00ioo`040000<P0b00020380
1000038000000P0b00<0005h0GP05@5h00<0005h0GP02P5h5P009@5h00<0005h0GP0;05h00<0005h
0GP08@5h00<0005h0GP0805h00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol0;Goo000fOol0
0`00Oomoo`0>Ool010000380<P000P0b0`000`0b00D0005h0GP1N00001<1N0030001N05h01D1N003
0001N05h00P1N1d000P1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003001oogoo
00Uoo`03001oogoo03Qoo`03001oogoo02eoo`00Agoo00D0000b0380000b008000030380000b0080
<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1N00U0GPU000B0GP00`000GP1N00Q0GP0
0`000GP1N00P0GP00`00Oomoo`09Ool00`00Oomoo`0fOol3000_Ool004Moo`030000<P0b00<00080
<P050000<P0b038000030GP00`000GP1N00A0GP01@000GP1N05h00004`5h00<0005h0GP0;@5h00<0
005h0GP06P5h7P00605h00<0005h0GP0805h00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol0
;Goo0017Ool01P000380000003800080<P050000<P0b038000030GP00`000GP1N00A0GP00`000GP1
N00E0GP00`000GP1N00]0GP00`000GP1N00/0GP00`000GP1N0090GPI000R0GP00`00Oomoo`09Ool0
0`00Oomoo`0hOol00`00Oomoo`0]Ool003Ioo`03001oogoo00ioo`<00080<P040000<P0b00030380
1@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h0GP0;@5h00<0005h0GP0;05h00<0005h0GP0
8@5h60002`5h00<007ooOol0A7oo00<007ooOol0;Goo000fOol00`00Oomoo`0=Ool010000380<P00
0P0b00@0000b038000<0<P030001N05h01D1N0030001N05h01D1N0030001N05h02d1N0030001N05h
02`1N0030001N05h0241N0030001N05h01D1N0`004Ioo`03001oogoo02eoo`00=Woo00<007ooOol0
3Goo00@0000b03800080<P040000<P0b000303800`000GP1N00E0GP00`000GP1N00E0GP00`000GP1
N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`14Ool00`00Oomo
o`0]Ool003Ioo`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00<0005h0GP05@5h
00<0005h0GP05@5h00<0005h0GP0;@5h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h
00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol0;Goo000fOol00`00Oomoo`0=Ool010000380
<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1N00]0GP0
0`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`09Ool00`00Oomoo`0hOol0
0`00Oomoo`0]Ool004Ioo`040000<P0b0002038010000380<P000`0b00D0005h0GP1N00001<1N003
0001N05h01D1N0030001N05h02d1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003
001oogoo00Uoo`03001oogoo03Qoo`03001oogoo02eoo`00AWoo00@0000b03800080<P040000<P0b
000303801@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h0GP0;@5h00<0005h0GP0;05h00<0
005h0GP08@5h00<0005h0GP0805h00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol0;Goo0016
Ool010000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP00`000GP1N00E0GP00`00
0GP1N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`09Ool00`00
Oomoo`0hOol00`00Oomoo`0]Ool003Ioo`03001oogoo00eoo`040000<P0b0002038010000380<P00
0`0b00D0005h0GP1N00001<1N0030001N05h01D1N0030001N05h02d1N0030001N05h02`1N0030001
N05h0241N0030001N05h0201N003001oogoo04Aoo`03001oogoo02eoo`00=Woo00<007ooOol03Goo
00@0000b03800080<P040000<P0b000303800`000GP1N00E0GP00`000GP1N00E0GP00`000GP1N00]
0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`12Ool3000_Ool003Io
o`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00<0005h0GP05@5h00<0005h0GP0
5@5h00<0005h0GP0;@5h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<007ooOol0
A7oo00<007ooOol0;Goo000fOol00`00Oomoo`0=Ool010000380<P000P0b00@0000b038000<0<P03
0001N05h01D1N0030001N05h01D1N0030001N05h02d1N0030001N05h02`1N0030001N05h0241N003
0001N05h0201N003001oogoo00Uoo`03001oogoo03Qoo`03001oogoo02eoo`00=Woo00<007ooOol0
3Goo00@0000b03800080<P040000<P0b000303801@000GP1N05h00004`5h00<0005h0GP05@5h00<0
005h0GP0;@5h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<007ooOol02Goo00<0
07ooOol0>7oo00<007ooOol0;Goo0016Ool010000380<P000P0b00@0000b038000<0<P050001N05h
0GP0000C0GP00`000GP1N00E0GP00`000GP1N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`00
0GP1N00P0GP00`00Oomoo`09Ool00`00Oomoo`0hOol2000^Ool004Ioo`040000<P0b000203801000
0380<P000`0b00D0005h0GP1N00001<1N0030001N05h01D1N0030001N05h02d1N0030001N05h02`1
N0030001N05h0241N0030001N05h0201N003001oogoo00Uoo`03001oogoo03Qoo`8002ioo`00AWoo
00@0000b03800080<P040000<P0b000303801@000GP1N05h00004`5h00<0005h0GP05@5h00<0005h
0GP0;@5h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<007ooOol02Goo00<007oo
Ool0>7oo0P00;Woo000fOol00`00Oomoo`0=Ool010000380<P000P0b00@0000b038000<0<P050001
N05h0GP0000C0GP00`000GP1N00E0GP00`000GP1N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP0
0`000GP1N00P0GP00`00Oomoo`09Ool00`00Oomoo`0hOol2000^Ool003Ioo`03001oogoo00eoo`04
0000<P0b0002038010000380<P000`0b00<0005h0GP05@5h00<0005h0GP05@5h00<0005h0GP0;@5h
00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<007ooOol0A7oo0P00;Woo000fOol0
0`00Oomoo`0=Ool010000380<P000P0b00@0000b038000<0<P030001N05h01D1N0030001N05h01D1
N0030001N05h02d1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003001oogoo04Eo
o`03001oogoo02aoo`00=Woo00<007ooOol03Goo00@0000b03800080<P040000<P0b000303800`00
0GP1N00E0GP00`000GP1N00E0GP00`000GP1N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`00
0GP1N00P0GP00`00Oomoo`15Ool00`00Oomoo`04Ool30003Ool30003Ool3000IOol003Ioo`03001o
ogoo00eoo`040000<P0b0002038010000380<P000`0b00D0005h0GP1N00001<1N0030001N05h01D1
N0030001N05h02d1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003001oogoo00Uo
o`03001oogoo03Uoo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomo
o`0FOol003Ioo`03001oogoo00eoo`040000<P0b0002038010000380<P000`0b00D0005h0GP1N000
01<1N0030001N05h0181N0040001N05h000_0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1
N00P0GP00`00Oomoo`09Ool00`00Oomoo`0fOol40007Ool01@00Oomoogoo00000goo00<007oo0000
0goo00<007ooOol05Woo0016Ool010000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C
0GP00`000GP1N00E0GP00`000GP1N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P
0GP00`00Oomoo`09Ool00`00Oomoo`0hOol20007Ool01@00Oomoogoo00000goo00<007oo00000goo
00<007ooOol05Woo0016Ool010000380<P000P0b00@0000b038000<0<P050001N05h0GP0000C0GP0
0`000GP1N00E0GP00`000GP1N00]0GP00`000GP1N00/0GP00`000GP1N00Q0GP00`000GP1N00P0GP0
0`00Oomoo`09Ool00`00Oomoo`0hOol20007Ool01@00Oomoogoo00000goo00<007oo00000goo00<0
07ooOol05Woo0016Ool010000380<P000P0b00@0000b03800080<Pd000`1N0030001N05h01D1N003
0001N05h02d1N0030001N05h02`1N0030001N05h0241N0030001N05h0201N003001oogoo00Uoo`03
001oogoo03Qoo`8000Moo`05001oogooOol00003Ool00`00Ool00003Ool00`00Oomoo`0FOol003Io
o`03001oogoo00eoo`040000<P0b000203800`000380<P0300050Ml010000Ml1g`7O7000305h00<0
005h0GP0;@5h00<0005h0GP0;05h00<0005h0GP08@5h00<0005h0GP0805h00<007ooOol0A7oo0P00
1goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oogoo01Ioo`00=Woo00<007ooOol03Goo
00@0000b03800080<P030000<P0001/000T1gb000201N0030001N05h02`1N0030001N05h0241N003
0001N05h0201N003001oogoo04Eoo`03001oogoo00Aoo`8000=oo`07001oogooOol007oo00000goo
00<007ooOol05Woo000fOol00`00Oomoo`0=Ool010000380<P000P0b30003P7O:P000`7O8@00;P5h
00<0005h0GP08@5h00<0005h0GP0805h00<007ooOol0AGoo00<007ooOol01Goo00<007ooOol00Woo
0`000goo0`006Goo000fOol00`00Oomoo`0=Ool00`000380<P0300030Ml00`000Ml1g`060MlH000>
0Ml2000@0MlO00000`7O0000000Q000?0GP00`000GP1N00Q0GP00`000GP1N00P0GP00`00Oomoo`09
Ool00`00Oomoo`0iOol00`00Oomoo`0/Ool003Ioo`03001oogoo00eoo`030000<P0001P000030Ml0
000000`1g`h002l1gb4000<1gb<00181N0030001N05h0201N003001oogoo00Uoo`03001oogoo03Uo
o`03001oogoo02aoo`00AWoo30003P7O:000107O8@008@7O8@0000<1g`0000009P004@5h00<007oo
Ool02Goo00<007ooOol0>7oo0P00;Woo001BOolH000=0Ml2000?0MlO0000107O0000007O7`004@7O
0`004@7O9`000P7O50002Goo00<007ooOol0>7oo0P00;Woo0018Ool00`00Oomoo`0OOolK000P0MlQ
00040MlQ000B0Ml5000A0MlE0004Ool30003Ool50004Ool50003Ool50003Ool2000SOol2000^Ool0
03Ioo`03001oogoo00eoo`8003eoob000241gb4000@1gb<001<1g`@002Qoo`<000=oo`H000=oo`D0
00=oo`D000Aoo`03001oo`00008002ioo`00=Woo00<007ooOol02goo0P00GGoo7P004@7O0`004P7O
8P001@7O4`00Agoo00@007ooOomoo`H002ioo`00=Woo00<007ooOol0R7oo8@004P7O10004@7O5@00
AGoo00<007ooOol00Woo00@007ooOomoo`@0031oo`00=Woo00<007ooOol027oo00<007ooOol0WWoo
8`004`7O0`006Woo00<007ooOol0:goo00@007ooOomoo`D003Aoo`00=Woo00<007ooOol01Woo0P00
a7oo4`007Goo00<007ooOol09goo00@007ooOomoo`D003Qoo`00?Goo0P00mWoo00<007ooOol08Woo
00<007ooOol00Woo1@00?7oo003oOolfOol00`00Oomoo`0IOol00`00Oomoo`02Ool01P00Oomoogoo
001oo`@0041oo`00>7oo0P00ngoo00<007ooOol06Goo00<007ooOol00Woo1P00A7oo000fOol2003o
OolFOol01@00Oomoogoo00000Woo1000B7oo000hOol30003Ool50003Ool50003Ool60003Ool2003`
Ool01P00Oomoogoo001oo`D004aoo`00FGoo0`000goo1@000goo1@0017oo1@000goo1@00b7oo00D0
07ooOomoo`00009oo`@0051oo`00P7oo1@000goo1P000goo1@000goo1@00Wgoo00D007ooOomoo`00
00=oo`03001oo`0000@005Aoo`00XGoo1P000goo1@000goo1@000goo1@0017oo0P00L7oo00<007oo
Ool01Goo00D007ooOomoo`00009oo`@005Qoo`00aGoo0`000goo1@000goo1@000goo1P000goo0P00
Cgoo00D007ooOomoo`0000=oo`03001oo`0000@001ioo`<000Aoo`<003Aoo`00iWoo0`000goo1@00
0goo1@0017oo1@000goo1@00:goo00D007ooOomoo`00009oo`@002Eoo`04001oogoo0003Ool00`00
Oomoo`0aOol00?moo`ioo`D000Aoo`D000=oo`D000=oo`D000Yoo`03001oo`0000@002Yoo`03001o
o`0000=oo`03001oogoo035oo`00ogoo;goo1P0000Aoo`00000002ioo`03001oo`0000=oo`03001o
ogoo035oo`00ogooIgoo00<007oo00000goo00<007ooOol0<Goo003oOomVOol01000Oomoo`000goo
00<007ooOol0<Goo003oOomAOol3000@Ool20003Ool01@00Oomoogoo0000<goo003oOom@Ool01@00
Oomoogoo00003goo00<007ooOol00Woo00D007ooOomoo`0003=oo`00ogooD7oo00D007ooOomoo`00
011oo`<0009oo`<003Aoo`00ogooD7oo00D007ooOomoo`0004aoo`00ogooD7oo00D007ooOomoo`00
04aoo`00ogoo?7oo0`0017oo0`002Woo00D007ooOomoo`0004aoo`00ogoo?goo00@007ooOol000=o
o`03001oogoo00Moo`05001oogooOol0001<Ool00?mood1oo`03001oo`0000=oo`03001oogoo00Mo
o`05001oogooOol0001<Ool00?moocAoo`L000Eoo`03001oo`0000=oo`03001oogoo00Qoo`<004eo
o`00ogoo@7oo00<007oo00000goo00<007ooOol0F7oo003oOoloOol01000Oomoo`000goo00<007oo
Ool0F7oo003oOolmOol20003Ool01@00Oomoogoo0000FWoo003oOolmOol00`00Oomoo`02Ool01@00
Oomoogoo0000FWoo003oOolnOol30002Ool3001KOol00?mooj5oo`00ogooXGoo003oOonQOol00?mo
oj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo
003oOonQOol00?moodeoo`<0009oo`<004aoo`00ogooCWoo00<007ooOol00Woo00<007ooOol0Bgoo
003oOom?Ool01000Oomoo`00CWoo003oOom@Ool2001?Ool00?mooe5oo`03001oogoo04eoo`00ogoo
D7oo0P00Cgoo003oOom?Ool01000Oomoo`00CWoo003oOom>Ool00`00Oomoo`02Ool00`00Oomoo`1;
Ool00?moodeoo`<0009oo`<004aoo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQ
Ool00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00
ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQ
Ool00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00ogooXGoo003oOonQOol00?mooj5oo`00
ogooXGoo003oOonQOol00001\
\>"],
  ImageRangeCache->{{{0, 415}, {415, 0}} -> {-5.00005*^-06, -5.00005*^-06, 
  0.00240966, 0.00240966}}],

Cell[BoxData[
    \(" Segmenting iron corners into parallellepiped should be avoided. \
Instead, one should use a circular or ellipsoidal segmentation"\)], "Print"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{503, 629},
WindowMargins->{{65, Automatic}, {Automatic, 58}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\

Modify the definitions below to change the default appearance of all cells in \

a given style.  Make modifications to any definition using commands in the 
Format menu.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\

The options defined for the style below will be used at the Notebook level.
\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageHeaderLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    Background->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{22, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\

The cells in this section define styles used for input and output to the 
kernel.  Be careful when modifying, renaming, or removing these styles, 
because the front end associates special meanings with these style names.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{62, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {4, 4}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{44, 0}, {6, 6}},
    Background->GrayLevel[0.8]]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{62, Inherited}, {12, 5}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{40, Inherited}, {4, 1}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{44, 0}, {6, 2}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->16,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->20],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->12],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    ShowCellBracket->False,
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{17, Inherited}, {2, 12}},
    FontSize->10],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->{{0, 0}, {0.5, 0}},
    CellDingbat->None,
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{62, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{74, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{52, 10}, {2, 2}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{54, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\

The following styles are useful for numbered equations, figures, etc.  They 
automatically give the cell a FrameLabel containing a reference to a 
particular counter, and also increment that counter.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->6],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\

The cells below define styles useful for making hypertext ButtonBoxes.  The 
\"Hyperlink\" style is for links within the same Notebook, or between 
Notebooks.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\

The following styles are for linking automatically to the on-line help 
system.
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[1, 0.4, 0],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000c82>?odoo<3?P960dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 136, 3, 40, "Title",
  Evaluatable->False],
Cell[1848, 54, 102, 3, 26, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1975, 61, 79, 2, 53, "Section",
  Evaluatable->False],
Cell[2057, 65, 4544, 62, 850, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6638, 132, 92, 2, 33, "Section",
  Evaluatable->False],
Cell[6733, 136, 283, 6, 48, "Text"],
Cell[7019, 144, 85, 4, 68, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7141, 153, 85, 2, 33, "Section",
  Evaluatable->False],
Cell[7229, 157, 97, 2, 29, "Text"],
Cell[7329, 161, 2020, 79, 1490, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9386, 245, 97, 2, 33, "Section",
  Evaluatable->False],
Cell[9486, 249, 2550, 38, 504, "Text"],

Cell[CellGroupData[{
Cell[12061, 291, 1229, 48, 878, "Input"],
Cell[13293, 341, 634, 14, 70, "Print"],
Cell[13930, 357, 275, 6, 70, "Print"],
Cell[14208, 365, 562, 12, 70, "Print"],
Cell[14773, 379, 578, 14, 70, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15400, 399, 94, 2, 33, "Section",
  Evaluatable->False],
Cell[15497, 403, 186, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[15708, 412, 338, 6, 190, "Input"],
Cell[16049, 420, 93085, 5604, 296, 68493, 5296, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[109183, 6030, 89, 2, 33, "Section",
  Evaluatable->False],
Cell[109275, 6034, 538, 15, 76, "Text"],
Cell[109816, 6051, 91, 1, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[109944, 6057, 144, 6, 33, "Section",
  Evaluatable->False],
Cell[110091, 6065, 192, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[110308, 6074, 450, 11, 150, "Input"],
Cell[110761, 6087, 198563, 8425, 382, 144967, 7759, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[309373, 14518, 88, 2, 33, "Section",
  Evaluatable->False],
Cell[309464, 14522, 1731, 27, 333, "Text"],

Cell[CellGroupData[{
Cell[311220, 14553, 351, 7, 170, "Input"],
Cell[311574, 14562, 57444, 1522, 263, 19758, 1052, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369055, 16089, 461, 11, 110, "Input"],
Cell[369519, 16102, 97872, 2172, 325, 38034, 1429, "GraphicsData", 
"PostScript", "Graphics"],
Cell[467394, 18276, 137, 3, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[467568, 18284, 227, 5, 110, "Input"],
Cell[467798, 18291, 47064, 1373, 255, 18527, 1016, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[514911, 19670, 82, 2, 33, "Section",
  Evaluatable->False],
Cell[514996, 19674, 541, 10, 105, "Text"],

Cell[CellGroupData[{
Cell[515562, 19688, 266, 4, 150, "Input"],
Cell[515831, 19694, 724, 18, 25, "Print"],
Cell[516558, 19714, 307, 7, 25, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[516914, 19727, 149, 4, 51, "Section",
  Evaluatable->False],
Cell[517066, 19733, 380, 8, 86, "Text"],

Cell[CellGroupData[{
Cell[517471, 19745, 1388, 55, 1022, "Input"],
Cell[518862, 19802, 620, 14, 25, "Print"],
Cell[519485, 19818, 271, 6, 25, "Print"],
Cell[519759, 19826, 561, 13, 25, "Print"],
Cell[520323, 19841, 165023, 6883, 424, 107810, 6172, "GraphicsData", 
"PostScript", "Graphics"],
Cell[685349, 26726, 164, 2, 63, "Print"]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

